(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    797604,      22810]*)
(*NotebookOutlinePosition[    798332,      22835]*)
(*  CellTagsIndexPosition[    798288,      22831]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\( (*\ 
        This\ file\ creates\ the\ curve\ for\ the\ matter\ initial\ \
conditions\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ This\ part\ solves\ the\ ODE\ system\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(Off[General::"\<spell1\>", 
      NIntegrate::"\<slwcon\>"]; $TextStyle = {FontFamily \[Rule] \
"\<Times\>", FontSize \[Rule] 20}; 
    SetDirectory["\<D:\mathfiles\>"];\)], "Input"],

Cell[BoxData[{
    \(h[z_] := \@\(om\ \((1 + z)\)^3 + 1 - om\)\), "\n", 
    \(\(tt = 
        2 - \((1 + z)\) \(h'\)[z]/h[z] /. z \[Rule] \((Exp[\(-n\)] - 1)\) // 
          Simplify;\)\), "\[IndentingNewLine]", 
    \(\(eqns = {\(-1\) - x3[N] - 3  x2[N] + x1[N]^2 - x1[N]\ x3[N] + 
              x4[N] \[Equal] \(x1'\)[N], 
          4\ x3[N] - 2\ x3[N]\^2 - \(x3'\)[N] - 
              x2[N] \((2  x3[N] - 4 - x1[N])\) \[Equal] \(x2'\)[
              N], \(-2\) x3[N] x4[N] + x1[N] x4[N] \[Equal] \(x4'\)[
              N]};\)\), "\n", 
    \(x3[N_] := \(\(tt /. n \[Rule] N\) /. om \[Rule] om0\) /. 
        or \[Rule] or0\), "\n", 
    \(\(\(R[z_] := 
      6 \((2  h[z]^2 - \((1 + z)\) h[z] \(h'\)[z])\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(nmin = \(-6\);\)\), "\n", 
    \(\(nmax = 6;\)\), "\[IndentingNewLine]", 
    \(\(om0 = 0.30;\)\), "\n", 
    \(\(or0 = 10^\((\(-4\))\);\)\), "\n", 
    \(\(x3min = x3[nmin];\)\), "\n", 
    \(\(x1min = 0;\)\), "\n", 
    \(\(x2min = \(-1\)/2;\)\), "\[IndentingNewLine]", 
    \(\(\(x4min = 0;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(nsol = \(NDSolve[\((Flatten[{eqns, x1[nmin] \[Equal] x1min, 
                  x2[nmin] \[Equal] x2min, x4[nmin] \[Equal] x4min}])\), {x1[
                N], x2[N], x4[N]}, {N, nmin, nmax}, 
            MaxStepFraction \[Rule] 1/10]\)[\([1]\)];\)\)}], "Input"],

Cell[BoxData[{
    \(xx1[N_] := x1[N] /. nsol // Evaluate\), "\n", 
    \(xx2[N_] := x2[N] /. nsol // Evaluate\), "\[IndentingNewLine]", 
    \(xx4[N_] := x4[N] /. nsol // Evaluate\), "\[IndentingNewLine]", 
    \(x1z[z_] := xx1[N] /. N \[Rule] \(-Log[1 + z]\)\), "\n", 
    \(x2z[z_] := xx2[N] /. N \[Rule] \(-Log[1 + z]\)\), "\n", 
    \(x3z[z_] := x3[N] /. N \[Rule] \(-Log[1 + z]\)\), "\n", 
    \(x4z[z_] := 
      x4[N] /. N \[Rule] \(-Log[1 + z]\)\), "\[IndentingNewLine]", 
    \(\(zmax = \((\(-1\) + \[ExponentialE]\^\(-N\) /. 
            N \[Rule] nmin)\);\)\)}], "Input"],

Cell[BoxData[
    \(\(flnm = "\<figs_mat\>";\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 1\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(\(weff[N_] := \(-\((1/3)\)\) \((2  x3[N] - 1)\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig1weff = 
        Plot[weff[N], {N, nmin, nmax}, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(w\_eff\)(N)\>\""}, 
          PlotRange \[Rule] All, Axes \[Rule] False, 
          PlotStyle \[Rule] Hue[0.7]];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig1_weff\>" <> "\<.m\>", fig1weff];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.603319 0.588604 [
[.02381 -0.0125 -14 -24.5625 ]
[.02381 -0.0125 14 0 ]
[.18254 -0.0125 -14 -24.5625 ]
[.18254 -0.0125 14 0 ]
[.34127 -0.0125 -14 -24.5625 ]
[.34127 -0.0125 14 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.65873 -0.0125 -7.03125 -24.5625 ]
[.65873 -0.0125 7.03125 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -28 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .13244 -43.0625 -12.2813 ]
[-0.0125 .13244 0 12.2813 ]
[-0.0125 .25016 -43.0625 -12.2813 ]
[-0.0125 .25016 0 12.2813 ]
[-0.0125 .36788 -43.0625 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .4856 -43.0625 -12.2813 ]
[-0.0125 .4856 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -31.9063 ]
[-0.01875 .30902 -43.0625 31.9063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -148.25 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
92.9063 16.2813 translate
90 rotate
-92.9063 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
77.500 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(eff) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.250 23.000 moveto
(H) show
101.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.375 23.000 moveto
(L) show
122.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06349 .61428 m
.06349 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30159 .61428 m
.30159 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.46032 .61428 m
.46032 .61803 L
s
.53968 .61428 m
.53968 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.69841 .61428 m
.69841 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.93651 .61428 m
.93651 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.2 0 1 r
.5 Mabswid
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07295 .60332 L
.08265 .60332 L
.08804 .60332 L
.09308 .60332 L
.09858 .60332 L
.10458 .60332 L
.10996 .60332 L
.11496 .60332 L
.12013 .60332 L
.12483 .60332 L
.13379 .60332 L
.14335 .60332 L
.14823 .60332 L
.15338 .60332 L
.1626 .60331 L
.16773 .60331 L
.17252 .60331 L
.17774 .60331 L
.18342 .60331 L
.18885 .60331 L
.19387 .60331 L
.19858 .6033 L
.20377 .6033 L
.21277 .60329 L
.2177 .60329 L
.22233 .60328 L
.23216 .60326 L
.2371 .60325 L
.24251 .60324 L
.2521 .6032 L
.26101 .60316 L
.26606 .60312 L
.27154 .60308 L
.27636 .60303 L
.28147 .60296 L
.29114 .60281 L
.30006 .6026 L
.3095 .6023 L
.31479 .60207 L
.31963 .60182 L
.32903 .60118 L
Mistroke
.33795 .60033 L
.34756 .59903 L
.35293 .59808 L
.35779 .59703 L
.36727 .59436 L
.37619 .59084 L
.38598 .58543 L
.39091 .5819 L
.39631 .57726 L
.40588 .56662 L
.41479 .55316 L
.42527 .53175 L
.43519 .50466 L
.45376 .43327 L
.49214 .23005 L
.51195 .14087 L
.52195 .10742 L
.53297 .0793 L
.54309 .06036 L
.55236 .04763 L
.56253 .03753 L
.56764 .03365 L
.57323 .03014 L
.57853 .0274 L
.58353 .02525 L
.59288 .02216 L
.59812 .02083 L
.60294 .01982 L
.6082 .01891 L
.61384 .01811 L
.61892 .01752 L
.62356 .01707 L
.63264 .01639 L
.63772 .0161 L
.64324 .01584 L
.64843 .01564 L
.6533 .01548 L
.66268 .01525 L
.66767 .01516 L
.67305 .01508 L
.67838 .01501 L
.684 .01496 L
.68926 .01491 L
.69405 .01488 L
.70357 .01483 L
.70881 .01481 L
.71376 .01479 L
.72257 .01477 L
.7275 .01476 L
.73212 .01475 L
Mistroke
.74157 .01474 L
.74658 .01474 L
.75197 .01473 L
.75761 .01473 L
.76296 .01473 L
.76823 .01473 L
.77301 .01472 L
.7826 .01472 L
.78787 .01472 L
.79283 .01472 L
.80167 .01472 L
.80661 .01472 L
.81122 .01472 L
.82074 .01472 L
.82577 .01472 L
.83117 .01472 L
.83684 .01472 L
.8422 .01472 L
.84697 .01472 L
.85224 .01472 L
.86191 .01472 L
.8672 .01472 L
.87217 .01472 L
.88104 .01472 L
.89059 .01472 L
.89556 .01472 L
.90017 .01472 L
.90566 .01472 L
.91065 .01472 L
.92086 .01472 L
.92646 .01472 L
.93175 .01472 L
.94148 .01472 L
.94639 .01472 L
.95178 .01472 L
.96132 .01472 L
.97024 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{493.25, 304.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007]0001<2000`400?l00000o`00003oo`3oooo^
0?ooo`00o`3oooo^0?ooo`00o`3oooo^0?ooo`00o`3oooo^0?ooo`00o`3oooo^0?ooo`00o`3oooo^
0?ooo`00o`3ooolE0?ooo`060;md00000000000000000000B9`0gooo103oool00`3ookl0M01d0;oo
o`3<0?ooo`00o`3ooolF0?ooo`030?oo_`1d07@0_ooo00D0oooo00@0oooO09a8000007@0_oooc03o
ool00?l0oooo5P3oool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000001d0;oool`0oooo003o
0?oooaH0oooo00<0oooO09a8M02oool0103oool01@3OW4P000000000B018B7@0_ooo0<`0oooo003o
0?oooaH0oooo00<0oooO09a8M02oool00`3oool01P3o_g@000000000M02ooml0W4Qd0;oool`0oooo
003o0?oooaH0oooo00<0oooO09a8M02oool00P3oool01`3ogi`0B0000000B02Lgol0oooO09a8M02o
ool0c03oool00?l0oooo5P3oool0303ooml0W4Qd0;ooo`3oool0oono07@000000000M;oo0?ooo`3o
oml0W4Qd0;oool`0oooo003o0?oooaH0oooo00L0oooO09a8M02oool0oooO09a800000000B9cO0080
oooo00<0oooO09a8M02oool0c03oool00?l0oooo5P3oool01P3ooml0W4Qd0;oog`2LB0000000001d
_`<0oooo00<0oooO09a8M02oool0c03oool00?l0oooo5P3oool01P3ooml0W4Qd07Ad0000000004RL
0=ooo`<0oooo00<0oooO09a8M02oool0c03oool00?l0oooo5P3oool01@3ooml0W4P00000000007@0
_ooo00@0oooo00<0oooO09a8M02oool0c03oool00?l0oooo5P3oool0103OW4P000000000M02oool5
0?ooo`030?oo_`1d07@0_ooo0<`0oooo003o0?oooa@0oooo00D0gia8000000000000001809cOo`04
0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0b@3oool00?l0ooookP3oool00?l0
ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0
ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0
ooookP3oool006@0oooo00H0oooO09a80000000000000000M02ooolk0?ooo`030?noM0000000M;oo
03L0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0_0?ooo`040;md000000000000
04RLgcP0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0h0?ooo`030?noM0000000
M;oo03T0oooo00H0oooO09a80000000000000000M02ooolC0?ooo`00H`3oool0203ookl0M0000018
W03Oool0oooo0=nLB00004P0W=oo>P3oool00`3o_g@0000007Boo`0h0?ooo`030=nLB00000000000
00@0000000<007Bo0?ooo`3oool0;@3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0>03o
ool00`3OW4P000000000000400000003001d_`3oool0oooo03P0oooo00<0okmd0000001d_ol0>03o
ool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo4P3oool006<0oooo00<0_g@00000M02o
ool00`3oool00`2oM00007Bo0?ooo`0i0?ooo`030?noM0000000M;oo03T0oooo00<0gia804RLg`3o
ool00P3oool00`3ooml0W4Qd0;ooo`0^0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol0>03oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo03T0oooo00<0okmd0000001d
_ol0>03oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo0140oooo001R0?ooo`030?oo
_`1d000007Bo00@0oooo00<0gia80000M02oool0=03oool00`3OW4P0000000000005000000030000
B02Lgol0oooo03L0oooo00<0gia804RLg`3oool0<@3oool0103ooml0W4P00018W03Oool20?ooo`03
0?oog`2LB00007Bo03T0oooo00<0gia804RLg`3oool0>03oool00`3OW4P000000000000500000003
0000B02Lgol0oooo03@0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`0A0?ooo`00
HP3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo03@0oooo00<0omnL04Qd_`3oool0
0P3oool00`3o_g@0000007Boo`0k0?ooo`030=nLB01d_ol0oooo0300oooo00<0oono07@00000M;l0
103oool00`2oM000001d0;ooo`0i0?ooo`030=nLB01d_ol0oooo03L0oooo00<0omnL04Qd_`3oool0
0P3oool00`3o_g@0000007Boo`0g0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol0
4@3oool005D0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`<0
oooo00@0oono07@0000007@0_ooo9`3oool00`2oM0000000000000070000000604RLg`3oool0oooo
0?ooo`3OW4P0M;oo0P3oool00`3o_g@0000007Boo`0Z0?ooo`030;md00000000000000L0000000<0
B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`0`0?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000M02oool0>@3oool00`3ooml0W4Q809cOo`0h0?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0
000007Boo`0g0?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_ooo4@3oool00680
oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0=P3oool01`3ookl0M01d0;oo
o`3oool0okmd0000001d_ol0?03oool00`3ogi`0B01d0;ooo`0_0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol0>P3oool00`3ogi`0B01d0;ooo`0g0?ooo`070?oo_`1d07@0_ooo0?oo
o`3o_g@0000007Boo`0g0?ooo`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO0180
oooo001R0?ooo`050?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`0f0?ooo`06
0?noM000M;l0oooo0?noM0000000M;oo?@3oool00`2oM000B9cO0?ooo`0^0?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol0>`3oool00`2oM000B9cO0?ooo`0g0?ooo`060?noM000M;l0
oooo0?noM0000000M;oo=`3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3o
ool04@3oool006<0oooo00<0okmd00000018W=l0?@3oool01@2oM000M;oo0?noM0000000M;oo03d0
oooo00<0gia80000M02oool0;P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo03/0
oooo00<0gia80000M02oool0>03oool01@2oM000M;oo0?noM0000000M;oo03P0oooo00<0okmd0000
0018W=l05`3oool006<0oooo00@0oooO09a8000004P0W=oo?03oool01@3ookl0M01d0;noM0000000
M;oo03d0oooo00<0okmd0000001d_ol0;`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo03`0oooo00<0okmd0000001d_ol0>03oool01@3ookl0M01d0;noM0000000M;oo03P0oooo00@0
oooO09a8000004P0W=oo5P3oool006@0oooo00@0oono07@0000007@0_ooo?03oool0103o_g@00000
0000001d_olg0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0;`3oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo03H0oooo00<0omnL09boo`3oool00`3oool00`2oM000
000007Boo`0i0?ooo`040?noM0000000000007BoocT0oooo00@0oono07@0000007@0_ooo5@3oool0
06D0oooo00@0oooO09a80000000007Bo>`3oool0103ooml0W4P00000001d_olh0?ooo`080;md001d
_ol0oooo0?ooo`3OW4P000000018W03Oool`0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo>03o
ool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo>@3oool0103ooml0W4P00000001d_olj
0?ooo`040?oog`2LB0000000001d_a@0oooo001W0?ooo`050?oOW018000000000018W03Oool0>@3o
ool00`3ogi`0B00007Boo`0i0?ooo`050;md00000000000000000000M;l0<`3oool0102oM0000000
00000000M;lj0?ooo`050;md00000000000000000000M;l0?03oool00`3ogi`0B00007Boo`0l0?oo
o`050?oOW018000000000018W03Oool04@3oool00?l0ooookP3oool00?l0ooookP3oool00?l0oooo
kP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0ooookP3oool00?l0oooo
kP3oool00?l0ooookP3oool00?l0ooookP3oool004L0oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`070?ooool00000S000000<0?ooo`00B@3oool00`2oM000001d0;ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`00
B@3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0:0?ooo`00B@3oool00`2oM000001d0;ooo`0:0?ooo`030000003o
ool0oooo0?l0ooooR03oool00`000000oooo0?ooo`0:0?ooo`00B@3oool00`2oM000001d0;ooo`0:
0?ooo`030000003oool0oooo0?l0ooooR03oool00`000000oooo0?ooo`0:0?ooo`00>03oool00`2o
M0000000000000070000000304RLg`3oool0oooo00@0oooo00<0_g@00000M02oool02P3oool40000
0?l0oooo5P3ooomY03<0o`D0oooo1000000<0?ooo`00B@3oool00`2oM000001d0;ooo`0:0?ooo`03
0000003oool0oooo0?<0oooo8`0c0?ma0?ooo`030000003oool0oooo00X0oooo00190?ooo`030;md
000007@0_ooo00X0oooo00<000000?ooo`3oool0j`3oool803<0oi@0oooo00<000000?ooo`3oool0
2P3oool004T0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3W0?ooo`@0<`3oW03o
ool00`000000oooo0?ooo`0:0?ooo`00B@3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0
oooo0>D0oooo0P0c0?nP0?ooo`030000003oool0oooo00X0oooo00190?ooo`030;md000007@0_ooo
00X0oooo00<000000?ooo`3oool0h@3oool403<0oj80oooo00<000000?ooo`3oool02P3oool004L0
oooo00D0gia8000000000000001d0;ooo`0:0?ooo`030000003oool0oooo0>00oooo00<0<`3o0?oo
o`3oool0Y03oool00`000000oooo0?ooo`0:0?ooo`00B03oool0103ookl0M0000000M02oool:0?oo
o`030000003oool0oooo0=l0oooo00<0<`3o0?ooo`3oool0Y@3oool00`000000oooo0?ooo`0:0?oo
o`00EP3oool00`000000oooo0?ooo`3M0?ooo`80<`3oZ03oool00`000000oooo0?ooo`0:0?ooo`00
EP3oool00`000000oooo0?ooo`3K0?ooo`80<`3oZP3oool00`000000oooo0?ooo`0:0?ooo`00EP3o
ool00`000000oooo0?ooo`3J0?ooo`0303<0o`3oool0oooo0:X0oooo00<000000?ooo`3oool02P3o
ool005H0oooo00<000000?ooo`3oool0f@3oool00`0c0?l0oooo0?ooo`2[0?ooo`030000003oool0
oooo00X0oooo001F0?ooo`<00000f03oool00`0c0?l0oooo0?ooo`2Z0?ooo`<00000303oool005H0
oooo00<000000?ooo`3oool0e`3oool00`0c0?l0oooo0?ooo`2]0?ooo`030000003oool0oooo00X0
oooo001F0?ooo`030000003oool0oooo0=H0oooo00<0<`3o0?ooo`3oool0[P3oool00`000000oooo
0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`3E0?ooo`0303<0o`3oool0oooo0:l0oooo00<0
00000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0e@3oool00`0c0?l0oooo0?ooo`2_
0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0=@0oooo00<0<`3o0?oo
o`3oool0/03oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`3C0?ooo`03
03<0o`3oool0oooo0;40oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0
dP3oool00`0c0?l0oooo0?ooo`2b0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003o
ool0oooo0=80oooo00<0<`3o0?ooo`3oool0/P3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool0
0`000000oooo0?ooo`3A0?ooo`0303<0o`3oool0oooo0;<0oooo00<000000?ooo`3oool02P3oool0
05H0oooo00<000000?ooo`3oool0d@3oool00`0c0?l0oooo0?ooo`2c0?ooo`030000003oool0oooo
00X0oooo001F0?ooo`030000003oool0oooo0=00oooo00<0<`3o0?ooo`3oool0]03oool00`000000
oooo0?ooo`0:0?ooo`00EP3oool300000=00oooo00<0<`3o0?ooo`3oool0/P3oool3000000`0oooo
001F0?ooo`030000003oool0oooo0<l0oooo00<0<`3o0?ooo`3oool0]@3oool00`000000oooo0?oo
o`0:0?ooo`00EP3oool00`000000oooo0?ooo`3?0?ooo`0303<0o`3oool0oooo0;D0oooo00<00000
0?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0c`3oool00`0c0?l0oooo0?ooo`2e0?oo
o`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0<h0oooo00<0<`3o0?ooo`3o
ool0]P3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`3>0?ooo`0303<0
o`3oool0oooo0;H0oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0cP3o
ool00`0c0?l0oooo0?ooo`2f0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0
oooo0<d0oooo00<0<`3o0?ooo`3oool0]`3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`00
0000oooo0?ooo`3=0?ooo`0303<0o`3oool0oooo0;L0oooo00<000000?ooo`3oool02P3oool005H0
oooo00<000000?ooo`3oool0c03oool00`0c0?l0oooo0?ooo`2h0?ooo`030000003oool0oooo00X0
oooo001F0?ooo`030000003oool0oooo0<`0oooo00<0<`3o0?ooo`3oool0^03oool00`000000oooo
0?ooo`0:0?ooo`00EP3oool300000<`0oooo00<0<`3o0?ooo`3oool0]P3oool3000000`0oooo001F
0?ooo`030000003oool0oooo0</0oooo00<0<`3o0?ooo`3oool0^@3oool00`000000oooo0?ooo`0:
0?ooo`00EP3oool00`000000oooo0?ooo`3;0?ooo`0303<0o`3oool0oooo0;T0oooo00<000000?oo
o`3oool02P3oool005H0oooo00<000000?ooo`3oool0b`3oool00`0c0?l0oooo0?ooo`2i0?ooo`03
0000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0<X0oooo00<0<`3o0?ooo`3oool0
^P3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`3:0?ooo`0303<0o`3o
ool0oooo0;X0oooo00<000000?ooo`3oool02P3oool003T0oooo00@0_g@0000000000000B9cO103o
ool00`3OW4P0000004RLg`030?ooo`060?oOW018000000000000000004P0W=oo2@3oool00`000000
oooo0?ooo`3:0?ooo`0303<0o`3oool0oooo0;X0oooo00<000000?ooo`3oool02P3oool003L0oooo
00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool0203o
gi`0B0000018W03Oool0oooo0?oOW0180000M;oo203oool00`000000oooo0?ooo`390?ooo`0303<0
o`3oool0oooo0;/0oooo00<000000?ooo`3oool02P3oool003L0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03Oool01`3o
ool00`000000oooo0?ooo`390?ooo`0303<0o`3oool0oooo0;/0oooo00<000000?ooo`3oool02P3o
ool003H0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`070?ooo`030;md0000
07@0_ooo00<0oooo00<0_g@00018W03Oool01`3oool00`000000oooo0?ooo`390?ooo`0303<0o`3o
ool0oooo0;/0oooo00<000000?ooo`3oool02P3oool003H0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`060?ooo`030?noM00004P0W=oo0080oooo00<0gia800000000M;l0203oool0
0`000000oooo0?ooo`390?ooo`0303<0o`3oool0oooo0;/0oooo00<000000?ooo`3oool02P3oool0
02T0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0
_g@00000M02oool01`3oool01`3OW4P007Bo0?ooo`2oM00000000000M02oool0203oool00`000000
oooo0?ooo`380?ooo`0303<0o`3oool0oooo0;`0oooo00<000000?ooo`3oool02P3oool003H0oooo
00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`080?ooo`050?noM000000000000018W03O
ool02@3oool400000<L0oooo00<0<`3o0?ooo`3oool0^@3oool4000000`0oooo000f0?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol01`3oool01@3ogi`0B000000000000000B9cO00X0
oooo00<000000?ooo`3oool0b03oool00`0c0?l0oooo0?ooo`2l0?ooo`030000003oool0oooo00X0
oooo000f0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool01`3ogi`0B000
0000B02Lgol0oooo0=nLB000M;l02@3oool00`000000oooo0?ooo`370?ooo`0303<0o`3oool0oooo
0;d0oooo00<000000?ooo`3oool02P3oool003L0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`070?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8001d_ol0203oool00`000000
oooo0?ooo`370?ooo`0303<0o`3oool0oooo0;d0oooo00<000000?ooo`3oool02P3oool003L0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030=nLB000B9`0gooo0080oooo
00<0oooO09a80018W=l0203oool00`000000oooo0?ooo`370?ooo`0303<0o`3oool0oooo0;d0oooo
00<000000?ooo`3oool02P3oool003P0oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`03
0?oOW0180000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`370?ooo`03
03<0o`3oool0oooo0;d0oooo00<000000?ooo`3oool02P3oool003T0oooo00@0_g@0000000000000
07Bo2P3oool01P3ookl0M000000000000000001809cOo`T0oooo00<000000?ooo`3oool0aP3oool0
0`0c0?l0oooo0?ooo`2n0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo
0<H0oooo00<0<`3o0?ooo`3oool0_P3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000
oooo0?ooo`360?ooo`0303<0o`3oool0oooo0;h0oooo00<000000?ooo`3oool02P3oool005H0oooo
00<000000?ooo`3oool0aP3oool00`0c0?l0oooo0?ooo`2n0?ooo`030000003oool0oooo00X0oooo
001F0?ooo`030000003oool0oooo0<D0oooo00<0<`3o0?ooo`3oool0_`3oool00`000000oooo0?oo
o`0:0?ooo`00EP3oool300000<D0oooo00<0<`3o0?ooo`3oool0_@3oool3000000`0oooo001F0?oo
o`030000003oool0oooo0<D0oooo00<0<`3o0?ooo`3oool0_`3oool00`000000oooo0?ooo`0:0?oo
o`00EP3oool00`000000oooo0?ooo`350?ooo`0303<0o`3oool0oooo0;l0oooo00<000000?ooo`3o
ool02P3oool005H0oooo00<000000?ooo`3oool0a03oool00`0c0?l0oooo0?ooo`300?ooo`030000
003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0<@0oooo00<0<`3o0?ooo`3oool0`03o
ool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`340?ooo`0303<0o`3oool0
oooo0<00oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0a03oool00`0c
0?l0oooo0?ooo`300?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0<@0
oooo00<0<`3o0?ooo`3oool0`03oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo
0?ooo`330?ooo`0303<0o`3oool0oooo0<40oooo00<000000?ooo`3oool02P3oool005H0oooo00<0
00000?ooo`3oool0``3oool00`0c0?l0oooo0?ooo`310?ooo`030000003oool0oooo00X0oooo001F
0?ooo`030000003oool0oooo0<<0oooo00<0<`3o0?ooo`3oool0`@3oool00`000000oooo0?ooo`0:
0?ooo`00EP3oool00`000000oooo0?ooo`330?ooo`0303<0o`3oool0oooo0<40oooo00<000000?oo
o`3oool02P3oool005H0oooo0`0000320?ooo`0303<0o`3oool0oooo0<00oooo0`00000<0?ooo`00
EP3oool00`000000oooo0?ooo`320?ooo`0303<0o`3oool0oooo0<80oooo00<000000?ooo`3oool0
2P3oool005H0oooo00<000000?ooo`3oool0`P3oool00`0c0?l0oooo0?ooo`320?ooo`030000003o
ool0oooo00X0oooo001F0?ooo`030000003oool0oooo0<80oooo00<0<`3o0?ooo`3oool0`P3oool0
0`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`320?ooo`0303<0o`3oool0oooo
0<80oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0`@3oool00`0c0?l0
oooo0?ooo`330?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0<40oooo
00<0<`3o0?ooo`3oool0``3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?oo
o`310?ooo`0303<0o`3oool0oooo0<<0oooo00<000000?ooo`3oool02P3oool005H0oooo00<00000
0?ooo`3oool0`@3oool00`0c0?l0oooo0?ooo`330?ooo`030000003oool0oooo00X0oooo001F0?oo
o`030000003oool0oooo0<00oooo00<0<`3o0?ooo`3oool0a03oool00`000000oooo0?ooo`0:0?oo
o`00EP3oool00`000000oooo0?ooo`300?ooo`0303<0o`3oool0oooo0<@0oooo00<000000?ooo`3o
ool02P3oool005H0oooo00<000000?ooo`3oool0`03oool00`0c0?l0oooo0?ooo`340?ooo`030000
003oool0oooo00X0oooo001F0?ooo`<00000`03oool00`0c0?l0oooo0?ooo`320?ooo`<00000303o
ool005H0oooo00<000000?ooo`3oool0_`3oool00`0c0?l0oooo0?ooo`350?ooo`030000003oool0
oooo00X0oooo001F0?ooo`030000003oool0oooo0;l0oooo00<0<`3o0?ooo`3oool0a@3oool00`00
0000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2o0?ooo`0303<0o`3oool0oooo0<D0
oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0_`3oool00`0c0?l0oooo
0?ooo`350?ooo`030000003oool0oooo00X0oooo000D0?ooo`030?noM018W=l0oooo0280oooo00@0
_g@0000000000000B9cO103oool00`3OW4P0000004RLg`030?ooo`060?oog`2LB000000000000000
07@0_ooo2@3oool00`000000oooo0?ooo`2o0?ooo`0303<0o`3oool0oooo0<D0oooo00<000000?oo
o`3oool02P3oool001@0oooo00D0okmd00000000000004RL0=ooo`0N0?ooo`070?oog`2LB00007Bo
0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0oono07@00000B9`0gooo
0?ooo`3OW4P0001809cOo`P0oooo00<000000?ooo`3oool0_P3oool00`0c0?l0oooo0?ooo`360?oo
o`030000003oool0oooo00X0oooo000D0?ooo`030?noM0000000000000<0000000<004RL0=ooo`3o
ool06P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0_g@00000M02o
ool00`3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo0;h0oooo00<0<`3o0?ooo`3o
ool0aP3oool00`000000oooo0?ooo`0:0?ooo`00603oool00`3ogi`0B00000000002000000030018
W03Oool0oooo01H0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`03
0?oo_`1d000007Bo00@0oooo00<0gia80000M02oool01`3oool00`000000oooo0?ooo`2n0?ooo`03
03<0o`3oool0oooo0<H0oooo00<000000?ooo`3oool02P3oool001/0oooo00@0omnL04P0000007@0
_ooo5`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018
W=l0103oool00`2oM000001809cOo`070?ooo`030000003oool0oooo0;h0oooo00<0<`3o0?ooo`3o
ool0aP3oool00`000000oooo0?ooo`0:0?ooo`006@3oool0103ooml0W4P00000B02Lgol<0?ooo`03
0;md00000000000000L0000000H0B9cO0?ooo`3oool0omnL04P00018W=l40?ooo`030;md000007@0
_ooo00D0oooo00<0omnL04P00018W=l00`3oool0103ookl0M0000000M02oool70?ooo`030000003o
ool0oooo0;h0oooo00<0<`3o0?ooo`3oool0aP3oool00`000000oooo0?ooo`0:0?ooo`00503oool0
1`3o_g@0M;oo0?ooo`3ooml0W4P00000B02Lgol06`3oool00`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo00D0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0203oool4
00000;`0oooo00<0<`3o0?ooo`3oool0a03oool4000000`0oooo000D0?ooo`050?noM00000000000
0000B02Lgol07@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00D0oooO
09a8000007@0_mnL04P000020000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0_@3o
ool00`0c0?l0oooo0?ooo`370?ooo`030000003oool0oooo00X0oooo000D0?ooo`030?noM0000000
000000<0000000<004RL0=ooo`3oool06@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0
_ooo00H0oooo00<0okmd00000018W=l03@3oool00`000000oooo0?ooo`2m0?ooo`0303<0o`3oool0
oooo0<L0oooo00<000000?ooo`3oool02P3oool001P0oooo00<0_g@00000000000000P0000000`00
07@0_ooo0?ooo`0G0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3oool0103o
oml0W4P00000B02Lgol<0?ooo`030000003oool0oooo0;d0oooo00<0<`3o0?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool0103OW4P000000000M02ooolH0?ooo`030?noM00004P0
W=oo0080oooo00<0omnL04P0001d_ol0203oool0103ookl0M0000000M02oool;0?ooo`030000003o
ool0oooo0;d0oooo00<0<`3o0?ooo`3oool0a`3oool00`000000oooo0?ooo`0:0?ooo`00603oool0
103ookl0M00000000018W=lL0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2P3oool0103ooml0
W4P000000000M;l:0?ooo`030000003oool0oooo0;d0oooo00<0<`3o0?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0:0?ooo`00503oool01P3o_g@0M;oo0=nLB0000000001d0;oooal0oooo00@0_g@0
00000000000007Bo3@3oool01@3ogi`0B00000000000B9`0gooo00L0oooo00<000000?ooo`3oool0
_03oool00`0c0?l0oooo0?ooo`380?ooo`030000003oool0oooo00X0oooo000D0?ooo`030?noM000
0000B9cO03l0oooo00<000000?ooo`3oool0_03oool00`0c0?l0oooo0?ooo`380?ooo`030000003o
ool0oooo00X0oooo000D0?ooo`030?noM01d_ol0oooo03l0oooo00<000000?ooo`3oool0_03oool0
0`0c0?l0oooo0?ooo`380?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo
0;`0oooo00<0<`3o0?ooo`3oool0b03oool00`000000oooo0?ooo`0:0?ooo`006`3oool01P2oM000
000000000000000004RL0=ooocD0oooo00<000000?ooo`3oool0_03oool00`0c0?l0oooo0?ooo`38
0?ooo`030000003oool0oooo00X0oooo000J0?ooo`070?noM01d_ol0gibL0;ooo`3ookl0M000001d
_`0e0?ooo`030000003oool0oooo0;/0oooo00<0<`3o0?ooo`3oool0b@3oool00`000000oooo0?oo
o`0:0?ooo`006P3oool0202oW9`0gooo0=nLW02oool0oooo0?oOW01807@0_ooo=03oool300000;/0
oooo00<0<`3o0?ooo`3oool0a`3oool3000000`0oooo000J0?ooo`080=nLM02Lgol0gibL0;ooo`3o
ool0okmd0018W03Ooold0?ooo`030000003oool0oooo0;/0oooo00<0<`3o0?ooo`3oool0b@3oool0
0`000000oooo0?ooo`0:0?ooo`006P3oool01`3ooml0W4P00000M02oool0gia80000B02Lgol0=@3o
ool00`000000oooo0?ooo`2k0?ooo`0303<0o`3oool0oooo0<T0oooo00<000000?ooo`3oool02P3o
ool005H0oooo00<000000?ooo`3oool0^`3oool00`0c0?l0oooo0?ooo`390?ooo`030000003oool0
oooo00X0oooo000J0?ooo`030;nLW03Oool0oooo00<0oooo00<0gibL0;ooo`3oool0<`3oool00`00
0000oooo0?ooo`2j0?ooo`0303<0o`3oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool001L0
oooo00<0okmd0000000000001P0000000`0007@0_ooo0?ooo`0c0?ooo`030000003oool0oooo0;X0
oooo00<0<`3o0?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`005P3oool01P3ooml0W9bo
0?ooo`3oool0_ibL0=ooo`@0oooo00<0gibL0;ooo`3oool0<`3oool00`000000oooo0?ooo`2j0?oo
o`0303<0o`3oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool001H0oooo00H0oono07A8W03O
ool0oooo0;nLW03Ooolj0?ooo`030000003oool0oooo0;X0oooo00<0<`3o0?ooo`3oool0bP3oool0
0`000000oooo0?ooo`0:0?ooo`005`3oool00`2oM00007Bo0?ooo`0l0?ooo`030000003oool0oooo
0;X0oooo00<0<`3o0?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`006P3oool00`2oW9`0
gooo0?ooo`030?ooo`030=nLW02oool0oooo03<0oooo00<000000?ooo`3oool0^P3oool00`0c0?l0
oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo000G0?ooo`030?noM0000000000000H00000
00<0001d0;ooo`3oool0<`3oool00`000000oooo0?ooo`2i0?ooo`0303<0o`3oool0oooo0</0oooo
00<000000?ooo`3oool02P3oool001H0oooo00H0oooO09bL_`3oool0oooo0;nLW03Oool40?ooo`03
0=nLW02oool0oooo03<0oooo0`00002i0?ooo`0303<0o`3oool0oooo0<T0oooo0`00000<0?ooo`00
5P3oool01P3ookl0M4RL0=ooo`3oool0_ibL0=ooocX0oooo00<000000?ooo`3oool0^@3oool00`0c
0?l0oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo000G0?ooo`030;md0000M;l0oooo03`0
oooo00<000000?ooo`3oool0^@3oool00`0c0?l0oooo0?ooo`3;0?ooo`030000003oool0oooo00X0
oooo001F0?ooo`030000003oool0oooo0;T0oooo00<0<`3o0?ooo`3oool0b`3oool00`000000oooo
0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2h0?ooo`0303<0o`3oool0oooo0<`0oooo00<0
00000?ooo`3oool02P3oool001D0oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0g
0?ooo`030000003oool0oooo0;P0oooo00<0<`3o0?ooo`3oool0c03oool00`000000oooo0?ooo`0:
0?ooo`004`3oool00`3OW4P0000000000008000000030000B02Lgol0oooo03D0oooo00<000000?oo
o`3oool0^03oool00`0c0?l0oooo0?ooo`3<0?ooo`030000003oool0oooo00X0oooo000B0?ooo`04
0;md00000000000007Boo`L0oooo00@0_g@0000000000000B9cO=@3oool00`000000oooo0?ooo`2h
0?ooo`0303<0o`3oool0oooo0<`0oooo00<000000?ooo`3oool02P3oool00140oooo00<0_g@0001d
_`3oool02`3oool00`3ooml0W4P004RLg`0d0?ooo`030000003oool0oooo0;P0oooo00<0<`3o0?oo
o`3oool0c03oool00`000000oooo0?ooo`0:0?ooo`00403oool00`3oSdP0B:So0?ooo`0>0?ooo`03
0=nLM02Lgol0oooo0380oooo00<000000?ooo`3oool0]`3oool00`0c0?l0oooo0?ooo`3=0?ooo`03
0000003oool0oooo00X0oooo000@0?ooo`030?noM01d_ol0oooo00X0oooo00<0gibL0;ooo`3oool0
=P3oool00`000000oooo0?ooo`2g0?ooo`0303<0o`3oool0oooo0<d0oooo00<000000?ooo`3oool0
2P3oool00100oooo00<0okmd0018W03Oool02P3oool00`2oM7@0_ooo0?ooo`0f0?ooo`030000003o
ool0oooo0;L0oooo00<0<`3o0?ooo`3oool0c@3oool00`000000oooo0?ooo`0:0?ooo`00403oool0
0`3o_g@000000000000:000000030000M02oool0oooo03H0oooo0`00002g0?ooo`0303<0o`3oool0
oooo0</0oooo0`00000<0?ooo`004@3oool0102oM00000000000B02Lgol80?ooo`030;mdM02oool0
oooo03H0oooo00<000000?ooo`3oool0]`3oool00`0c0?l0oooo0?ooo`3=0?ooo`030000003oool0
oooo00X0oooo000B0?ooo`040=nLB0000000000007Boo`L0oooo00<0gibL0;ooo`3oool0=P3oool0
0`000000oooo0?ooo`2g0?ooo`0303<0o`3oool0oooo0<d0oooo00<000000?ooo`3oool02P3oool0
01<0oooo00@0okmd00000000000007Bo?`3oool00`000000oooo0?ooo`2f0?ooo`0303<0o`3oool0
oooo0<h0oooo00<000000?ooo`3oool02P3oool001@0oooo00D0omnL04P00000000004RL0=ooo`0m
0?ooo`030000003oool0oooo0;H0oooo00<0<`3o0?ooo`3oool0cP3oool00`000000oooo0?ooo`0:
0?ooo`005@3oool01@3ookl0M0000000000004P0W=oo03`0oooo00<000000?ooo`3oool0]P3oool0
0`0c0?l0oooo0?ooo`3>0?ooo`030000003oool0oooo00X0oooo000F0?ooo`050?oog`2LB0000000
0000001d_ol07P3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00H0oooo00<0
okmd0000001d_ol02@3oool00`000000oooo0?ooo`2f0?ooo`0303<0o`3oool0oooo0<h0oooo00<0
00000?ooo`3oool02P3oool00100oooo00<0oknL09cOo`3oool01@3oool0102oM000000000000000
M;lK0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO00H0
oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`2f0?ooo`0303<0o`3oool0oooo0<h0
oooo00<000000?ooo`3oool02P3oool00100oooo00<0okmd07Boo`3oool01P3oool01@3OW4P00000
00000000B9`0gooo01T0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0;0?ooo`03
0?noM0000000M;oo00T0oooo00<000000?ooo`3oool0]@3oool00`0c0?l0oooo0?ooo`3?0?ooo`03
0000003oool0oooo00X0oooo000@0?ooo`030?noM0000000000000X0000000<0001809cOo`3oool0
5P3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0gia800000000
00001@0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0oooo0;D0oooo00<0<`3o0?ooo`3o
ool0c`3oool00`000000oooo0?ooo`0:0?ooo`00403oool00`3o_g@0M;oo0?ooo`0S0?ooo`030?oo
_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?no
M0000000M;oo00T0oooo00<000000?ooo`3oool0]@3oool00`0c0?l0oooo0?ooo`3?0?ooo`030000
003oool0oooo00X0oooo000@0?ooo`030?noW02Lgol0oooo01H0oooo00<0_g@00000000000001`00
00001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool01P3oool01`3OW4P0
M;oo0?ooo`3oool0okmd0000001d_ol02@3oool00`000000oooo0?ooo`2e0?ooo`0303<0o`3oool0
oooo0<l0oooo00<000000?ooo`3oool02P3oool003H0oooo00<0omnL04P00018W=l0103oool00`3O
W4P0001809cOo`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`090?ooo`@00000]03o
ool00`0c0?l0oooo0?ooo`3<0?ooo`@00000303oool00100oooo00<0okmd07Boo`3oool03P3oool0
0`2oM4P0W=oo0?ooo`0B0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3oool0
1P3o_g@007Bo0?ooo`3o_g@0000007Boo`T0oooo00<000000?ooo`3oool0]03oool00`0c0?l0oooo
0?ooo`3@0?ooo`030000003oool0oooo00X0oooo000A0?ooo`030;md0000M;l0oooo00/0oooo00<0
oooO09a8001d_ol0503oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00D0
_g@007Boo`3o_g@0000007Boo`090?ooo`030000003oool0oooo0;@0oooo00<0<`3o0?ooo`3oool0
d03oool00`000000oooo0?ooo`0:0?ooo`004P3oool0102oM00000000000001d_ol70?ooo`040;md
00000000000004RLgaH0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`090?ooo`05
0?oo_`1d07@0_kmd0000001d_ol02@3oool00`000000oooo0?ooo`2d0?ooo`0303<0o`3oool0oooo
0=00oooo00<000000?ooo`3oool02P3oool001<0oooo00<0gia8000000000000200000000`0004P0
W=oo0?ooo`0F0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol02P3oool0103o_g@0
00000000001d_ol90?ooo`030000003oool0oooo0;@0oooo00<0<`3o0?ooo`3oool0d03oool00`00
0000oooo0?ooo`0:0?ooo`005@3oool00`3o_g@0000000000004000000030000M02oool0oooo01T0
oooo00H0_g@00018W03Oool0oooo0;md0000M;l;0?ooo`040?oog`2LB000000007Boo`T0oooo00<0
00000?ooo`3oool0]03oool00`0c0?l0oooo0?ooo`3@0?ooo`030000003oool0oooo00X0oooo000i
0?ooo`040;md000000000000001d_`d0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?oo
o`2d0?ooo`0303<0o`3oool0oooo0=00oooo00<000000?ooo`3oool02P3oool005H0oooo00<00000
0?ooo`3oool0/`3oool00`0c0?l0oooo0?ooo`3A0?ooo`030000003oool0oooo00X0oooo001F0?oo
o`030000003oool0oooo0;<0oooo00<0<`3o0?ooo`3oool0d@3oool00`000000oooo0?ooo`0:0?oo
o`00EP3oool00`000000oooo0?ooo`2c0?ooo`0303<0o`3oool0oooo0=40oooo00<000000?ooo`3o
ool02P3oool005H0oooo00<000000?ooo`3oool0/`3oool00`0c0?l0oooo0?ooo`3A0?ooo`030000
003oool0oooo00X0oooo001F0?ooo`<00000/`3oool00`0c0?l0oooo0?ooo`3?0?ooo`<00000303o
ool005H0oooo00<000000?ooo`3oool0/P3oool00`0c0?l0oooo0?ooo`3B0?ooo`030000003oool0
oooo00X0oooo001F0?ooo`030000003oool0oooo0;80oooo00<0<`3o0?ooo`3oool0dP3oool00`00
0000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2b0?ooo`0303<0o`3oool0oooo0=80
oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0/P3oool00`0c0?l0oooo
0?ooo`3B0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0;80oooo00<0
<`3o0?ooo`3oool0dP3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2a
0?ooo`0303<0o`3oool0oooo0=<0oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?oo
o`3oool0/@3oool00`0c0?l0oooo0?ooo`3C0?ooo`030000003oool0oooo00X0oooo001F0?ooo`03
0000003oool0oooo0;40oooo00<0<`3o0?ooo`3oool0d`3oool00`000000oooo0?ooo`0:0?ooo`00
EP3oool00`000000oooo0?ooo`2a0?ooo`0303<0o`3oool0oooo0=<0oooo00<000000?ooo`3oool0
2P3oool005H0oooo00<000000?ooo`3oool0/@3oool00`0c0?l0oooo0?ooo`3C0?ooo`030000003o
ool0oooo00X0oooo001F0?ooo`030000003oool0oooo0;40oooo00<0<`3o0?ooo`3oool0d`3oool0
0`000000oooo0?ooo`0:0?ooo`00EP3oool300000;00oooo00<0<`3o0?ooo`3oool0dP3oool30000
00`0oooo001F0?ooo`030000003oool0oooo0;00oooo00<0<`3o0?ooo`3oool0e03oool00`000000
oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2`0?ooo`0303<0o`3oool0oooo0=@0oooo
00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0/03oool00`0c0?l0oooo0?oo
o`3D0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0:l0oooo00<0<`3o
0?ooo`3oool0e@3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2_0?oo
o`0303<0o`3oool0oooo0=D0oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3o
ool0[`3oool00`0c0?l0oooo0?ooo`3E0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000
003oool0oooo0:l0oooo00<0<`3o0?ooo`3oool0e@3oool00`000000oooo0?ooo`0:0?ooo`00EP3o
ool00`000000oooo0?ooo`2^0?ooo`0303<0o`3oool0oooo0=H0oooo00<000000?ooo`3oool02P3o
ool005H0oooo00<000000?ooo`3oool0[P3oool00`0c0?l0oooo0?ooo`3F0?ooo`030000003oool0
oooo00X0oooo001F0?ooo`030000003oool0oooo0:h0oooo00<0<`3o0?ooo`3oool0eP3oool00`00
0000oooo0?ooo`0:0?ooo`00EP3oool300000:h0oooo00<0<`3o0?ooo`3oool0e03oool3000000`0
oooo001F0?ooo`030000003oool0oooo0:d0oooo00<0<`3o0?ooo`3oool0e`3oool00`000000oooo
0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2]0?ooo`0303<0o`3oool0oooo0=L0oooo00<0
00000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0[@3oool00`0c0?l0oooo0?ooo`3G
0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0:d0oooo00<0<`3o0?oo
o`3oool0e`3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2/0?ooo`03
03<0o`3oool0oooo0=P0oooo00<000000?ooo`3oool02P3oool003T0oooo00@0_g@0000000000000
B9cO103oool01@3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?ooo`3oool01P3oool00`00
0000oooo0?ooo`2/0?ooo`0303<0o`3oool0oooo0=P0oooo00<000000?ooo`3oool02P3oool003L0
oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool0
0`3OW4P000000000000400000003001d_`3oool0oooo00H0oooo00<000000?ooo`3oool0[03oool0
0`0c0?l0oooo0?ooo`3H0?ooo`030000003oool0oooo00X0oooo000g0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol0203oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo
00L0oooo00<000000?ooo`3oool0[03oool00`0c0?l0oooo0?ooo`3H0?ooo`030000003oool0oooo
00X0oooo000f0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02@3oool00`3O
W4P0B9cO0?ooo`0;0?ooo`030000003oool0oooo0:/0oooo00<0<`3o0?ooo`3oool0f@3oool00`00
0000oooo0?ooo`0:0?ooo`00=P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00T0
oooo00<0gia807Boo`3oool02P3oool00`000000oooo0?ooo`2[0?ooo`0303<0o`3oool0oooo0=T0
oooo00<000000?ooo`3oool02P3oool002T0oooo00<0_g@00000000000001`0000001P18W=l0oooo
0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool02@3oool00`3ooml0W4Q809cOo`0:0?oo
o`030000003oool0oooo0:/0oooo00<0<`3o0?ooo`3oool0f@3oool00`000000oooo0?ooo`0:0?oo
o`00=P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00X0oooo00<0omnL04P0M02o
ool02@3oool400000:X0oooo00<0<`3o0?ooo`3oool0eP3oool4000000`0oooo000f0?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol02`3oool00`2oM000B9cO0?ooo`080?ooo`030000
003oool0oooo0:X0oooo00<0<`3o0?ooo`3oool0fP3oool00`000000oooo0?ooo`0:0?ooo`00=P3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0gia80000M02oool0203o
ool00`000000oooo0?ooo`2Z0?ooo`0303<0o`3oool0oooo0=X0oooo00<000000?ooo`3oool02P3o
ool003L0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0<0?ooo`030?noM0000000
M;oo00P0oooo00<000000?ooo`3oool0ZP3oool00`0c0?l0oooo0?ooo`3J0?ooo`030000003oool0
oooo00X0oooo000g0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01P3oool00`3o
gi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00P0oooo00<000000?ooo`3oool0ZP3oool00`0c
0?l0oooo0?ooo`3J0?ooo`030000003oool0oooo00X0oooo000h0?ooo`060;md0000B9`0gooo0?oo
o`2oM00007Bo203oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo203oool00`000000
oooo0?ooo`2Y0?ooo`0303<0o`3oool0oooo0=/0oooo00<000000?ooo`3oool02P3oool003T0oooo
00@0_g@000000000000007Bo2P3oool01@2oM000000000000000000007Bo00X0oooo00<000000?oo
o`3oool0Z@3oool00`0c0?l0oooo0?ooo`3K0?ooo`030000003oool0oooo00X0oooo001F0?ooo`03
0000003oool0oooo0:T0oooo00<0<`3o0?ooo`3oool0f`3oool00`000000oooo0?ooo`0:0?ooo`00
EP3oool00`000000oooo0?ooo`2Y0?ooo`0303<0o`3oool0oooo0=/0oooo00<000000?ooo`3oool0
2P3oool005H0oooo00<000000?ooo`3oool0Z03oool00`0c0?l0oooo0?ooo`3L0?ooo`030000003o
ool0oooo00X0oooo001F0?ooo`030000003oool0oooo0:P0oooo00<0<`3o0?ooo`3oool0g03oool0
0`000000oooo0?ooo`0:0?ooo`00EP3oool300000:P0oooo00<0<`3o0?ooo`3oool0fP3oool30000
00`0oooo001F0?ooo`030000003oool0oooo0:L0oooo00<0<`3o0?ooo`3oool0g@3oool00`000000
oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2W0?ooo`0303<0o`3oool0oooo0=d0oooo
00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0YP3oool00`0c0?l0oooo0?oo
o`3N0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0:H0oooo00<0<`3o
0?ooo`3oool0gP3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2V0?oo
o`0303<0o`3oool0oooo0=h0oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3o
ool0Y@3oool00`0c0?l0oooo0?ooo`3O0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000
003oool0oooo0:D0oooo00<0<`3o0?ooo`3oool0g`3oool00`000000oooo0?ooo`0:0?ooo`00EP3o
ool00`000000oooo0?ooo`2T0?ooo`0303<0o`3oool0oooo0>00oooo00<000000?ooo`3oool02P3o
ool005H0oooo00<000000?ooo`3oool0Y03oool00`0c0?l0oooo0?ooo`3P0?ooo`030000003oool0
oooo00X0oooo001F0?ooo`030000003oool0oooo0:<0oooo00<0<`3o0?ooo`3oool0h@3oool00`00
0000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2S0?ooo`0303<0o`3oool0oooo0>40
oooo00<000000?ooo`3oool02P3oool005H0oooo0`00002R0?ooo`0303<0o`3oool0oooo0>00oooo
0`00000<0?ooo`00EP3oool00`000000oooo0?ooo`2R0?ooo`0303<0o`3oool0oooo0>80oooo00<0
00000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0X@3oool00`0c0?l0oooo0?ooo`3S
0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo0:40oooo00<0<`3o0?oo
o`3oool0h`3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2P0?ooo`03
03<0o`3oool0oooo0>@0oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0
X03oool00`0c0?l0oooo0?ooo`3T0?ooo`030000003oool0oooo00X0oooo001F0?ooo`030000003o
ool0oooo09l0oooo00<0<`3o0?ooo`3oool0i@3oool00`000000oooo0?ooo`0:0?ooo`00EP3oool0
0`000000oooo0?ooo`2N0?ooo`0303<0o`3oool0oooo0>H0oooo00<000000?ooo`3oool02P3oool0
05H0oooo00<000000?ooo`3oool0WP3oool00`0c0?l0oooo0?ooo`3V0?ooo`030000003oool0oooo
00X0oooo001F0?ooo`030000003oool0oooo09d0oooo00<0<`3o0?ooo`3oool0i`3oool00`000000
oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2L0?ooo`0303<0o`3oool0oooo0>P0oooo
00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0V`3oool00`0c0?l0oooo0?oo
o`3Y0?ooo`030000003oool0oooo00X0oooo001F0?ooo`<00000VP3oool00`0c0?l0oooo0?ooo`3X
0?ooo`<00000303oool005H0oooo00<000000?ooo`3oool0V@3oool00`0c0?l0oooo0?ooo`3[0?oo
o`030000003oool0oooo00X0oooo001F0?ooo`030000003oool0oooo09P0oooo00<0<`3o0?ooo`3o
ool0k03oool00`000000oooo0?ooo`0:0?ooo`00EP3oool00`000000oooo0?ooo`2G0?ooo`0303<0
o`3oool0oooo0>d0oooo00<000000?ooo`3oool02P3oool005H0oooo00<000000?ooo`3oool0U@3o
ool203<0oo00oooo00<000000?ooo`3oool02P3oool004P0oooo00@0_g@0000000000000B9cO2P3o
ool00`000000oooo0?ooo`2C0?ooo`80<`3olP3oool00`000000oooo0?ooo`0:0?ooo`00AP3oool0
1`3ooml0W4P0001d_`3oool0oooO09a80000M;l02@3oool00`000000oooo0?ooo`2A0?ooo`80<`3o
m03oool00`000000oooo0?ooo`0:0?ooo`00AP3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo00P0oooo00<000000?ooo`3oool0S`3oool203<0ooH0oooo00<000000?ooo`3oool02P3o
ool004D0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`080?ooo`030000003o
ool0oooo08d0oooo0P0c0?oh0?ooo`030000003oool0oooo00X0oooo00150?ooo`030?oo_`1d0000
07Bo00@0oooo00<0_g@00000M02oool01`3oool00`000000oooo0?ooo`280?ooo`D0<`3onP3oool0
0`000000oooo0?ooo`0:0?ooo`00A@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo
00L0oooo00<000000?ooo`3oool0OP3oool:03<0ool0oooo00<000000?ooo`3oool02P3oool004D0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`@000001P3ooomg03<0ool0
oooo1`3oool4000000`0oooo00150?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
1`3oool00`000000oooo0?ooo`3o0?ooohP0oooo00<000000?ooo`3oool02P3oool004D0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo0?l0ooooR03o
ool00`000000oooo0?ooo`0:0?ooo`00AP3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo00P0oooo00<000000?ooo`3oool0o`3ooon80?ooo`030000003oool0oooo00X0oooo00160?oo
o`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool004L0oooo00H0_g@00018W03O
ool0oooo0;md0000M;l90?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0:0?ooo`00B03oool0102oM000000000000000M;l:0?ooool00000S000000<
0?ooo`00o`3oooo^0?ooo`00o`3oooo^0?ooo`00o`3oooo^0?ooo`00o`3oooo^0?ooo`00o`3oooo^
0?ooo`00o`3oooo^0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 492.25}, {303.875, 0}} -> {-9.0746, -1.25822, \
0.0320017, 0.00431498}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 2\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig2x1 = 
        Plot[xx1[N], {N, nmin, nmax}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[ .7], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_1\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(fig2x2 = 
        Plot[xx2[N], {N, nmin, nmax}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[ .7], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_2\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(fig2x3 = 
        Plot[x3[N], {N, nmin, nmax}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[ .7], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_3\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(fig2x4 = 
        Plot[xx4[N], {N, nmin, nmax}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[ .7], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_4\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{fig2x1, fig2x2}, {fig2x3, fig2x4}}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] \(-0.05\)];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x1\>" <> "\<.m\>", 
        fig2x1];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x2\>" <> "\<.m\>", 
        fig2x2];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x3\>" <> "\<.m\>", 
        fig2x3];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x4\>" <> "\<.m\>", fig2x4];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.51221 0.316563 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 -0.181486 0.392403 [
[.02381 -0.0125 -14 -24.5625 ]
[.02381 -0.0125 14 0 ]
[.18254 -0.0125 -14 -24.5625 ]
[.18254 -0.0125 14 0 ]
[.34127 -0.0125 -14 -24.5625 ]
[.34127 -0.0125 14 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.65873 -0.0125 -7.03125 -24.5625 ]
[.65873 -0.0125 7.03125 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .05396 -29.125 -12.2813 ]
[-0.0125 .05396 0 12.2813 ]
[-0.0125 .13244 -29.125 -12.2813 ]
[-0.0125 .13244 0 12.2813 ]
[-0.0125 .21092 -14.0625 -12.2813 ]
[-0.0125 .21092 0 12.2813 ]
[-0.0125 .2894 -29.125 -12.2813 ]
[-0.0125 .2894 0 12.2813 ]
[-0.0125 .36788 -29.125 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .44636 -29.125 -12.2813 ]
[-0.0125 .44636 0 12.2813 ]
[-0.0125 .52484 -29.125 -12.2813 ]
[-0.0125 .52484 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -24.5938 ]
[-0.01875 .30902 -29.125 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05396 m
.00625 .05396 L
s
gsave
-0.0125 .05396 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .21092 m
.00625 .21092 L
s
gsave
-0.0125 .21092 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2894 m
.00625 .2894 L
s
gsave
-0.0125 .2894 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .44636 m
.00625 .44636 L
s
gsave
-0.0125 .44636 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .52484 m
.00625 .52484 L
s
gsave
-0.0125 .52484 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .11282 m
.00375 .11282 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .30902 m
.00375 .30902 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .3875 m
.00375 .3875 L
s
0 .40712 m
.00375 .40712 L
s
0 .42674 m
.00375 .42674 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .50522 m
.00375 .50522 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
0 .03434 m
.00375 .03434 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06349 .61428 m
.06349 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30159 .61428 m
.30159 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.46032 .61428 m
.46032 .61803 L
s
.53968 .61428 m
.53968 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.69841 .61428 m
.69841 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.93651 .61428 m
.93651 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05396 m
1 .05396 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .2894 m
1 .2894 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .44636 m
1 .44636 L
s
.99375 .52484 m
1 .52484 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .07358 m
1 .07358 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .11282 m
1 .11282 L
s
.99625 .15206 m
1 .15206 L
s
.99625 .17168 m
1 .17168 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .23054 m
1 .23054 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .26978 m
1 .26978 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32864 m
1 .32864 L
s
.99625 .34826 m
1 .34826 L
s
.99625 .3875 m
1 .3875 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .46598 m
1 .46598 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .56408 m
1 .56408 L
s
.99625 .5837 m
1 .5837 L
s
.99625 .03434 m
1 .03434 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.2 0 1 r
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03793 .01472 L
.04262 .01472 L
.0522 .01472 L
.05746 .01472 L
.06244 .01472 L
.06754 .01472 L
.07295 .01472 L
.08265 .01472 L
.08804 .01472 L
.09308 .01472 L
.09858 .01472 L
.10458 .01472 L
.10996 .01472 L
.11496 .01472 L
.12013 .01472 L
.12483 .01472 L
.13379 .01472 L
.14335 .01472 L
.14823 .01472 L
.15338 .01472 L
.1626 .01472 L
.16773 .01472 L
.17252 .01472 L
.17774 .01472 L
.18342 .01472 L
.18885 .01473 L
.19387 .01473 L
.19858 .01473 L
.20377 .01473 L
.21277 .01474 L
.2177 .01475 L
.22233 .01475 L
.23216 .01477 L
.2371 .01478 L
.24251 .0148 L
.2521 .01483 L
.26101 .01488 L
.26606 .01491 L
.27154 .01496 L
.27636 .01501 L
.28147 .01507 L
.29114 .01523 L
.30006 .01543 L
.3095 .01574 L
.31479 .01596 L
.31963 .01621 L
.32903 .01685 L
Mistroke
.33795 .0177 L
.34756 .019 L
.35293 .01996 L
.35779 .021 L
.36727 .02367 L
.37619 .02719 L
.38598 .03261 L
.39091 .03613 L
.39631 .04077 L
.40588 .05141 L
.41479 .06488 L
.42527 .08629 L
.43519 .11337 L
.45376 .18476 L
.49214 .38798 L
.51195 .47716 L
.52195 .51062 L
.53297 .53874 L
.54309 .55767 L
.55236 .57041 L
.56253 .58051 L
.56764 .58439 L
.57323 .58789 L
.57853 .59064 L
.58353 .59278 L
.59288 .59588 L
.59812 .5972 L
.60294 .59821 L
.6082 .59913 L
.61384 .59993 L
.61892 .60052 L
.62356 .60097 L
.63264 .60165 L
.63772 .60194 L
.64324 .6022 L
.64843 .6024 L
.6533 .60255 L
.66268 .60278 L
.66767 .60287 L
.67305 .60296 L
.67838 .60302 L
.684 .60308 L
.68926 .60312 L
.69405 .60315 L
.70357 .6032 L
.70881 .60322 L
.71376 .60324 L
.72257 .60326 L
.7275 .60327 L
.73212 .60328 L
Mistroke
.74157 .60329 L
.74658 .6033 L
.75197 .6033 L
.75761 .6033 L
.76296 .60331 L
.76823 .60331 L
.77301 .60331 L
.7826 .60331 L
.78787 .60331 L
.79283 .60331 L
.80167 .60332 L
.80661 .60332 L
.81122 .60332 L
.82074 .60332 L
.82577 .60332 L
.83117 .60332 L
.83684 .60332 L
.8422 .60332 L
.84697 .60332 L
.85224 .60332 L
.86191 .60332 L
.8672 .60332 L
.87217 .60332 L
.88104 .60332 L
.89059 .60332 L
.89556 .60332 L
.90017 .60332 L
.90566 .60332 L
.91065 .60332 L
.92086 .60332 L
.92646 .60332 L
.93175 .60332 L
.94148 .60332 L
.94639 .60332 L
.95178 .60332 L
.96132 .60332 L
.97024 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.48779 0.0147151 0.97619 0.316563 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.309017 0.294302 [
[.02381 -0.0125 -14 -24.5625 ]
[.02381 -0.0125 14 0 ]
[.18254 -0.0125 -14 -24.5625 ]
[.18254 -0.0125 14 0 ]
[.34127 -0.0125 -14 -24.5625 ]
[.34127 -0.0125 14 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.65873 -0.0125 -7.03125 -24.5625 ]
[.65873 -0.0125 7.03125 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -28 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .16187 -43.0625 -12.2813 ]
[-0.0125 .16187 0 12.2813 ]
[-0.0125 .30902 -14.0625 -12.2813 ]
[-0.0125 .30902 0 12.2813 ]
[-0.0125 .45617 -29.125 -12.2813 ]
[-0.0125 .45617 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -24.5938 ]
[-0.01875 .30902 -43.0625 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .16187 m
.00625 .16187 L
s
gsave
-0.0125 .16187 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .45617 m
.00625 .45617 L
s
gsave
-0.0125 .45617 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -140.938 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06349 .61428 m
.06349 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30159 .61428 m
.30159 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.46032 .61428 m
.46032 .61803 L
s
.53968 .61428 m
.53968 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.69841 .61428 m
.69841 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.93651 .61428 m
.93651 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.2 0 1 r
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.07956 .30902 L
.0802 .30902 L
.08095 .30902 L
.08166 .30902 L
.08291 .30902 L
.08362 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11822 .30902 L
.11892 .30902 L
Mistroke
.11958 .30902 L
.12081 .30902 L
.12194 .30902 L
.12323 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13214 .30902 L
.13327 .30902 L
.13441 .30902 L
.13564 .30902 L
.1368 .30902 L
.13785 .30902 L
.13909 .30902 L
.13979 .30902 L
.14043 .30902 L
.14162 .30902 L
.14288 .30902 L
.14402 .30902 L
.14526 .30902 L
.14656 .30902 L
.14777 .30902 L
.14891 .30902 L
.14994 .30902 L
.15113 .30902 L
.15226 .30902 L
.15348 .30902 L
.15478 .30902 L
.15589 .30902 L
.15711 .30902 L
.15842 .30902 L
.15915 .30902 L
.15982 .30902 L
.16113 .30902 L
.16236 .30902 L
.16352 .30902 L
.16456 .30902 L
.16577 .30902 L
.1669 .30902 L
.16796 .30902 L
.16893 .30902 L
.16999 .30902 L
.17111 .30902 L
.17225 .30902 L
.17347 .30902 L
.17462 .30902 L
Mistroke
.17566 .30902 L
.17689 .30902 L
.17758 .30902 L
.17823 .30902 L
.1794 .30902 L
.18065 .30902 L
.18185 .30902 L
.18316 .30902 L
.18441 .30902 L
.18556 .30902 L
.1867 .30902 L
.18773 .30902 L
.18893 .30902 L
.19005 .30902 L
.19128 .30902 L
.19258 .30902 L
.19369 .30902 L
.19491 .30902 L
.19623 .30902 L
.19696 .30902 L
.19763 .30902 L
.19894 .30902 L
.20017 .30902 L
.20122 .30902 L
.20238 .30902 L
.20359 .30902 L
.20472 .30902 L
.20578 .30902 L
.20675 .30902 L
.20781 .30902 L
.20894 .30902 L
.21008 .30902 L
.21129 .30902 L
.21244 .30902 L
.21349 .30902 L
.21472 .30902 L
.21541 .30902 L
.21605 .30902 L
.21723 .30902 L
.21847 .30902 L
.21968 .30902 L
.221 .30902 L
.22224 .30902 L
.2234 .30902 L
.22454 .30902 L
.22558 .30902 L
.22677 .30902 L
.2279 .30902 L
.22914 .30902 L
.23044 .30902 L
Mistroke
.23155 .30902 L
.23277 .30902 L
.23409 .30902 L
.23482 .30902 L
.2355 .30902 L
.2368 .30902 L
.23804 .30902 L
.23909 .30902 L
.24025 .30902 L
.24146 .30902 L
.2426 .30902 L
.24365 .30902 L
.24462 .30902 L
.24569 .30902 L
.24681 .30902 L
.24795 .30902 L
.24917 .30902 L
.25032 .30902 L
.25137 .30902 L
.2526 .30902 L
.25329 .30902 L
.25393 .30902 L
.2551 .30902 L
.25635 .30902 L
.25756 .30902 L
.25888 .30902 L
.26013 .30902 L
.26129 .30902 L
.26233 .30902 L
.26348 .30902 L
.26467 .30902 L
.2658 .30902 L
.26704 .30902 L
.26835 .30902 L
.26946 .30902 L
.27068 .30902 L
.272 .30902 L
.27274 .30902 L
.27341 .30902 L
.27472 .30902 L
.27595 .30902 L
.27701 .30902 L
.27817 .30902 L
.27938 .30902 L
.28052 .30902 L
.28158 .30902 L
.28255 .30902 L
.28367 .30902 L
.28474 .30902 L
.28588 .30902 L
Mistroke
.2871 .30902 L
.28825 .30902 L
.2893 .30902 L
.29053 .30902 L
.29122 .30902 L
.29186 .30902 L
.29303 .30902 L
.29427 .30902 L
.29549 .30902 L
.29618 .30902 L
.29682 .30902 L
.29799 .30902 L
.29923 .30902 L
.30034 .30902 L
.30138 .30902 L
.30252 .30902 L
.30375 .30902 L
.30499 .30902 L
.30569 .30902 L
.30634 .30902 L
.30765 .30902 L
.30839 .30902 L
.30906 .30902 L
.31026 .30902 L
.31156 .30902 L
.31278 .30902 L
.31392 .30902 L
.31497 .30902 L
.31611 .30902 L
.31718 .30902 L
.31816 .30902 L
.3193 .30902 L
.32055 .30902 L
.32173 .30902 L
.32282 .30902 L
.32406 .30902 L
.32522 .30902 L
.32626 .30902 L
.32739 .30902 L
.32862 .30902 L
.32992 .30902 L
.33103 .30902 L
.33225 .30902 L
.33356 .30902 L
.33477 .30902 L
.33541 .30902 L
.3361 .30902 L
.33683 .30902 L
.33751 .30902 L
.33876 .30902 L
Mistroke
.33991 .30902 L
.34123 .30902 L
.34249 .30902 L
.3436 .30902 L
.3448 .30902 L
.34592 .30902 L
.34694 .30902 L
.34814 .30902 L
.34945 .30902 L
.35067 .30902 L
.35181 .30902 L
.35302 .30902 L
.35431 .30902 L
.35554 .30902 L
.35665 .30902 L
.35796 .30902 L
.3587 .30902 L
.35939 .30902 L
.36064 .30902 L
.36128 .30902 L
.36198 .30902 L
.36266 .30902 L
.36337 .30902 L
.36465 .30902 L
.36536 .30902 L
.36602 .30902 L
.36675 .30902 L
.36753 .30902 L
.3682 .30902 L
.36893 .30902 L
.36962 .30902 L
.37026 .30902 L
.37146 .30902 L
.37274 .30902 L
.37394 .30902 L
.37526 .30902 L
.37651 .30902 L
.37766 .30902 L
.3788 .30902 L
.37984 .30902 L
.38103 .30902 L
.38216 .30902 L
.38339 .30902 L
.3847 .30902 L
.38581 .30902 L
.38703 .30902 L
.38834 .30902 L
.38908 .30902 L
.38975 .30902 L
.39106 .30902 L
Mistroke
.39229 .30902 L
.39334 .30902 L
.3945 .30902 L
.39571 .30902 L
.39685 .30902 L
.39791 .30902 L
.39888 .30902 L
.39994 .30902 L
.40106 .30902 L
.40221 .30902 L
.40342 .30902 L
.40457 .30902 L
.40562 .30902 L
.40685 .30902 L
.40754 .30902 L
.40818 .30902 L
.40936 .30902 L
.4106 .30902 L
.41181 .30902 L
.41313 .30902 L
.41438 .30902 L
.41554 .30902 L
.41669 .30902 L
.41772 .30902 L
.41892 .30902 L
.42005 .30902 L
.42129 .30902 L
.42259 .30902 L
.42371 .30902 L
.42493 .30902 L
.42624 .30902 L
.42698 .30902 L
.42765 .30902 L
.42896 .30902 L
.43019 .30902 L
.43125 .30902 L
.43241 .30902 L
.43362 .30902 L
.43476 .30902 L
.43582 .30902 L
.43679 .30902 L
.43791 .30902 L
.43898 .30902 L
.44012 .30902 L
.44134 .30902 L
.44249 .30902 L
.44354 .30902 L
.44477 .30902 L
.44546 .30902 L
.4461 .30902 L
Mistroke
.44727 .30902 L
.44851 .30902 L
.44973 .30902 L
.45042 .30902 L
.45106 .30902 L
.45223 .30902 L
.45347 .30902 L
.45458 .30902 L
.45562 .30902 L
.45676 .30902 L
.45799 .30902 L
.45922 .30902 L
.45992 .30902 L
.46057 .30902 L
.46188 .30902 L
.46262 .30902 L
.46329 .30902 L
.46449 .30902 L
.46579 .30902 L
.46702 .30902 L
.46815 .30902 L
.4692 .30902 L
.47034 .30902 L
.47141 .30902 L
.47239 .30902 L
.47353 .30902 L
.47478 .30902 L
.47596 .30902 L
.47705 .30902 L
.47829 .30902 L
.47945 .30902 L
.48049 .30902 L
.48162 .30902 L
.48285 .30902 L
.48415 .30902 L
.48526 .30902 L
.48648 .30902 L
.48779 .30902 L
.489 .30902 L
.48963 .30902 L
.49033 .30902 L
.49105 .30902 L
.49174 .30902 L
.49299 .30902 L
.49413 .30902 L
.49539 .30902 L
.49671 .30902 L
.49783 .30902 L
.49902 .30902 L
.50014 .30902 L
Mistroke
.50116 .30902 L
.50236 .30902 L
.50366 .30902 L
.50489 .30902 L
.50603 .30902 L
.50723 .30902 L
.50853 .30902 L
.50975 .30902 L
.51087 .30902 L
.51218 .30902 L
.51292 .30902 L
.51361 .30902 L
.51486 .30902 L
.5155 .30902 L
.5162 .30902 L
.51687 .30902 L
.51759 .30902 L
.51886 .30902 L
.51958 .30902 L
.52024 .30902 L
.52096 .30902 L
.52174 .30902 L
.52241 .30902 L
.52314 .30902 L
.52383 .30902 L
.52447 .30902 L
.52568 .30902 L
.52695 .30902 L
.52816 .30902 L
.52947 .30902 L
.53072 .30902 L
.53187 .30902 L
.53301 .30902 L
.53405 .30902 L
.53525 .30902 L
.53637 .30902 L
.5376 .30902 L
.53891 .30902 L
.54002 .30902 L
.54124 .30902 L
.54255 .30902 L
.54329 .30902 L
.54396 .30902 L
.54526 .30902 L
.5465 .30902 L
.54755 .30902 L
.54871 .30902 L
.54992 .30902 L
.55105 .30902 L
.55211 .30902 L
Mistroke
.55308 .30902 L
.55415 .30902 L
.55527 .30902 L
.55641 .30902 L
.55763 .30902 L
.55878 .30902 L
.55982 .30902 L
.56105 .30902 L
.56175 .30902 L
.56238 .30902 L
.56356 .30902 L
.5648 .30902 L
.56601 .30902 L
.56734 .30902 L
.56858 .30902 L
.56974 .30902 L
.57088 .30902 L
.57192 .30902 L
.57312 .30902 L
.57425 .30902 L
.57548 .30902 L
.57679 .30902 L
.5779 .30902 L
.57912 .30902 L
.58044 .30902 L
.58118 .30902 L
.58185 .30902 L
.58315 .30902 L
.58439 .30902 L
.58544 .30902 L
.5866 .30902 L
.58782 .30902 L
.58895 .30902 L
.59001 .30902 L
.59098 .30902 L
.5921 .30902 L
.59317 .30902 L
.59431 .30902 L
.59553 .30902 L
.59668 .30902 L
.59773 .30902 L
.59896 .30902 L
.59965 .30902 L
.60029 .30902 L
.60146 .30902 L
.60271 .30902 L
.60392 .30902 L
.60461 .30902 L
.60525 .30902 L
.60642 .30902 L
Mistroke
.60766 .30902 L
.60876 .30902 L
.6098 .30902 L
.61094 .30902 L
.61217 .30902 L
.61341 .30902 L
.6141 .30902 L
.61475 .30902 L
.61607 .30902 L
.6168 .30902 L
.61747 .30902 L
.61867 .30902 L
.61997 .30902 L
.6212 .30902 L
.62233 .30902 L
.62339 .30902 L
.62452 .30902 L
.62559 .30902 L
.62657 .30902 L
.62771 .30902 L
.62896 .30902 L
.63014 .30902 L
.63123 .30902 L
.63247 .30902 L
.63363 .30902 L
.63467 .30902 L
.6358 .30902 L
.63703 .30902 L
.63833 .30902 L
.63944 .30902 L
.64066 .30902 L
.64197 .30902 L
.64318 .30902 L
.64381 .30902 L
.6445 .30902 L
.64523 .30902 L
.64591 .30902 L
.64716 .30902 L
.64831 .30902 L
.64956 .30902 L
.65088 .30902 L
.652 .30902 L
.65319 .30902 L
.65431 .30902 L
.65533 .30902 L
.65653 .30902 L
.65784 .30902 L
.65906 .30902 L
.6602 .30902 L
.6614 .30902 L
Mistroke
.6627 .30902 L
.66392 .30902 L
.66504 .30902 L
.66635 .30902 L
.66709 .30902 L
.66777 .30902 L
.66903 .30902 L
.66966 .30902 L
.67036 .30902 L
.67104 .30902 L
.67175 .30902 L
.67303 .30902 L
.67374 .30902 L
.6744 .30902 L
.67513 .30902 L
.67591 .30902 L
.67658 .30902 L
.67731 .30902 L
.678 .30902 L
.67864 .30902 L
.67984 .30902 L
.68112 .30902 L
.68232 .30902 L
.68364 .30902 L
.68488 .30902 L
.68603 .30902 L
.68718 .30902 L
.68821 .30902 L
.68941 .30902 L
.69053 .30902 L
.69176 .30902 L
.69307 .30902 L
.69418 .30902 L
.6954 .30902 L
.69671 .30902 L
.69745 .30902 L
.69812 .30902 L
.69942 .30902 L
.70066 .30902 L
.70171 .30902 L
.70286 .30902 L
.70407 .30902 L
.70521 .30902 L
.70627 .30902 L
.70724 .30902 L
.7083 .30902 L
.70942 .30902 L
.71056 .30902 L
.71178 .30902 L
.71293 .30902 L
Mistroke
.71398 .30902 L
.71521 .30902 L
.7159 .30902 L
.71654 .30902 L
.71771 .30902 L
.71896 .30902 L
.72017 .30902 L
.72149 .30902 L
.72273 .30902 L
.72389 .30902 L
.72503 .30902 L
.72607 .30902 L
.72727 .30902 L
.7284 .30902 L
.72963 .30902 L
.73094 .30902 L
.73205 .30902 L
.73327 .30902 L
.73458 .30902 L
.73532 .30902 L
.73599 .30902 L
.7373 .30902 L
.73853 .30902 L
.73959 .30902 L
.74075 .30902 L
.74196 .30902 L
.7431 .30902 L
.74416 .30902 L
.74513 .30902 L
.74619 .30902 L
.74731 .30902 L
.74846 .30902 L
.74967 .30902 L
.75083 .30902 L
.75187 .30902 L
.7531 .30902 L
.75379 .30902 L
.75443 .30902 L
.75561 .30902 L
.75685 .30902 L
.75806 .30902 L
.75875 .30902 L
.75939 .30902 L
.76056 .30902 L
.7618 .30902 L
.7629 .30902 L
.76394 .30902 L
.76508 .30902 L
.76631 .30902 L
.76754 .30902 L
Mistroke
.76824 .30902 L
.76889 .30902 L
.7702 .30902 L
.77094 .30902 L
.77161 .30902 L
.7728 .30902 L
.7741 .30902 L
.77533 .30902 L
.77646 .30902 L
.77752 .30902 L
.77865 .30902 L
.77972 .30902 L
.7807 .30902 L
.78184 .30902 L
.78309 .30902 L
.78427 .30902 L
.78536 .30902 L
.7866 .30902 L
.78776 .30902 L
.7888 .30902 L
.78993 .30902 L
.79116 .30902 L
.79246 .30902 L
.79357 .30902 L
.79479 .30902 L
.7961 .30902 L
.7973 .30902 L
.79793 .30902 L
.79863 .30902 L
.79936 .30902 L
.80004 .30902 L
.80129 .30902 L
.80243 .30902 L
.80369 .30902 L
.80501 .30902 L
.80612 .30902 L
.80731 .30902 L
.80843 .30902 L
.80945 .30902 L
.81066 .30902 L
.81196 .30902 L
.81318 .30902 L
.81432 .30902 L
.81552 .30902 L
.81682 .30902 L
.81804 .30902 L
.81916 .30902 L
.82047 .30902 L
.8212 .30902 L
.82189 .30902 L
Mistroke
.82315 .30902 L
.82385 .30902 L
.82448 .30902 L
.82516 .30902 L
.82587 .30902 L
.82715 .30902 L
.82786 .30902 L
.82852 .30902 L
.82925 .30902 L
.83002 .30902 L
.8307 .30902 L
.83143 .30902 L
.83212 .30902 L
.83275 .30902 L
.83396 .30902 L
.83524 .30902 L
.83644 .30902 L
.83775 .30902 L
.839 .30902 L
.84015 .30902 L
.84129 .30902 L
.84232 .30902 L
.84352 .30902 L
.84464 .30902 L
.84587 .30902 L
.84718 .30902 L
.84829 .30902 L
.8495 .30902 L
.85082 .30902 L
.85155 .30902 L
.85222 .30902 L
.85353 .30902 L
.85476 .30902 L
.85581 .30902 L
.85697 .30902 L
.85818 .30902 L
.85932 .30902 L
.86037 .30902 L
.86134 .30902 L
.86241 .30902 L
.86353 .30902 L
.86467 .30902 L
.86589 .30902 L
.86704 .30902 L
.86808 .30902 L
.86931 .30902 L
.87 .30902 L
.87064 .30902 L
.87182 .30902 L
.87306 .30902 L
Mistroke
.87427 .30902 L
.87559 .30902 L
.87684 .30902 L
.87799 .30902 L
.87914 .30902 L
.88017 .30902 L
.88137 .30902 L
.88249 .30902 L
.88373 .30902 L
.88503 .30902 L
.88615 .30902 L
.88737 .30902 L
.88868 .30902 L
.88942 .30902 L
.89009 .30902 L
.89139 .30902 L
.89263 .30902 L
.89368 .30902 L
.89484 .30902 L
.89605 .30902 L
.89719 .30902 L
.89825 .30902 L
.89922 .30902 L
.90029 .30902 L
.90141 .30902 L
.90255 .30902 L
.90377 .30902 L
.90492 .30902 L
.90596 .30902 L
.90719 .30902 L
.90789 .30902 L
.90852 .30902 L
.9097 .30902 L
.91094 .30902 L
.91216 .30902 L
.91284 .30902 L
.91348 .30902 L
.91464 .30902 L
.91589 .30902 L
.91699 .30902 L
.91803 .30902 L
.91917 .30902 L
.9204 .30902 L
.92163 .30902 L
.92233 .30902 L
.92297 .30902 L
.92429 .30902 L
.92502 .30902 L
.92569 .30902 L
.92689 .30902 L
Mistroke
.92819 .30902 L
.92941 .30902 L
.93055 .30902 L
.9316 .30902 L
.93273 .30902 L
.9338 .30902 L
.93478 .30902 L
.93592 .30902 L
.93717 .30902 L
.93835 .30902 L
.93944 .30902 L
.94068 .30902 L
.94184 .30902 L
.94288 .30902 L
.94401 .30902 L
.94524 .30902 L
.94654 .30902 L
.94765 .30902 L
.94887 .30902 L
.94975 .30902 L
.95057 .30902 L
.95146 .30902 L
.95241 .30902 L
.95324 .30902 L
.95401 .30902 L
.95486 .30902 L
.95577 .30902 L
.95653 .30902 L
.95737 .30902 L
.95824 .30902 L
.95905 .30902 L
.95981 .30902 L
.9605 .30902 L
.9613 .30902 L
.96206 .30902 L
.96287 .30902 L
.96377 .30902 L
.96471 .30902 L
.96559 .30902 L
.96641 .30902 L
.96716 .30902 L
.96802 .30902 L
.96884 .30902 L
.96972 .30902 L
.97067 .30902 L
.97155 .30902 L
.97236 .30902 L
.97331 .30902 L
.97433 .30902 L
.9753 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.301471 0.51221 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.603319 0.389117 [
[.02381 -0.0125 -14 -24.5625 ]
[.02381 -0.0125 14 0 ]
[.18254 -0.0125 -14 -24.5625 ]
[.18254 -0.0125 14 0 ]
[.34127 -0.0125 -14 -24.5625 ]
[.34127 -0.0125 14 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.65873 -0.0125 -7.03125 -24.5625 ]
[.65873 -0.0125 7.03125 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .05856 -43.0625 -12.2813 ]
[-0.0125 .05856 0 12.2813 ]
[-0.0125 .13638 -43.0625 -12.2813 ]
[-0.0125 .13638 0 12.2813 ]
[-0.0125 .2142 -28 -12.2813 ]
[-0.0125 .2142 0 12.2813 ]
[-0.0125 .29203 -43.0625 -12.2813 ]
[-0.0125 .29203 0 12.2813 ]
[-0.0125 .36985 -43.0625 -12.2813 ]
[-0.0125 .36985 0 12.2813 ]
[-0.0125 .44767 -43.0625 -12.2813 ]
[-0.0125 .44767 0 12.2813 ]
[-0.0125 .5255 -43.0625 -12.2813 ]
[-0.0125 .5255 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -24.5938 ]
[-0.01875 .30902 -43.0625 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05856 m
.00625 .05856 L
s
gsave
-0.0125 .05856 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .13638 m
.00625 .13638 L
s
gsave
-0.0125 .13638 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .2142 m
.00625 .2142 L
s
gsave
-0.0125 .2142 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .29203 m
.00625 .29203 L
s
gsave
-0.0125 .29203 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .36985 m
.00625 .36985 L
s
gsave
-0.0125 .36985 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .44767 m
.00625 .44767 L
s
gsave
-0.0125 .44767 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .5255 m
.00625 .5255 L
s
gsave
-0.0125 .5255 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07801 m
.00375 .07801 L
s
0 .09747 m
.00375 .09747 L
s
0 .11692 m
.00375 .11692 L
s
0 .15583 m
.00375 .15583 L
s
0 .17529 m
.00375 .17529 L
s
0 .19475 m
.00375 .19475 L
s
0 .23366 m
.00375 .23366 L
s
0 .25311 m
.00375 .25311 L
s
0 .27257 m
.00375 .27257 L
s
0 .31148 m
.00375 .31148 L
s
0 .33094 m
.00375 .33094 L
s
0 .35039 m
.00375 .35039 L
s
0 .3893 m
.00375 .3893 L
s
0 .40876 m
.00375 .40876 L
s
0 .42822 m
.00375 .42822 L
s
0 .46713 m
.00375 .46713 L
s
0 .48658 m
.00375 .48658 L
s
0 .50604 m
.00375 .50604 L
s
0 .54495 m
.00375 .54495 L
s
0 .56441 m
.00375 .56441 L
s
0 .58386 m
.00375 .58386 L
s
0 .0391 m
.00375 .0391 L
s
0 .01964 m
.00375 .01964 L
s
0 .00019 m
.00375 .00019 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -140.938 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06349 .61428 m
.06349 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30159 .61428 m
.30159 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.46032 .61428 m
.46032 .61803 L
s
.53968 .61428 m
.53968 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.69841 .61428 m
.69841 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.93651 .61428 m
.93651 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05856 m
1 .05856 L
s
.99375 .13638 m
1 .13638 L
s
.99375 .2142 m
1 .2142 L
s
.99375 .29203 m
1 .29203 L
s
.99375 .36985 m
1 .36985 L
s
.99375 .44767 m
1 .44767 L
s
.99375 .5255 m
1 .5255 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .07801 m
1 .07801 L
s
.99625 .09747 m
1 .09747 L
s
.99625 .11692 m
1 .11692 L
s
.99625 .15583 m
1 .15583 L
s
.99625 .17529 m
1 .17529 L
s
.99625 .19475 m
1 .19475 L
s
.99625 .23366 m
1 .23366 L
s
.99625 .25311 m
1 .25311 L
s
.99625 .27257 m
1 .27257 L
s
.99625 .31148 m
1 .31148 L
s
.99625 .33094 m
1 .33094 L
s
.99625 .35039 m
1 .35039 L
s
.99625 .3893 m
1 .3893 L
s
.99625 .40876 m
1 .40876 L
s
.99625 .42822 m
1 .42822 L
s
.99625 .46713 m
1 .46713 L
s
.99625 .48658 m
1 .48658 L
s
.99625 .50604 m
1 .50604 L
s
.99625 .54495 m
1 .54495 L
s
.99625 .56441 m
1 .56441 L
s
.99625 .58386 m
1 .58386 L
s
.99625 .0391 m
1 .0391 L
s
.99625 .01964 m
1 .01964 L
s
.99625 .00019 m
1 .00019 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.2 0 1 r
.5 Mabswid
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.04262 .60332 L
.0522 .60332 L
.05753 .60332 L
.06244 .60332 L
.06788 .60332 L
.07379 .60332 L
.07889 .60332 L
.08451 .60332 L
.08954 .60332 L
.09425 .60332 L
.10458 .60332 L
.10954 .60332 L
.11496 .60332 L
.11974 .60332 L
.12483 .60332 L
.12987 .60332 L
.13443 .60332 L
.14335 .60332 L
.14823 .60332 L
.15338 .60332 L
.1626 .60332 L
.16773 .60332 L
.17252 .60332 L
.17774 .60332 L
.18342 .60331 L
.18885 .60331 L
.19387 .60331 L
.19858 .60331 L
.20377 .60331 L
.21277 .6033 L
.2177 .6033 L
.22233 .60329 L
.23216 .60328 L
.2371 .60327 L
.24251 .60326 L
.24714 .60325 L
.2521 .60323 L
.26101 .60319 L
.26634 .60316 L
.27126 .60312 L
.27654 .60307 L
.28236 .603 L
.29215 .60283 L
.2975 .6027 L
.30251 .60256 L
.30749 .60238 L
.31292 .60214 L
Mistroke
.3177 .60187 L
.3228 .60152 L
.32785 .60108 L
.33242 .60061 L
.34134 .59936 L
.34623 .59845 L
.35139 .59726 L
.36062 .59437 L
.36576 .59222 L
.37056 .58975 L
.37578 .58645 L
.38145 .58198 L
.3869 .57663 L
.39193 .57054 L
.40185 .55452 L
.41086 .53392 L
.42042 .50389 L
.42981 .46439 L
.43993 .40959 L
.45822 .28269 L
.4779 .13993 L
.4833 .10735 L
.48905 .07775 L
.49444 .05533 L
.49941 .03934 L
.50455 .02732 L
.50726 .02273 L
.50864 .02082 L
.51012 .01909 L
.51142 .01782 L
.5126 .01687 L
.51381 .01608 L
.51493 .01552 L
.51623 .01506 L
.51691 .0149 L
.51764 .01478 L
.51886 .01472 L
.51956 .01475 L
.52021 .01483 L
.52131 .01505 L
.52252 .01543 L
.52377 .01596 L
.52495 .01657 L
.52929 .01978 L
.53402 .02464 L
.53909 .03104 L
.58055 .09633 L
.60133 .12405 L
.6205 .14437 L
.63916 .15985 L
Mistroke
.65894 .17251 L
.67849 .18208 L
.69679 .189 L
.71705 .19489 L
.73558 .19904 L
.75458 .20235 L
.77531 .20513 L
.795 .20715 L
.81598 .20881 L
.8374 .2101 L
.85758 .21103 L
.87767 .21174 L
.89615 .21226 L
.91499 .21267 L
.93566 .21302 L
.95518 .21328 L
.9761 .21349 L
.97619 .21349 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.48779 0.301471 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.24336 0.45729 [
[.02381 -0.0125 -14 -24.5625 ]
[.02381 -0.0125 14 0 ]
[.18254 -0.0125 -14 -24.5625 ]
[.18254 -0.0125 14 0 ]
[.34127 -0.0125 -14 -24.5625 ]
[.34127 -0.0125 14 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.65873 -0.0125 -7.03125 -24.5625 ]
[.65873 -0.0125 7.03125 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .06044 -43.0625 -12.2813 ]
[-0.0125 .06044 0 12.2813 ]
[-0.0125 .1519 -43.0625 -12.2813 ]
[-0.0125 .1519 0 12.2813 ]
[-0.0125 .24336 -14.0625 -12.2813 ]
[-0.0125 .24336 0 12.2813 ]
[-0.0125 .33482 -29.125 -12.2813 ]
[-0.0125 .33482 0 12.2813 ]
[-0.0125 .42628 -29.125 -12.2813 ]
[-0.0125 .42628 0 12.2813 ]
[-0.0125 .51773 -29.125 -12.2813 ]
[-0.0125 .51773 0 12.2813 ]
[-0.0125 .60919 -29.125 -12.2813 ]
[-0.0125 .60919 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -24.5938 ]
[-0.01875 .30902 -43.0625 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06044 m
.00625 .06044 L
s
gsave
-0.0125 .06044 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .1519 m
.00625 .1519 L
s
gsave
-0.0125 .1519 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24336 m
.00625 .24336 L
s
gsave
-0.0125 .24336 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .33482 m
.00625 .33482 L
s
gsave
-0.0125 .33482 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .42628 m
.00625 .42628 L
s
gsave
-0.0125 .42628 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .51773 m
.00625 .51773 L
s
gsave
-0.0125 .51773 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .60919 m
.00625 .60919 L
s
gsave
-0.0125 .60919 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08331 m
.00375 .08331 L
s
0 .10617 m
.00375 .10617 L
s
0 .12904 m
.00375 .12904 L
s
0 .17477 m
.00375 .17477 L
s
0 .19763 m
.00375 .19763 L
s
0 .2205 m
.00375 .2205 L
s
0 .26622 m
.00375 .26622 L
s
0 .28909 m
.00375 .28909 L
s
0 .31195 m
.00375 .31195 L
s
0 .35768 m
.00375 .35768 L
s
0 .38055 m
.00375 .38055 L
s
0 .40341 m
.00375 .40341 L
s
0 .44914 m
.00375 .44914 L
s
0 .47201 m
.00375 .47201 L
s
0 .49487 m
.00375 .49487 L
s
0 .5406 m
.00375 .5406 L
s
0 .56346 m
.00375 .56346 L
s
0 .58633 m
.00375 .58633 L
s
0 .03758 m
.00375 .03758 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -140.938 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06349 .61428 m
.06349 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30159 .61428 m
.30159 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.46032 .61428 m
.46032 .61803 L
s
.53968 .61428 m
.53968 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.69841 .61428 m
.69841 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.93651 .61428 m
.93651 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06044 m
1 .06044 L
s
.99375 .1519 m
1 .1519 L
s
.99375 .24336 m
1 .24336 L
s
.99375 .33482 m
1 .33482 L
s
.99375 .42628 m
1 .42628 L
s
.99375 .51773 m
1 .51773 L
s
.99375 .60919 m
1 .60919 L
s
.125 Mabswid
.99625 .08331 m
1 .08331 L
s
.99625 .10617 m
1 .10617 L
s
.99625 .12904 m
1 .12904 L
s
.99625 .17477 m
1 .17477 L
s
.99625 .19763 m
1 .19763 L
s
.99625 .2205 m
1 .2205 L
s
.99625 .26622 m
1 .26622 L
s
.99625 .28909 m
1 .28909 L
s
.99625 .31195 m
1 .31195 L
s
.99625 .35768 m
1 .35768 L
s
.99625 .38055 m
1 .38055 L
s
.99625 .40341 m
1 .40341 L
s
.99625 .44914 m
1 .44914 L
s
.99625 .47201 m
1 .47201 L
s
.99625 .49487 m
1 .49487 L
s
.99625 .5406 m
1 .5406 L
s
.99625 .56346 m
1 .56346 L
s
.99625 .58633 m
1 .58633 L
s
.99625 .03758 m
1 .03758 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.2 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.03053 .01472 L
.03279 .01472 L
.03527 .01472 L
.0379 .01472 L
.04262 .01472 L
.04749 .01472 L
.05205 .01472 L
.05702 .01472 L
.05965 .01472 L
.06244 .01472 L
.06526 .01472 L
.06788 .01472 L
.07305 .01472 L
.07813 .01472 L
.08274 .01472 L
.08814 .01472 L
.09119 .01472 L
.09399 .01472 L
.0991 .01472 L
.10458 .01472 L
.10967 .01472 L
.11432 .01472 L
.11898 .01472 L
.1234 .01472 L
.12855 .01472 L
.1333 .01472 L
.13852 .01472 L
.14407 .01472 L
.14896 .01472 L
.15344 .01472 L
.15826 .01472 L
.16354 .01472 L
.17244 .01472 L
.1773 .01472 L
.18182 .01472 L
.18687 .01472 L
.19234 .01472 L
.19751 .01472 L
.20228 .01472 L
.2113 .01473 L
.21586 .01473 L
.22086 .01474 L
.22608 .01474 L
.23103 .01475 L
.24031 .01477 L
Mistroke
.2455 .01478 L
.25031 .0148 L
.25558 .01482 L
.2612 .01485 L
.26658 .01489 L
.27151 .01493 L
.27694 .01499 L
.28265 .01507 L
.29228 .01526 L
.29774 .0154 L
.30284 .01558 L
.30786 .01579 L
.31332 .01609 L
.31813 .01641 L
.32323 .01684 L
.32782 .01732 L
.33288 .01797 L
.3418 .01952 L
.34673 .02067 L
.35192 .02218 L
.36118 .02586 L
.36635 .02863 L
.37116 .03181 L
.37639 .03608 L
.38205 .04186 L
.38755 .04887 L
.3926 .05683 L
.40255 .07779 L
.41159 .10466 L
.42115 .14341 L
.43061 .19401 L
.44076 .26223 L
.45909 .40956 L
.46925 .48857 L
.47461 .52434 L
.48031 .55583 L
.48527 .57689 L
.48809 .58611 L
.49075 .59291 L
.49317 .59759 L
.4954 .60063 L
.49657 .60175 L
.49784 .60263 L
.49849 .60294 L
.49918 .60316 L
.50042 .60332 L
.50165 .60316 L
.50235 .60294 L
.503 .60264 L
.50432 .6018 L
Mistroke
.50574 .60055 L
.5083 .59743 L
.51065 .59369 L
.51633 .5817 L
.52174 .56735 L
.54188 .50293 L
.56193 .44128 L
.5801 .39578 L
.59979 .35788 L
.62076 .3281 L
.64002 .30794 L
.66085 .29177 L
.6808 .28028 L
.70187 .2712 L
.72153 .26484 L
.73986 .26025 L
.76023 .25633 L
.77879 .25356 L
.79789 .25135 L
.81866 .24948 L
.83845 .24812 L
.85946 .247 L
.87895 .2462 L
.89723 .24562 L
.91743 .24511 L
.93594 .24474 L
.95488 .24445 L
.97558 .2442 L
.97619 .24419 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{847.125, 523.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=?00022b000`400?l00000o`00003oo`3ooooo
0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00
o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo003o0?ooool0ooooo`3ooomB
0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo003o0?ooool0oooo
o`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo003o0?oo
ool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo
003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oo
oe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?T0oooo00H0
_g@000000000000000000018W03Oool40?ooo`030?oo_`1d07@0_ooo0?l0ooooP`3oool01P2oM000
000000000000000004RL0=ooo`@0oooo00<0oono07@0M02oool0^P3oool00?X0oooo00<0oono07@0
M02oool01@3oool0103ooml0W4P00000M02ooooo0?oooh@0oooo00<0oono07@0M02oool01@3oool0
103ooml0W4P00000M02ooonj0?ooo`00nP3oool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000
001d0;ooool0ooooQ03oool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000001d0;oookX0oooo
003j0?ooo`030?oog`2LB7@0_ooo00@0oooo00D0gia80000000004P0B4Qd0;ooo`3o0?oooh@0oooo
00<0oooO09a8M02oool0103oool01@3OW4P000000000B018B7@0_ooo0;X0oooo003j0?ooo`030?oo
g`2LB7@0_ooo00<0oooo00H0okmd0000000007@0_ooO09a8M02ooooo0?oooh@0oooo00<0oooO09a8
M02oool00`3oool01P3o_g@000000000M02ooml0W4Qd0;oookX0oooo003j0?ooo`030?oog`2LB7@0
_ooo0080oooo00L0omnL04P0000004P0W=oo0?oog`2LB7@0_ooo0?l0ooooQ03oool00`3ooml0W4Qd
0;ooo`020?ooo`070?oOW0180000001809cOo`3ooml0W4Qd0;ooo`2j0?ooo`00nP3oool0303ooml0
W4Qd0;ooo`3oool0oono07@000000000M;oo0?ooo`3ooml0W4Qd0;ooool0ooooQ03oool0303ooml0
W4Qd0;ooo`3oool0oono07@000000000M;oo0?ooo`3ooml0W4Qd0;oookX0oooo003j0?ooo`070?oo
g`2LB7@0_ooo0?oog`2LB000000004RLg`020?ooo`030?oog`2LB7@0_ooo0?l0ooooQ03oool01`3o
oml0W4Qd0;ooo`3ooml0W4P000000018W=l00P3oool00`3ooml0W4Qd0;ooo`2j0?ooo`00nP3oool0
1P3ooml0W4Qd0;oog`2LB0000000001d_`<0oooo00<0oooO09a8M02oool0o`3ooon40?ooo`060?oo
g`2LB7@0_ooO09a80000000007Bo0`3oool00`3ooml0W4Qd0;ooo`2j0?ooo`00nP3oool01P3ooml0
W4Qd07Ad0000000004RL0=ooo`<0oooo00<0oooO09a8M02oool0o`3ooon40?ooo`060?oog`2LB7@0
M7@000000000B9`0gooo0`3oool00`3ooml0W4Qd0;ooo`2j0?ooo`00nP3oool01@3ooml0W4P00000
000007@0_ooo00@0oooo00<0oooO09a8M02oool0o`3ooon40?ooo`050?oog`2LB00000000000M02o
ool0103oool00`3ooml0W4Qd0;ooo`2j0?ooo`00nP3oool0103OW4P000000000M02oool50?ooo`03
0?oo_`1d07@0_ooo0?l0ooooQ03oool0103OW4P000000000M02oool50?ooo`030?oo_`1d07@0_ooo
0;X0oooo003h0?ooo`050=nLB000000000000000B02Lgol0103oool00`3ooml0W4P0000000020000
00030018W03Oool0oooo0?l0ooooO`3oool01@3OW4P000000000000004P0W=oo00@0oooo00<0oooO
09a8000000000P0000000`00B9`0gooo0?ooo`2g0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0
ooooo`3ooooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3o
ool00?l0ooooo`3ooooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0
ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo
0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00
KP3oool01P3ooml0W4P0000000000000001d0;ooobl0oooo00<0okmd0000001d_ol0:P3oool00`3O
W4P00000000000050000000307Boo`3oool0oooo02<0oooo00@0_g@0000000000000B9cO:`3oool0
0`3OW4P00000000000050000000307Boo`3oool0oooo02`0oooo00<0okmd0000001d_ol0;03oool0
1P3ooml0W4P0000000000000001d0;ooof@0oooo00H0oooO09a80000000000000000M02oool_0?oo
o`030?noM0000000M;oo02X0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0S0?oo
o`040;md00000000000004RLgb/0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0/
0?ooo`030?noM0000000M;oo02`0oooo00H0oooO09a80000000000000000M02ooolW0?ooo`00K@3o
ool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo;P3oool00`3o_g@0000007Boo`0[0?oo
o`030=nLB0000000000000@0000000<007Bo0?ooo`3oool08@3oool01`3ooml0W4P0001d_`3oool0
oooO09a80000M;l0:`3oool00`3OW4P000000000000400000003001d_`3oool0oooo02`0oooo00<0
okmd0000001d_ol0:`3oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=ooHP3oool0203o
okl0M0000018W03Oool0oooo0=nLB00004P0W=oo;P3oool00`3o_g@0000007Boo`0[0?ooo`030=nL
B0000000000000@0000000<007Bo0?ooo`3oool08@3oool01`3ooml0W4P0001d_`3oool0oooO09a8
0000M;l0:`3oool00`3OW4P000000000000400000003001d_`3oool0oooo02`0oooo00<0okmd0000
001d_ol0:`3oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo9P3oool006d0oooo00<0
_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`0]0?ooo`030?noM0000000M;oo02`0oooo00<0
gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0R0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol0:`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo02d0oooo00<0
okmd0000001d_ol0:`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo0640oooo00<0
_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`0]0?ooo`030?noM0000000M;oo02`0oooo00<0
gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0R0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol0:`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo02d0oooo00<0
okmd0000001d_ol0:`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo02D0oooo001/
0?ooo`030?oo_`1d000007Bo00@0oooo00<0gia80000M02oool0:03oool00`3OW4P0000000000005
000000030000B02Lgol0oooo02X0oooo00<0gia804RLg`3oool09@3oool0103ooml0W4P00018W03O
ool20?ooo`030?oog`2LB00007Bo02`0oooo00<0gia804RLg`3oool0;03oool00`3OW4P000000000
0005000000030000B02Lgol0oooo02L0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;oo
o`1P0?ooo`030?oo_`1d000007Bo00@0oooo00<0gia80000M02oool0:03oool00`3OW4P000000000
0005000000030000B02Lgol0oooo02X0oooo00<0gia804RLg`3oool09@3oool0103ooml0W4P00018
W03Oool20?ooo`030?oog`2LB00007Bo02`0oooo00<0gia804RLg`3oool0;03oool00`3OW4P00000
00000005000000030000B02Lgol0oooo02L0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d
0;ooo`0U0?ooo`00K03oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo02P0oooo00<0
omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0^0?ooo`030=nLB01d_ol0oooo02@0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`0/0?ooo`030=nLB01d_ol0oooo02/0oooo00<0
omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0Z0?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000B02Lgol0H03oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo02P0oooo00<0
omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0^0?ooo`030=nLB01d_ol0oooo02@0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`0/0?ooo`030=nLB01d_ol0oooo02/0oooo00<0
omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0Z0?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000B02Lgol09@3oool005l0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3o
gi`0B00004RLg`<0oooo00@0oono07@0000007@0_ooo6`3oool00`2oM00000000000000700000006
04RLg`3oool0oooo0?ooo`3OW4P0M;oo0P3oool00`3o_g@0000007Boo`0M0?ooo`030;md00000000
000000L0000000<0B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`0T0?ooo`030?oOW0180000
B9cO00@0oooo00<0_g@00000M02oool0;03oool00`3ooml0W4Q809cOo`0/0?ooo`070=nLB01d_ol0
oooo0?ooo`3o_g@0000007Boo`0Z0?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0
_oooE03oool00`2oM0000000000000070000000504RLg`3oool0omnL04P00018W=l00`3oool0103o
okl0M0000000M02ooolK0?ooo`030;md00000000000000L0000000H0B9cO0?ooo`3oool0oooo0=nL
B01d_ol20?ooo`030?noM0000000M;oo01d0oooo00<0_g@00000000000001`0000000`18W=l0oooo
0?ooo`040?ooo`030?oog`2LB4P0W=oo02@0oooo00<0omnL04P00018W=l0103oool00`2oM000001d
0;ooo`0/0?ooo`030?oog`2LB4P0W=oo02`0oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo
02X0oooo00<0omnL04P00018W=l00`3oool0103ookl0M0000000M02ooolU0?ooo`00K03oool02@3o
okl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`0Z0?ooo`070?oo_`1d07@0_ooo0?ooo`3o
_g@0000007Boo`0_0?ooo`030?oOW01807@0_ooo02<0oooo00<0omnL04P00018W=l0103oool00`3O
W4P0001809cOo`0]0?ooo`030?oOW01807@0_ooo02/0oooo00L0oono07@0M02oool0oooo0?noM000
0000M;oo02X0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0H@3oool02@3o
okl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`0Z0?ooo`070?oo_`1d07@0_ooo0?ooo`3o
_g@0000007Boo`0_0?ooo`030?oOW01807@0_ooo02<0oooo00<0omnL04P00018W=l0103oool00`3O
W4P0001809cOo`0]0?ooo`030?oOW01807@0_ooo02/0oooo00L0oono07@0M02oool0oooo0?noM000
0000M;oo02X0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l09P3oool006`0
oooo00D0oooO09a8000007@0_mnL04P000020000000304RLg`3oool0oooo02X0oooo00H0okmd001d
_`3oool0okmd0000001d_ol`0?ooo`030;md0018W=l0oooo0280oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`0^0?ooo`030;md0018W=l0oooo02/0oooo00H0okmd001d_`3oool0okmd
0000001d_olZ0?ooo`050?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`1P0?oo
o`050?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`0Z0?ooo`060?noM000M;l0
oooo0?noM0000000M;oo<03oool00`2oM000B9cO0?ooo`0R0?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol0;P3oool00`2oM000B9cO0?ooo`0[0?ooo`060?noM000M;l0oooo0?noM000
0000M;oo:P3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool09@3oool0
06d0oooo00<0okmd00000018W=l0<@3oool01@2oM000M;oo0?noM0000000M;oo0300oooo00<0gia8
0000M02oool08P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02h0oooo00<0gia8
0000M02oool0;03oool01@2oM000M;oo0?noM0000000M;oo02/0oooo00<0okmd00000018W=l0I`3o
ool00`3o_g@0000004RLg`0a0?ooo`050;md001d_ol0okmd0000001d_ol0<03oool00`3OW4P0001d
0;ooo`0R0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0;P3oool00`3OW4P0001d
0;ooo`0/0?ooo`050;md001d_ol0okmd0000001d_ol0:`3oool00`3o_g@0000004RLg`0[0?ooo`00
K@3oool0103ooml0W4P00000B02Lgol`0?ooo`050?oo_`1d07@0_kmd0000001d_ol0<03oool00`3o
_g@0000007Boo`0S0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0;`3oool00`3o
_g@0000007Boo`0/0?ooo`050?oo_`1d07@0_kmd0000001d_ol0:`3oool0103ooml0W4P00000B02L
gomV0?ooo`040?oog`2LB000001809cOoc00oooo00D0oono07@0M02o_g@0000007Boo`0`0?ooo`03
0?noM0000000M;oo02<0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0_0?ooo`03
0?noM0000000M;oo02`0oooo00D0oono07@0M02o_g@0000007Boo`0[0?ooo`040?oog`2LB0000018
09cOobX0oooo001^0?ooo`040?oo_`1d0000001d0;oooc00oooo00@0okmd000000000000M;oo:P3o
ool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo02<0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`0Y0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0;@3o
ool0103o_g@000000000001d_ol/0?ooo`040?oo_`1d0000001d0;ooofH0oooo00@0oono07@00000
07@0_ooo<03oool0103o_g@000000000001d_olZ0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@0
0000001d_ol08`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo02T0oooo00<0omnL
09boo`3oool00`3oool00`2oM000000007Boo`0]0?ooo`040?noM0000000000007Boob`0oooo00@0
oono07@0000007@0_ooo:@3oool006l0oooo00@0oooO09a80000000007Bo;`3oool0103ooml0W4P0
0000001d_ol[0?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03OoolT0?ooo`060;md0000
B9`0gooo0?ooo`2oM00007Bo:`3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo;@3o
ool0103ooml0W4P00000001d_ol]0?ooo`040?oog`2LB0000000001d_fH0oooo00@0oooO09a80000
000007Bo;`3oool0103ooml0W4P00000001d_ol[0?ooo`080;md001d_ol0oooo0?ooo`3OW4P00000
0018W03OoolT0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo:`3oool0202oM000M;oo0?ooo`3o
ool0gia800000000B9`0gooo;@3oool0103ooml0W4P00000001d_ol]0?ooo`040?oog`2LB0000000
001d_bP0oooo001a0?ooo`050?oOW018000000000018W03Oool0;@3oool00`3ogi`0B00007Boo`0/
0?ooo`050;md00000000000000000000M;l09`3oool0102oM000000000000000M;l]0?ooo`050;md
00000000000000000000M;l0<03oool00`3ogi`0B00007Boo`0_0?ooo`050?oOW018000000000018
W03Oool0I@3oool01@3ogi`0B00000000000B9`0gooo02d0oooo00<0omnL04P0001d_ol0;03oool0
1@2oM000000000000000000007Bo02L0oooo00@0_g@000000000000007Bo;@3oool01@2oM0000000
00000000000007Bo0300oooo00<0omnL04P0001d_ol0;`3oool01@3ogi`0B00000000000B9`0gooo
02D0oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3o
oooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0
ooooo`3ooooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooU0?ooo`030?noM000
000000000080000000<007Bo0?ooo`3oool0o`3ooomT0?ooo`00H`3ooooo000003`00000B03oool0
0`2oM000001d0;ooo`090?ooool00000?@00000Q0?ooo`00H`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0AP3oool00`2oM000001d0;ooo`090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?oo
o`00H`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0AP3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo0?ooo`3o0?ooocP0oooo
00<000000?ooo`3oool0AP3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo0?l0oooo
>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<0
00000?ooo`3oool0=@3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0
_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3o
ool006<0oooo0P0000050?oooe/0<`3oe`3oool2000004P0oooo00<0_g@00000M02oool02@3oool3
00000?l0oooo=`3oool300000240oooo001S0?ooo`030000003oool0oooo05l0oooo300c0?o<0?oo
o`030000003oool0oooo04H0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?oo
ocT0oooo00<000000?ooo`3oool07`3oool006<0oooo00<000000?ooo`3oool0J`3oool403<0olP0
oooo00<000000?ooo`3oool0AP3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo0?l0
oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo0?ooo`1_0?ooo`<0<`3o
a@3oool00`000000oooo0?ooo`160?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0
o`3oooli0?ooo`030000003oool0oooo01l0oooo001S0?ooo`030000003oool0oooo0780oooo0P0c
0?o30?ooo`030000003oool0oooo04H0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?oo
o`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool006<0oooo00<000000?ooo`3oool0M03oool2
03<0ol40oooo00<000000?ooo`3oool0A03oool01@3OW4P000000000000007@0_ooo00T0oooo00<0
00000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S0?ooo`800000M`3oool0
0`0c0?l0oooo0?ooo`2m0?ooo`800000A`3oool0103ookl0M0000000M02oool90?ooo`030000003o
ool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00A`3oool0102oM000000000000018
W=l40?ooo`030=nLB0000000B9cO00<0oooo00H0oooO09a80000000000000000M02oool80?ooo`03
0000003oool0oooo07L0oooo0P0c0?nn0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo01l0oooo00150?ooo`070?oog`2LB00007Bo0?ooo`3o
oml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0oono07@00000B9`0gooo0?ooo`3O
W4P0001809cOo`L0oooo00<000000?ooo`3oool0N@3oool00`0c0?l0oooo0?ooo`2k0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo
00150?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000001d0;oo
o`030?ooo`030;md0000M;l0oooo00H0oooo00<000000?ooo`3oool0NP3oool00`0c0?l0oooo0?oo
o`2j0?ooo`030000003oool0oooo0580oooo0P00003o0?ooocT0oooo0P00000Q0?ooo`00A03oool0
103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0oono07@00000M;l0103o
ool00`3OW4P0001d0;ooo`060?ooo`030000003oool0oooo07X0oooo00<0<`3o0?ooo`3oool0^P3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?oo
o`0O0?ooo`00A03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL
04P00018W=l0103oool00`2oM000001809cOo`060?ooo`030000003oool0oooo07/0oooo00<0<`3o
0?ooo`3oool0^@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool0
0`000000oooo0?ooo`0O0?ooo`00A03oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo
00D0oooo00<0omnL04P00018W=l00`3oool0103ookl0M0000000M02oool60?ooo`<00000O03oool0
0`0c0?l0oooo0?ooo`2f0?ooo`<00000E03oool00`000000oooo0?ooo`3o0?ooocT0oooo00<00000
0?ooo`3oool07`3oool004@0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?oo
o`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO00L0oooo00<000000?ooo`3oool0
O@3oool00`0c0?l0oooo0?ooo`2g0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
o`3oooli0?ooo`030000003oool0oooo01l0oooo00140?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol01@3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool0
1P3oool00`000000oooo0?ooo`1m0?ooo`0303<0o`3oool0oooo0;L0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool004@0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?noM0000000B9cO00`0oooo00<0
00000?ooo`3oool0OP3oool00`0c0?l0oooo0?ooo`2f0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo00150?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l01`3oool0103ooml0W4P00000B02Lgol;0?ooo`030000003o
ool0oooo07l0oooo00<0<`3o0?ooo`3oool0]@3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00A@3oool00`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo00P0oooo00@0oono07@0000007@0_ooo2P3oool00`000000oooo0?oo
o`200?ooo`0303<0o`3oool0oooo0;@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool004H0oooo00H0_g@00018W03Oool0oooo0;md
0000M;l:0?ooo`040?oog`2LB0000000001d_`T0oooo00<000000?ooo`3oool0P03oool00`0c0?l0
oooo0?ooo`2d0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`03
0000003oool0oooo01l0oooo00170?ooo`040;md000000000000001d_`d0oooo00D0omnL04P00000
000004RL0=ooo`060?ooo`800000PP3oool00`0c0?l0oooo0?ooo`2b0?ooo`800000E03oool20000
0?l0oooo>@3oool200000240oooo001S0?ooo`030000003oool0oooo0840oooo00<0<`3o0?ooo`3o
ool0/`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000
oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo0?ooo`220?ooo`0303<0o`3oool0oooo0;80oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool006<0oooo00<000000?ooo`3oool0PP3oool00`0c0?l0oooo0?ooo`2b0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S
0?ooo`030000003oool0oooo08<0oooo00<0<`3o0?ooo`3oool0/@3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool00`00
0000oooo0?ooo`230?ooo`0303<0o`3oool0oooo0;40oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool006<0oooo0P0000250?ooo`03
03<0o`3oool0oooo0:l0oooo0P00001D0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000
oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo0?ooo`240?ooo`0303<0o`3oool0oooo0;00oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool006<0oooo00<000000?ooo`3oool0Q03oool00`0c0?l0oooo0?ooo`2`0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S
0?ooo`030000003oool0oooo08D0oooo00<0<`3o0?ooo`3oool0[`3oool00`000000oooo0?ooo`1B
0?ooo`800000o`3oooli0?ooo`8000008@3oool006<0oooo00<000000?ooo`3oool0Q@3oool00`0c
0?l0oooo0?ooo`2_0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?oo
o`030000003oool0oooo01l0oooo001S0?ooo`030000003oool0oooo08H0oooo00<0<`3o0?ooo`3o
ool0[P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000
oooo0?ooo`0O0?ooo`00A`3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00<0
oooo00H0omnL04P00000000000000000B02Lgol80?ooo`800000Q`3oool00`0c0?l0oooo0?ooo`2]
0?ooo`800000E03oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool0
04D0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3o
ool0203ogi`0B0000018W03Oool0oooo0?oOW0180000M;oo1`3oool00`000000oooo0?ooo`260?oo
o`0303<0o`3oool0oooo0:h0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?oo
ocT0oooo00<000000?ooo`3oool07`3oool004D0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0
B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03Oool01P3oool00`000000
oooo0?ooo`270?ooo`0303<0o`3oool0oooo0:d0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool004@0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3ooml0W4P0001d_`070?ooo`030;md000007@0_ooo00<0oooo00<0_g@00018W03O
ool01P3oool00`000000oooo0?ooo`270?ooo`0303<0o`3oool0oooo0:d0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool004@0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?noM00004P0W=oo0080oooo
00<0gia800000000M;l01`3oool00`000000oooo0?ooo`270?ooo`0303<0o`3oool0oooo0:d0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool004@0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`070?ooo`070=nLB000
M;l0oooo0;md00000000001d0;ooo`070?ooo`030000003oool0oooo08L0oooo00<0<`3o0?ooo`3o
ool0[@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000
oooo0?ooo`0O0?ooo`00A03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo
00D0okmd00000000000004RL0=ooo`080?ooo`<00000R03oool00`0c0?l0oooo0?ooo`2Z0?ooo`<0
0000E03oool200000?l0oooo>@3oool200000240oooo00140?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol01`3oool01@3ogi`0B000000000000000B9cO00T0oooo00<000000?ooo`3o
ool0R03oool00`0c0?l0oooo0?ooo`2/0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo01l0oooo00140?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool01P3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l0203oool00`00
0000oooo0?ooo`280?ooo`0303<0o`3oool0oooo0:`0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool004D0oooo00<0_g@00018W03O
ool00P3oool00`3ooml0W4P0001d_`070?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8001d
_ol01`3oool00`000000oooo0?ooo`280?ooo`0303<0o`3oool0oooo0:`0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool004D0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030=nLB000B9`0gooo0080oooo
00<0oooO09a80018W=l01`3oool00`000000oooo0?ooo`290?ooo`0303<0o`3oool0oooo0:/0oooo
00<000000?ooo`3oool0=P3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO0080
oooo00H0_g@000000000000000000018W03Oool90?ooo`030000003oool0oooo0?l0oooo>@3oool0
0`000000oooo0?ooo`0O0?ooo`00AP3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<0
omnL04P00018W=l00P3oool00`3o_g@0001809cOo`070?ooo`030000003oool0oooo08T0oooo00<0
<`3o0?ooo`3oool0Z`3oool00`000000oooo0?ooo`0d0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0
W4P0001d_`030?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo00P0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo00170?oo
o`040;md000000000000001d_`X0oooo00H0oono07@00000000000000000B02Lgol80?ooo`800000
RP3oool00`0c0?l0oooo0?ooo`2Z0?ooo`800000=P3oool00`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo00`0oooo00<0omnL04Qd_`3oool01`3oool00`000000oooo0?ooo`3o0?ooocT0oooo
00<000000?ooo`3oool07`3oool006<0oooo00<000000?ooo`3oool0R@3oool00`0c0?l0oooo0?oo
o`2[0?ooo`030000003oool0oooo03<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0
001d_`0<0?ooo`030?oo_`1d04P0W=oo00L0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000
003oool0oooo01l0oooo001S0?ooo`030000003oool0oooo08X0oooo00<0<`3o0?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`0c0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02`3o
ool00`3ookl0M00007Boo`070?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?oo
o`0O0?ooo`00H`3oool00`000000oooo0?ooo`2:0?ooo`0303<0o`3oool0oooo0:X0oooo00<00000
0?ooo`3oool09P3oool00`2oM0000000000000070000000604RLg`3oool0oooo0?oOW0180000B9cO
103oool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000M;oo00L0oooo0`00003o0?ooocL0oooo
0`00000Q0?ooo`00H`3oool00`000000oooo0?ooo`2:0?ooo`0303<0o`3oool0oooo0:X0oooo00<0
00000?ooo`3oool0<`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00X0oooo00@0
omnL04P0000007@0_ooo1`3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool006<0oooo00<000000?ooo`3oool0RP3oool00`0c0?l0oooo0?ooo`2Z0?ooo`030000003o
ool0oooo03<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooocT0oooo
00<000000?ooo`3oool07`3oool006<0oooo00<000000?ooo`3oool0R`3oool00`0c0?l0oooo0?oo
o`2Y0?ooo`030000003oool0oooo03<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;oo
o`060?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool006<0oooo0P00002<0?ooo`0303<0o`3oool0
oooo0:P0oooo0P00000f0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3oool0
1@3ooml0W4P00000000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003o
ool0oooo01l0oooo001S0?ooo`030000003oool0oooo08/0oooo00<0<`3o0?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`0d0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool0
0`3o_g@007Bo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O
0?ooo`00H`3oool00`000000oooo0?ooo`2;0?ooo`0303<0o`3oool0oooo0:T0oooo00<000000?oo
o`3oool0=@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00<0oooO09a8000000000P00
00000`0007@0_ooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?oo
o`0O0?ooo`00H`3oool00`000000oooo0?ooo`2<0?ooo`0303<0o`3oool0oooo0:P0oooo00<00000
0?ooo`3oool0=P3oool0102oM000000000000000M;l;0?ooo`030?noM000000000000080000000<0
M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3o
ool006<0oooo00<000000?ooo`3oool0S03oool00`0c0?l0oooo0?ooo`2X0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S0?oo
o`030000003oool0oooo08`0oooo00<0<`3o0?ooo`3oool0Z03oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00E@3oool00`3o_g@0
00000000000200000003001d_`3oool0oooo00H0oooo0P00002=0?ooo`0303<0o`3oool0oooo0:L0
oooo0P00001D0?ooo`800000o`3oooli0?ooo`8000008@3oool005L0oooo00<0_g@00000M02oool0
2@3oool00`000000oooo0?ooo`2=0?ooo`0303<0o`3oool0oooo0:L0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool005L0oooo00<0
_g@00000M02oool02@3oool00`000000oooo0?ooo`2=0?ooo`0303<0o`3oool0oooo0:L0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3o
ool005L0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`2=0?ooo`0303<0o`3oool0
oooo0:L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<00000
0?ooo`3oool07`3oool005L0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`2=0?oo
o`0303<0o`3oool0oooo0:L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?oo
ocT0oooo00<000000?ooo`3oool07`3oool005L0oooo00<0_g@00000M02oool02@3oool00`000000
oooo0?ooo`2=0?ooo`0303<0o`3oool0oooo0:L0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool005L0oooo00<0_g@00000M02oool0
2@3oool3000008d0oooo00<0<`3o0?ooo`3oool0Y@3oool3000005@0oooo00<000000?ooo`3oool0
o`3oooli0?ooo`030000003oool0oooo01l0oooo001G0?ooo`030;md000007@0_ooo00T0oooo00<0
00000?ooo`3oool0SP3oool00`0c0?l0oooo0?ooo`2V0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001G0?ooo`030;md000007@0
_ooo00T0oooo00<000000?ooo`3oool0SP3oool00`0c0?l0oooo0?ooo`2V0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001G0?oo
o`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0SP3oool00`0c0?l0oooo0?ooo`2V0?oo
o`030000003oool0oooo0580oooo0P00003o0?ooocT0oooo0P00000Q0?ooo`00E`3oool00`2oM000
001d0;ooo`090?ooo`030000003oool0oooo08h0oooo00<0<`3o0?ooo`3oool0YP3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00
E@3oool01@3OW4P000000000000007@0_ooo00T0oooo00<000000?ooo`3oool0SP3oool00`0c0?l0
oooo0?ooo`2V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`03
0000003oool0oooo01l0oooo001F0?ooo`040?oo_`1d0000001d0;ooo`T0oooo0P00002@0?ooo`03
03<0o`3oool0oooo0:@0oooo0P00001D0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000
oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo0?ooo`2?0?ooo`0303<0o`3oool0oooo0:D0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool006<0oooo00<000000?ooo`3oool0S`3oool00`0c0?l0oooo0?ooo`2U0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo000`
0?ooo`030?noM01d_ol0oooo00H0oooo00<0_gAd0;ooo`3oool09`3oool00`000000oooo0?ooo`2?
0?ooo`0303<0o`3oool0oooo0:D0oooo00<000000?ooo`3oool04P3oool00`3o_g@0M;oo0?ooo`06
0?ooo`030;mdM02oool0oooo03@0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0
oooo01l0oooo000`0?ooo`030?noM00007@0_ooo00@0oooo00@0oooO09a8000007@0_ooo:03oool0
0`000000oooo0?ooo`2?0?ooo`0303<0o`3oool0oooo0:D0oooo00<000000?ooo`3oool04P3oool0
0`3o_g@0001d0;ooo`040?ooo`040?oog`2LB000001d0;ooocD0oooo00<000000?ooo`3oool0o`3o
ooli0?ooo`030000003oool0oooo01l0oooo000`0?ooo`040?noM0000000000004RLg`80oooo00D0
oono07@0B02Lgol0gibL0;ooo`0X0?ooo`030000003oool0oooo0900oooo00<0<`3o0?ooo`3oool0
Y03oool00`000000oooo0?ooo`0B0?ooo`040?noM0000000000004RLg`80oooo00D0oono07@0B02L
gol0gibL0;ooo`0e0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?oo
o`00<03oool0203o_i`0W=oo0=nLB0000000001807AdB00007@0_ooo:`3oool200000940oooo00<0
<`3o0?ooo`3oool0X`3oool2000001@0oooo00P0oknL09cOo`3OW4P000000000B01dM4P0001d0;oo
ocP0oooo0P00003o0?ooocT0oooo0P00000Q0?ooo`00<`3oool0103ookl0M00000000000M;l/0?oo
o`030000003oool0oooo0900oooo00<0<`3o0?ooo`3oool0Y03oool00`000000oooo0?ooo`0E0?oo
o`040?oo_`1d00000000001d_cT0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0
oooo01l0oooo000`0?ooo`0;0?noW02Lgol0okmd0000B02Lgol0gia80000000004P0W=oo0=nLW02o
ool0:03oool00`000000oooo0?ooo`2@0?ooo`0303<0o`3oool0oooo0:@0oooo00<000000?ooo`3o
ool04P3oool02`3o_i`0W=oo0?noM00004P0W=oo0=nLB0000000001809cOo`3OW9`0_ooo03D0oooo
00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo000`0?ooo`030?noM000
000007Bo00<0oooo00D0oono07@000000000001d0;ooo`0X0?ooo`030000003oool0oooo0900oooo
00<0<`3o0?ooo`3oool0Y03oool00`000000oooo0?ooo`0B0?ooo`030?noM000000007Bo00<0oooo
00D0oono07@000000000001d0;ooo`0e0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000
oooo0?ooo`0O0?ooo`00<03oool00`3o_g@0B9cO0?ooo`050?ooo`030=nLB00007@0_ooo02P0oooo
00<000000?ooo`3oool0T03oool00`0c0?l0oooo0?ooo`2T0?ooo`030000003oool0oooo0180oooo
00<0okmd04RLg`3oool01@3oool00`3OW4P0001d0;ooo`0e0?ooo`030000003oool0oooo0?l0oooo
>@3oool00`000000oooo0?ooo`0O0?ooo`00<03oool00`3o_i`0W=oo0?ooo`060?ooo`030;mdM02o
ool0oooo02L0oooo00<000000?ooo`3oool0T@3oool00`0c0?l0oooo0?ooo`2S0?ooo`030000003o
ool0oooo0180oooo00<0oknL09cOo`3oool01P3oool00`2oM7@0_ooo0?ooo`0d0?ooo`030000003o
ool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool200000980oooo00<0<`3o
0?ooo`3oool0XP3oool2000005@0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0
oooo01l0oooo00160?ooo`030?noM000000000000080000000T007Bo0?ooo`3oool0oooo0=nLB000
0000B9cO0?ooo`3OW4P01`0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo0940oooo
00<0<`3o0?ooo`3oool0X`3oool00`000000oooo0?ooo`0J0?ooo`030;md00000000B9cO03D0oooo
00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo000d0?ooo`030=nLB01d
_ol0oooo00@0oooo00<0omnL04Q8W03Oool02P3oool00`2oM000001d0;ooo`040?ooo`030=nLB000
0000B9cO0080oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`050?ooo`030000003o
ool0oooo0940oooo00<0<`3o0?ooo`3oool0X`3oool00`000000oooo0?ooo`0H0?ooo`050?oOW018
0000M;oo0=nLB018W=l0=@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool003<0oooo00<0okmd04RLg`3oool01@3oool00`3ooml0W4Qd0;ooo`0:0?ooo`030;md0000
07@0_ooo00X0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?ooo`030000003o
ool0oooo0940oooo00<0<`3o0?ooo`3oool0X`3oool00`000000oooo0?ooo`0G0?ooo`060=nLB000
B9`0gooo0?ooo`3OW4P0B9cO=@3oool200000?l0oooo>@3oool200000240oooo000c0?ooo`060=nL
B01d_ol0oooo0?oog`2LB000M;oo0`3oool00`3O_kl0gooo0?ooo`090?ooo`030;md000007@0_ooo
00/0oooo00<0gia804RLg`3oool02P3oool00`000000oooo0?ooo`2B0?ooo`0303<0o`3oool0oooo
0:80oooo00<000000?ooo`3oool05P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo
03@0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo000c0?ooo`0:
0=nLB000B9`0gooo0;mdB02LW7@0001d0;ooo`3oool0gia804RLg`/0oooo00<0_g@00000M02oool0
303oool00`3OW4P0M;oo0?ooo`090?ooo`030000003oool0oooo0980oooo00<0<`3o0?ooo`3oool0
XP3oool00`000000oooo0?ooo`0E0?ooo`030=nLB0000000000000H0000000<0001d0;ooo`3oool0
<@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool003<0oooo00H0
oooO09a800000000M;oo0?ooo`2oM0020000000304RLg`3oool0oooo00X0oooo00<0_g@00000M02o
ool0303oool00`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo0980oooo00<0<`3o0?ooo`3o
ool0XP3oool00`000000oooo0?ooo`0K0?ooo`030=nLB018W=l0oooo03@0oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo01l0oooo00180?ooo`030;md000007@0_ooo00d0oooo
00<0omnL04P0M02oool0203oool300000980oooo00<0<`3o0?ooo`3oool0X03oool3000004L0oooo
00@0_g@0000000000000B9cO2@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3o
ool07`3oool004P0oooo00<0_g@00000M02oool03P3oool00`2oM000B9cO0?ooo`070?ooo`030000
003oool0oooo0980oooo00<0<`3o0?ooo`3oool0XP3oool00`000000oooo0?ooo`130?ooo`070?oo
g`2LB00007Bo0?ooo`3ooml0W4P0001d_`080?ooo`030000003oool0oooo0?l0oooo>@3oool00`00
0000oooo0?ooo`0O0?ooo`00B03oool00`2oM000001d0;ooo`0>0?ooo`030=nLB00007@0_ooo00L0
oooo00<000000?ooo`3oool0T`3oool00`0c0?l0oooo0?ooo`2Q0?ooo`030000003oool0oooo04<0
oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030000003oool0oooo0?l0
oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00<@3oool00`3o_g@0000000000004000000030000
M02oool0oooo00d0oooo00<0_g@00000M02oool03P3oool00`3o_g@0000007Boo`070?ooo`030000
003oool0oooo09<0oooo00<0<`3o0?ooo`3oool0X@3oool00`000000oooo0?ooo`0C0?ooo`030?no
M0000000000000@0000000<0001d0;ooo`3oool09@3oool0103ooml0W4P00018W03Oool20?ooo`03
0?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0
oooo000_0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool02`3oool00`2oM000001d
0;ooo`080?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol01`3oool00`000000oooo
0?ooo`2C0?ooo`0303<0o`3oool0oooo0:40oooo00<000000?ooo`3oool04@3oool00`3OW4P00000
00000008000000030000B02Lgol0oooo02<0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`060?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00;P3o
ool0102oM00000000000001d_ol70?ooo`040;md00000000000004RLg`T0oooo00D0gia800000000
0000001d0;ooo`090?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03Oool70?ooo`030000
003oool0oooo09<0oooo00<0<`3o0?ooo`3oool0X@3oool00`000000oooo0?ooo`0@0?ooo`040;md
00000000000007Boo`L0oooo00@0_g@0000000000000B9cO8`3oool00`3ogi`0B00004RLg`040?oo
o`030;md000007@0_ooo00H0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo
01l0oooo000]0?ooo`030;md0000M;l0oooo00/0oooo00<0oooO09a80018W=l02@3oool0103ookl0
M0000000M02oool:0?ooo`050;md00000000000000000000M;l02@3oool2000009@0oooo00<0<`3o
0?ooo`3oool0X03oool200000140oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P004RLg`0R
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool3000000D0ooooo`0c0?l]
03<0o`D0oooo0`00000Q0?ooo`00;03oool00`3oSdP0B:So0?ooo`0>0?ooo`030=nLM02Lgol0oooo
02<0oooo00<000000?ooo`3oool0T`3oool00`0c0?l0oooo0?ooo`2Q0?ooo`030000003oool0oooo
00h0oooo00<0ohm804RXo`3oool03P3oool00`3OW7@0W=oo0?ooo`0P0?ooo`030?oOW0180000B9cO
00@0oooo00<0gia80000B02Lgol01P3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?oo
o`3oool07`3oool002`0oooo00<0okmd07Boo`3oool02P3oool00`3OW9`0_ooo0?ooo`0W0?ooo`03
0000003oool0oooo09@0oooo00<0<`3o0?ooo`3oool0X03oool00`000000oooo0?ooo`0>0?ooo`03
0?noM01d_ol0oooo00X0oooo00<0gibL0;ooo`3oool0903oool00`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo00H0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0
oooo000/0?ooo`030?noM000B9`0gooo00X0oooo00<0_gAd0;ooo`3oool09`3oool00`000000oooo
0?ooo`2D0?ooo`0303<0o`3oool0oooo0:00oooo00<000000?ooo`3oool03P3oool00`3o_g@004RL
0=ooo`0:0?ooo`030;mdM02oool0oooo02D0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0
001d_`070?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00;03o
ool00`3o_g@000000000000:000000030000M02oool0oooo02L0oooo00<000000?ooo`3oool0U03o
ool00`0c0?l0oooo0?ooo`2P0?ooo`030000003oool0oooo00h0oooo00<0okmd0000000000002P00
00000`0007@0_ooo0?ooo`0U0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3o
ool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool002d0oooo00@0_g@0
0000000004P0W=oo203oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003oool0oooo09@0oooo00<0
<`3o0?ooo`3oool0X03oool00`000000oooo0?ooo`0?0?ooo`040;md00000000001809cOo`P0oooo
00<0_gAd0;ooo`3oool09P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<000000?oo
o`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo000^0?ooo`040=nLB0000000000007Bo
o`L0oooo00<0gibL0;ooo`3oool09`3oool2000009D0oooo00<0<`3o0?ooo`3oool0W`3oool20000
0180oooo00@0gia8000000000000M;oo1`3oool00`3OW9`0_ooo0?ooo`0W0?ooo`040;md00000000
0000001d_`T0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo000_
0?ooo`040?noM00000000000001d_c00oooo00<000000?ooo`3oool0U@3oool00`0c0?l0oooo0?oo
o`2O0?ooo`030000003oool0oooo0140oooo00@0okmd00000000000007Bo?@3oool00`000000oooo
0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool00300oooo00D0omnL04P00000000004RL
0=ooo`0^0?ooo`030000003oool0oooo09D0oooo00<0<`3o0?ooo`3oool0W`3oool00`000000oooo
0?ooo`0B0?ooo`050?oOW018000000000018W03Oool0>`3oool00`000000oooo0?ooo`3o0?ooocT0
oooo00<000000?ooo`3oool07`3oool00340oooo00D0oono07@000000000001809cOo`0]0?ooo`03
0000003oool0oooo09D0oooo00<0<`3o0?ooo`3oool0W`3oool00`000000oooo0?ooo`0C0?ooo`05
0?oo_`1d000000000000B02Lgol0>P3oool200000?l0oooo>@3oool200000240oooo000b0?ooo`05
0?oog`2LB00000000000001d_ol0;03oool00`000000oooo0?ooo`2E0?ooo`0303<0o`3oool0oooo
09l0oooo00<000000?ooo`3oool0503oool01@3ooml0W4P0000000000000M;oo03T0oooo00<00000
0?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo000/0?ooo`030?noW02Lgol0oooo
00D0oooo00@0_g@000000000000007Bo:`3oool00`000000oooo0?ooo`2E0?ooo`0303<0o`3oool0
oooo09l0oooo00<000000?ooo`3oool03P3oool00`3o_i`0W=oo0?ooo`050?ooo`040;md00000000
0000001d_cP0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo000/
0?ooo`030?noM01d_ol0oooo00H0oooo00D0gia800000000000004RL0=ooo`0Y0?ooo`800000U`3o
ool00`0c0?l0oooo0?ooo`2M0?ooo`800000403oool00`3o_g@0M;oo0?ooo`060?ooo`050=nLB000
000000000018W03Oool0=P3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool002`0oooo00<0okmd0000000000002P0000000`0004P0W=oo0?ooo`0:0?ooo`030?noM000
000000000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO00H0oooo00<0okmd0000001d
_ol0203oool00`000000oooo0?ooo`2F0?ooo`0303<0o`3oool0oooo09h0oooo00<000000?ooo`3o
ool03P3oool00`3o_g@000000000000:000000030000B02Lgol0oooo03@0oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo01l0oooo000/0?ooo`030?noM01d_ol0oooo01T0oooo
00<0_g@00000M02oool0103oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo00P0oooo
00<000000?ooo`3oool0UP3oool00`0c0?l0oooo0?ooo`2N0?ooo`030000003oool0oooo00h0oooo
00<0okmd07Boo`3oool0@@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool002`0oooo00<0oknL09cOo`3oool06@3oool00`2oM000001d0;ooo`0=0?ooo`030?noM000
0000M;oo00P0oooo00<000000?ooo`3oool0UP3oool00`0c0?l0oooo0?ooo`2N0?ooo`030000003o
ool0oooo00h0oooo00<0oknL09cOo`3oool0@@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<0
00000?ooo`3oool07`3oool004P0oooo00<0_g@00000M02oool0203oool00`3OW4P0000000000005
000000030000B02Lgol0oooo00D0oooo00<000000?ooo`3oool0UP3oool00`0c0?l0oooo0?ooo`2N
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0
oooo01l0oooo000/0?ooo`030?noM01d_ol0oooo00h0oooo00<0_gA809cOo`3oool0203oool00`2o
M000001d0;ooo`080?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0203oool00`00
0000oooo0?ooo`2F0?ooo`0303<0o`3oool0oooo09h0oooo00<000000?ooo`3oool03P3oool00`3o
_g@0M;oo0?ooo`0>0?ooo`030;mdB02Lgol0oooo0300oooo00<000000?ooo`3oool0o`3oooli0?oo
o`030000003oool0oooo01l0oooo000]0?ooo`030;md0000M;l0oooo00/0oooo00<0oooO09a8001d
_ol02P3oool00`2oM000001d0;ooo`090?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`08
0?ooo`<00000U`3oool00`0c0?l0oooo0?ooo`2K0?ooo`<000004@3oool00`2oM00007Bo0?ooo`0;
0?ooo`030?oog`2LB000M;oo0380oooo0P00003o0?ooocT0oooo0P00000Q0?ooo`00;P3oool0102o
M00000000000001d_ol70?ooo`040;md00000000000004RLg`/0oooo00<0_g@00000M02oool02@3o
ool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0203oool00`000000oooo0?ooo`2G0?ooo`03
03<0o`3oool0oooo09d0oooo00<000000?ooo`3oool0403oool0102oM00000000000001d_ol70?oo
o`040;md00000000000004RLgc<0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0
oooo01l0oooo000_0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool02`3oool00`2o
M000001d0;ooo`0:0?ooo`060?noM000M;l0oooo0?noM0000000M;oo203oool00`000000oooo0?oo
o`2G0?ooo`0303<0o`3oool0oooo09d0oooo00<000000?ooo`3oool04@3oool00`3OW4P000000000
0008000000030000B02Lgol0oooo03<0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003o
ool0oooo01l0oooo000a0?ooo`030?noM0000000000000@0000000<0001d0;ooo`3oool03@3oool0
0`2oM000001d0;ooo`0;0?ooo`050;md001d_ol0okmd0000001d_ol0203oool00`000000oooo0?oo
o`2G0?ooo`0303<0o`3oool0oooo09d0oooo00<000000?ooo`3oool04`3oool00`3o_g@000000000
0004000000030000M02oool0oooo03D0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003o
ool0oooo01l0oooo00180?ooo`030;md000007@0_ooo00/0oooo00D0oono07@0M02o_g@0000007Bo
o`080?ooo`030000003oool0oooo09L0oooo00<0<`3o0?ooo`3oool0W@3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00B03oool0
0`2oM000001d0;ooo`0<0?ooo`040?noM0000000000007Boo`P0oooo00<000000?ooo`3oool0V03o
ool00`0c0?l0oooo0?ooo`2L0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3o
ooli0?ooo`030000003oool0oooo01l0oooo00160?ooo`050=nLB000000000000000M02oool0303o
ool0103ooml0W4P00000001d_ol80?ooo`800000V@3oool00`0c0?l0oooo0?ooo`2K0?ooo`800000
E03oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool004L0oooo00@0
oono07@0000007@0_ooo3@3oool00`3ogi`0B00007Boo`080?ooo`030000003oool0oooo09P0oooo
00<0<`3o0?ooo`3oool0W03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo
>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo0?ooo`2H0?ooo`0303<0o`3o
ool0oooo09`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<0
00000?ooo`3oool07`3oool006<0oooo00<000000?ooo`3oool0V03oool00`0c0?l0oooo0?ooo`2L
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0
oooo01l0oooo001S0?ooo`030000003oool0oooo09T0oooo00<0<`3o0?ooo`3oool0V`3oool00`00
0000oooo0?ooo`1B0?ooo`800000o`3oooli0?ooo`8000008@3oool006<0oooo00<000000?ooo`3o
ool0V@3oool00`0c0?l0oooo0?ooo`2K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S0?ooo`030000003oool0oooo09T0oooo
00<0<`3o0?ooo`3oool0V`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo
>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool2000009X0oooo00<0<`3o0?ooo`3oool0VP3o
ool2000005@0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S
0?ooo`030000003oool0oooo09T0oooo00<0<`3o0?ooo`3oool0V`3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool00`00
0000oooo0?ooo`2J0?ooo`0303<0o`3oool0oooo09X0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool006<0oooo00<000000?ooo`3o
ool0VP3oool00`0c0?l0oooo0?ooo`2J0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S0?ooo`030000003oool0oooo09X0oooo
00<0<`3o0?ooo`3oool0VP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo
>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo0?ooo`2J0?ooo`0303<0o`3o
ool0oooo09X0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<0
00000?ooo`3oool07`3oool004H0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3o
ool0gia800000018W=l00`3oool01P3ooml0W4P0000000000000001d0;ooo`P0oooo0P00002L0?oo
o`0303<0o`3oool0oooo09P0oooo0P00001D0?ooo`800000o`3oooli0?ooo`8000008@3oool004P0
oooo00<0_g@00000M02oool0103oool00`3OW4P0000004RLg`020?ooo`080?oo_`1d000004RL0=oo
o`3oool0gia80000B02Lgol70?ooo`030000003oool0oooo09/0oooo00<0<`3o0?ooo`3oool0V@3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?oo
o`0O0?ooo`00B03oool00`2oM000001d0;ooo`090?ooo`030;md000007@0_ooo00<0oooo00<0_g@0
001d_`3oool01P3oool00`000000oooo0?ooo`2K0?ooo`0303<0o`3oool0oooo09T0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool0
04P0oooo00<0_g@00000M02oool0203oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0_ooo
00H0oooo00<000000?ooo`3oool0V`3oool00`0c0?l0oooo0?ooo`2I0?ooo`030000003oool0oooo
03H0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`020?ooo`060;md00000000
000000000000B9`0gooo2@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool004P0oooo00<0_g@00000M02oool0203oool00`3ogi`0B00004RLg`040?ooo`030;md0000
04P0W=oo00H0oooo00<000000?ooo`3oool0V`3oool00`0c0?l0oooo0?ooo`2I0?ooo`030000003o
ool0oooo03@0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00L0gia800000018
W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0203oool00`000000oooo0?ooo`3o
0?ooocT0oooo00<000000?ooo`3oool07`3oool004P0oooo00<0_g@00000M02oool0203oool00`3o
gi`0B00004RLg`030?ooo`040?oo_`1d0000001d0;ooo`H0oooo00<000000?ooo`3oool0W03oool0
0`0c0?l0oooo0?ooo`2H0?ooo`030000003oool0oooo03@0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`0<0?ooo`030?oOW018M;l0oooo00L0oooo00<000000?ooo`3oool0o`3oooli
0?ooo`030000003oool0oooo01l0oooo00180?ooo`030;md000007@0_ooo00P0oooo00T0oono07@0
0000000004RL0=ooo`3oool0_g@000000018W=l01`3oool3000009`0oooo00<0<`3o0?ooo`3oool0
UP3oool3000003D0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0<0?ooo`03
0?oo_`1d04P0W=oo00L0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0
oooo00180?ooo`030;md000007@0_ooo00P0oooo00D0oooO09a8000007@0_mnL04P0000200000003
04RLg`3oool0oooo00H0oooo00<000000?ooo`3oool0W03oool00`0c0?l0oooo0?ooo`2H0?ooo`03
0000003oool0oooo03<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`03
0?oo_`1d0000M;oo00L0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0
oooo00180?ooo`030;md000007@0_ooo00T0oooo00<0okmd00000018W=l0303oool00`000000oooo
0?ooo`2L0?ooo`0303<0o`3oool0oooo09P0oooo00<000000?ooo`3oool0<`3oool00`3ogi`0B000
04RLg`040?ooo`030;md000007@0_ooo00/0oooo00<0okmd0000001d_ol01`3oool00`000000oooo
0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool004P0oooo00<0_g@00000M02oool02@3o
ool0103ooml0W4P00000B02Lgol;0?ooo`030000003oool0oooo09`0oooo00<0<`3o0?ooo`3oool0
V03oool00`000000oooo0?ooo`0c0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
2P3oool0103ogi`0B0000000M02oool70?ooo`<00000o`3ooolg0?ooo`<000008@3oool004P0oooo
00<0_g@00000M02oool02P3oool0103ookl0M0000000M02oool:0?ooo`030000003oool0oooo09d0
oooo00<0<`3o0?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol01P3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo
00H0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo00160?ooo`05
0=nLB000000000000000M02oool02`3oool0103ooml0W4P000000000M;l90?ooo`030000003oool0
oooo09d0oooo00<0<`3o0?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030?oo_`1d0000
07Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@000000000000200000003001d_`3oool0
oooo00L0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo00170?oo
o`040?oo_`1d0000001d0;ooo`d0oooo00D0omnL04P00000000004RL0=ooo`060?ooo`800000WP3o
ool00`0c0?l0oooo0?ooo`2F0?ooo`800000=P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2L
B00007Bo00L0oooo00D0oooO09a800000000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0oooo
>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo0?ooo`2M0?ooo`0303<0o`3o
ool0oooo09L0oooo00<000000?ooo`3oool0=03oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo00P0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<0
00000?ooo`3oool07`3oool006<0oooo00<000000?ooo`3oool0WP3oool00`0c0?l0oooo0?ooo`2F
0?ooo`030000003oool0oooo03D0oooo00H0_g@00018W03Oool0oooo0;md0000M;l90?ooo`030?oo
g`2LB00000000080000000<0001d0;ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooocT0oooo
00<000000?ooo`3oool07`3oool006<0oooo00<000000?ooo`3oool0WP3oool00`0c0?l0oooo0?oo
o`2F0?ooo`030000003oool0oooo03H0oooo00@0_g@000000000000007Bo2`3oool00`3o_g@00000
000000020000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000
003oool0oooo01l0oooo001S0?ooo`030000003oool0oooo09h0oooo00<0<`3o0?ooo`3oool0UP3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?oo
o`0O0?ooo`00H`3oool00`000000oooo0?ooo`2N0?ooo`0303<0o`3oool0oooo09H0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool0
06<0oooo0P00002P0?ooo`0303<0o`3oool0oooo09@0oooo0P00001D0?ooo`800000o`3oooli0?oo
o`8000008@3oool006<0oooo00<000000?ooo`3oool0W`3oool00`0c0?l0oooo0?ooo`2E0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0
oooo001S0?ooo`030000003oool0oooo09l0oooo00<0<`3o0?ooo`3oool0U@3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3o
ool00`000000oooo0?ooo`2O0?ooo`0303<0o`3oool0oooo09D0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool006<0oooo00<00000
0?ooo`3oool0X03oool00`0c0?l0oooo0?ooo`2D0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S0?ooo`030000003oool0oooo
0:00oooo00<0<`3o0?ooo`3oool0U03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool200000:40oooo00<0<`3o0?ooo`3o
ool0T`3oool2000005@0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0
oooo00160?ooo`030?noM000000000000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO
00<0oooo00H0omnL04P00000000000000000B02Lgol80?ooo`030000003oool0oooo0:40oooo00<0
<`3o0?ooo`3oool0T`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3o
ool00`000000oooo0?ooo`0O0?ooo`00B03oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000
B9cO0080oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`L0oooo00<000000?ooo`3o
ool0X@3oool00`0c0?l0oooo0?ooo`2C0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo01l0oooo00180?ooo`030;md000007@0_ooo00T0oooo
00<0_g@00000M02oool00`3oool00`3OW4P004RL0=ooo`060?ooo`030000003oool0oooo0:40oooo
00<0<`3o0?ooo`3oool0T`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo
>@3oool00`000000oooo0?ooo`0O0?ooo`00B03oool00`2oM000001d0;ooo`090?ooo`030;md0000
07@0_ooo00<0oooo00<0_g@00018W03Oool01P3oool00`000000oooo0?ooo`2R0?ooo`0303<0o`3o
ool0oooo0980oooo00<000000?ooo`3oool0DP3oool200000?l0oooo>@3oool200000240oooo0018
0?ooo`030;md000007@0_ooo00T0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P00000001d_`07
0?ooo`030000003oool0oooo0:80oooo00<0<`3o0?ooo`3oool0TP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00B03oool00`2o
M000001d0;ooo`0:0?ooo`070=nLB000M;l0oooo0;md00000000001d0;ooo`070?ooo`030000003o
ool0oooo0:80oooo00<0<`3o0?ooo`3oool0TP3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00B03oool00`2oM000001d0;ooo`0;
0?ooo`050?noM000000000000018W03Oool0203oool300000:<0oooo00<0<`3o0?ooo`3oool0S`3o
ool3000005@0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo0018
0?ooo`030;md000007@0_ooo00X0oooo00D0omnL04P000000000000004RLg`090?ooo`030000003o
ool0oooo0:<0oooo00<0<`3o0?ooo`3oool0T@3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00B03oool00`2oM000001d0;ooo`09
0?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`080?ooo`030000003oool0oooo0:<0oooo
00<0<`3o0?ooo`3oool0T@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo
>@3oool00`000000oooo0?ooo`0O0?ooo`00B03oool00`2oM000001d0;ooo`090?ooo`030=nLB000
04P0W=oo0080oooo00<0oooO09a8001d_ol01`3oool00`000000oooo0?ooo`2T0?ooo`0303<0o`3o
ool0oooo0900oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<0
00000?ooo`3oool07`3oool004P0oooo00<0_g@00000M02oool02@3oool00`3OW4P004RL0=ooo`02
0?ooo`030?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool0Y03oool00`0c0?l0oooo0?ooo`2@
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0
oooo01l0oooo00160?ooo`050=nLB000000000000000M02oool02@3oool00`3ogi`0B00004RLg`02
0?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0Y@3oool00`0c0?l0oooo0?ooo`2?
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0
oooo01l0oooo00170?ooo`040?oo_`1d0000001d0;ooo`X0oooo00H0oono07@00000000000000000
B02Lgol80?ooo`800000YP3oool00`0c0?l0oooo0?ooo`2>0?ooo`800000E03oool200000?l0oooo
>@3oool200000240oooo001S0?ooo`030000003oool0oooo0:H0oooo00<0<`3o0?ooo`3oool0SP3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?oo
o`0O0?ooo`00H`3oool00`000000oooo0?ooo`2W0?ooo`0303<0o`3oool0oooo08d0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool0
06<0oooo00<000000?ooo`3oool0Y`3oool00`0c0?l0oooo0?ooo`2=0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S0?ooo`03
0000003oool0oooo0:P0oooo00<0<`3o0?ooo`3oool0S03oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00H`3oool00`000000oooo
0?ooo`2Y0?ooo`0303<0o`3oool0oooo08/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool006<0oooo0P00002Z0?ooo`0303<0o`3o
ool0oooo08X0oooo0P00001D0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?oo
o`0O0?ooo`00H`3oool00`000000oooo0?ooo`2Z0?ooo`0303<0o`3oool0oooo08X0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool0
06<0oooo00<000000?ooo`3oool0Z`3oool00`0c0?l0oooo0?ooo`290?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001S0?ooo`03
0000003oool0oooo0:`0oooo00<0<`3o0?ooo`3oool0R03oool00`000000oooo0?ooo`1B0?ooo`80
0000o`3oooli0?ooo`8000008@3oool006<0oooo00<000000?ooo`3oool0[@3oool00`0c0?l0oooo
0?ooo`270?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000
003oool0oooo01l0oooo001S0?ooo`030000003oool0oooo0:h0oooo00<0<`3o0?ooo`3oool0QP3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?oo
o`0O0?ooo`00H`3oool200000;00oooo00<0<`3o0?ooo`3oool0Q03oool2000005@0oooo00<00000
0?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001C0?ooo`030=nLB00000000000
00D0000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`2`0?ooo`80<`3oQ@3oool00`00
0000oooo0?ooo`140?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01P3oool00`00
0000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool07`3oool005@0oooo00<0gia800000000
0000100000000`00M;l0oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo0P0c0?n30?ooo`03
0000003oool0oooo04H0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?ooocT0
oooo00<000000?ooo`3oool07`3oool005D0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd
0;ooo`060?ooo`030000003oool0oooo0;@0oooo0P0c0?n10?ooo`030000003oool0oooo04H0oooo
00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool005H0oooo00<0gia804RLg`3oool02P3oool00`000000oooo0?ooo`2f0?ooo`@0<`3oO@3o
ool00`000000oooo0?ooo`160?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3o
ooli0?ooo`030000003oool0oooo01l0oooo001G0?ooo`030=nLB01d_ol0oooo00T0oooo00<00000
0?ooo`3oool0^P3oool703<0ogH0oooo00<000000?ooo`3oool0AP3oool00`2oM000001d0;ooo`09
0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0O0?ooo`00E`3oool00`3o
oml0W4Q809cOo`090?ooo`<00000`@3ooom`03<0o`@0oooo0`0000180?ooo`030;md000007@0_ooo
00T0oooo0`00003o0?ooocL0oooo0`00000Q0?ooo`00F03oool00`3ogi`0B01d0;ooo`080?ooo`03
0000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`160?ooo`030;md000007@0_ooo00T0
oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01l0oooo001I0?ooo`030;md
0018W=l0oooo00L0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo04H0oooo
00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0
7`3oool005T0oooo00<0gia80000M02oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0AP3oool00`2oM000001d0;ooo`090?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`00F@3oool0
0`3o_g@0000007Boo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`160?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo001C0?ooo`030?oOW02L_ol0oooo
00<0oooo00<0_g@00000001d_ol01`3ooooo000003`00000B03oool00`2oM000001d0;ooo`090?oo
ool00000?@00000Q0?ooo`00E03oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0goooY03o
ool01P2oM000000000000000000004RL0=ooo`@0oooo00<0oono07@0M02oool0e`3oool01@3OW4P0
00000000000007@0_ooo09l0oooo00H0_g@000000000000000000018W03Oool40?ooo`030?oo_`1d
07@0_ooo0;X0oooo001E0?ooo`050;md00000000000000000000M;l0Y`3oool00`3ookl0M01d0;oo
o`050?ooo`040?oog`2LB000001d0;ooomP0oooo00@0oono07@0000007@0_oooX03oool00`3ookl0
M01d0;ooo`050?ooo`040?oog`2LB000001d0;oookX0oooo003o0?ooo`80oooo00<0oooO09a8M02o
ool01@3oool0102oM00000000000M02ooooo0?ooogd0oooo00<0oooO09a8M02oool01@3oool0102o
M00000000000M02ooonj0?ooo`00o`3oool20?ooo`030?oog`2LB7@0_ooo00@0oooo00D0gia80000
000004P0B4Qd0;ooo`3o0?ooogd0oooo00<0oooO09a8M02oool0103oool01@3OW4P000000000B018
B7@0_ooo0;X0oooo003o0?ooo`80oooo00<0oooO09a8M02oool00`3oool01P3o_g@000000000M02o
oml0W4Qd0;ooool0ooooO@3oool00`3ooml0W4Qd0;ooo`030?ooo`060?noM0000000001d0;oog`2L
B7@0_ooo^P3oool00?l0oooo0P3oool00`3ooml0W4Qd0;ooo`020?ooo`070?oOW0180000001809cO
o`3ooml0W4Qd0;ooo`3o0?ooogd0oooo00<0oooO09a8M02oool00P3oool01`3ogi`0B0000000B02L
gol0oooO09a8M02oool0^P3oool00?l0oooo0P3oool0303ooml0W4Qd0;ooo`3oool0oono07@00000
0000M;oo0?ooo`3ooml0W4Qd0;ooool0ooooO@3oool0303ooml0W4Qd0;ooo`3oool0oono07@00000
0000M;oo0?ooo`3ooml0W4Qd0;oookX0oooo003o0?ooo`80oooo00L0oooO09a8M02oool0oooO09a8
00000000B9cO0080oooo00<0oooO09a8M02oool0o`3ooomm0?ooo`070?oog`2LB7@0_ooo0?oog`2L
B000000004RLg`020?ooo`030?oog`2LB7@0_ooo0;X0oooo003o0?ooo`80oooo00H0oooO09a8M02o
oml0W4P000000000M;l30?ooo`030?oog`2LB7@0_ooo0?l0ooooO@3oool01P3ooml0W4Qd0;oog`2L
B0000000001d_`<0oooo00<0oooO09a8M02oool0^P3oool00?l0oooo0P3oool01P3ooml0W4Qd07Ad
0000000004RL0=ooo`<0oooo00<0oooO09a8M02oool0o`3ooomm0?ooo`060?oog`2LB7@0M7@00000
0000B9`0gooo0`3oool00`3ooml0W4Qd0;ooo`2j0?ooo`00o`3oool20?ooo`050?oog`2LB0000000
0000M02oool0103oool00`3ooml0W4Qd0;ooo`3o0?ooogd0oooo00D0oooO09a800000000001d0;oo
o`040?ooo`030?oog`2LB7@0_ooo0;X0oooo003o0?ooo`80oooo00@0gia80000000007@0_ooo1@3o
ool00`3ookl0M01d0;ooo`3o0?ooogd0oooo00@0gia80000000007@0_ooo1@3oool00`3ookl0M01d
0;ooo`2j0?ooo`00o`3oool01@3OW4P000000000000004P0W=oo00@0oooo00<0oooO09a800000000
0P0000000`00B9`0gooo0?ooo`3o0?ooogP0oooo00D0gia8000000000000001809cOo`040?ooo`03
0?oog`2LB00000000080000000<004RL0=ooo`3oool0]`3oool00?l0ooooo`3ooooo0?oooe80oooo
003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oo
oe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3o
oooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0
ooooo`3ooooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3o
ool007D0oooo00H0oooO09a80000000000000000M02oool_0?ooo`030?noM0000000M;oo02X0oooo
00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0S0?ooo`040;md00000000000004RLgb/0
oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0/0?ooo`030?noM0000000M;oo02`0
oooo00H0oooO09a80000000000000000M02ooomO0?ooo`060?oog`2LB00000000000000007@0_ooo
;P3oool00`3o_g@0000007Boo`0Z0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool0
8P3oool0102oM000000000000018W=l[0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3o
ool0:`3oool00`3o_g@0000007Boo`0/0?ooo`060?oog`2LB00000000000000007@0_ooo:03oool0
07@0oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOobh0oooo00<0okmd0000001d_ol0
:`3oool00`3OW4P000000000000400000003001d_`3oool0oooo0240oooo00L0oooO09a80000M;l0
oooo0?oog`2LB00007Bo02/0oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`0/0?oo
o`030?noM0000000M;oo02/0oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOoed0oooo
00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOobd0oooo00<0okmd0000001d_ol0:`3oool0
0`3OW4P000000000000400000003001d_`3oool0oooo0200oooo00L0oooO09a80000M;l0oooo0?oo
g`2LB00007Bo02/0oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`0[0?ooo`030?no
M0000000M;oo02/0oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOobL0oooo001d0?oo
o`030;md000007@0_ooo00<0oooo00<0_g@0001d_`3oool0;@3oool00`3o_g@0000007Boo`0/0?oo
o`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool08P3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo02/0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0]0?oo
o`030?noM0000000M;oo02/0oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`1L0?oo
o`030;md000007@0_ooo00<0oooo00<0_g@0001d_`3oool0;03oool00`3o_g@0000007Boo`0/0?oo
o`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool08@3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo02/0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0/0?oo
o`030?noM0000000M;oo02/0oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`0V0?oo
o`00L`3oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0_ooo02P0oooo00<0gia800000000
00001@0000000`0004P0W=oo0?ooo`0Z0?ooo`030=nLB018W=l0oooo02D0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3ooml0W4P0001d_`0/0?ooo`030=nLB018W=l0oooo02`0oooo00<0gia80000
000000001@0000000`0004P0W=oo0?ooo`0W0?ooo`030?oo_`1d000007Bo00@0oooo00<0gia80000
M02oool0F`3oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0_ooo02L0oooo00<0gia80000
000000001@0000000`0004P0W=oo0?ooo`0Z0?ooo`030=nLB018W=l0oooo02@0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3ooml0W4P0001d_`0/0?ooo`030=nLB018W=l0oooo02/0oooo00<0gia8
0000000000001@0000000`0004P0W=oo0?ooo`0W0?ooo`030?oo_`1d000007Bo00@0oooo00<0gia8
0000M02oool09P3oool007<0oooo00<0omnL04P00018W=l0103oool00`2oM000001809cOo`0X0?oo
o`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0;P3oool00`3OW4P0M;oo0?ooo`0T0?oo
o`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0;03oool00`3OW4P0M;oo0?ooo`0[0?oo
o`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0:P3oool00`3ogi`0B00004RLg`040?oo
o`030;md000004P0W=oo05/0oooo00<0omnL04P00018W=l0103oool00`2oM000001809cOo`0W0?oo
o`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0;P3oool00`3OW4P0M;oo0?ooo`0S0?oo
o`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0;03oool00`3OW4P0M;oo0?ooo`0Z0?oo
o`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0:P3oool00`3ogi`0B00004RLg`040?oo
o`030;md000004P0W=oo02H0oooo001V0?ooo`030;md00000000000000L0000000H0B9cO0?ooo`3o
ool0omnL04P00018W=l30?ooo`040?oo_`1d0000001d0;oooa/0oooo00<0_g@00000000000001`00
00001P18W=l0oooo0?ooo`3oool0gia807Boo`80oooo00<0okmd0000001d_ol07@3oool00`2oM000
0000000000070000000304RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol0903oool00`3ogi`0
B00004RLg`040?ooo`030;md000007@0_ooo02`0oooo00<0oooO09a8B02Lgol0;03oool01`3OW4P0
M;oo0?ooo`3oool0okmd0000001d_ol0:P3oool00`3ogi`0B00004RLg`030?ooo`040?oo_`1d0000
001d0;ooodh0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`<0
oooo00@0oono07@0000007@0_ooo6P3oool00`2oM0000000000000070000000604RLg`3oool0oooo
0?ooo`3OW4P0M;oo0P3oool00`3o_g@0000007Boo`0M0?ooo`030;md00000000000000L0000000<0
B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`0S0?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000M02oool0;03oool00`3ooml0W4Q809cOo`0[0?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0
000007Boo`0Z0?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_ooo9P3oool007<0
oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0:P3oool01`3ookl0M01d0;oo
o`3oool0okmd0000001d_ol0;`3oool00`3ogi`0B01d0;ooo`0S0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol0;@3oool00`3ogi`0B01d0;ooo`0[0?ooo`070?oo_`1d07@0_ooo0?oo
o`3o_g@0000007Boo`0Z0?ooo`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO05`0
oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0:@3oool01`3ookl0M01d0;oo
o`3oool0okmd0000001d_ol0;`3oool00`3ogi`0B01d0;ooo`0R0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol0;@3oool00`3ogi`0B01d0;ooo`0Z0?ooo`070?oo_`1d07@0_ooo0?oo
o`3o_g@0000007Boo`0Z0?ooo`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO02L0
oooo001c0?ooo`050?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`0Z0?ooo`06
0?noM000M;l0oooo0?noM0000000M;oo<03oool00`2oM000B9cO0?ooo`0R0?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol0;P3oool00`2oM000B9cO0?ooo`0[0?ooo`060?noM000M;l0
oooo0?noM0000000M;oo:P3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3o
ool0F`3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool0:@3oool01P3o
_g@007Bo0?ooo`3o_g@0000007Booc00oooo00<0_g@004RLg`3oool08@3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo02h0oooo00<0_g@004RLg`3oool0:P3oool01P3o_g@007Bo0?oo
o`3o_g@0000007BoobX0oooo00D0oooO09a8000007@0_mnL04P000020000000304RLg`3oool0oooo
02H0oooo001d0?ooo`030?noM0000000B9cO0340oooo00D0_g@007Boo`3o_g@0000007Boo`0`0?oo
o`030=nLB00007@0_ooo0280oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0^0?oo
o`030=nLB00007@0_ooo02`0oooo00D0_g@007Boo`3o_g@0000007Boo`0[0?ooo`030?noM0000000
B9cO0680oooo00<0okmd00000018W=l0<03oool01@2oM000M;oo0?noM0000000M;oo0300oooo00<0
gia80000M02oool08@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02h0oooo00<0
gia80000M02oool0:`3oool01@2oM000M;oo0?noM0000000M;oo02/0oooo00<0okmd00000018W=l0
;03oool007@0oooo00@0oooO09a8000004P0W=oo<03oool01@3ookl0M01d0;noM0000000M;oo0300
oooo00<0okmd0000001d_ol08`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo02l0
oooo00<0okmd0000001d_ol0;03oool01@3ookl0M01d0;noM0000000M;oo02/0oooo00@0oooO09a8
000004P0W=ooH@3oool0103ooml0W4P00000B02Lgol_0?ooo`050?oo_`1d07@0_kmd0000001d_ol0
<03oool00`3o_g@0000007Boo`0R0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0
;`3oool00`3o_g@0000007Boo`0[0?ooo`050?oo_`1d07@0_kmd0000001d_ol0:`3oool0103ooml0
W4P00000B02Lgol[0?ooo`00M@3oool0103ookl0M0000000M02oool`0?ooo`040?noM00000000000
07BoobX0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`0S0?ooo`030?noM00004P0
W=oo0080oooo00<0omnL04P0001d_ol0:@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000
M;oo02d0oooo00@0okmd000000000000M;oo;03oool0103ookl0M0000000M02ooomQ0?ooo`040?oo
_`1d0000001d0;ooobl0oooo00@0okmd000000000000M;oo:P3oool00`3ogi`0W;oo0?ooo`030?oo
o`030;md00000000M;oo0280oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0Y0?oo
o`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0;03oool0103o_g@000000000001d_ol/
0?ooo`040?oo_`1d0000001d0;ooobX0oooo001f0?ooo`040?oog`2LB0000000001d_bl0oooo00@0
oooO09a800000000M;oo:`3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo903oool0
1P2oM00004RL0=ooo`3oool0_g@0001d_b/0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL
0=ooobd0oooo00@0oooO09a800000000M;oo;@3oool0103ooml0W4P000000000M;mQ0?ooo`040?oo
g`2LB0000000001d_bh0oooo00@0oooO09a800000000M;oo:`3oool0202oM000M;oo0?ooo`3oool0
gia800000000B9`0gooo8`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_b/0oooo00P0_g@007Bo
o`3oool0oooo0=nLB000000004RL0=ooob`0oooo00@0oooO09a800000000M;oo;@3oool0103ooml0
W4P000000000M;lY0?ooo`00N03oool01@3ogi`0B00000000000B9`0gooo02d0oooo00<0omnL04P0
001d_ol0;03oool01@2oM000000000000000000007Bo02L0oooo00@0_g@000000000000007Bo;@3o
ool01@2oM000000000000000000007Bo0300oooo00<0omnL04P0001d_ol0;`3oool01@3ogi`0B000
00000000B9`0gooo0600oooo00D0omnL04P00000000004RL0=ooo`0/0?ooo`030?oOW0180000M;oo
02`0oooo00D0_g@00000000000000000001d_`0V0?ooo`040;md000000000000001d_bd0oooo00D0
_g@00000000000000000001d_`0_0?ooo`030?oOW0180000M;oo02l0oooo00D0omnL04P000000000
04RL0=ooo`0V0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo003o
0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80
oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo
0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00JP3ooooo000003`00000C`3ooooo000003T0
00008`3oool006X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0240oooo001Z0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0Q0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool08@3oool0
06X0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo04d0oooo0P0000050?oo
od@0<`3oj`3oool2000002<0oooo001Z0?ooo`030000003oool0oooo09h0oooo1@0c0?nD0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0B03ooolN03<0olh0oooo00<000000?ooo`3o
ool08@3oool006X0oooo0P00002N0?ooo`80<`3o103oool00`0c0?l0oooo0?ooo`2@0?ooo`800000
C`3oool00`000000oooo0?ooo`1V0?ooo`@0<`3obP3oool00`000000oooo0?ooo`0Q0?ooo`00JP3o
ool00`000000oooo0?ooo`2L0?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool0T03o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo06X0oooo0P0c0?o80?ooo`030000003o
ool0oooo0240oooo001Z0?ooo`030000003oool0oooo09`0oooo00<0<`3o0?ooo`3oool01P3oool0
0`0c0?l0oooo0?ooo`2?0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0K03oool2
03<0olH0oooo00<000000?ooo`3oool08@3oool006X0oooo00<000000?ooo`3oool0W03oool00`0c
0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo08l0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`1^0?ooo`80<`3oa03oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool00`000000
oooo0?ooo`2K0?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool0SP3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo0700oooo00<0<`3o0?ooo`3oool0`@3oool00`000000
oooo0?ooo`0Q0?ooo`00JP3oool00`000000oooo0?ooo`2K0?ooo`0303<0o`3oool0oooo00T0oooo
00<0<`3o0?ooo`3oool0S@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0740oooo
0P0c0?o10?ooo`030000003oool0oooo0240oooo001Z0?ooo`800000V`3oool00`0c0?l0oooo0?oo
o`0:0?ooo`0303<0o`3oool0oooo08`0oooo0P00001?0?ooo`800000M03oool00`0c0?l0oooo0?oo
o`2m0?ooo`8000008`3oool004d0oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3o
ool0gia800000018W=l01P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo09X0oooo
00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`2<0?ooo`030000003oool0oooo0300oooo
00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo00T0
oooo00<000000?ooo`3oool0M03oool00`0c0?l0oooo0?ooo`2m0?ooo`030000003oool0oooo0240
oooo001?0?ooo`030;md000007@0_ooo00@0oooo00<0gia800000018W=l01P3oool00`3o_g@00000
07Boo`080?ooo`030000003oool0oooo09T0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo
0?ooo`2;0?ooo`030000003oool0oooo02h0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo
00<0oooo00<0gia800000018W=l01P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo
07@0oooo00<0<`3o0?ooo`3oool0_@3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`2oM000
001d0;ooo`0=0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0V@3oool00`0c0?l0
oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo08/0oooo00<000000?ooo`3oool0;P3oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo00/0oooo00<0okmd0000001d_ol02@3oool00`000000
oooo0?ooo`1e0?ooo`0303<0o`3oool0oooo0;`0oooo00<000000?ooo`3oool08@3oool004l0oooo
00<0_g@00000M02oool0203oool00`3OW4P0000000000005000000030000B02Lgol0oooo00D0oooo
00<000000?ooo`3oool0V03oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo08X0oooo
00<000000?ooo`3oool0;@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0
oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0oooo07H0
oooo00<0<`3o0?ooo`3oool0^`3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`2oM000001d
0;ooo`080?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0203oool00`000000oooo
0?ooo`2H0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool0R@3oool00`000000oooo
0?ooo`0]0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0B7Bo
0?ooo`020?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool0MP3oool00`0c0?l0oooo
0?ooo`2k0?ooo`030000003oool0oooo0240oooo000n0?ooo`030;md00000000000000L0000000<0
B9cO0?ooo`3oool0103oool00`2oM000001d0;ooo`090?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0
000007Boo`080?ooo`<00000V03oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo08L0
oooo0`00000S0?ooo`030;md00000000000000L0000000D0B9cO0?ooo`3ogi`0B00004RLg`040?oo
o`030;md000007@0_ooo00H0oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo00T0oooo00<0
00000?ooo`3oool0M`3oool00`0c0?l0oooo0?ooo`2j0?ooo`030000003oool0oooo0240oooo001?
0?ooo`030;md000007@0_ooo00T0oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo00P0oooo
00<000000?ooo`3oool0V03oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo08P0oooo
00<000000?ooo`3oool0;@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo
00L0oono07@0M02oool0oooo0?noM0000000M;oo00T0oooo0P00001h0?ooo`0303<0o`3oool0oooo
0;P0oooo0`00000S0?ooo`00C`3oool00`2oM000001d0;ooo`0:0?ooo`060?noM000M;l0oooo0?no
M0000000M;oo203oool00`000000oooo0?ooo`2H0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o
0?ooo`3oool0R03oool00`000000oooo0?ooo`0]0?ooo`030?oOW0180000B9cO00@0oooo00<0gia8
0000B02Lgol01`3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`T0oooo00<000000?ooo`3oool0
N03oool00`0c0?l0oooo0?ooo`2i0?ooo`030000003oool0oooo0240oooo001?0?ooo`030;md0000
07@0_ooo00/0oooo00D0_g@007Boo`3o_g@0000007Boo`080?ooo`030000003oool0oooo09L0oooo
00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`270?ooo`030000003oool0oooo02d0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`080?ooo`050;md001d_ol0okmd0000001d
_ol02@3oool00`000000oooo0?ooo`1h0?ooo`0303<0o`3oool0oooo0;T0oooo00<000000?ooo`3o
ool08@3oool004l0oooo00<0_g@00000M02oool02`3oool01@3ookl0M01d0;noM0000000M;oo00P0
oooo00<000000?ooo`3oool0U`3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo08H0
oooo00<000000?ooo`3oool0;P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0
oooo00D0oono07@0M02o_g@0000007Boo`090?ooo`030000003oool0oooo07T0oooo00<0<`3o0?oo
o`3oool0^03oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`2oM000001d0;ooo`0<0?ooo`04
0?noM0000000000007Boo`P0oooo00<000000?ooo`3oool0U`3oool00`0c0?l0oooo0?ooo`0D0?oo
o`0303<0o`3oool0oooo08H0oooo00<000000?ooo`3oool0;P3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00X0oooo00@0okmd000000000000M;oo2@3oool00`000000oooo0?ooo`1i
0?ooo`0303<0o`3oool0oooo0;P0oooo00<000000?ooo`3oool08@3oool004d0oooo00D0gia80000
00000000001d0;ooo`0<0?ooo`040?oog`2LB000000007Boo`P0oooo0P00002H0?ooo`0303<0o`3o
ool0oooo01D0oooo00<0<`3o0?ooo`3oool0Q03oool200000340oooo00H0_g@00018W03Oool0oooo
0;md0000M;l;0?ooo`040?oog`2LB000000007Boo`T0oooo00<000000?ooo`3oool0NP3oool00`0c
0?l0oooo0?ooo`2g0?ooo`030000003oool0oooo0240oooo001>0?ooo`040?oo_`1d0000001d0;oo
o`d0oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?ooo`2G0?ooo`0303<0o`3oool0oooo
01H0oooo00<0<`3o0?ooo`3oool0Q03oool00`000000oooo0?ooo`0`0?ooo`040;md000000000000
001d_`d0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`1j0?ooo`0303<0o`3oool0
oooo0;L0oooo00<000000?ooo`3oool08@3oool006X0oooo00<000000?ooo`3oool0U`3oool00`0c
0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo08@0oooo00<000000?ooo`3oool0C@3oool20000
07`0oooo00<0<`3o0?ooo`3oool0]@3oool2000002<0oooo001Z0?ooo`030000003oool0oooo09H0
oooo00<0<`3o0?ooo`3oool0603oool00`0c0?l0oooo0?ooo`230?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0N`3oool00`0c0?l0oooo0?ooo`2f0?ooo`030000003oool0oooo0240
oooo001Z0?ooo`030000003oool0oooo09H0oooo00<0<`3o0?ooo`3oool06@3oool00`0c0?l0oooo
0?ooo`220?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0N`3oool00`0c0?l0oooo
0?ooo`2f0?ooo`030000003oool0oooo0240oooo001Z0?ooo`030000003oool0oooo09H0oooo00<0
<`3o0?ooo`3oool06@3oool00`0c0?l0oooo0?ooo`220?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0O03oool00`0c0?l0oooo0?ooo`2e0?ooo`030000003oool0oooo0240oooo001Z
0?ooo`030000003oool0oooo09H0oooo00<0<`3o0?ooo`3oool06P3oool00`0c0?l0oooo0?ooo`21
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0O03oool00`0c0?l0oooo0?ooo`2e
0?ooo`030000003oool0oooo0240oooo001Z0?ooo`800000U`3oool00`0c0?l0oooo0?ooo`0K0?oo
o`0303<0o`3oool0oooo07l0oooo0P00001?0?ooo`030000003oool0oooo07`0oooo00<0<`3o0?oo
o`3oool0]@3oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool00`000000oooo0?ooo`2E0?ooo`03
03<0o`3oool0oooo01d0oooo00<0<`3o0?ooo`3oool0O`3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo07d0oooo00<0<`3o0?ooo`3oool0]03oool00`000000oooo0?ooo`0Q0?ooo`00
JP3oool00`000000oooo0?ooo`2E0?ooo`0303<0o`3oool0oooo01d0oooo00<0<`3o0?ooo`3oool0
O`3oool00`000000oooo0?ooo`1=0?ooo`800000OP3oool00`0c0?l0oooo0?ooo`2c0?ooo`800000
8`3oool006X0oooo00<000000?ooo`3oool0U@3oool00`0c0?l0oooo0?ooo`0N0?ooo`0303<0o`3o
ool0oooo07h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1m0?ooo`0303<0o`3o
ool0oooo0;@0oooo00<000000?ooo`3oool08@3oool006X0oooo00<000000?ooo`3oool0U@3oool0
0`0c0?l0oooo0?ooo`0O0?ooo`0303<0o`3oool0oooo07d0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`1m0?ooo`0303<0o`3oool0oooo0;@0oooo00<000000?ooo`3oool08@3oool0
06X0oooo00<000000?ooo`3oool0U@3oool00`0c0?l0oooo0?ooo`0P0?ooo`0303<0o`3oool0oooo
07`0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1n0?ooo`0303<0o`3oool0oooo
0;<0oooo00<000000?ooo`3oool08@3oool004d0oooo00<0okmd0000000000000P0000002@00M;l0
oooo0?ooo`3oool0gia800000018W=l0oooo0=nLB0070000000307Boo`3oool0oooo00D0oooo0P00
002E0?ooo`0303<0o`3oool0oooo0240oooo00<0<`3o0?ooo`3oool0N`3oool2000004l0oooo00<0
00000?ooo`3oool0OP3oool00`0c0?l0oooo0?ooo`2c0?ooo`030000003oool0oooo0240oooo001?
0?ooo`030;md000007@0_ooo00@0oooo00<0gia800000018W=l00P3oool00`3OW4P0000000000004
00000003001d_`3oool0oooo00D0oooo00<000000?ooo`3oool0U03oool00`0c0?l0oooo0?ooo`0R
0?ooo`0303<0o`3oool0oooo07/0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1n
0?ooo`0303<0o`3oool0oooo0;<0oooo00<000000?ooo`3oool08@3oool004l0oooo00<0_g@00000
M02oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00H0oooo00<000000?oo
o`3oool0U03oool00`0c0?l0oooo0?ooo`0S0?ooo`0303<0o`3oool0oooo07X0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`1n0?ooo`0303<0o`3oool0oooo0;<0oooo00<000000?oo
o`3oool08@3oool004l0oooo00<0_g@00000M02oool02`3oool00`3OW4P0B9cO0?ooo`0:0?ooo`03
0000003oool0oooo09@0oooo00<0<`3o0?ooo`3oool0903oool00`0c0?l0oooo0?ooo`1i0?ooo`03
0000003oool0oooo04d0oooo0P0000200?ooo`0303<0o`3oool0oooo0;40oooo0P00000S0?ooo`00
C`3oool00`2oM000001d0;ooo`0<0?ooo`030=nLB01d_ol0oooo00T0oooo00<000000?ooo`3oool0
U03oool00`0c0?l0oooo0?ooo`0U0?ooo`0303<0o`3oool0oooo07P0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`1o0?ooo`0303<0o`3oool0oooo0;80oooo00<000000?ooo`3oool0
8@3oool003h0oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030;md0000
07@0_ooo00`0oooo00<0oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`2C0?ooo`0303<0o`3o
ool0oooo02L0oooo00<0<`3o0?ooo`3oool0M`3oool00`000000oooo0?ooo`0`0?ooo`040;md0000
0000000004RLg`@0oooo00D0gia800000018W=l0oooo0=nLB0070000000307Boo`3oool0oooo00H0
oooo00<000000?ooo`3oool0O`3oool00`0c0?l0oooo0?ooo`2b0?ooo`030000003oool0oooo0240
oooo001?0?ooo`030;md000007@0_ooo00d0oooo00<0omnL04P0M02oool0203oool3000009<0oooo
00<0<`3o0?ooo`3oool0:03oool00`0c0?l0oooo0?ooo`1d0?ooo`<00000<03oool01`3ooml0W4P0
001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`030=nLB00000000000
00@0000000<007Bo0?ooo`3oool01P3oool00`000000oooo0?ooo`1o0?ooo`0303<0o`3oool0oooo
0;80oooo00<000000?ooo`3oool08@3oool004l0oooo00<0_g@00000M02oool03P3oool00`2oM000
B9cO0?ooo`070?ooo`030000003oool0oooo09<0oooo00<0<`3o0?ooo`3oool0:@3oool00`0c0?l0
oooo0?ooo`1e0?ooo`030000003oool0oooo02h0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0
B00007Boo`080?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01`3oool00`000000
oooo0?ooo`200?ooo`0303<0o`3oool0oooo0;40oooo00<000000?ooo`3oool08@3oool004l0oooo
00<0_g@00000M02oool03P3oool00`3OW4P0001d0;ooo`070?ooo`030000003oool0oooo09<0oooo
00<0<`3o0?ooo`3oool0:P3oool00`0c0?l0oooo0?ooo`1d0?ooo`030000003oool0oooo02d0oooo
00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`090?ooo`030=nLB018W=l0oooo00/0
oooo00<000000?ooo`3oool0P03oool00`0c0?l0oooo0?ooo`2a0?ooo`030000003oool0oooo0240
oooo001?0?ooo`030;md000007@0_ooo00h0oooo00<0okmd0000001d_ol01`3oool00`000000oooo
0?ooo`2C0?ooo`0303<0o`3oool0oooo02/0oooo00<0<`3o0?ooo`3oool0L`3oool00`000000oooo
0?ooo`0]0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`3OW4P0M;oo
0?ooo`0:0?ooo`030000003oool0oooo0800oooo00<0<`3o0?ooo`3oool0/@3oool00`000000oooo
0?ooo`0Q0?ooo`00C`3oool00`2oM000001d0;ooo`080?ooo`030?oOW02L_ol0oooo00<0oooo00<0
_g@00000001d_ol01`3oool00`000000oooo0?ooo`2C0?ooo`0303<0o`3oool0oooo02`0oooo00<0
<`3o0?ooo`3oool0LP3oool00`000000oooo0?ooo`0Q0?ooo`030;md00000000000000L0000000D0
B9cO0?ooo`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00T0oooo00<0oooO09a8B02Lgol0
2P3oool200000840oooo00<0<`3o0?ooo`3oool0[`3oool3000002<0oooo001=0?ooo`050=nLB000
000000000000M02oool02@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo1`3oool0
0`000000oooo0?ooo`2B0?ooo`0303<0o`3oool0oooo02h0oooo0P0c0?mb0?ooo`030000003oool0
oooo02d0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`030?oOW01807@0
_ooo00T0oooo00<000000?ooo`3oool0P@3oool00`0c0?l0oooo0?ooo`2`0?ooo`030000003oool0
oooo0240oooo001>0?ooo`040?oo_`1d0000001d0;ooo`X0oooo00D0_g@00000000000000000001d
_`090?ooo`800000T`3oool00`0c0?l0oooo0?ooo`0`0?ooo`0303<0o`3oool0oooo06h0oooo0P00
000_0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02`3oool00`2oM000B9cO0?oo
o`080?ooo`030000003oool0oooo0840oooo00<0<`3o0?ooo`3oool0/03oool00`000000oooo0?oo
o`0Q0?ooo`00JP3oool00`000000oooo0?ooo`2B0?ooo`0303<0o`3oool0oooo0340oooo00<0<`3o
0?ooo`3oool0KP3oool00`000000oooo0?ooo`0]0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool02`3oool00`3OW4P0001d0;ooo`080?ooo`030000003oool0oooo0840oooo00<0<`3o
0?ooo`3oool0/03oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool00`000000oooo0?ooo`2B0?oo
o`0303<0o`3oool0oooo0380oooo0P0c0?m^0?ooo`030000003oool0oooo02h0oooo00<0_g@00018
W03Oool00P3oool00`3ooml0W4P0001d_`0<0?ooo`030?noM0000000M;oo00P0oooo00<000000?oo
o`3oool0P@3oool00`0c0?l0oooo0?ooo`2`0?ooo`030000003oool0oooo0240oooo001Z0?ooo`03
0000003oool0oooo0980oooo00<0<`3o0?ooo`3oool0=03oool00`0c0?l0oooo0?ooo`1[0?ooo`03
0000003oool0oooo02h0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`060?ooo`03
0?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`000000oooo0?ooo`210?ooo`03
03<0o`3oool0oooo0;00oooo00<000000?ooo`3oool08@3oool006X0oooo00<000000?ooo`3oool0
TP3oool00`0c0?l0oooo0?ooo`0e0?ooo`80<`3oJ`3oool00`000000oooo0?ooo`0_0?ooo`060;md
0000B9`0gooo0?ooo`2oM00007Bo203oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo
203oool00`000000oooo0?ooo`220?ooo`0303<0o`3oool0oooo0:l0oooo00<000000?ooo`3oool0
8@3oool006X0oooo00<000000?ooo`3oool0TP3oool00`0c0?l0oooo0?ooo`0g0?ooo`0303<0o`3o
ool0oooo06P0oooo00<000000?ooo`3oool0<03oool0102oM000000000000000M;l:0?ooo`050;md
00000000000000000000M;l02P3oool2000008<0oooo00<0<`3o0?ooo`3oool0[P3oool2000002<0
oooo001Z0?ooo`800000T`3oool00`0c0?l0oooo0?ooo`0h0?ooo`80<`3oI`3oool2000004l0oooo
00<000000?ooo`3oool0PP3oool00`0c0?l0oooo0?ooo`2_0?ooo`030000003oool0oooo0240oooo
001Z0?ooo`030000003oool0oooo0940oooo00<0<`3o0?ooo`3oool0>`3oool203<0ofH0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`220?ooo`0303<0o`3oool0oooo0:l0oooo00<0
00000?ooo`3oool08@3oool006X0oooo00<000000?ooo`3oool0T@3oool00`0c0?l0oooo0?ooo`0m
0?ooo`<0<`3oH`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0880oooo00<0<`3o
0?ooo`3oool0[`3oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool00`000000oooo0?ooo`2A0?oo
o`0303<0o`3oool0oooo0400oooo0`0c0?mP0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0P`3oool00`0c0?l0oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo001Z0?ooo`03
0000003oool0oooo0940oooo00<0<`3o0?ooo`3oool0@`3oool303<0oed0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`230?ooo`0303<0o`3oool0oooo0:h0oooo00<000000?ooo`3o
ool08@3oool006X0oooo00<000000?ooo`3oool0T@3oool00`0c0?l0oooo0?ooo`160?ooo`<0<`3o
FP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08<0oooo00<0<`3o0?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool200000980oooo00<0<`3o0?ooo`3oool0B@3o
ool303<0oeH0oooo0P00001?0?ooo`800000Q03oool00`0c0?l0oooo0?ooo`2]0?ooo`8000008`3o
ool005`0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`060?ooo`030000003oool0
oooo0940oooo00<0<`3o0?ooo`3oool0C03oool303<0oe@0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`230?ooo`0303<0o`3oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool0
05h0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`2@0?ooo`0303<0o`3oool0oooo
0500oooo100c0?m@0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0P`3oool00`0c
0?l0oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo001N0?ooo`030;md000007@0_ooo00T0
oooo00<000000?ooo`3oool0T03oool00`0c0?l0oooo0?ooo`1D0?ooo`d0<`3o@`3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo08@0oooo00<0<`3o0?ooo`3oool0[@3oool00`000000
oooo0?ooo`0Q0?ooo`00GP3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo0900oooo
00<0<`3o0?ooo`3oool0H@3oool703<0oc`0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`240?ooo`0303<0o`3oool0oooo0:d0oooo00<000000?ooo`3oool08@3oool005h0oooo00<0
_g@00000M02oool02@3oool00`000000oooo0?ooo`2@0?ooo`0303<0o`3oool0oooo06P0oooo4`0c
0?lY0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0Q03oool00`0c0?l0oooo0?oo
o`2]0?ooo`030000003oool0oooo0240oooo001=0?ooo`030;md00000000000000L0000000<0B9cO
0?ooo`3oool0103oool00`2oM000001d0;ooo`090?ooo`<00000T03oool00`0c0?l0oooo0?ooo`1k
0?ooob<0<`3o103oool3000004l0oooo00<000000?ooo`3oool0Q03oool00`0c0?l0oooo0?ooo`2]
0?ooo`030000003oool0oooo0240oooo001N0?ooo`030;md000007@0_ooo00T0oooo00<000000?oo
o`3oool0T03oool00`0c0?l0oooo0?ooo`2T0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0Q03oool00`0c0?l0oooo0?ooo`2]0?ooo`030000003oool0oooo0240oooo001N0?ooo`03
0;md000007@0_ooo00T0oooo00<000000?ooo`3oool0T03oool00`0c0?l0oooo0?ooo`2T0?ooo`03
0000003oool0oooo04d0oooo0P0000250?ooo`0303<0o`3oool0oooo0:`0oooo0P00000S0?ooo`00
GP3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo0900oooo00<0<`3o0?ooo`3oool0
Y03oool00`000000oooo0?ooo`100?ooo`040;md00000000000004RLg`T0oooo00<000000?ooo`3o
ool0Q03oool00`0c0?l0oooo0?ooo`2]0?ooo`030000003oool0oooo0240oooo001N0?ooo`030;md
000007@0_ooo00T0oooo00<000000?ooo`3oool0S`3oool00`0c0?l0oooo0?ooo`2U0?ooo`030000
003oool0oooo03h0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00P0oooo00<000000?oo
o`3oool0Q03oool00`0c0?l0oooo0?ooo`2]0?ooo`030000003oool0oooo0240oooo001N0?ooo`03
0;md000007@0_ooo00T0oooo00<000000?ooo`3oool0S`3oool00`0c0?l0oooo0?ooo`2U0?ooo`03
0000003oool0oooo03h0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`03
0000003oool0oooo08D0oooo00<0<`3o0?ooo`3oool0[03oool00`000000oooo0?ooo`0Q0?ooo`00
G03oool01@3OW4P000000000000007@0_ooo00T0oooo0P00002@0?ooo`0303<0o`3oool0oooo0:@0
oooo0P00000o0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01`3oool00`00
0000oooo0?ooo`250?ooo`0303<0o`3oool0oooo0:`0oooo00<000000?ooo`3oool08@3oool005d0
oooo00@0oono07@0000007@0_ooo2@3oool00`000000oooo0?ooo`2?0?ooo`0303<0o`3oool0oooo
0:D0oooo00<000000?ooo`3oool0?@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
00H0oooo00<000000?ooo`3oool0Q@3oool00`0c0?l0oooo0?ooo`2/0?ooo`030000003oool0oooo
0240oooo001Z0?ooo`030000003oool0oooo08l0oooo00<0<`3o0?ooo`3oool0Y@3oool00`000000
oooo0?ooo`0<0?ooo`030?noM01d_ol0oooo00H0oooo00<0_gAd0;ooo`3oool09@3oool00`3ogi`0
B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo00<000000?ooo`3oool0Q@3oool00`0c0?l0
oooo0?ooo`2/0?ooo`030000003oool0oooo0240oooo000Y0?ooo`030?noM01d_ol0oooo00H0oooo
00<0_gAd0;ooo`3oool0=@3oool00`000000oooo0?ooo`2?0?ooo`0303<0o`3oool0oooo0:D0oooo
00<000000?ooo`3oool0303oool00`3o_g@0001d0;ooo`040?ooo`040?oog`2LB000001d0;ooobH0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`800000QP3oool00`0c0?l0
oooo0?ooo`2:0?oooa`0<`3o103oool3000002<0oooo000Y0?ooo`030?noM00007@0_ooo00@0oooo
00@0oooO09a8000007@0_ooo=P3oool00`000000oooo0?ooo`2?0?ooo`0303<0o`3oool0oooo0:D0
oooo00<000000?ooo`3oool0303oool0103o_g@0000000000018W=l20?ooo`050?oo_`1d04P0W=oo
0=nLW02oool09P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00<00000
0?ooo`3oool0Q@3oool00`0c0?l0oooo0?ooo`1h0?oooa80<`3o8P3oool00`000000oooo0?ooo`0Q
0?ooo`00:@3oool0103o_g@0000000000018W=l20?ooo`050?oo_`1d04P0W=oo0=nLW02oool0=P3o
ool00`000000oooo0?ooo`2>0?ooo`0303<0o`3oool0oooo0:H0oooo00<000000?ooo`3oool0303o
ool0203o_i`0W=oo0=nLB0000000001807AdB00007@0_ooo:@3oool00`3ookl0M000001d_`040?oo
o`030;md000007@0_ooo00H0oooo00<000000?ooo`3oool0Q@3oool00`0c0?l0oooo0?ooo`1[0?oo
o`d0<`3o=03oool00`000000oooo0?ooo`0Q0?ooo`00:@3oool0203o_i`0W=oo0=nLB00000000018
07AdB00007@0_ooo>@3oool00`000000oooo0?ooo`2>0?ooo`0303<0o`3oool0oooo0:H0oooo00<0
00000?ooo`3oool03`3oool0103ookl0M00000000000M;l[0?ooo`030;md0000B9`0gooo0080oooo
00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`260?ooo`0303<0o`3oool0oooo06@0oooo
1P0c0?m10?ooo`030000003oool0oooo0240oooo000/0?ooo`040?oo_`1d00000000001d_cX0oooo
0P00002?0?ooo`0303<0o`3oool0oooo0:D0oooo0P00000>0?ooo`0;0?noW02Lgol0okmd0000B02L
gol0gia80000000004P0W=oo0=nLW02oool09`3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo00L0oooo00<000000?ooo`3oool0QP3oool00`0c0?l0oooo0?ooo`1N0?ooo`H0<`3oA`3o
ool00`000000oooo0?ooo`0Q0?ooo`00:@3oool02`3o_i`0W=oo0?noM00004P0W=oo0=nLB0000000
001809cOo`3OW9`0_ooo03H0oooo00<000000?ooo`3oool0SP3oool00`0c0?l0oooo0?ooo`2V0?oo
o`030000003oool0oooo00`0oooo00<0okmd00000000M;l00`3oool01@3ookl0M0000000000007@0
_ooo02P0oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`030000003oool0oooo08H0oooo
00<0<`3o0?ooo`3oool0F03oool603<0odd0oooo00<000000?ooo`3oool08@3oool002T0oooo00<0
okmd00000000M;l00`3oool01@3ookl0M0000000000007@0_ooo03H0oooo00<000000?ooo`3oool0
SP3oool00`0c0?l0oooo0?ooo`2V0?ooo`030000003oool0oooo00`0oooo00<0okmd04RLg`3oool0
1@3oool00`3OW4P0001d0;ooo`0Y0?ooo`040;md000000000000001d_`T0oooo00<000000?ooo`3o
ool0QP3oool00`0c0?l0oooo0?ooo`1C0?ooo`D0<`3oD`3oool00`000000oooo0?ooo`0Q0?ooo`00
:@3oool00`3o_g@0B9cO0?ooo`050?ooo`030=nLB00007@0_ooo03H0oooo00<000000?ooo`3oool0
SP3oool00`0c0?l0oooo0?ooo`2V0?ooo`030000003oool0oooo00`0oooo00<0oknL09cOo`3oool0
1P3oool00`2oM7@0_ooo0?ooo`0e0?ooo`800000Q`3oool00`0c0?l0oooo0?ooo`1@0?ooo`<0<`3o
E`3oool2000002<0oooo000Y0?ooo`030?noW02Lgol0oooo00H0oooo00<0_gAd0;ooo`3oool0=@3o
ool00`000000oooo0?ooo`2>0?ooo`0303<0o`3oool0oooo0:H0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`260?ooo`0303<0o`3oool0oooo04h0oooo0P0c0?mK0?ooo`030000003o
ool0oooo0240oooo001Z0?ooo`030000003oool0oooo08h0oooo00<0<`3o0?ooo`3oool0YP3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08H0oooo00<0<`3o0?ooo`3oool0C03oool2
03<0oed0oooo00<000000?ooo`3oool08@3oool004h0oooo00@0_g@0000000000000B9cO103oool0
0`3OW4P0000004RLg`030?ooo`060?oOW018000000000000000004P0W=oo203oool2000008h0oooo
00<0<`3o0?ooo`3oool0YP3oool200000180oooo00<0gia80018W03Oool0103oool00`3OW7@0B4Qd
0;ooo`0c0?ooo`030000003oool0oooo08L0oooo00<0<`3o0?ooo`3oool0B@3oool203<0oel0oooo
00<000000?ooo`3oool08@3oool004`0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0
oooo00<0gia800000018W=l00P3oool0203ogi`0B0000018W03Oool0oooo0?oOW0180000M;oo1`3o
ool00`000000oooo0?ooo`2=0?ooo`0303<0o`3oool0oooo0:L0oooo00<000000?ooo`3oool03`3o
ool00`3o_g@007Bo0?ooo`040?ooo`040;md0018W9`0M01d0;oooc<0oooo00<000000?ooo`3oool0
Q`3oool00`0c0?l0oooo0?ooo`170?ooo`80<`3oH@3oool00`000000oooo0?ooo`0Q0?ooo`00;03o
ool00`3ooml0W7BL0=ooo`060?ooo`030=nLW02oool0oooo01@0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03Oool01P3o
ool00`000000oooo0?ooo`2=0?ooo`0303<0o`3oool0oooo0:L0oooo00<000000?ooo`3oool03`3o
ool00`3OW4P0B9cO0?ooo`020?ooo`060?oog`2LB000M;oo0?oo_`1d07@0_ooo<`3oool00`000000
oooo0?ooo`270?ooo`0303<0o`3oool0oooo04D0oooo0P0c0?mS0?ooo`030000003oool0oooo0240
oooo000/0?ooo`030?noM0000000000000H0000000<0001d0;ooo`3oool04`3oool0103ooml0W4P0
0018W03Oool20?ooo`030?oog`2LB00007Bo00L0oooo00<0_g@00000M02oool00`3oool00`2oM000
04RL0=ooo`060?ooo`030000003oool0oooo08d0oooo00<0<`3o0?ooo`3oool0Y`3oool00`000000
oooo0?ooo`0?0?ooo`0;0?noM00004P0W=oo0?ooo`3o_g@0001809cOo`3oool0omnL04P0M02oool0
<`3oool00`000000oooo0?ooo`270?ooo`0303<0o`3oool0oooo04<0oooo0P0c0?mU0?ooo`030000
003oool0oooo0240oooo000e0?ooo`030=nLW02oool0oooo01<0oooo00<0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`060?ooo`030?noM00004P0W=oo0080oooo00<0gia800000000M;l01`3o
ool00`000000oooo0?ooo`2=0?ooo`0303<0o`3oool0oooo0:L0oooo00<000000?ooo`3oool0403o
ool0103OW4P0000000000000M;l20?ooo`040?oog`2LB00004RL0=oooc<0oooo0P0000280?ooo`03
03<0o`3oool0oooo0440oooo0P0c0?mV0?ooo`8000008`3oool003h0oooo00<0_g@0000000000000
1`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool01`3oool01`3O
W4P007Bo0?ooo`2oM00000000000M02oool01`3oool00`000000oooo0?ooo`2=0?ooo`0303<0o`3o
ool0oooo0:L0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`270?ooo`0303<0o`3o
ool0oooo0400oooo00<0<`3o0?ooo`3oool0I`3oool00`000000oooo0?ooo`0Q0?ooo`00B`3oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo00D0okmd00000000000004RL0=oo
o`080?ooo`<00000S@3oool00`0c0?l0oooo0?ooo`2U0?ooo`<00000C`3oool00`000000oooo0?oo
o`270?ooo`0303<0o`3oool0oooo03l0oooo00<0<`3o0?ooo`3oool0J03oool00`000000oooo0?oo
o`0Q0?ooo`00B`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL
04P000000000000004RLg`090?ooo`030000003oool0oooo08`0oooo00<0<`3o0?ooo`3oool0Z03o
ool00`000000oooo0?ooo`0=0?ooo`030?noM0000000000000@0000000<0001d0;ooo`3oool0=P3o
ool00`000000oooo0?ooo`270?ooo`0303<0o`3oool0oooo03h0oooo00<0<`3o0?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0Q0?ooo`00:P3oool00`3o_g@0000000000004000000030000M02oool0
oooo01L0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`070?oOW0180000
001809cOo`3oool0gia8001d_`080?ooo`030000003oool0oooo08`0oooo00<0<`3o0?ooo`3oool0
Z03oool00`000000oooo0?ooo`0;0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool0
=03oool00`000000oooo0?ooo`280?ooo`0303<0o`3oool0oooo03/0oooo0P0c0?m/0?ooo`030000
003oool0oooo0240oooo000X0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool05P3o
ool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol00P3o
ool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo08`0oooo00<0<`3o0?ooo`3oool0Z03o
ool00`000000oooo0?ooo`0:0?ooo`040;md00000000000007Boo`L0oooo00@0_g@0000000000000
B9cO=03oool00`000000oooo0?ooo`280?ooo`0303<0o`3oool0oooo03X0oooo00<0<`3o0?ooo`3o
ool0K03oool00`000000oooo0?ooo`0Q0?ooo`009`3oool0102oM00000000000001d_ol70?ooo`04
0;md00000000000004RLgaH0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?oo
o`030=nLB000B9`0gooo0080oooo00<0oooO09a80018W=l01`3oool00`000000oooo0?ooo`2<0?oo
o`0303<0o`3oool0oooo0:P0oooo00<000000?ooo`3oool02@3oool00`2oM00007Bo0?ooo`0;0?oo
o`030?oog`2LB000B9cO03<0oooo00<000000?ooo`3oool0R03oool00`0c0?l0oooo0?ooo`0i0?oo
o`0303<0o`3oool0oooo06d0oooo00<000000?ooo`3oool08@3oool002H0oooo00<0_g@0001d_`3o
ool02`3oool00`3ooml0W4P004RLg`0F0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool0
0`3ogi`0B00004RLg`020?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0S03oool0
0`0c0?l0oooo0?ooo`2X0?ooo`030000003oool0oooo00P0oooo00<0okmd07Boo`3oool03P3oool0
0`3OW7@0W=oo0?ooo`0a0?ooo`800000R@3oool00`0c0?l0oooo0?ooo`0h0?ooo`0303<0o`3oool0
oooo06d0oooo0P00000S0?ooo`009@3oool00`3o_g@0M;oo0?ooo`0>0?ooo`030=nLM02Lgol0oooo
01D0oooo00@0_g@000000000000007Bo2P3oool01P3ookl0M000000000000000001809cOo`P0oooo
0P00002=0?ooo`0303<0o`3oool0oooo0:L0oooo0P00000:0?ooo`030?noW02Lgol0oooo0480oooo
00<000000?ooo`3oool0R03oool00`0c0?l0oooo0?ooo`0g0?ooo`0303<0o`3oool0oooo06l0oooo
00<000000?ooo`3oool08@3oool002D0oooo00<0oknL09cOo`3oool0@P3oool00`000000oooo0?oo
o`2;0?ooo`0303<0o`3oool0oooo0:T0oooo00<000000?ooo`3oool0203oool00`3o_g@0M;oo0?oo
o`0:0?ooo`030=nLW02oool0oooo01P0oooo00@0_g@0000000000000B9cO103oool01@3OW4P00000
04RLg`3oool0gia800L0000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?ooo`280?ooo`03
03<0o`3oool0oooo03H0oooo00<0<`3o0?ooo`3oool0L03oool00`000000oooo0?ooo`0Q0?ooo`00
9@3oool00`3o_g@0M;oo0?ooo`0:0?ooo`030=nLW02oool0oooo03D0oooo00<000000?ooo`3oool0
R`3oool00`0c0?l0oooo0?ooo`2Y0?ooo`030000003oool0oooo00P0oooo00<0okmd0018W03Oool0
2P3oool00`2oM7@0_ooo0?ooo`0F0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?oo
o`030=nLB0000000B9cO0080oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`060?oo
o`030000003oool0oooo08P0oooo00<0<`3o0?ooo`3oool0=@3oool00`0c0?l0oooo0?ooo`1a0?oo
o`030000003oool0oooo0240oooo000U0?ooo`030?noM000B9`0gooo00X0oooo00<0_gAd0;ooo`3o
ool0=@3oool00`000000oooo0?ooo`2;0?ooo`0303<0o`3oool0oooo0:T0oooo00<000000?ooo`3o
ool0203oool00`3o_g@000000000000:000000030000M02oool0oooo01H0oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`080?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02o
ool01`3oool00`000000oooo0?ooo`280?ooo`0303<0o`3oool0oooo03@0oooo00<0<`3o0?ooo`3o
ool0LP3oool00`000000oooo0?ooo`0Q0?ooo`009@3oool00`3o_g@000000000000:000000030000
M02oool0oooo03D0oooo00<000000?ooo`3oool0R`3oool00`0c0?l0oooo0?ooo`2Y0?ooo`030000
003oool0oooo00T0oooo00@0_g@00000000004P0W=oo203oool00`2oM7@0_ooo0?ooo`0E0?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02@3oool00`3OW4P0B9cO0?ooo`0;0?oo
o`030000003oool0oooo08T0oooo00<0<`3o0?ooo`3oool0<P3oool00`0c0?l0oooo0?ooo`1c0?oo
o`030000003oool0oooo0240oooo000V0?ooo`040;md00000000001809cOo`P0oooo00<0_gAd0;oo
o`3oool0=@3oool00`000000oooo0?ooo`2;0?ooo`0303<0o`3oool0oooo0:T0oooo00<000000?oo
o`3oool02P3oool0103OW4P000000000001d_ol70?ooo`030=nLW02oool0oooo01D0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`090?ooo`030=nLB01d_ol0oooo00X0oooo00<00000
0?ooo`3oool0R@3oool00`0c0?l0oooo0?ooo`0a0?ooo`0303<0o`3oool0oooo07@0oooo00<00000
0?ooo`3oool08@3oool002L0oooo00@0gia8000000000000M;oo1`3oool00`3OW9`0_ooo0?ooo`0e
0?ooo`800000S03oool00`0c0?l0oooo0?ooo`2X0?ooo`8000003@3oool0103o_g@0000000000000
M;lN0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02@3oool00`3ooml0W4Q809cO
o`0:0?ooo`800000RP3oool00`0c0?l0oooo0?ooo`0`0?ooo`0303<0o`3oool0oooo07<0oooo0`00
000S0?ooo`00:03oool0103o_g@0000000000000M;ln0?ooo`030000003oool0oooo08/0oooo00<0
<`3o0?ooo`3oool0Z@3oool00`000000oooo0?ooo`0<0?ooo`050?oOW018000000000018W03Oool0
703oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00X0oooo00<0omnL04P0M02oool0
2@3oool00`000000oooo0?ooo`290?ooo`0303<0o`3oool0oooo0300oooo00<0<`3o0?ooo`3oool0
M@3oool00`000000oooo0?ooo`0Q0?ooo`00:@3oool01@3ogi`0B00000000000B9`0gooo03`0oooo
00<000000?ooo`3oool0RP3oool00`0c0?l0oooo0?ooo`2Z0?ooo`030000003oool0oooo00d0oooo
00D0oono07@000000000001809cOo`0K0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol02`3oool00`2oM000B9cO0?ooo`080?ooo`030000003oool0oooo08T0oooo00<0<`3o0?ooo`3o
ool0;`3oool00`0c0?l0oooo0?ooo`1f0?ooo`030000003oool0oooo0240oooo000Z0?ooo`050?oo
_`1d000000000000B02Lgol0>`3oool00`000000oooo0?ooo`2:0?ooo`0303<0o`3oool0oooo0:X0
oooo00<000000?ooo`3oool03P3oool01@3ooml0W4P0000000000000M;oo01X0oooo00<0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`030=nLB00007@0_ooo00P0oooo00<000000?oo
o`3oool0R@3oool00`0c0?l0oooo0?ooo`0^0?ooo`0303<0o`3oool0oooo07L0oooo00<000000?oo
o`3oool08@3oool002/0oooo00D0oooO09a800000000000007Boo`0j0?ooo`030000003oool0oooo
08X0oooo00<0<`3o0?ooo`3oool0ZP3oool00`000000oooo0?ooo`080?ooo`030?noW02Lgol0oooo
00D0oooo00@0_g@000000000000007Bo6P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo00`0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`290?ooo`0303<0o`3oool0
oooo02d0oooo00<0<`3o0?ooo`3oool0N03oool00`000000oooo0?ooo`0Q0?ooo`009@3oool00`3o
_i`0W=oo0?ooo`050?ooo`040;md000000000000001d_cT0oooo00<000000?ooo`3oool0RP3oool0
0`0c0?l0oooo0?ooo`2Z0?ooo`030000003oool0oooo00P0oooo00<0okmd07Boo`3oool01P3oool0
1@3OW4P0000000000000B9`0gooo01P0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Bo
o`060?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`000000oooo0?oo
o`2:0?ooo`0303<0o`3oool0oooo02`0oooo00<0<`3o0?ooo`3oool0N03oool00`000000oooo0?oo
o`0Q0?ooo`009@3oool00`3o_g@0M;oo0?ooo`060?ooo`050=nLB000000000000018W03Oool0=`3o
ool2000008/0oooo00<0<`3o0?ooo`3oool0Z@3oool2000000X0oooo00<0okmd0000000000002P00
00000`0004P0W=oo0?ooo`0G0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool0202oM000
M;oo0?ooo`3oool0gia800000000B9`0gooo203oool00`000000oooo0?ooo`2:0?ooo`0303<0o`3o
ool0oooo02/0oooo00<0<`3o0?ooo`3oool0N@3oool00`000000oooo0?ooo`0Q0?ooo`009@3oool0
0`3o_g@000000000000:000000030000B02Lgol0oooo01T0oooo00@0_g@0000000000000B9cO103o
ool00`3OW4P0000004RLg`030?ooo`060?oog`2LB00000000000000007@0_ooo203oool00`000000
oooo0?ooo`2:0?ooo`0303<0o`3oool0oooo0:X0oooo00<000000?ooo`3oool0203oool00`3o_g@0
M;oo0?ooo`0U0?ooo`040;md000000000000001d_`X0oooo00D0_g@00000000000000000001d_`0:
0?ooo`800000R`3oool00`0c0?l0oooo0?ooo`0Z0?ooo`0303<0o`3oool0oooo07T0oooo0P00000S
0?ooo`009@3oool00`3o_g@0M;oo0?ooo`0T0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d
_`030?ooo`030=nLB0000000B9cO0080oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cO
o`L0oooo00<000000?ooo`3oool0RP3oool00`0c0?l0oooo0?ooo`2Z0?ooo`030000003oool0oooo
00P0oooo00<0oknL09cOo`3oool0@P3oool00`000000oooo0?ooo`2:0?ooo`0303<0o`3oool0oooo
02T0oooo00<0<`3o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0Q0?ooo`009@3oool00`3o_i`0
W=oo0?ooo`0T0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000
001d0;ooo`030?ooo`030;md0000M;l0oooo00H0oooo00<000000?ooo`3oool0R@3oool00`0c0?l0
oooo0?ooo`2[0?ooo`030000003oool0oooo00P0oooo00<0okmd07Boo`3oool03P3oool00`2oM4P0
W=oo0?ooo`0a0?ooo`030000003oool0oooo08X0oooo00<0<`3o0?ooo`3oool0:@3oool00`0c0?l0
oooo0?ooo`1k0?ooo`030000003oool0oooo0240oooo000U0?ooo`030?noM01d_ol0oooo00h0oooo
00<0_gA809cOo`3oool04P3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0
oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`060?ooo`030000003oool0oooo08T0
oooo00<0<`3o0?ooo`3oool0Z`3oool00`000000oooo0?ooo`090?ooo`030;md0000M;l0oooo00/0
oooo00<0oooO09a8001d_ol0<`3oool00`000000oooo0?ooo`2:0?ooo`0303<0o`3oool0oooo02P0
oooo00<0<`3o0?ooo`3oool0O03oool00`000000oooo0?ooo`0Q0?ooo`009P3oool00`2oM00007Bo
0?ooo`0;0?ooo`030?oog`2LB000M;oo01@0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`050?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol01P3oool00`000000oooo
0?ooo`290?ooo`0303<0o`3oool0oooo0:/0oooo00<000000?ooo`3oool02P3oool0102oM0000000
0000001d_ol70?ooo`040;md00000000000004RLgc@0oooo00<000000?ooo`3oool0RP3oool00`0c
0?l0oooo0?ooo`0X0?ooo`0303<0o`3oool0oooo07`0oooo00<000000?ooo`3oool08@3oool002L0
oooo00@0_g@0000000000000M;oo1`3oool0102oM000000000000018W=l80?ooo`030;md00000000
000000L0000000H0B9cO0?ooo`3oool0omnL04P00018W=l40?ooo`030;md000007@0_ooo00D0oooo
00<0omnL04P00018W=l00`3oool0103ookl0M0000000M02oool60?ooo`<00000R@3oool00`0c0?l0
oooo0?ooo`2Y0?ooo`<000003@3oool00`3OW4P0000000000008000000030000B02Lgol0oooo03@0
oooo00<000000?ooo`3oool0RP3oool00`0c0?l0oooo0?ooo`0W0?ooo`0303<0o`3oool0oooo07d0
oooo00<000000?ooo`3oool08@3oool002P0oooo00<0gia8000000000000200000000`0004P0W=oo
0?ooo`0E0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool02@3ookl0M000
00000000B9`0gooo0?ooo`2oM000000004RLg`070?ooo`030000003oool0oooo08T0oooo00<0<`3o
0?ooo`3oool0Z`3oool00`000000oooo0?ooo`0=0?ooo`030?noM0000000000000@0000000<0001d
0;ooo`3oool0=P3oool00`000000oooo0?ooo`2;0?ooo`0303<0o`3oool0oooo02H0oooo00<0<`3o
0?ooo`3oool0O@3oool00`000000oooo0?ooo`0Q0?ooo`00:P3oool00`3o_g@00000000000040000
00030000M02oool0oooo01L0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?oo
o`050?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`060?ooo`030000003oool0
oooo08T0oooo00<0<`3o0?ooo`3oool0Z`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo08/0oooo00<0<`3o0?ooo`3oool09@3oool00`0c0?l0oooo0?ooo`1n0?ooo`030000003oool0
oooo0240oooo001;0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o
_g@0000004RLg`0<0?ooo`030000003oool0oooo08P0oooo00<0<`3o0?ooo`3oool0[03oool00`00
0000oooo0?ooo`1=0?ooo`800000S03oool00`0c0?l0oooo0?ooo`0U0?ooo`0303<0o`3oool0oooo
07d0oooo0P00000S0?ooo`00C03oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0
oooo00@0oooO09a8000004P0W=oo2`3oool00`000000oooo0?ooo`280?ooo`0303<0o`3oool0oooo
0:`0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2;0?ooo`0303<0o`3oool0oooo
02@0oooo00<0<`3o0?ooo`3oool0O`3oool00`000000oooo0?ooo`0Q0?ooo`00C03oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00@0oono07@0000007@0_ooo2P3oool00`00
0000oooo0?ooo`280?ooo`0303<0o`3oool0oooo0:`0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`2;0?ooo`0303<0o`3oool0oooo02@0oooo00<0<`3o0?ooo`3oool0O`3oool00`00
0000oooo0?ooo`0Q0?ooo`00C@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`X0oooo00@0oooO
09a80000000007Bo2@3oool2000008T0oooo00<0<`3o0?ooo`3oool0Z`3oool2000004l0oooo00<0
00000?ooo`3oool0R`3oool00`0c0?l0oooo0?ooo`0S0?ooo`0303<0o`3oool0oooo0800oooo00<0
00000?ooo`3oool08@3oool004h0oooo00@0_g@000000000000007Bo3@3oool01@3ogi`0B0000000
0000B9`0gooo00H0oooo00<000000?ooo`3oool0R03oool00`0c0?l0oooo0?ooo`2/0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0R`3oool00`0c0?l0oooo0?ooo`0S0?ooo`0303<0
o`3oool0oooo0800oooo00<000000?ooo`3oool08@3oool006X0oooo00<000000?ooo`3oool0R03o
ool00`0c0?l0oooo0?ooo`2/0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0R`3o
ool00`0c0?l0oooo0?ooo`0S0?ooo`0303<0o`3oool0oooo0800oooo00<000000?ooo`3oool08@3o
ool006X0oooo00<000000?ooo`3oool0R03oool00`0c0?l0oooo0?ooo`2/0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0S03oool00`0c0?l0oooo0?ooo`0Q0?ooo`0303<0o`3oool0
oooo0840oooo00<000000?ooo`3oool08@3oool006X0oooo00<000000?ooo`3oool0Q`3oool00`0c
0?l0oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo0P00002=0?ooo`0303<0o`3oool0oooo
0240oooo00<0<`3o0?ooo`3oool0P03oool2000002<0oooo001Z0?ooo`030000003oool0oooo08L0
oooo00<0<`3o0?ooo`3oool0[@3oool00`000000oooo0?ooo`0`0?ooo`040;md00000000000004RL
g`@0oooo00<0gia800000018W=l01P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo
08`0oooo00<0<`3o0?ooo`3oool08@3oool00`0c0?l0oooo0?ooo`210?ooo`030000003oool0oooo
0240oooo001Z0?ooo`030000003oool0oooo08L0oooo00<0<`3o0?ooo`3oool0[@3oool00`000000
oooo0?ooo`0^0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000
B9cO00H0oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`2<0?ooo`0303<0o`3oool0
oooo0200oooo00<0<`3o0?ooo`3oool0PP3oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool20000
08P0oooo00<0<`3o0?ooo`3oool0[03oool200000300oooo00<0okmd0000B02Lgol00P3oool00`3o
gi`0B00007Boo`0;0?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool0S03oool00`0c
0?l0oooo0?ooo`0P0?ooo`0303<0o`3oool0oooo0880oooo00<000000?ooo`3oool08@3oool006X0
oooo00<000000?ooo`3oool0Q`3oool00`0c0?l0oooo0?ooo`2]0?ooo`030000003oool0oooo02d0
oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB00000000000
00D0000000<0001809cOo`3oool01P3oool00`000000oooo0?ooo`2<0?ooo`0303<0o`3oool0oooo
01l0oooo00<0<`3o0?ooo`3oool0P`3oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool00`000000
oooo0?ooo`270?ooo`0303<0o`3oool0oooo0:d0oooo00<000000?ooo`3oool0;@3oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0
000007Boo`090?ooo`030000003oool0oooo08`0oooo00<0<`3o0?ooo`3oool07`3oool00`0c0?l0
oooo0?ooo`230?ooo`030000003oool0oooo0240oooo001Z0?ooo`030000003oool0oooo08H0oooo
00<0<`3o0?ooo`3oool0[P3oool00`000000oooo0?ooo`0]0?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool01P3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d_ol02@3oool00`00
0000oooo0?ooo`2<0?ooo`0303<0o`3oool0oooo01l0oooo00<0<`3o0?ooo`3oool0P`3oool00`00
0000oooo0?ooo`0Q0?ooo`00JP3oool00`000000oooo0?ooo`260?ooo`0303<0o`3oool0oooo0:h0
oooo00<000000?ooo`3oool0;@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0
oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo00T0oooo0P00002>0?ooo`0303<0o`3oool0
oooo01d0oooo00<0<`3o0?ooo`3oool0PP3oool3000002<0oooo001Z0?ooo`030000003oool0oooo
08H0oooo00<0<`3o0?ooo`3oool0[P3oool00`000000oooo0?ooo`0]0?ooo`030?oOW0180000B9cO
00@0oooo00<0gia80000B02Lgol01`3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`T0oooo00<0
00000?ooo`3oool0S@3oool00`0c0?l0oooo0?ooo`0M0?ooo`0303<0o`3oool0oooo08@0oooo00<0
00000?ooo`3oool08@3oool004h0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RL
g`060?ooo`030?noM0000000M;oo00P0oooo0P0000270?ooo`0303<0o`3oool0oooo0:d0oooo0P00
000_0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0203oool01@2oM000M;oo0?no
M0000000M;oo00T0oooo00<000000?ooo`3oool0S@3oool00`0c0?l0oooo0?ooo`0M0?ooo`0303<0
o`3oool0oooo08@0oooo00<000000?ooo`3oool08@3oool004`0oooo00L0oooO09a80000M;l0oooo
0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l01P3oool00`3o_g@0000007Boo`080?ooo`03
0000003oool0oooo08H0oooo00<0<`3o0?ooo`3oool0[P3oool00`000000oooo0?ooo`0^0?ooo`03
0;md0000B9`0gooo0080oooo00<0oooO09a80000M;l02@3oool01@3ookl0M01d0;noM0000000M;oo
00T0oooo00<000000?ooo`3oool0S@3oool00`0c0?l0oooo0?ooo`0L0?ooo`0303<0o`3oool0oooo
08D0oooo00<000000?ooo`3oool08@3oool004`0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0
B00007Boo`0;0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0QP3oool00`0c0?l0
oooo0?ooo`2^0?ooo`030000003oool0oooo02h0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0
B00007Boo`0:0?ooo`040?noM0000000000007Boo`T0oooo00<000000?ooo`3oool0S@3oool00`0c
0?l0oooo0?ooo`0L0?ooo`0303<0o`3oool0oooo08D0oooo00<000000?ooo`3oool08@3oool004/0
oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB00000000000
00D0000000<0001809cOo`3oool01@3oool00`000000oooo0?ooo`250?ooo`0303<0o`3oool0oooo
0:l0oooo00<000000?ooo`3oool0;`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0
oooO09a800000000M;oo2@3oool00`000000oooo0?ooo`2=0?ooo`0303<0o`3oool0oooo01`0oooo
00<0<`3o0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0Q0?ooo`00B`3oool00`3ookl0M000001d
_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Bo
o`080?ooo`030000003oool0oooo08D0oooo00<0<`3o0?ooo`3oool0[`3oool00`000000oooo0?oo
o`0`0?ooo`040;md000000000000001d_`d0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo
0?ooo`2=0?ooo`0303<0o`3oool0oooo01/0oooo00<0<`3o0?ooo`3oool0QP3oool00`000000oooo
0?ooo`0Q0?ooo`00?P3oool00`2oM0000000000000070000000604RLg`3oool0oooo0?oOW0180000
B9cO103oool00`2oM000001d0;ooo`060?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`08
0?ooo`030000003oool0oooo08D0oooo00<0<`3o0?ooo`3oool0[`3oool00`000000oooo0?ooo`1=
0?ooo`800000SP3oool00`0c0?l0oooo0?ooo`0K0?ooo`0303<0o`3oool0oooo08D0oooo0P00000S
0?ooo`00B`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00L0oono07@0
M02oool0oooo0?noM0000000M;oo00P0oooo0`0000250?ooo`0303<0o`3oool0oooo0:d0oooo0`00
001?0?ooo`030000003oool0oooo08h0oooo00<0<`3o0?ooo`3oool06P3oool00`0c0?l0oooo0?oo
o`260?ooo`030000003oool0oooo0240oooo001;0?ooo`030?oOW0180000B9cO00@0oooo00<0gia8
0000B02Lgol01`3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`P0oooo00<000000?ooo`3oool0
Q@3oool00`0c0?l0oooo0?ooo`2_0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
SP3oool00`0c0?l0oooo0?ooo`0I0?ooo`0303<0o`3oool0oooo08L0oooo00<000000?ooo`3oool0
8@3oool004/0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`080?ooo`050;md001d
_ol0okmd0000001d_ol0203oool00`000000oooo0?ooo`250?ooo`0303<0o`3oool0oooo0:l0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2>0?ooo`0303<0o`3oool0oooo01T0oooo
00<0<`3o0?ooo`3oool0Q`3oool00`000000oooo0?ooo`0Q0?ooo`00C03oool00`2oM00004RL0=oo
o`020?ooo`030?oog`2LB00007Bo00T0oooo00D0oono07@0M02o_g@0000007Boo`080?ooo`030000
003oool0oooo08@0oooo00<0<`3o0?ooo`3oool0/03oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo08h0oooo00<0<`3o0?ooo`3oool06@3oool00`0c0?l0oooo0?ooo`270?ooo`030000
003oool0oooo0240oooo001<0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol02P3o
ool0103o_g@000000000001d_ol80?ooo`030000003oool0oooo08@0oooo00<0<`3o0?ooo`3oool0
/03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08h0oooo00<0<`3o0?ooo`3oool0
603oool00`0c0?l0oooo0?ooo`280?ooo`030000003oool0oooo0240oooo001=0?ooo`060;md0000
B9`0gooo0?ooo`2oM00007Bo2`3oool0103ooml0W4P00000001d_ol80?ooo`030000003oool0oooo
08@0oooo00<0<`3o0?ooo`3oool0/03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
08h0oooo00<0<`3o0?ooo`3oool0603oool00`0c0?l0oooo0?ooo`280?ooo`030000003oool0oooo
0240oooo001>0?ooo`040;md000000000000001d_`d0oooo00<0omnL04P0001d_ol0203oool20000
08D0oooo00<0<`3o0?ooo`3oool0[`3oool2000004l0oooo0P00002?0?ooo`0303<0o`3oool0oooo
01L0oooo00<0<`3o0?ooo`3oool0R03oool2000002<0oooo001Z0?ooo`030000003oool0oooo08<0
oooo00<0<`3o0?ooo`3oool0/@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08h0
oooo00<0<`3o0?ooo`3oool05`3oool00`0c0?l0oooo0?ooo`290?ooo`030000003oool0oooo0240
oooo001Z0?ooo`030000003oool0oooo08<0oooo00<0<`3o0?ooo`3oool0/@3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo08l0oooo00<0<`3o0?ooo`3oool05P3oool00`0c0?l0oooo
0?ooo`290?ooo`030000003oool0oooo0240oooo001Z0?ooo`030000003oool0oooo08<0oooo00<0
<`3o0?ooo`3oool0/@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08l0oooo00<0
<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`2:0?ooo`030000003oool0oooo0240oooo001Z
0?ooo`030000003oool0oooo08<0oooo00<0<`3o0?ooo`3oool0/@3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo08l0oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`2:
0?ooo`030000003oool0oooo0240oooo001Z0?ooo`030000003oool0oooo0880oooo00<0<`3o0?oo
o`3oool0/P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08l0oooo00<0<`3o0?oo
o`3oool05@3oool00`0c0?l0oooo0?ooo`2:0?ooo`030000003oool0oooo0240oooo001Z0?ooo`80
0000P`3oool00`0c0?l0oooo0?ooo`2a0?ooo`800000C`3oool00`000000oooo0?ooo`2?0?ooo`03
03<0o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool0R`3oool00`000000oooo0?ooo`0Q0?ooo`00
JP3oool00`000000oooo0?ooo`220?ooo`0303<0o`3oool0oooo0;80oooo00<000000?ooo`3oool0
C@3oool200000900oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`2:0?ooo`800000
8`3oool006X0oooo00<000000?ooo`3oool0PP3oool00`0c0?l0oooo0?ooo`2b0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0S`3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3o
ool0oooo08/0oooo00<000000?ooo`3oool08@3oool006X0oooo00<000000?ooo`3oool0P@3oool0
0`0c0?l0oooo0?ooo`2c0?ooo`030000003oool0oooo0300oooo00@0_g@0000000000000B9cO103o
ool00`3OW4P0000004RLg`030?ooo`060?oog`2LB00000000000000007@0_ooo2@3oool00`000000
oooo0?ooo`2?0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool0S03oool00`000000
oooo0?ooo`0Q0?ooo`00JP3oool00`000000oooo0?ooo`210?ooo`0303<0o`3oool0oooo0;<0oooo
00<000000?ooo`3oool0;P3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3O
W4P0000004RLg`020?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgol80?ooo`030000
003oool0oooo08l0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`2<0?ooo`030000
003oool0oooo0240oooo001Z0?ooo`030000003oool0oooo0840oooo00<0<`3o0?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0^0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3o
ool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool0T03o
ool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo08`0oooo00<000000?ooo`3oool08@3o
ool006X0oooo0P0000220?ooo`0303<0o`3oool0oooo0;80oooo0P00000_0?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3ookl0M000001d_`040?ooo`030=nLB000
07@0_ooo00L0oooo00<000000?ooo`3oool0T03oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3o
ool0oooo08d0oooo00<000000?ooo`3oool08@3oool004h0oooo00@0_g@0000000000000B9cO103o
ool01@3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?ooo`3oool01@3oool00`000000oooo
0?ooo`200?ooo`0303<0o`3oool0oooo0;@0oooo00<000000?ooo`3oool0;@3oool00`3ookl0M000
001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018W=l0103oool00`2oM0000018
09cOo`070?ooo`030000003oool0oooo0900oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo
0?ooo`2=0?ooo`030000003oool0oooo0240oooo001<0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0
W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00<0gia8000000000000100000000`00M;l0
oooo0?ooo`050?ooo`030000003oool0oooo0800oooo00<0<`3o0?ooo`3oool0]03oool00`000000
oooo0?ooo`0]0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0
B00004RLg`030?ooo`040?oo_`1d0000001d0;ooo`L0oooo0P00002A0?ooo`0303<0o`3oool0oooo
0140oooo00<0<`3o0?ooo`3oool0R`3oool3000002<0oooo001<0?ooo`030?noM00004P0W=oo0080
oooo00<0omnL04P0001d_ol0203oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00H0
oooo00<000000?ooo`3oool0P03oool00`0c0?l0oooo0?ooo`2d0?ooo`030000003oool0oooo02d0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`090?oo_`1d000000000018
W03Oool0oooo0;md00000000B9cO00P0oooo00<000000?ooo`3oool0T03oool00`0c0?l0oooo0?oo
o`0@0?ooo`0303<0o`3oool0oooo08h0oooo00<000000?ooo`3oool08@3oool004/0oooo00@0oooO
09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`090?ooo`030=nLB018W=l0oooo00X0oooo00<0
00000?ooo`3oool0O`3oool00`0c0?l0oooo0?ooo`2e0?ooo`030000003oool0oooo02d0oooo00<0
omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`050?oog`2LB000001d0;oOW0180000
0P0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo0900oooo00<0<`3o0?ooo`3oool0
403oool00`0c0?l0oooo0?ooo`2>0?ooo`030000003oool0oooo0240oooo001;0?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`3OW4P0M;oo0?ooo`090?ooo`030000003o
ool0oooo07l0oooo00<0<`3o0?ooo`3oool0]@3oool00`000000oooo0?ooo`0]0?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@0000004RLg`0=0?ooo`030000003o
ool0oooo0900oooo00<0<`3o0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`2>0?ooo`030000003o
ool0oooo0240oooo000n0?ooo`030;md00000000000000L0000000H0B9cO0?ooo`3oool0omnL04P0
0018W=l40?ooo`030;md000007@0_ooo00T0oooo00<0oooO09a8B02Lgol02@3oool3000007l0oooo
00<0<`3o0?ooo`3oool0/`3oool300000300oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0
001d_`070?ooo`040?oog`2LB000001809cOo``0oooo00<000000?ooo`3oool0T03oool00`0c0?l0
oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo08h0oooo00<000000?ooo`3oool08@3oool004/0oooo
00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`030?oOW01807@0_ooo00P0oooo
00<000000?ooo`3oool0O`3oool00`0c0?l0oooo0?ooo`2e0?ooo`030000003oool0oooo02h0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`040?oo_`1d0000001d0;ooo`/0
oooo00<000000?ooo`3oool0T@3oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo08l0
oooo00<000000?ooo`3oool08@3oool004/0oooo00<0omnL04P00018W=l0103oool00`3OW4P00018
09cOo`0;0?ooo`030;md0018W=l0oooo00L0oooo00<000000?ooo`3oool0OP3oool00`0c0?l0oooo
0?ooo`2f0?ooo`030000003oool0oooo02l0oooo00H0_g@00018W03Oool0oooo0;md0000M;l:0?oo
o`040?oog`2LB0000000001d_`X0oooo00<000000?ooo`3oool0T@3oool00`0c0?l0oooo0?ooo`0>
0?ooo`0303<0o`3oool0oooo08l0oooo00<000000?ooo`3oool08@3oool004/0oooo00<0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`030=nLB00007@0_ooo00L0oooo00<000000?oo
o`3oool0OP3oool00`0c0?l0oooo0?ooo`2f0?ooo`030000003oool0oooo0300oooo00@0_g@00000
0000000007Bo3@3oool01@3ogi`0B00000000000B9`0gooo00L0oooo0P00002B0?ooo`0303<0o`3o
ool0oooo00h0oooo00<0<`3o0?ooo`3oool0SP3oool2000002<0oooo001<0?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l0303oool00`3o_g@0000007Boo`070?ooo`030000003oool0
oooo07d0oooo00<0<`3o0?ooo`3oool0]`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo0940oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`2@0?ooo`030000003oool0
oooo0240oooo001<0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01P3oool00`3o
gi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00L0oooo00<000000?ooo`3oool0O@3oool00`0c
0?l0oooo0?ooo`2g0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0T@3oool00`0c
0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo0900oooo00<000000?ooo`3oool08@3oool004d0
oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`080;md001d_ol0oooo0?ooo`3OW4P00000
0018W03Oool70?ooo`800000O@3oool00`0c0?l0oooo0?ooo`2g0?ooo`800000C`3oool00`000000
oooo0?ooo`2B0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool0T03oool00`000000
oooo0?ooo`0Q0?ooo`00CP3oool0102oM000000000000000M;l:0?ooo`050;md0000000000000000
0000M;l02@3oool00`000000oooo0?ooo`1l0?ooo`0303<0o`3oool0oooo0;P0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`2B0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?oo
o`3oool0T@3oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool00`000000oooo0?ooo`1k0?ooo`03
03<0o`3oool0oooo0;T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2B0?ooo`03
03<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool0T@3oool00`000000oooo0?ooo`0Q0?ooo`00
JP3oool00`000000oooo0?ooo`1k0?ooo`0303<0o`3oool0oooo0;T0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`2B0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool0
T@3oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool00`000000oooo0?ooo`1j0?ooo`0303<0o`3o
ool0oooo0;X0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2C0?ooo`0303<0o`3o
ool0oooo00X0oooo00<0<`3o0?ooo`3oool0T@3oool00`000000oooo0?ooo`0Q0?ooo`00JP3oool0
0`000000oooo0?ooo`1j0?ooo`0303<0o`3oool0oooo0;X0oooo00<000000?ooo`3oool0C@3oool2
000009@0oooo00<0<`3o0?ooo`3oool02@3oool00`0c0?l0oooo0?ooo`2A0?ooo`8000008`3oool0
06X0oooo00<000000?ooo`3oool0N@3oool00`0c0?l0oooo0?ooo`2k0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0T`3oool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo
0980oooo00<000000?ooo`3oool08@3oool006X0oooo0P00001j0?ooo`0303<0o`3oool0oooo0;X0
oooo0P00001?0?ooo`030000003oool0oooo09<0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0
oooo0?ooo`2C0?ooo`030000003oool0oooo0240oooo001Z0?ooo`030000003oool0oooo07P0oooo
00<0<`3o0?ooo`3oool0_03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo09@0oooo
00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`2C0?ooo`030000003oool0oooo0240oooo
001Z0?ooo`030000003oool0oooo07L0oooo00<0<`3o0?ooo`3oool0_@3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo09@0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?oo
o`2D0?ooo`030000003oool0oooo0240oooo001Z0?ooo`030000003oool0oooo07H0oooo00<0<`3o
0?ooo`3oool0_P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo09@0oooo00<0<`3o
0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`2D0?ooo`030000003oool0oooo0240oooo001Z0?oo
o`030000003oool0oooo07D0oooo00<0<`3o0?ooo`3oool0_`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo09D0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`2D0?oo
o`030000003oool0oooo0240oooo001Z0?ooo`030000003oool0oooo07D0oooo00<0<`3o0?ooo`3o
ool0_`3oool00`000000oooo0?ooo`1=0?ooo`800000UP3oool00`0c0?l0oooo0?ooo`040?ooo`03
03<0o`3oool0oooo09@0oooo0P00000S0?ooo`00G@3oool0102oM000000000000018W=l90?ooo`80
0000M03oool203<0ol40oooo0P00000b0?ooo`040;md00000000000004RLg`@0oooo00<0gia80000
0018W=l00`3oool01P3ogi`0B000000000000000001809cOo`T0oooo00<000000?ooo`3oool0U@3o
ool00`0c0?l0oooo0?ooo`040?ooo`0303<0o`3oool0oooo09D0oooo00<000000?ooo`3oool08@3o
ool005/0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00P0oooo00<000000?ooo`3oool0
LP3oool00`0c0?l0oooo0?ooo`320?ooo`030000003oool0oooo02h0oooo00L0oooO09a80000M;l0
oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool0203ogi`0B0000018W03Oool0
oooo0?oOW0180000M;oo203oool00`000000oooo0?ooo`2E0?ooo`0303<0o`3oool0oooo00@0oooo
00<0<`3o0?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00F`3oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00L0oooo00<000000?ooo`3oool0L03oool203<0olD0oooo00<0
00000?ooo`3oool0;P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0
_g@00000M02oool00`3oool00`3OW4P004RL0=ooo`070?ooo`030000003oool0oooo09H0oooo00<0
<`3o0?ooo`3oool00P3oool00`0c0?l0oooo0?ooo`2F0?ooo`030000003oool0oooo0240oooo001J
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?oo
o`1]0?ooo`<0<`3oa`3oool00`000000oooo0?ooo`0]0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0oooO09a80000M;l01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo00L0oooo
00<000000?ooo`3oool0U`3oool0100c0?l0oooo0?ooo`0c0?nI0?ooo`030000003oool0oooo0240
oooo001J0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`000000oooo
0?ooo`1Z0?ooo`<0<`3obP3oool00`000000oooo0?ooo`0]0?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool01P3oool00`3o_g@0001809cOo`020?ooo`030=nLB000000007Bo00P0oooo
00<000000?ooo`3oool0V03oool203<0oiX0oooo00<000000?ooo`3oool08@3oool005X0oooo00<0
omnL04P00018W=l0103oool00`2oM000001d0;ooo`060?ooo`030000003oool0oooo05h0oooo300c
0?o=0?ooo`030000003oool0oooo02d0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`070?ooo`070=nLB000M;l0oooo0;md00000000001d0;ooo`080?ooo`030000003oool0oooo0?l0
oooo=@3oool00`000000oooo0?ooo`0Q0?ooo`00FP3oool00`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo00H0oooo0`0000040?oooeX0<`3oe`3oool3000002l0oooo00<0omnL04P00018W=l0
103oool00`3OW4P0001809cOo`080?ooo`050?noM000000000000018W03Oool02@3oool200000?l0
oooo=03oool3000002<0oooo001J0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
1P3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0;@3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL04P000000000000004RLg`0:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`00
FP3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02d0oooo00<0oono07@00000M;l0
103oool00`2oM000001d0;ooo`060?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`090?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?oo
o`00F`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02h0oooo00<0_g@00018W03O
ool00P3oool00`3ooml0W4P0001d_`070?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8001d
_ol0203ooooo000003T000008`3oool005/0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`070?ooool00000?000000`0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
1`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO0?l0ooooI03oool005`0oooo00H0
_g@00018W03Oool0oooo0;md0000M;oo0?ooogD0oooo00H0_g@00018W03Oool0oooo0;md0000M;l8
0?ooo`030?oOW0180000B9cO0080oooo00<0okmd0000B02Lgol0o`3ooomT0?ooo`00G@3oool0102o
M000000000000000M;oo0?ooogL0oooo00@0_g@000000000000007Bo2P3oool01P3ookl0M0000000
00000000001809cOool0ooooI@3oool00?l0ooooo`3ooooo0?oooe80oooo003o0?ooool0ooooo`3o
oomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo003o0?ooool0
ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80oooo003o
0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo0?oooe80
oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0ooooo`3ooooo
0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool00?l0oooo
o`3ooooo0?oooe80oooo003o0?ooool0ooooo`3ooomB0?ooo`00o`3ooooo0?ooool0ooooDP3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 846.125}, {522.563, 0}} -> {-0.0507502, -0.0309082, \
0.00248368, 0.00248368}, {{20.375, 433.375}, {510.063, 254.875}} -> \
{-10.2751, -0.0684449, 0.0400421, 0.00809868}, {{412.688, 825.688}, {510.063, \
254.875}} -> {-26.2631, -1.75793, 0.0400421, 0.0107982}, {{20.375, 433.375}, \
{267.625, 12.4375}} -> {-10.5541, -4.06591, 0.0400421, 0.00816707}, \
{{412.688, 825.688}, {267.625, 12.4375}} -> {-26.5123, -2.69275, 0.0404238, \
0.00701576}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 3\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig3x1x2 = 
        ParametricPlot[{xx1[N], xx2[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] {{\(-5\), 1}, {\(-1\), 6}}, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0.7], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<x1\>", "\<x2\>"}];\)\), \
"\[IndentingNewLine]", 
    \(\(fig3x3x4 = 
        ParametricPlot[{x3[N], xx4[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 2}}, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0.7], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<x3\>", "\<x4\>"}];\)\), \
"\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{fig3x1x2, fig3x3x4}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] \(-0.05\)];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig3_x1x2\>" <> "\<.m\>", 
        fig3x1x2];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig3_x3x4\>" <> "\<.m\>", fig3x3x4];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .31694 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0075462 0.47619 [
[ 0 0 0 0 ]
[ 1 .31694 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .31694 L
0 .31694 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0075462 0.51221 0.309394 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.833333 0.166667 0.0882906 0.0882906 [
[.16667 -0.0125 -14 -24.5625 ]
[.16667 -0.0125 14 0 ]
[.33333 -0.0125 -14 -24.5625 ]
[.33333 -0.0125 14 0 ]
[.5 -0.0125 -14 -24.5625 ]
[.5 -0.0125 14 0 ]
[.66667 -0.0125 -14 -24.5625 ]
[.66667 -0.0125 14 0 ]
[.83333 -0.0125 -7.03125 -24.5625 ]
[.83333 -0.0125 7.03125 0 ]
[1 -0.0125 -7.03125 -24.5625 ]
[1 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12.0625 -49.125 ]
[.5 -0.0125 12.0625 -24.5625 ]
[-0.0125 .08829 -14.0625 -12.2813 ]
[-0.0125 .08829 0 12.2813 ]
[-0.0125 .17658 -14.0625 -12.2813 ]
[-0.0125 .17658 0 12.2813 ]
[-0.0125 .26487 -14.0625 -12.2813 ]
[-0.0125 .26487 0 12.2813 ]
[-0.0125 .35316 -14.0625 -12.2813 ]
[-0.0125 .35316 0 12.2813 ]
[-0.0125 .44145 -14.0625 -12.2813 ]
[-0.0125 .44145 0 12.2813 ]
[-0.0125 .52974 -14.0625 -12.2813 ]
[-0.0125 .52974 0 12.2813 ]
[-0.0125 .61803 -14.0625 -12.2813 ]
[-0.0125 .61803 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -38.625 -12.0625 ]
[-0.01875 .30902 -14.0625 12.0625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -73.0625 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
83.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
gsave
-0.0125 .08829 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .17658 m
.00625 .17658 L
s
gsave
-0.0125 .17658 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .26487 m
.00625 .26487 L
s
gsave
-0.0125 .26487 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .35316 m
.00625 .35316 L
s
gsave
-0.0125 .35316 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .44145 m
.00625 .44145 L
s
gsave
-0.0125 .44145 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .52974 m
.00625 .52974 L
s
gsave
-0.0125 .52974 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.4063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.0625 16.2813 translate
90 rotate
-73.0625 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
83.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.03333 .61428 m
.03333 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.13333 .61428 m
.13333 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.23333 .61428 m
.23333 .61803 L
s
.26667 .61428 m
.26667 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.43333 .61428 m
.43333 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.53333 .61428 m
.53333 .61803 L
s
.56667 .61428 m
.56667 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.76667 .61428 m
.76667 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.93333 .61428 m
.93333 .61803 L
s
.96667 .61428 m
.96667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .08829 m
1 .08829 L
s
.99375 .17658 m
1 .17658 L
s
.99375 .26487 m
1 .26487 L
s
.99375 .35316 m
1 .35316 L
s
.99375 .44145 m
1 .44145 L
s
.99375 .52974 m
1 .52974 L
s
.125 Mabswid
.99625 .01766 m
1 .01766 L
s
.99625 .03532 m
1 .03532 L
s
.99625 .05297 m
1 .05297 L
s
.99625 .07063 m
1 .07063 L
s
.99625 .10595 m
1 .10595 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14126 m
1 .14126 L
s
.99625 .15892 m
1 .15892 L
s
.99625 .19424 m
1 .19424 L
s
.99625 .2119 m
1 .2119 L
s
.99625 .22956 m
1 .22956 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .28253 m
1 .28253 L
s
.99625 .30019 m
1 .30019 L
s
.99625 .31785 m
1 .31785 L
s
.99625 .3355 m
1 .3355 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .38848 m
1 .38848 L
s
.99625 .40614 m
1 .40614 L
s
.99625 .42379 m
1 .42379 L
s
.99625 .45911 m
1 .45911 L
s
.99625 .47677 m
1 .47677 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .51209 m
1 .51209 L
s
.99625 .5474 m
1 .5474 L
s
.99625 .56506 m
1 .56506 L
s
.99625 .58272 m
1 .58272 L
s
.99625 .60038 m
1 .60038 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 0 1 r
.5 Mabswid
.83333 .04415 m
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83333 .04415 L
.83332 .04415 L
.83327 .04417 L
.83301 .04431 L
.83169 .04503 L
.82427 .04921 L
.79081 .0683 L
.74925 .09135 L
.68388 .12488 L
.65169 .13944 L
.62205 .15083 L
.61194 .15397 L
.60273 .15627 L
.60035 .15674 L
.59823 .15711 L
.59629 .15739 L
.59462 .15758 L
.59314 .1577 L
.59167 .15777 L
.5903 .15779 L
.58957 .15777 L
.58891 .15774 L
.58779 .15764 L
.5867 .15748 L
.58577 .15727 L
.58501 .15705 L
.58421 .15674 L
.58346 .15634 L
.58286 .15593 L
.58239 .1555 L
.582 .15502 L
.58171 .15455 L
.58147 .15399 L
.58137 .15366 L
.5813 .15336 L
.58123 .15272 L
.58122 .15234 L
Mistroke
.58124 .15199 L
.58132 .15132 L
.5814 .15094 L
.58148 .15059 L
.58193 .14922 L
.58253 .14792 L
.5844 .14486 L
.58918 .13915 L
.60196 .12779 L
.61599 .11765 L
.63684 .10466 L
.64899 .09779 L
.65647 .09372 L
.66061 .0915 L
.66298 .09025 L
.66448 .08945 L
.66534 .08899 L
.66585 .08873 L
.66617 .08855 L
.66636 .08845 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.48779 0.0075462 0.97619 0.309394 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.25 0.206011 0.206011 [
[.125 -0.0125 -21.5313 -24.5625 ]
[.125 -0.0125 21.5313 0 ]
[.25 -0.0125 -7.03125 -24.5625 ]
[.25 -0.0125 7.03125 0 ]
[.375 -0.0125 -14.5625 -24.5625 ]
[.375 -0.0125 14.5625 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.625 -0.0125 -14.5625 -24.5625 ]
[.625 -0.0125 14.5625 0 ]
[.75 -0.0125 -7.03125 -24.5625 ]
[.75 -0.0125 7.03125 0 ]
[.875 -0.0125 -14.5625 -24.5625 ]
[.875 -0.0125 14.5625 0 ]
[1 -0.0125 -7.03125 -24.5625 ]
[1 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12.0625 -49.125 ]
[.5 -0.0125 12.0625 -24.5625 ]
[-0.0125 .10301 -43.0625 -12.2813 ]
[-0.0125 .10301 0 12.2813 ]
[-0.0125 .20601 -14.0625 -12.2813 ]
[-0.0125 .20601 0 12.2813 ]
[-0.0125 .30902 -29.125 -12.2813 ]
[-0.0125 .30902 0 12.2813 ]
[-0.0125 .41202 -14.0625 -12.2813 ]
[-0.0125 .41202 0 12.2813 ]
[-0.0125 .51503 -29.125 -12.2813 ]
[-0.0125 .51503 0 12.2813 ]
[-0.0125 .61803 -14.0625 -12.2813 ]
[-0.0125 .61803 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -12.0625 ]
[-0.01875 .30902 -43.0625 12.0625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -82.5313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -73.0625 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
83.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .20601 m
.00625 .20601 L
s
gsave
-0.0125 .20601 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .41202 m
.00625 .41202 L
s
gsave
-0.0125 .41202 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .51503 m
.00625 .51503 L
s
gsave
-0.0125 .51503 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -128.406 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.0625 16.2813 translate
90 rotate
-73.0625 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x4) show
83.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 0 1 r
.5 Mabswid
.375 .20601 m
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
Mistroke
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
Mistroke
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
Mistroke
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.375 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37501 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37502 .20601 L
.37503 .20601 L
.37503 .20601 L
.37503 .20601 L
.37503 .20601 L
.37503 .20601 L
.37503 .20601 L
.37503 .20601 L
Mistroke
.37503 .20601 L
.37504 .20601 L
.37504 .20601 L
.37504 .20601 L
.37504 .20601 L
.37504 .20601 L
.37504 .20601 L
.37505 .20601 L
.37505 .20601 L
.37505 .20601 L
.37505 .20601 L
.37505 .20601 L
.37506 .20601 L
.37506 .20601 L
.37506 .20601 L
.37506 .20601 L
.37507 .20601 L
.37507 .20601 L
.37507 .20601 L
.37508 .20601 L
.37508 .20601 L
.37508 .20601 L
.37508 .20601 L
.37509 .20601 L
.37509 .20601 L
.3751 .20601 L
.3751 .20601 L
.37511 .20601 L
.37511 .20601 L
.37511 .20601 L
.37512 .20601 L
.37513 .20601 L
.37513 .20601 L
.37514 .20601 L
.37514 .20601 L
.37515 .20601 L
.37516 .20601 L
.37516 .20601 L
.37517 .20601 L
.37518 .20601 L
.37518 .20601 L
.37519 .20601 L
.3752 .20601 L
.37521 .20601 L
.37522 .20601 L
.37523 .20601 L
.37524 .20601 L
.37525 .20601 L
.37526 .20601 L
.37527 .20601 L
Mistroke
.37528 .20601 L
.37529 .20601 L
.3753 .20601 L
.37532 .20601 L
.37533 .20601 L
.37533 .20601 L
.37535 .20601 L
.37537 .20601 L
.37538 .20601 L
.37539 .20601 L
.3754 .20601 L
.37542 .20601 L
.37544 .20601 L
.37546 .20601 L
.37548 .20601 L
.3755 .20601 L
.37552 .20601 L
.37555 .20601 L
.37556 .20601 L
.37558 .20601 L
.37561 .20601 L
.37562 .20601 L
.37564 .20601 L
.37567 .20601 L
.3757 .20601 L
.37574 .20601 L
.37577 .20601 L
.3758 .20601 L
.37584 .20601 L
.37587 .20601 L
.3759 .20601 L
.37594 .20601 L
.37599 .20601 L
.37603 .20601 L
.37608 .20601 L
.37613 .20601 L
.37618 .20601 L
.37623 .20601 L
.37628 .20601 L
.37634 .20601 L
.37641 .20601 L
.37647 .20601 L
.37654 .20601 L
.37661 .20601 L
.37669 .20601 L
.37673 .20601 L
.37678 .20601 L
.37682 .20601 L
.37687 .20601 L
.37696 .20601 L
Mistroke
.37705 .20601 L
.37715 .20601 L
.37726 .20601 L
.37735 .20601 L
.37746 .20601 L
.37757 .20601 L
.37767 .20601 L
.37779 .20601 L
.37793 .20601 L
.37807 .20601 L
.3782 .20601 L
.37835 .20601 L
.37852 .20601 L
.37868 .20601 L
.37884 .20601 L
.37903 .20601 L
.37915 .20601 L
.37925 .20601 L
.37946 .20601 L
.37956 .20601 L
.37969 .20601 L
.37981 .20601 L
.37994 .20601 L
.38018 .20601 L
.38032 .20601 L
.38045 .20601 L
.3806 .20601 L
.38076 .20601 L
.38091 .20601 L
.38107 .20601 L
.38123 .20601 L
.38138 .20601 L
.38167 .20601 L
.38199 .20601 L
.38231 .20601 L
.38268 .20601 L
.38304 .20601 L
.38339 .20601 L
.38375 .20601 L
.38409 .20601 L
.3845 .20601 L
.38491 .20601 L
.38537 .20601 L
.38587 .20601 L
.38633 .20601 L
.38684 .20601 L
.38743 .20601 L
.38777 .20601 L
.38808 .20601 L
.38872 .20601 L
Mistroke
.38935 .20601 L
.38991 .20601 L
.39055 .20601 L
.39125 .20601 L
.39193 .20601 L
.39259 .20601 L
.39321 .20601 L
.39392 .20601 L
.3947 .20601 L
.39552 .20601 L
.39643 .20601 L
.39733 .20601 L
.39817 .20601 L
.3992 .20601 L
.3998 .20601 L
.40037 .20601 L
.40144 .20601 L
.40262 .20601 L
.40381 .20601 L
.40517 .20601 L
.4065 .20601 L
.40779 .20601 L
.40911 .20601 L
.41035 .20601 L
.41182 .20601 L
.41326 .20601 L
.4149 .20601 L
.41669 .20601 L
.41828 .20601 L
.42008 .20601 L
.42209 .20601 L
.42325 .20601 L
.42433 .20601 L
.42648 .20601 L
.42859 .20601 L
.43045 .20601 L
.43255 .20601 L
.43482 .20601 L
.43702 .20601 L
.43912 .20601 L
.44109 .20601 L
.44343 .20601 L
.44571 .20601 L
.44823 .20601 L
.45098 .20601 L
.45365 .20601 L
.45613 .20601 L
.45913 .20601 L
.46085 .20601 L
.46246 .20601 L
Mistroke
.46547 .20601 L
.46873 .20601 L
.47201 .20601 L
.47389 .20601 L
.47565 .20601 L
.47894 .20601 L
.48251 .20601 L
.48575 .20601 L
.48884 .20601 L
.49229 .20601 L
.49607 .20601 L
.49992 .20601 L
.50213 .20601 L
.5042 .20601 L
.50844 .20601 L
.51084 .20601 L
.51304 .20601 L
.51701 .20601 L
.52137 .20601 L
.52554 .20601 L
.52941 .20601 L
.53305 .20601 L
.53698 .20601 L
.54071 .20601 L
.54414 .20601 L
.54817 .20601 L
.55257 .20601 L
.55674 .20601 L
.56061 .20601 L
.56499 .20601 L
.5691 .20601 L
.57279 .20601 L
.57677 .20601 L
.5811 .20601 L
.58566 .20601 L
.58952 .20601 L
.59373 .20601 L
.59822 .20601 L
.60234 .20601 L
.60447 .20601 L
.6068 .20601 L
.60923 .20601 L
.61149 .20601 L
.61559 .20601 L
.6193 .20601 L
.62331 .20601 L
.62747 .20601 L
.63092 .20601 L
.63455 .20601 L
.63792 .20601 L
Mistroke
.64093 .20601 L
.64441 .20601 L
.6481 .20601 L
.65151 .20601 L
.65458 .20601 L
.6578 .20601 L
.66116 .20601 L
.66426 .20601 L
.66702 .20601 L
.67017 .20601 L
.67192 .20601 L
.67351 .20601 L
.67636 .20601 L
.67777 .20601 L
.6793 .20601 L
.68075 .20601 L
.68226 .20601 L
.6849 .20601 L
.68634 .20601 L
.68765 .20601 L
.68906 .20601 L
.69055 .20601 L
.69181 .20601 L
.69315 .20601 L
.6944 .20601 L
.69553 .20601 L
.69761 .20601 L
.69975 .20601 L
.7017 .20601 L
.70376 .20601 L
.70563 .20601 L
.70731 .20601 L
.70891 .20601 L
.71033 .20601 L
.7119 .20601 L
.71333 .20601 L
.71484 .20601 L
.71638 .20601 L
.71765 .20601 L
.71898 .20601 L
.72037 .20601 L
.72112 .20601 L
.72179 .20601 L
.72305 .20601 L
.72419 .20601 L
.72513 .20601 L
.72613 .20601 L
.72713 .20601 L
.72804 .20601 L
.72885 .20601 L
Mistroke
.72957 .20601 L
.73033 .20601 L
.73111 .20601 L
.73187 .20601 L
.73264 .20601 L
.73335 .20601 L
.73397 .20601 L
.73467 .20601 L
.73505 .20601 L
.73539 .20601 L
.736 .20601 L
.73662 .20601 L
.7372 .20601 L
.7378 .20601 L
.73835 .20601 L
.73883 .20601 L
.73929 .20601 L
.73969 .20601 L
.74013 .20601 L
.74054 .20601 L
.74096 .20601 L
.74138 .20601 L
.74173 .20601 L
.7421 .20601 L
.74247 .20601 L
.74267 .20601 L
.74285 .20601 L
.74319 .20601 L
.7435 .20601 L
.74375 .20601 L
.74401 .20601 L
.74428 .20601 L
.74451 .20601 L
.74473 .20601 L
.74491 .20601 L
.74512 .20601 L
.74531 .20601 L
.74551 .20601 L
.74571 .20601 L
.74589 .20601 L
.74605 .20601 L
.74622 .20601 L
.74632 .20601 L
.74641 .20601 L
.74656 .20601 L
.74672 .20601 L
.74686 .20601 L
.74694 .20601 L
.74702 .20601 L
.74714 .20601 L
Mistroke
.74727 .20601 L
.74738 .20601 L
.74748 .20601 L
.74759 .20601 L
.7477 .20601 L
.7478 .20601 L
.74786 .20601 L
.74791 .20601 L
.74801 .20601 L
.74807 .20601 L
.74811 .20601 L
.7482 .20601 L
.74828 .20601 L
.74836 .20601 L
.74843 .20601 L
.74849 .20601 L
.74855 .20601 L
.74861 .20601 L
.74866 .20601 L
.74872 .20601 L
.74878 .20601 L
.74883 .20601 L
.74888 .20601 L
.74893 .20601 L
.74897 .20601 L
.74901 .20601 L
.74905 .20601 L
.7491 .20601 L
.74914 .20601 L
.74918 .20601 L
.74921 .20601 L
.74925 .20601 L
.74928 .20601 L
.7493 .20601 L
.74932 .20601 L
.74934 .20601 L
.74935 .20601 L
.74938 .20601 L
.74941 .20601 L
.74944 .20601 L
.74946 .20601 L
.74949 .20601 L
.74951 .20601 L
.74953 .20601 L
.74955 .20601 L
.74957 .20601 L
.74959 .20601 L
.74961 .20601 L
.74962 .20601 L
.74964 .20601 L
Mistroke
.74966 .20601 L
.74967 .20601 L
.74969 .20601 L
.7497 .20601 L
.74971 .20601 L
.74972 .20601 L
.74973 .20601 L
.74974 .20601 L
.74974 .20601 L
.74975 .20601 L
.74976 .20601 L
.74977 .20601 L
.74977 .20601 L
.74978 .20601 L
.74979 .20601 L
.74979 .20601 L
.7498 .20601 L
.7498 .20601 L
.74981 .20601 L
.74981 .20601 L
.74982 .20601 L
.74983 .20601 L
.74984 .20601 L
.74984 .20601 L
.74985 .20601 L
.74986 .20601 L
.74986 .20601 L
.74987 .20601 L
.74988 .20601 L
.74988 .20601 L
.74989 .20601 L
.74989 .20601 L
.7499 .20601 L
.7499 .20601 L
.74991 .20601 L
.74991 .20601 L
.74991 .20601 L
.74991 .20601 L
.74992 .20601 L
.74992 .20601 L
.74992 .20601 L
.74993 .20601 L
.74993 .20601 L
.74993 .20601 L
.74994 .20601 L
.74994 .20601 L
.74994 .20601 L
.74994 .20601 L
.74995 .20601 L
.74995 .20601 L
Mistroke
.74995 .20601 L
.74995 .20601 L
.74995 .20601 L
.74996 .20601 L
.74996 .20601 L
.74996 .20601 L
.74996 .20601 L
.74996 .20601 L
.74996 .20601 L
.74997 .20601 L
.74997 .20601 L
.74997 .20601 L
.74997 .20601 L
.74997 .20601 L
.74997 .20601 L
.74997 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
Mistroke
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
Mistroke
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
Mistroke
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
Mistroke
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
Mistroke
.75 .20601 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{905.5, 287},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>900017b000`400?l00000o`00003oo`3ooooo
0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0ooooo`3ooon<0?ooo`00
o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0ooooo`3ooon<
0?ooo`00o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0oooo
o`3ooon<0?ooo`00o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?oo
ool0ooooo`3ooon<0?ooo`00o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo
003k0?ooo`060;md00000000001d0;ooo`3ookl0M0000P0000001000B9`0gooo0?ooo`3o_g@40000
0003001d_`3oool0oooo0?l0ooooW`3oool01P2oM00000000000M02oool0oono07@00080000000<0
04RL0=oog`2LB0000`0000000`00B9`0gooo0?ooo`3<0?ooo`00n`3oool00`3ooml0W4Q809cOo`02
0?ooo`030?oOW018000007Bo00D0oooo00<0_g@00000M02oool0o`3ooonR0?ooo`030?oog`2LB4P0
W=oo0080oooo00`0omnL04P00000M;l0oooo0?oOW018000004RL0=ooo`3oool0omnL04P0B02Lgoo<
0?ooo`00o03oool01`3ookl0M4RL0=ooo`3ooml0W4P00018W03Oool01@3oool00`2oM000001d0;oo
o`3o0?oooj<0oooo00L0oono07A8W03Oool0oooO09a80000B9`0gooo00L0oooo00<0okmd0018W03O
ool0b`3oool00?d0oooo00D0omnL04Qd_`2oM000001809cOo`060?ooo`030;md000007@0_ooo0?l0
ooooY03oool01@3ogi`0B7Bo0;md000004P0W=oo00P0oooo00<0okmd0000B02Lgol0b`3oool00?h0
oooo00<0okmd00000018W=l01`3oool00`2oM000001d0;ooo`3o0?ooojD0oooo00<0okmd00000018
W=l02@3oool00`2oM000001809cOo`3;0?ooo`00o@3oool0103ookl0M0000000M02oool70?ooo`03
0;md000007@0_ooo0?l0ooooY03oool0103ookl0M0000000M02oool80?ooo`040;md00000000001d
0;oool/0oooo003l0?ooo`060?oog`2LB000001809cO_`1dB9`0gooo1P3oool00`2oM000001d0;oo
o`3o0?oooj<0oooo00H0oooO09a8000004P0W=no07A8W03Oool40?ooo`030?oo_`1d000000000080
000000<0B9cO0?ooo`3oool0bP3oool00?`0oooo00L0gia80000001d_ol0oooo0?oOW018B9`0gooo
00D0oooo00<0_g@00000M02oool0o`3ooonS0?ooo`070=nLB0000000M;oo0?ooo`3ogi`0B4RL0=oo
o`050?ooo`030?noM00004P0W=oo0<d0oooo003j0?ooo`0:0?oog`2LB00000000000000007@0_ooO
09a800000000001d0;ooo`@0oooo00<0_g@00000M02oool0o`3ooonQ0?ooo`0:0?oog`2LB0000000
0000000007@0_ooO09a800000000001d0;ooo`D0oooo00<0omnL04Qd_`3oool0c03oool00?l0oooo
2@3oool00`2oM000001d0;ooo`3o0?oook00oooo00<0oooO09a80018W=l0c03oool00?l0oooo2@3o
ool00`2oM000001d0;ooo`3o0?oooj/0oooo00<0oooO09adW03Oool00P3oool00`3ooml0W4P0001d
_`3<0?ooo`00o`3oool70?ooo`050=nLB000000000000000M02oool0o`3ooon/0?ooo`070?oOW018
B9`0gooo0?ooo`3OW4P0000007Boo`3<0?ooo`00o`3oool80?ooo`040?oo_`1d0000001d0;ooool0
oooo[@3oool01@3ogi`0B000000000000000B9cO0<d0oooo003o0?ooool0ooooo`3ooon<0?ooo`00
o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0ooooo`3ooon<
0?ooo`00o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0oooo
o`3ooon<0?ooo`00o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?oo
ool0ooooo`3ooon<0?ooo`00o`3ooooo0?ooool0ooooS03oool009d0oooo00<0okmd0000001d_ol0
;`3oool00`3ooml0W4P000000002000000030018W03Oool0oooo0300oooo00<0gia8000000000000
1@0000000`1d_ol0oooo0?ooo`0_0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0
:P3oool0102oM000000000000018W=lc0?ooo`030?noM000000000000080000000<007Bo0?ooo`3o
ool0Q03oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO0080oooo00H0_g@00000
0000000000000018W03OoolH0?ooo`040;md00000000000004RLgah0oooo00@0_g@0000000000000
B9cO103oool00`3OW4P0000004RLg`020?ooo`060;md00000000000000000000B9`0gooo7@3oool0
0`3o_g@000000000000200000003001d_`3oool0oooo01/0oooo00<0okmd0000000000000P000000
1`00M;l0oooo0?ooo`3oool0gia800000018W=l00P3oool01P2oM000000000000000000004RL0=oo
oa/0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0G0?ooo`030=nLB00000000000
00D0000000H0M;oo0?ooo`3oool0gia800000018W=l20?ooo`060;md00000000000000000000B9`0
gooo703oool00`3ooml0W4P000000002000000030018W03Oool0oooo02P0oooo002M0?ooo`030?no
M0000000M;oo02l0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOoc40oooo00<0gia8
000000000000100000000`00M;l0oooo0?ooo`0a0?ooo`030;md000007@0_ooo02/0oooo00L0oooO
09a80000M;l0oooo0?oog`2LB00007Bo03@0oooo00<0_g@00000M02oool0Q@3oool01`3ooml0W4P0
001d_`3oool0oooO09a80000M;l00`3oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3o
ool00`3ogi`0B4RL0=ooo`0E0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0K0?ooo`07
0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P0
04RLg`020?ooo`030?oOW018B9`0gooo01h0oooo00<0_g@00000M02oool0803oool00`2oM000001d
0;ooo`040?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo
01/0oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`0H0?ooo`030=nLB00000000000
00@0000000X007Bo0?ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO0P3oool00`3ogi`0
B4RL0=ooo`0K0?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0B02LgolX0?ooo`00W@3oool0
0`3o_g@0000007Boo`0e0?ooo`030?noM000B9`0gooo0340oooo00<0gia804RLg`3oool00P3oool0
0`3ooml0W4Qd0;ooo`0b0?ooo`030;md000007@0_ooo02/0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`0c0?ooo`030;md000007@0_ooo08D0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`0<0?ooo`030?oOW018M;l0oooo01@0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`0J0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0303oool0
0`3ogi`0B7Bo0?ooo`0M0?ooo`030;md000007@0_ooo0200oooo00<0_g@00000M02oool03P3oool0
0`3ogi`0B7Bo0?ooo`0K0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool06P3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00/0oooo00<0omnL04Qd_`3oool0803oool0
0`3o_g@004RL0=ooo`0W0?ooo`00V03oool00`3OW4P0000000000005000000030000B02Lgol0oooo
0380oooo00<0okmd0000B02Lgol0<P3oool00`3OW4P0B9cO0?ooo`0f0?ooo`030;md000007@0_ooo
02X0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0c0?ooo`030;md000007@0
_ooo08@0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0<0?ooo`030?oo_`1d
04P0W=oo01<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0I0?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0303oool00`3ookl0M01809cOo`0M0?ooo`03
0;md000007@0_ooo0200oooo00<0_g@00000M02oool03P3oool00`3ookl0M01809cOo`0L0?ooo`03
0=nLB018W=l0oooo01l0oooo00<0gia804RLg`3oool03`3oool00`3ookl0M01809cOo`0P0?ooo`03
0?noM00004P0W=oo02L0oooo002H0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0
=@3oool00`2oM000001809cOo`0c0?ooo`030=nLB01d_ol0oooo03D0oooo00<0_g@00000M02oool0
:P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo0380oooo00<0_g@00000M02oool0
Q03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0oono07@0001d_ol0
4`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo01P0oooo00<0oono07@00000M;l0
103oool00`2oM000001d0;ooo`0;0?ooo`030?oo_`1d0000M;oo01d0oooo00<0_g@00000M02oool0
803oool00`2oM000001d0;ooo`0>0?ooo`030?oo_`1d0000M;oo01d0oooo00<0gia807Boo`3oool0
7`3oool00`3OW4P0M;oo0?ooo`0>0?ooo`030?oo_`1d0000M;oo0200oooo00<0_g@00000B02Lgol0
9`3oool008/0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3oool0gia807Boo`80
oooo00<0okmd0000001d_ol08`3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0
oooo00@0_g@00000000007@0_ooo8P3oool00`2oM0000000000000070000000304RLg`3oool0oooo
00@0oooo00<0oooO09a8B02Lgol0903oool00`2oM0000000000000070000000304RLg`3oool0oooo
00@0oooo00<0_g@00000M02oool0:P3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo
0380oooo00<0_g@00000M02oool0M`3oool00`2oM0000000000000070000000604RLg`3oool0oooo
0?oOW0180000B9cO103oool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000M;oo01<0oooo00<0
omnL04P00018W=l0103oool00`2oM000001d0;ooo`0H0?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000M02oool02`3oool00`3o_g@0000007Boo`0M0?ooo`030;md000007@0_ooo0200oooo00<0
_g@00000M02oool03P3oool00`3o_g@0000007Boo`0M0?ooo`030?oog`2LB4P0W=oo01l0oooo00<0
oooO09a8B02Lgol03P3oool00`3o_g@0000007Boo`0O0?ooo`040;md00000000001d0;ooobL0oooo
002I0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`0a0?ooo`030?oo_`1d000000000080
000000<0B9cO0?ooo`3oool0<`3oool00`3ogi`0B01d0;ooo`0d0?ooo`030;md000007@0_ooo02X0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0b0?ooo`030;md000007@0_ooo08@0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`040?oOW0180000001d0;oo
oa<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0H0?ooo`030?oOW0180000B9cO
00@0oooo00<0gia80000B02Lgol02P3oool0103ogi`0B0000000M02ooolM0?ooo`030;md000007@0
_ooo0200oooo00<0_g@00000M02oool03@3oool0103ogi`0B0000000M02ooolN0?ooo`030?oOW018
07@0_ooo01l0oooo00<0omnL04P0M02oool0303oool0103ogi`0B0000000M02ooolL0?ooo`030?oo
_`1d000000000080000000<0B9cO0?ooo`3oool09P3oool009X0oooo00H0okmd001d_`3oool0okmd
0000001d_olc0?ooo`030?noM00004P0W=oo03L0oooo00<0_g@004RLg`3oool0<`3oool00`2oM000
001d0;ooo`0Z0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0<P3oool00`2oM000
001d0;ooo`240?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool0103Ogml0
oooo0?ooo`2oM0020000000304RLg`3oool0oooo0180oooo00<0omnL04P00018W=l0103oool00`3O
W4P0001809cOo`0H0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool0103O
gml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo01`0oooo00<0_g@00000M02oool0803oool0
0`2oM000001d0;ooo`090?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool07P3o
ool00`2oM000B9cO0?ooo`0O0?ooo`030;md0018W=l0oooo00L0oooo00@0gmoO0?ooo`3oool0_g@0
0P0000000`18W=l0oooo0?ooo`0M0?ooo`030?noM00004P0W=oo02T0oooo002K0?ooo`050;md001d
_ol0okmd0000001d_ol0=03oool00`3ogi`0B7Bo0?ooo`0f0?ooo`030=nLB00007@0_ooo03<0oooo
00<0_g@00000M02oool0:P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo0380oooo
00<0_g@00000M02oool0Q03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo
00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0C0?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool0603oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo
00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0M0?ooo`030;md000007@0_ooo0200oooo
00<0_g@00000M02oool02@3oool00`3o_g@000000000000200000003001d_`3oool0oooo01l0oooo
00<0gia80000M02oool07`3oool00`3OW4P0001d0;ooo`070?ooo`030?noM0000000000000800000
00<007Bo0?ooo`3oool07`3oool00`3ogi`0B7Bo0?ooo`0X0?ooo`00V`3oool01@3ookl0M01d0;no
M0000000M;oo03@0oooo00<0oooO09a80018W=l0=P3oool00`3o_g@0000007Boo`0c0?ooo`030;md
000007@0_ooo02/0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0c0?ooo`030;md
000007@0_ooo08D0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`050?oo
g`2LB00000000000M02oool05`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo01X0
oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`050?oog`2LB00000000000
M02oool0803oool00`2oM000001d0;ooo`0P0?ooo`030;md000007@0_ooo00T0oooo00D0oooO09a8
00000000001d0;ooo`0R0?ooo`030?noM0000000M;oo01l0oooo00<0okmd0000001d_ol01`3oool0
1@3ooml0W4P00000000007@0_ooo0280oooo00<0oooO09a80018W=l0:03oool009`0oooo00@0okmd
000000000000M;oo;`3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB00007Bo0300oooo00<0
omnL09boo`3oool00`3oool00`2oM000000007Boo`0c0?ooo`030;md000007@0_ooo02/0oooo00<0
okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0c0?ooo`030;md000007@0_ooo08D0oooo00<0
okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`030?noM000M;l0oooo01P0oooo00<0
okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0J0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol0203oool00`3o_g@007Bo0?ooo`0Q0?ooo`030;md000007@0_ooo0200oooo00<0
_g@00000M02oool02P3oool00`3o_g@007Bo0?ooo`0M0?ooo`030?oOW02L_ol0oooo00<0oooo00<0
_g@00000001d_ol06@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00P0oooo00<0
okmd001d_`3oool07P3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB00007Bo02P0oooo002L
0?ooo`040?oog`2LB000000007Booc00oooo00L0omnL04Q8W03Oool0oooo0=nLB0000000M;oo0340
oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=oooc40oooo00D0gia8000000000000001d
0;ooo`0/0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo<P3oool01@3OW4P000000000000007@0
_ooo08H0oooo00H0_g@00018W03Oool0oooo0;md0000M;l90?ooo`030?oog`2LB000000000800000
00<0001d0;ooo`3oool0503oool01P2oM00004RL0=ooo`3oool0_g@0001d_a`0oooo00H0_g@00018
W03Oool0oooo0;md0000M;l90?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool06P3o
ool01@3OW4P000000000000007@0_ooo01h0oooo00D0gia8000000000000001d0;ooo`0:0?ooo`03
0?oog`2LB00000000080000000<0001d0;ooo`3oool06@3oool0202oM000M;oo0?ooo`3oool0gia8
00000000B9`0gooo6P3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo203oool00`3o
oml0W4P000000002000000030000M02oool0oooo01X0oooo00L0omnL04Q8W03Oool0oooo0=nLB000
0000M;oo02P0oooo002M0?ooo`030?oOW0180000M;oo0340oooo00D0omnL04P000000000000004RL
g`0c0?ooo`050;md00000000000000000000M;l0=03oool0103ookl0M0000000M02oool]0?ooo`04
0;md000000000000001d_c@0oooo00@0oono07@0000007@0_oooQ`3oool0102oM000000000000000
M;l;0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0503oool0102oM00000000000
0000M;lN0?ooo`040;md000000000000001d_`/0oooo00<0okmd0000000000000P0000000`1d_ol0
oooo0?ooo`0J0?ooo`040?oo_`1d0000001d0;oooal0oooo00@0oono07@0000007@0_ooo2`3oool0
0`3o_g@00000000000020000000307Boo`3oool0oooo01T0oooo00D0_g@00000000000000000001d
_`0M0?ooo`050;md00000000000000000000M;l02`3oool00`3o_g@00000000000020000000307Bo
o`3oool0oooo01X0oooo00D0omnL04P000000000000004RLg`0Y0?ooo`00o`3ooooo0?ooool0oooo
S03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0ooooo`3ooon<0?ooo`00o`3ooooo0?oo
ool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0ooooo`3ooon<0?ooo`00o`3o
oooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0ooooo`3ooon<0?oo
o`00o`3ooooo0?ooool0ooooS03oool005h0ooooo`00001A00000640ooooo`00001A000002X0oooo
001N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0X0?ooo`00GP3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?oo
o`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000
003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0oooo
C@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool200000?l0ooooC03oool300000640oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0
oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`800000o`3ooom=0?ooo`800000:P3oool0
05h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0
ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000
oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo0P00
003o0?oood`0oooo0`00001Q0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?oo
o`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0G`3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo0P00003o0?ooodd0oooo0P00000Z0?oo
o`00GP3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<0<`3o0?ooo`3oool0=@3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00
GP3oool00`000000oooo0?ooo`3o0?oooa@0oooo00<0<`3o0?ooo`3oool0=P3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3o
ool00`000000oooo0?ooo`3o0?oooa80oooo0P0c0?li0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`800000o`3ooolA
0?ooo`80<`3o>@3oool300000640oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0
oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0oooo3P3oool203<0ocd0oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`80<`3o?`3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo
0?ooo`3o0?ooo`X0oooo0P0c0?m10?ooo`030000003oool0oooo05l0oooo0P00003o0?ooodd0oooo
0P00000Z0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooo`P0oooo0P0c0?m30?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N
0?ooo`030000003oool0oooo0?l0oooo1`3oool00`0c0?l0oooo0?ooo`130?ooo`030000003oool0
oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001A0?oo
o`040;md00000000000004RLg`T0oooo0P00003o0?ooo`H0oooo0P0c0?m40?ooo`<00000H@3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool004l0oooo00L0oooO09a8
0000M;l0oooo0?oog`2LB00007Bo00P0oooo00<000000?ooo`3oool0o`3oool30?ooo`80<`3oB03o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?oo
o`0X0?ooo`00C`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<00000
0?ooo`3oool0o`3oool10?ooo`80<`3oBP3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00CP3oool0103ooml0W4P00018W03Oool2
0?ooo`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool0o`3oool00`0c0?l0oooo0?ooo`1:
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0
oooo02P0oooo001>0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`00
0000oooo0?ooo`3m0?ooo`80<`3oC@3oool00`000000oooo0?ooo`1O0?ooo`800000o`3ooom=0?oo
o`800000:P3oool004h0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`060?ooo`03
0000003oool0oooo0?/0oooo0P0c0?m?0?ooo`030000003oool0oooo04<0oooo00@0_g@000000000
0000B9cO103oool00`3OW4P0000004RLg`020?ooo`060;md00000000000000000000B9`0gooo2@3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool004h0oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`<00000g03oool00`0c0?l0oooo0?ooo`0J
0?ooo`80<`3oC`3oool3000004<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo
00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0203oool00`00
0000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool004h0oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`060?ooo`030000003oool0oooo0=X0oooo0P0c0?lL0?ooo`03
03<0o`3oool0oooo0540oooo00<000000?ooo`3oool0@@3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo00`0oooo00<0omnL04Qd_`3oool01`3oool00`000000oooo0?ooo`3o0?ooodd0
oooo00<000000?ooo`3oool0:03oool004h0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`060?ooo`030000003oool0oooo0=P0oooo0P0c0?lL0?ooo`80<`3oE03oool00`000000oooo
0?ooo`100?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0303oool00`3ookl0
M01809cOo`070?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00
C`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool0
eP3oool203<0oa`0oooo0P0c0?mF0?ooo`030000003oool0oooo0400oooo00<0oono07@00000M;l0
103oool00`2oM000001d0;ooo`0;0?ooo`030?oo_`1d0000M;oo00L0oooo00<000000?ooo`3oool0
o`3ooom=0?ooo`030000003oool0oooo02P0oooo001?0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol01`3oool00`000000oooo0?ooo`3E0?ooo`0303<0o`3oool0oooo01X0oooo0P0c
0?mH0?ooo`030000003oool0oooo03<0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?oo
o`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool02`3oool00`3o_g@0000007Boo`070?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00D03oool01P2oM00004RL
0=ooo`3oool0_g@0001d_`P0oooo00<000000?ooo`3oool0d`3oool203<0oa/0oooo0P0c0?mJ0?oo
o`030000003oool0oooo0400oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?oo
o`040?oOW0180000001d0;ooo`L0oooo0`00003o0?oood/0oooo0`00000Z0?ooo`00D@3oool0102o
M000000000000000M;l90?ooo`800000d`3oool00`0c0?l0oooo0?ooo`0I0?ooo`80<`3oFP3oool3
00000480oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`040=oOg`3oool0
oooo0;md0080000000<0B9cO0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<0
00000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0d03oool203<0oaX0oooo0P0c0?mN
0?ooo`030000003oool0oooo0400oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`06
0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01`3oool00`000000oooo0?ooo`3o
0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0cP3oool203<0
oaX0oooo0P0c0?mP0?ooo`030000003oool0oooo0440oooo00<0_g@00018W03Oool00P3oool00`3o
oml0W4P0001d_`070?ooo`050?oog`2LB00000000000M02oool02P3oool00`000000oooo0?ooo`3o
0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0c03oool203<0
oaX0oooo0P0c0?mR0?ooo`030000003oool0oooo0440oooo00<0okmd0000B02Lgol00P3oool00`3o
gi`0B00007Boo`080?ooo`030?noM000M;l0oooo00/0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0</0oooo00<0<`3o0?ooo`3o
ool0603oool203<0of@0oooo00<000000?ooo`3oool0@P3oool01P2oM00004RL0=ooo`3oool0_g@0
001d_`T0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`060?ooo`030000003oool0
oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`390?oo
o`80<`3o6@3oool203<0ofH0oooo00<000000?ooo`3oool0@`3oool0102oM000000000000000M;l;
0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`3o
0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo0P0000380?ooo`80<`3o603oool303<0
ofH0oooo0`00001Q0?ooo`800000o`3ooom=0?ooo`800000:P3oool005h0oooo00<000000?ooo`3o
ool0aP3oool00`0c0?l0oooo0?ooo`0F0?ooo`80<`3oJ`3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo
0?ooo`350?ooo`0303<0o`3oool0oooo01D0oooo0P0c0?m]0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003o
ool0oooo0<@0oooo00<0<`3o0?ooo`3oool0503oool203<0ofl0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<00000
0?ooo`3oool0``3oool00`0c0?l0oooo0?ooo`0C0?ooo`80<`3oL@3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`00
0000oooo0?ooo`320?ooo`0303<0o`3oool0oooo0140oooo0`0c0?mc0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`80
0000`P3oool00`0c0?l0oooo0?ooo`0@0?ooo`80<`3oM03oool300000640oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0<40oooo
00<0<`3o0?ooo`3oool03@3oool303<0ogP0oooo00<000000?ooo`3oool0G`3oool200000?l0oooo
C@3oool2000002X0oooo001N0?ooo`030000003oool0oooo0<00oooo00<0<`3o0?ooo`3oool0303o
ool203<0og/0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<0
00000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0_`3oool203<0o`/0oooo0`0c0?mm
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0
oooo02P0oooo001N0?ooo`030000003oool0oooo0;l0oooo0P0c0?l80?ooo`<0<`3oP03oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?oo
o`00GP3oool00`000000oooo0?ooo`300?ooo`T0<`3oP`3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00D03oool00`3o_g@00000
0000000200000003001d_`3oool0oooo00H0oooo0P00003o0?oood`0oooo0`00001Q0?ooo`030000
003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00DP3oool00`2oM000001d0;oo
o`090?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00DP3oool00`2oM000001d0;ooo`09
0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`800000o`3ooom=
0?ooo`800000:P3oool00580oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?oo
o`3oool0:03oool00580oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?ooodd0
oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3o
ool0:03oool00580oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?ooodd0oooo
00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0
:03oool00580oooo00<0_g@00000M02oool02@3oool300000?l0ooooB`3oool300000640oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001B0?ooo`030;md000007@0
_ooo00T0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001B0?ooo`030;md000007@0_ooo
00T0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001B0?ooo`030;md000007@0_ooo00T0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo0P00003o0?ooodd0
oooo0P00000Z0?ooo`00DP3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo0?l0oooo
C@3oool00`000000oooo0?ooo`1B0?ooo`040;md00000000000004RLg`T0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001@0?ooo`050=nLB000000000000000M02o
ool02@3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0D03oool01`3ooml0
W4P0001d_`3oool0oooO09a80000M;l0203oool00`000000oooo0?ooo`3o0?ooodd0oooo00<00000
0?ooo`3oool0:03oool00540oooo00@0oono07@0000007@0_ooo2@3oool200000?l0ooooC03oool3
00000580oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030000003oool0
oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool0C`3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB000
07Bo00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?oo
o`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1?0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool01P3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?oo
o`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo04l0
oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`060?ooo`030000003oool0oooo07/0
oooo0`0c0?mi0?ooo`80<`3oD`3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo
0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0C`3oool00`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo00H0oooo0`00001k0?ooogh0<`3oD@3oool3000002X0oooo001N0?ooo`030000003o
ool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1?0?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol01P3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03o
ool005h0oooo0P00003o0?oood`0oooo0`00001A0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool01P3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool0
05h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo0500oooo00<0_g@00018
W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`030000003oool0oooo0?l0ooooC@3oool00`00
0000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3o
ool0D03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0oooo
C@3oool00`000000oooo0?ooo`1A0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool00`00
0000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000003oool0oooo0580oooo00@0_g@000000000000007Bo2@3oool20000
0?l0ooooC@3oool2000002X0oooo001N0?ooo`800000o`3ooom<0?ooo`<00000H@3oool00`000000
oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0
o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000
003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o
0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo
02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool200000?l0oooo
C03oool300000640oooo0P00003o0?ooodd0oooo0P00000Z0?ooo`00CP3oool00`3OW4P000000000
00050000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001?
0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool01@3oool00`000000oooo0?ooo`3o
0?ooodd0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<00000
0?ooo`3oool0:03oool00500oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?oo
o`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00D@3oool00`3OW4P0B9cO0?ooo`0:0?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0
ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00DP3oool00`3OW4P0M;oo0?ooo`090?ooo`030000
003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0oooo
C@3oool00`000000oooo0?ooo`0X0?ooo`00DP3oool00`3ooml0W4Q809cOo`090?ooo`<00000o`3o
oom;0?ooo`<00000H@3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03o
ool005<0oooo00<0omnL04P0M02oool0203oool00`000000oooo0?ooo`3o0?ooodd0oooo00<00000
0?ooo`3oool0G`3oool200000?l0ooooC@3oool2000002X0oooo001D0?ooo`030;md0018W=l0oooo
00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001D0?ooo`030=nLB00007@0_ooo00L0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001D0?ooo`030?noM0000000M;oo00L0oooo
00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
o`3ooom=0?ooo`030000003oool0oooo02P0oooo001>0?ooo`030?oOW02L_ol0oooo00<0oooo00<0
_g@00000001d_ol01`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool003X0oooo00<0okmd
07Boo`3oool01P3oool00`2oM7@0_ooo0?ooo`090?ooo`080;md001d_ol0oooo0?ooo`3OW4P00000
0018W03Oool70?ooo`800000o`3ooom<0?ooo`<00000803oool00`3o_g@0M;oo0?ooo`060?ooo`03
0;mdM02oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0
oooo000j0?ooo`030?noM00007@0_ooo00@0oooo00@0oooO09a8000007@0_ooo2`3oool01@2oM000
000000000000000007Bo00T0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo
01h0oooo00<0okmd0000M02oool0103oool0103ooml0W4P00000M02ooolf0?ooo`030000003oool0
oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00>P3oool0103o_g@0000000000018W=l2
0?ooo`050?oo_`1d04P0W=oo0=nLW02oool06@3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<0
00000?ooo`3oool07P3oool0103o_g@0000000000018W=l20?ooo`050?oo_`1d04P0W=oo0=nLW02o
ool0=P3oool200000?l0ooooC@3oool2000002X0oooo000j0?ooo`080?noW02Lgol0gia800000000
04P0M7A80000M02ooolL0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0N
0?ooo`080?noW02Lgol0gia80000000004P0M7A80000M02ooolM0?ooo`040;md00000000000004RL
g`@0oooo00<0gia800000018W=l00P3oool01P2oM000000000000000000004RL0=ooo`T0oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo000m0?ooo`040?oo_`1d0000
0000001d_ad0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo0240oooo00@0
oono07@00000000007Bo703oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool01`3O
W4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`080?ooo`030000003o
ool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00>P3oool02`3o_i`0W=oo0?noM000
04P0W=oo0=nLB0000000001809cOo`3OW9`0_ooo01T0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`030000003oool0oooo01h0oooo00/0oknL09cOo`3o_g@0001809cOo`3OW4P000000000B02Lgol0
gibL0;ooo`0H0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0303oool00`3ogi`0
B7Bo0?ooo`070?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00
>P3oool00`3o_g@00000001d_`030?ooo`050?oo_`1d000000000000M02oool06@3oool200000?l0
ooooC03oool300000200oooo00<0okmd00000000M;l00`3oool01@3ookl0M0000000000007@0_ooo
01L0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0<0?ooo`030?oo_`1d04P0
W=oo00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo000j0?oo
o`030?noM018W=l0oooo00D0oooo00<0gia80000M02oool06@3oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool07P3oool00`3o_g@0B9cO0?ooo`050?ooo`030=nLB00007@0_ooo
01L0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`030?oo_`1d0000M;oo
00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo000j0?ooo`03
0?noW02Lgol0oooo00H0oooo00<0_gAd0;ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooodd0
oooo00<000000?ooo`3oool07P3oool00`3o_i`0W=oo0?ooo`060?ooo`030;mdM02oool0oooo01H0
oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000M;oo00L0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000
003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`100?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol02P3oool0103ogi`0B0000000M02oool70?ooo`<00000o`3ooom;0?ooo`<0
0000:P3oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo0280oooo
00<0_g@000000018W=l06`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo
00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`060?ooo`030000003oool0oooo0?l0
ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00>03oool00`3OW4P0001809cOo`070?ooo`030?oo
_`1d07@0_ooo01T0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo0200oooo
00D0omnL04P0001d_ml0W4P004RLg`0K0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02o
ool01P3oool00`3o_g@000000000000200000003001d_`3oool0oooo00L0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo000g0?ooo`030;md0018W=l0oooo00L0oooo
00@0omnL04P0000007@0_ooo6@3oool200000?l0ooooC03oool300000240oooo00H0_g@00018W03O
ool0oooO09a80018W=lL0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3oool0
1@3ooml0W4P00000000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003o
ool0oooo02P0oooo000f0?ooo`030?oOW01804P0W=oo00L0oooo00D0gia80018W02oW4P0001d0;oo
o`0I0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0M0?ooo`030?oOW018
0000M;oo0080oooo00<0oooO09a80018W=l0703oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo00P0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<0
00000?ooo`3oool0:03oool003H0oooo00<0okmd0000001d_ol01@3oool01`3ooml0W4P004RLg`3o
ool0gia80000M02oool06@3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0
703oool00`3OW4P004RL0=ooo`030?ooo`030?oog`2LB000B9cO01d0oooo00H0_g@00018W03Oool0
oooo0;md0000M;l90?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool01P3oool00`00
0000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool003H0oooo00@0omnL04P00000
04P0W=oo0P3oool0103ooml0W4P00000001d_ol20?ooo`030=nLB00007@0_ooo01T0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo01X0oooo00<0omnL04P0000000002P000000
0`0007@0_ooo0?ooo`0I0?ooo`040;md000000000000001d_`/0oooo00<0okmd0000000000000P00
00000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?oo
o`0X0?ooo`00=P3oool00`3ooml0W4P000000004000000030000M02oool0oooo0080oooo00<0gia8
0000M02oool06@3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool06P3oool0
0`3o_g@000000000000:000000030000M02oool0oooo03D0oooo0P00003o0?ooodd0oooo0P00000Z
0?ooo`00=`3oool01P3ooml0W4P0000000000000001809cOo`@0oooo00@0oooO09a8000007@0_ooo
6@3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool08P3oool00`3ooml0W4P0
04RLg`0j0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00@@3o
ool00`3OW4P0001d0;ooo`0:0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0203o
ool200000?l0ooooC03oool3000002@0oooo00<0oooO09a80018W=l0>P3oool00`000000oooo0?oo
o`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool004h0oooo00P0omnL04P00000B9`0gooo0?oo
o`3ogi`0B01809cOo`P0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001D0?ooo`030?no
M000B9`0gooo00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001D0?ooo`030?noM000
04P0W=oo00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001D0?ooo`030;md000004P0
W=oo00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001C0?ooo`040;md00000000001d
0;ooo`L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo0P00003o
0?ooodd0oooo0P00000Z0?ooo`00D03oool00`3ookl0M000000000020000000304RLg`3oool0oooo
00H0oooo0`00003o0?oood/0oooo0`00001Q0?ooo`030000003oool0oooo0?l0ooooC@3oool00`00
0000oooo0?ooo`0X0?ooo`00DP3oool00`3o_g@0001809cOo`090?ooo`030000003oool0oooo0?l0
ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000
oooo0?ooo`0X0?ooo`00D`3oool00`3ogi`0B7Bo0?ooo`080?ooo`030000003oool0oooo0?l0oooo
C@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo
0?ooo`0X0?ooo`00D`3oool00`3ooml0W4P004RLg`080?ooo`030000003oool0oooo0?l0ooooC@3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?oo
o`0X0?ooo`00CP3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB00007Bo00P0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=
0?ooo`030000003oool0oooo02P0oooo001?0?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Bo
o`080?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00D03oool01@3ogi`0B00000000000
0000B9cO00T0oooo0P00003o0?oood`0oooo0`00001Q0?ooo`800000o`3ooom=0?ooo`800000:P3o
ool005h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo
0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`00
0000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo
00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?oo
o`0X0?ooo`00GP3oool200000?l0ooooC03oool300000640oooo00<000000?ooo`3oool0o`3ooom=
0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3oool00`00
0000oooo0?ooo`1O0?ooo`800000o`3ooom=0?ooo`800000:P3oool005h0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000003oool0oooo0540oooo00<0okmd0000000000000P0000000`00M;l0
oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00
GP3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0D`3oool00`2oM000001d
0;ooo`090?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0D`3oool00`2oM000001d0;oo
o`090?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0D`3oool00`2oM000001d0;ooo`09
0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool20000
0?l0ooooC03oool3000005D0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`03
0000003oool0oooo05<0oooo00<0_g@00000M02oool02@3oool300000?l0ooooB`3oool3000002X0
oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1C0?ooo`030;md
000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo
001N0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1C0?ooo`030;md0000
07@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N
0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1C0?ooo`030;md000007@0
_ooo00T0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?oo
o`800000o`3ooom<0?ooo`<00000E@3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo
0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00D`3oool00`3o_g@0000007Boo`080?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1C0?ooo`030;md000007@0_ooo00T0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001C0?ooo`030?no
M0000000M;oo00P0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo0540oooo
00D0gia8000000000000001d0;ooo`090?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000
oooo0?ooo`0X0?ooo`00D`3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo0?l0oooo
C@3oool00`000000oooo0?ooo`1B0?ooo`040?oo_`1d0000001d0;ooo`T0oooo0P00003o0?ooodd0
oooo0P00000Z0?ooo`00CP3oool00`3OW4P0000000000005000000030000B02Lgol0oooo00D0oooo
00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
o`3ooom=0?ooo`030000003oool0oooo02P0oooo001>0?ooo`030?oOW018M;l0oooo0080oooo00<0
okmd0000001d_ol0203oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool004l0oooo00L0gia8
07Boo`3oool0oooo0?noM0000000M;oo00P0oooo0`00003o0?oood/0oooo0`00001Q0?ooo`030000
003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00C`3oool01`3ookl0M01d0;oo
o`3oool0okmd0000001d_ol0203oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool00500oooo
00H0okmd001d_`3oool0okmd0000001d_ol80?ooo`030000003oool0oooo0?l0ooooC@3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?oo
o`00D@3oool01@2oM000M;oo0?noM0000000M;oo00P0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo
02P0oooo001A0?ooo`050?oo_`1d07@0_kmd0000001d_ol0203oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool0G`3oool200000?l0ooooC@3oool2000002X0oooo001B0?ooo`04
0?noM0000000000007Boo`P0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001B0?ooo`04
0?oog`2LB000000007Boo`P0oooo0P00003o0?oood`0oooo0`00001Q0?ooo`030000003oool0oooo
0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00D`3oool00`3ogi`0B00007Boo`080?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0
ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooodd0oooo
00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0
:03oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0
oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool0
0`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?oo
o`3oool0G`3oool200000?l0ooooC@3oool2000002X0oooo001N0?ooo`800000o`3ooom<0?ooo`<0
0000H@3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo
00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?oo
o`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0G`3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00
GP3oool200000?l0ooooC03oool300000640oooo0P00003o0?ooodd0oooo0P00000Z0?ooo`00GP3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0@P3oool00`3o_g@000000000
000200000007001d_`3oool0oooo0?ooo`3OW4P0000004RLg`020?ooo`060;md0000000000000000
0000B9`0gooo2@3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool0
05h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo04@0oooo00<0_g@00000
M02oool0103oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=oo
o`080?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0A03oool00`2oM000001d0;ooo`0>
0?ooo`030?oOW018M;l0oooo00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0
oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`140?oo
o`030;md000007@0_ooo00h0oooo00<0oono07@0B02Lgol01`3oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`03
0000003oool0oooo04@0oooo00<0_g@00000M02oool03P3oool00`3ookl0M00007Boo`070?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00C`3oool01P2oM0000000
00000000000004RL0=ooo`T0oooo0P00003o0?oood`0oooo0`0000160?ooo`030;md000007@0_ooo
00h0oooo00<0okmd0000001d_ol01`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?oo
o`3oool0:03oool004h0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`080?ooo`03
0000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`140?ooo`030;md000007@0_ooo00d0
oooo00@0omnL04P0000007@0_ooo1`3oool300000?l0ooooB`3oool3000002X0oooo001D0?ooo`03
0?oOW018M;l0oooo00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo04@0
oooo00<0_g@00000M02oool02@3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo
00H0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001D0?ooo`03
0?oo_`1d04P0W=oo00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo04@0
oooo00<0_g@00000M02oool02@3oool00`3o_g@000000000000200000003001d_`3oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001D0?ooo`030?oo
_`1d0000M;oo00L0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo04@0oooo
00<0_g@00000M02oool02@3oool01@3ooml0W4P00000000007@0_ooo00X0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001D0?ooo`030?noM0000000M;oo00L0oooo
00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo04@0oooo00<0_g@00000M02oool0
2P3oool00`3o_g@007Bo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo
0?ooo`0X0?ooo`00D`3oool0103ogi`0B0000000M02oool70?ooo`<00000o`3ooom;0?ooo`<00000
A03oool01@3OW4P000000000000007@0_ooo00X0oooo00<0oooO09a8000000000P0000000`0007@0
_ooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00
C`3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`030000003oool0oooo04<0oooo00@0oono07@0000007@0_ooo2`3oool00`3o
_g@00000000000020000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`030000003oool0oooo02P0oooo001?0?ooo`030?noM000000000000080000000<007Bo0?ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0G`3oool200000?l0
ooooC@3oool2000002X0oooo001?0?ooo`050?oog`2LB00000000000M02oool02P3oool00`000000
oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0
oooo00<000000?ooo`3oool0:03oool00500oooo00<0okmd001d_`3oool02`3oool00`000000oooo
0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo
00<000000?ooo`3oool0:03oool00500oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?oo
o`060?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00D@3oool00`3o_g@0000000000002
0000000307Boo`3oool0oooo00D0oooo0P00003o0?oood`0oooo0`00001Q0?ooo`030000003oool0
oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?oo
o`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000
003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`800000o`3ooom=0?ooo`800000
:P3oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0
oooo0?l0ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool0
0`000000oooo0?ooo`0X0?ooo`00GP3oool200000?l0ooooC03oool300000640oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0
ooooC@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000
oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3o
oom=0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3oool0
0`000000oooo0?ooo`1O0?ooo`800000o`3ooom=0?ooo`800000:P3oool005h0oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`030000003oool0oooo02P0oooo001N0?ooo`800000o`3ooom<0?ooo`<00000H@3oool00`000000
oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0
o`3ooom=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000
003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0X0?ooo`00GP3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o
0?ooodd0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo
02P0oooo001N0?ooo`800000o`3ooom<0?ooo`<00000H@3oool200000?l0ooooC@3oool2000002X0
oooo001@0?ooo`060?oog`2LB00000000000000007@0_ooo203oool00`000000oooo0?ooo`3o0?oo
odd0oooo00<000000?ooo`3oool0C`3oool00`3OW4P00000000000050000000307Boo`3oool0oooo
00D0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo02P0oooo001?0?ooo`08
0?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgol70?ooo`030000003oool0oooo0?l0ooooC@3o
ool00`000000oooo0?ooo`1@0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool004l0oooo00<0_g@0
0000M02oool00`3oool00`2oM00007Bo0?ooo`060?ooo`030000003oool0oooo0?l0ooooC@3oool0
0`000000oooo0?ooo`1A0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01P3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo00<000000?ooo`3oool0:03oool004h0oooo00<0oono07@0
0000M;l0103oool00`3OW4P0001d0;ooo`060?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0580oooo00<0gia804RL
g`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0:03oool004h0oooo00<0omnL04P00018W=l0103oool00`2oM000001809cOo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo05<0oooo00<0gia807Boo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02P0oooo001>0?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0
_ooo1P3ooooo000005400000E@3oool00`3ooml0W4Q809cOo`090?ooool00000D@00000Z0?ooo`00
CP3oool02@3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`3o0?ooojh0oooo00<0omnL
04P0M02oool0o`3ooon30?ooo`00CP3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO
0?ooo`3oool0o`3ooon^0?ooo`030;md0018W=l0oooo0?l0ooooPP3oool004l0oooo00<0okmd0000
0018W=l0o`3ooond0?ooo`030=nLB00007@0_ooo0?l0ooooPP3oool004l0oooo00@0oooO09a80000
04P0W=ooo`3ooonc0?ooo`030?noM0000000M;oo0?l0ooooPP3oool00500oooo00@0oono07@00000
07@0_oooo`3ooon/0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0o`3ooon20?oo
o`00D@3oool0103ooml0W4P000000000M;oo0?oooj`0oooo00P0_g@007Boo`3oool0oooo0=nLB000
000004RL0=ooool0ooooPP3oool005<0oooo00D0omnL04P00000000004RL0=ooo`3o0?ooojX0oooo
00D0_g@00000000000000000001d_`3o0?oooh@0oooo003o0?ooool0ooooo`3ooon<0?ooo`00o`3o
oooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0ooooo`3ooon<0?oo
o`00o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0ooooo`3o
oon<0?ooo`00o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo003o0?ooool0
ooooo`3ooon<0?ooo`00o`3ooooo0?ooool0ooooS03oool00?l0ooooo`3ooooo0?oooh`0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 904.5}, {286, 0}} -> {-0.0524785, -0.0158504, \
0.00232721, 0.00232721}, {{22.5, 463.25}, {279.188, 6.8125}} -> {-6.69489, \
-3.03518, 0.0179326, 0.0338515}, {{441.188, 881.938}, {279.188, 6.8125}} -> \
{-7.30873, -1.87222, 0.0119551, 0.0145078}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 4\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    RowBox[{"(*", " ", 
      RowBox[{
        StyleBox["Red",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[" ",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox["=",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[" ",
          FontColor->RGBColor[1, 0, 0]], 
        RowBox[{
          RowBox[{
            StyleBox[\(\[CapitalOmega]\_m\),
              FontColor->RGBColor[1, 0, 0]], " ", "and", " ", 
            StyleBox["Green",
              FontColor->RGBColor[0, 1, 0]]}], 
          StyleBox[" ",
            FontColor->RGBColor[0, 1, 0]], 
          StyleBox["=",
            FontColor->RGBColor[0, 1, 0]], 
          StyleBox[" ",
            FontColor->RGBColor[0, 1, 0]], 
          StyleBox[\(\[CapitalOmega]\_DE\),
            FontColor->RGBColor[0, 1, 0]]}]}], " ", "*)"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(fig4omega = 
        Plot[{1 - xx1[N] - xx2[N] - x3[N] - xx4[N], 
            xx1[N] + xx2[N] + x3[N]}, {N, nmin, nmax}, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<N\>", "\<\[CapitalOmega]\>"}, 
          PlotRange \[Rule] {\(-0.05\), 1.1}, Axes \[Rule] False, 
          PlotStyle \[Rule] {Hue[0], Hue[ .3], 
              Hue[ .7]}];\)\[IndentingNewLine]
    \ \(Export[flnm <> "\<_fig4_omega\>" <> "\<.m\>", 
        fig4omega];\)\)\(\ \)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.026871 0.537421 [
[.02381 -0.0125 -14 -24.5625 ]
[.02381 -0.0125 14 0 ]
[.18254 -0.0125 -14 -24.5625 ]
[.18254 -0.0125 14 0 ]
[.34127 -0.0125 -14 -24.5625 ]
[.34127 -0.0125 14 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.65873 -0.0125 -7.03125 -24.5625 ]
[.65873 -0.0125 7.03125 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .02687 -14.0625 -12.2813 ]
[-0.0125 .02687 0 12.2813 ]
[-0.0125 .13436 -29.125 -12.2813 ]
[-0.0125 .13436 0 12.2813 ]
[-0.0125 .24184 -29.125 -12.2813 ]
[-0.0125 .24184 0 12.2813 ]
[-0.0125 .34932 -29.125 -12.2813 ]
[-0.0125 .34932 0 12.2813 ]
[-0.0125 .45681 -29.125 -12.2813 ]
[-0.0125 .45681 0 12.2813 ]
[-0.0125 .56429 -14.0625 -12.2813 ]
[-0.0125 .56429 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -9.4375 ]
[-0.01875 .30902 -29.125 9.4375 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02687 m
.00625 .02687 L
s
gsave
-0.0125 .02687 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13436 m
.00625 .13436 L
s
gsave
-0.0125 .13436 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24184 m
.00625 .24184 L
s
gsave
-0.0125 .24184 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .34932 m
.00625 .34932 L
s
gsave
-0.0125 .34932 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .45681 m
.00625 .45681 L
s
gsave
-0.0125 .45681 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .56429 m
.00625 .56429 L
s
gsave
-0.0125 .56429 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .16123 m
.00375 .16123 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .26871 m
.00375 .26871 L
s
0 .29558 m
.00375 .29558 L
s
0 .32245 m
.00375 .32245 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .42994 m
.00375 .42994 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
0 .61803 m
.00375 .61803 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.844 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
70.4375 16.2813 translate
90 rotate
-70.4375 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\331) show
77.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06349 .61428 m
.06349 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30159 .61428 m
.30159 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.46032 .61428 m
.46032 .61803 L
s
.53968 .61428 m
.53968 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.69841 .61428 m
.69841 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.93651 .61428 m
.93651 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02687 m
1 .02687 L
s
.99375 .13436 m
1 .13436 L
s
.99375 .24184 m
1 .24184 L
s
.99375 .34932 m
1 .34932 L
s
.99375 .45681 m
1 .45681 L
s
.99375 .56429 m
1 .56429 L
s
.125 Mabswid
.99625 .05374 m
1 .05374 L
s
.99625 .08061 m
1 .08061 L
s
.99625 .10748 m
1 .10748 L
s
.99625 .16123 m
1 .16123 L
s
.99625 .1881 m
1 .1881 L
s
.99625 .21497 m
1 .21497 L
s
.99625 .26871 m
1 .26871 L
s
.99625 .29558 m
1 .29558 L
s
.99625 .32245 m
1 .32245 L
s
.99625 .37619 m
1 .37619 L
s
.99625 .40307 m
1 .40307 L
s
.99625 .42994 m
1 .42994 L
s
.99625 .48368 m
1 .48368 L
s
.99625 .51055 m
1 .51055 L
s
.99625 .53742 m
1 .53742 L
s
.99625 .59116 m
1 .59116 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .56429 m
.02846 .56429 L
.03279 .56429 L
.03793 .56429 L
.04262 .56429 L
.0522 .56429 L
.05746 .56429 L
.06244 .56429 L
.06754 .56429 L
.07295 .56429 L
.08265 .56429 L
.08804 .56429 L
.09308 .56429 L
.09858 .56429 L
.10458 .56429 L
.10996 .56429 L
.11496 .56429 L
.12013 .56429 L
.12483 .56429 L
.13379 .56429 L
.13872 .56429 L
.14335 .56429 L
.15311 .56429 L
.15803 .56429 L
.16343 .56429 L
.16804 .56429 L
.17298 .56429 L
.1819 .56428 L
.18719 .56428 L
.19208 .56428 L
.19734 .56427 L
.20314 .56427 L
.2129 .56426 L
.21824 .56425 L
.22326 .56425 L
.23309 .56422 L
.23804 .56421 L
.24345 .56419 L
.24808 .56417 L
.25303 .56414 L
.26195 .56408 L
.26728 .56403 L
.27219 .56398 L
.27748 .56391 L
.2833 .56381 L
.29309 .56358 L
.29844 .56342 L
.30345 .56323 L
.30843 .563 L
.31386 .56269 L
Mistroke
.31864 .56236 L
.32374 .56193 L
.32878 .56141 L
.33335 .56085 L
.34227 .55941 L
.34716 .55838 L
.35232 .55706 L
.36156 .55392 L
.3667 .55162 L
.3715 .54904 L
.37672 .54563 L
.38239 .54109 L
.38784 .53574 L
.39287 .52977 L
.40278 .5144 L
.41179 .49522 L
.42135 .46809 L
.43075 .43349 L
.44086 .38701 L
.45915 .28415 L
.47884 .17262 L
.48999 .12277 L
.49532 .10367 L
.50035 .08846 L
.50518 .07624 L
.51041 .06538 L
.51954 .0514 L
.52473 .04571 L
.53021 .04106 L
.53488 .03797 L
.54002 .03533 L
.54525 .03328 L
.55021 .03179 L
.55466 .03074 L
.55951 .02986 L
.56477 .02912 L
.57036 .02854 L
.57514 .02816 L
.58042 .02784 L
.58532 .02762 L
.59049 .02744 L
.59491 .02732 L
.59974 .02722 L
.60496 .02714 L
.61053 .02707 L
.6158 .02702 L
.62059 .02699 L
.62542 .02696 L
.63055 .02694 L
.63493 .02693 L
Mistroke
.63975 .02691 L
.64492 .0269 L
.65048 .0269 L
.65573 .02689 L
.66054 .02689 L
.66531 .02688 L
.67039 .02688 L
.67519 .02688 L
.67954 .02688 L
.68467 .02688 L
.69021 .02687 L
.69545 .02687 L
.70026 .02687 L
.70497 .02687 L
.71001 .02687 L
.71477 .02687 L
.7191 .02687 L
.72419 .02687 L
.72972 .02687 L
.73494 .02687 L
.73977 .02687 L
.74441 .02687 L
.74941 .02687 L
.75373 .02687 L
.75845 .02687 L
.76369 .02687 L
.76636 .02687 L
.7692 .02687 L
.77188 .02687 L
.77431 .02687 L
.77906 .02687 L
.78391 .02687 L
.78905 .02687 L
.79344 .02687 L
.79591 .02687 L
.79713 .02687 L
.79826 .02687 L
.79955 .02687 L
.80097 .02687 L
.80344 .02687 L
.80901 .02687 L
.81425 .02687 L
.81906 .02687 L
.82154 .02687 L
.82281 .02687 L
.82416 .02687 L
.82487 .02687 L
.82552 .02687 L
.82679 .02687 L
.8275 .02687 L
Mistroke
.82827 .02687 L
.82899 .02687 L
.82967 .02687 L
.83086 .02687 L
.83218 .02687 L
.83347 .02687 L
.83485 .02687 L
.83613 .02687 L
.83735 .02687 L
.83844 .02687 L
.83964 .02687 L
.84424 .02687 L
.84923 .02687 L
.85041 .02687 L
.85151 .02687 L
.85267 .02687 L
.85393 .02687 L
.85826 .02687 L
.86857 .02687 L
.87087 .02687 L
.87209 .02687 L
.87338 .02687 L
.87574 .02687 L
.87793 .02687 L
.87914 .02687 L
.88044 .02687 L
.88119 .02687 L
.88187 .02687 L
.88253 .02687 L
.88322 .02687 L
.88433 .02687 L
.88552 .02687 L
.88683 .02687 L
.88804 .02687 L
.89369 .02687 L
.89488 .02687 L
.89617 .02687 L
.8969 .02687 L
.89758 .02687 L
.8989 .02687 L
.90387 .02687 L
.90516 .02687 L
.90589 .02687 L
.90657 .02687 L
.9078 .02687 L
.90913 .02687 L
.90989 .02687 L
.91058 .02687 L
.91195 .02687 L
.91327 .02687 L
Mistroke
.91451 .02687 L
.91515 .02687 L
.91584 .02687 L
.91729 .02687 L
.92023 .02687 L
.92149 .02687 L
.92218 .02687 L
.92283 .02687 L
.92353 .02687 L
.92429 .02687 L
.92565 .02687 L
.92694 .02687 L
.92812 .02687 L
.9295 .02687 L
.93078 .02687 L
.93186 .02687 L
.93301 .02687 L
.93429 .02687 L
.93546 .02687 L
.93667 .02687 L
.93799 .02687 L
.94038 .02687 L
.94136 .02687 L
.94243 .02687 L
.94344 .02687 L
.94438 .02687 L
.94547 .02687 L
.94662 .02687 L
.9476 .02687 L
.94867 .02687 L
.9511 .02687 L
.95229 .02687 L
.95338 .02687 L
.9555 .02687 L
.95778 .02687 L
.95885 .02687 L
.96 .02687 L
.96108 .02687 L
.96206 .02687 L
.96322 .02687 L
.96447 .02687 L
.96565 .02687 L
.96675 .02687 L
.97619 .02687 L
Mfstroke
.2 1 0 r
.02381 .02687 m
.02846 .02687 L
.03279 .02687 L
.03793 .02687 L
.04262 .02687 L
.0522 .02687 L
.05746 .02687 L
.06244 .02687 L
.06754 .02687 L
.07295 .02687 L
.08265 .02687 L
.08804 .02687 L
.09308 .02687 L
.09858 .02687 L
.10458 .02687 L
.10996 .02687 L
.11496 .02687 L
.12013 .02687 L
.12483 .02687 L
.13379 .02687 L
.13872 .02687 L
.14335 .02687 L
.15311 .02687 L
.15803 .02687 L
.16343 .02688 L
.16804 .02688 L
.17298 .02688 L
.1819 .02688 L
.18719 .02688 L
.19208 .02688 L
.19734 .02689 L
.20314 .02689 L
.2129 .0269 L
.21824 .02691 L
.22326 .02692 L
.23309 .02694 L
.23804 .02695 L
.24345 .02697 L
.24808 .02699 L
.25303 .02702 L
.26195 .02708 L
.26728 .02713 L
.27219 .02718 L
.27748 .02726 L
.2833 .02735 L
.29309 .02758 L
.29844 .02775 L
.30345 .02794 L
.30843 .02817 L
.31386 .02847 L
Mistroke
.31864 .0288 L
.32374 .02923 L
.32878 .02975 L
.33335 .03031 L
.34227 .03175 L
.34716 .03278 L
.35232 .03411 L
.36156 .03724 L
.3667 .03954 L
.3715 .04213 L
.37672 .04553 L
.38239 .05007 L
.38784 .05542 L
.39287 .06139 L
.40278 .07676 L
.41179 .09594 L
.42135 .12307 L
.43075 .15768 L
.44086 .20415 L
.45915 .30701 L
.47884 .41854 L
.48999 .46839 L
.49532 .48749 L
.50035 .5027 L
.50518 .51493 L
.51041 .52578 L
.51954 .53977 L
.52473 .54545 L
.53021 .55011 L
.53488 .55319 L
.54002 .55583 L
.54525 .55788 L
.55021 .55938 L
.55466 .56042 L
.55951 .5613 L
.56477 .56204 L
.57036 .56262 L
.57514 .563 L
.58042 .56332 L
.58532 .56354 L
.59049 .56372 L
.59491 .56384 L
.59974 .56394 L
.60496 .56403 L
.61053 .5641 L
.6158 .56414 L
.62059 .56418 L
.62542 .5642 L
.63055 .56422 L
.63493 .56424 L
Mistroke
.63975 .56425 L
.64492 .56426 L
.65048 .56427 L
.65573 .56427 L
.66054 .56428 L
.66531 .56428 L
.67039 .56428 L
.67519 .56429 L
.67954 .56429 L
.68467 .56429 L
.69021 .56429 L
.69545 .56429 L
.70026 .56429 L
.70497 .56429 L
.71001 .56429 L
.71477 .56429 L
.7191 .56429 L
.72419 .56429 L
.72972 .56429 L
.73494 .56429 L
.73977 .56429 L
.74441 .56429 L
.74941 .56429 L
.75373 .56429 L
.75845 .56429 L
.76369 .56429 L
.76636 .56429 L
.7692 .56429 L
.77188 .56429 L
.77431 .56429 L
.77906 .56429 L
.78391 .56429 L
.78905 .56429 L
.79344 .56429 L
.79591 .56429 L
.79713 .56429 L
.79826 .56429 L
.79955 .56429 L
.80097 .56429 L
.80344 .56429 L
.80901 .56429 L
.81425 .56429 L
.81906 .56429 L
.82154 .56429 L
.82281 .56429 L
.82416 .56429 L
.82487 .56429 L
.82552 .56429 L
.82679 .56429 L
.8275 .56429 L
Mistroke
.82827 .56429 L
.82899 .56429 L
.82967 .56429 L
.83086 .56429 L
.83218 .56429 L
.83347 .56429 L
.83485 .56429 L
.83613 .56429 L
.83735 .56429 L
.83844 .56429 L
.83964 .56429 L
.84424 .56429 L
.84923 .56429 L
.85041 .56429 L
.85151 .56429 L
.85267 .56429 L
.85393 .56429 L
.85826 .56429 L
.86857 .56429 L
.87087 .56429 L
.87209 .56429 L
.87338 .56429 L
.87574 .56429 L
.87793 .56429 L
.87914 .56429 L
.88044 .56429 L
.88119 .56429 L
.88187 .56429 L
.88253 .56429 L
.88322 .56429 L
.88433 .56429 L
.88552 .56429 L
.88683 .56429 L
.88804 .56429 L
.89369 .56429 L
.89488 .56429 L
.89617 .56429 L
.8969 .56429 L
.89758 .56429 L
.8989 .56429 L
.90387 .56429 L
.90516 .56429 L
.90589 .56429 L
.90657 .56429 L
.9078 .56429 L
.90913 .56429 L
.90989 .56429 L
.91058 .56429 L
.91195 .56429 L
.91327 .56429 L
Mistroke
.91451 .56429 L
.91515 .56429 L
.91584 .56429 L
.91729 .56429 L
.92023 .56429 L
.92149 .56429 L
.92218 .56429 L
.92283 .56429 L
.92353 .56429 L
.92429 .56429 L
.92565 .56429 L
.92694 .56429 L
.92812 .56429 L
.9295 .56429 L
.93078 .56429 L
.93186 .56429 L
.93301 .56429 L
.93429 .56429 L
.93546 .56429 L
.93667 .56429 L
.93799 .56429 L
.94038 .56429 L
.94136 .56429 L
.94243 .56429 L
.94344 .56429 L
.94438 .56429 L
.94547 .56429 L
.94662 .56429 L
.9476 .56429 L
.94867 .56429 L
.9511 .56429 L
.95229 .56429 L
.95338 .56429 L
.9555 .56429 L
.95778 .56429 L
.95885 .56429 L
.96 .56429 L
.96108 .56429 L
.96206 .56429 L
.96322 .56429 L
.96447 .56429 L
.96565 .56429 L
.96675 .56429 L
.97619 .56429 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500.625, 309.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe
0?ooo`00o`3ooooe0?ooo`00o`3ooolB0?ooo`060;md00000000000000000000B9`0gooo103oool0
0`3ookl0M01d0;ooo`3F0?ooo`00o`3ooolC0?ooo`030?oo_`1d07@0_ooo00D0oooo00@0oooO09a8
000007@0_oooeP3oool00?l0oooo4`3oool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000001d
0;ooomH0oooo003o0?oooa<0oooo00<0oooO09a8M02oool0103oool01@3OW4P000000000B018B7@0
_ooo0=H0oooo003o0?oooa<0oooo00<0oooO09a8M02oool00`3oool01P3o_g@000000000M02ooml0
W4Qd0;ooomH0oooo003o0?oooa<0oooo00<0oooO09a8M02oool00P3oool01`3ogi`0B0000000B02L
gol0oooO09a8M02oool0eP3oool00?l0oooo4`3oool0303ooml0W4Qd0;ooo`3oool0oono07@00000
0000M;oo0?ooo`3ooml0W4Qd0;ooomH0oooo003o0?oooa<0oooo00L0oooO09a8M02oool0oooO09a8
00000000B9cO0080oooo00<0oooO09a8M02oool0eP3oool00?l0oooo4`3oool01P3ooml0W4Qd0;oo
g`2LB0000000001d_`<0oooo00<0oooO09a8M02oool0eP3oool00?l0oooo4`3oool01P3ooml0W4Qd
07Ad0000000004RL0=ooo`<0oooo00<0oooO09a8M02oool0eP3oool00?l0oooo4`3oool01@3ooml0
W4P00000000007@0_ooo00@0oooo00<0oooO09a8M02oool0eP3oool00?l0oooo4`3oool0103OW4P0
00000000M02oool50?ooo`030?oo_`1d07@0_ooo0=H0oooo003o0?oooa40oooo00D0gia800000000
0000001809cOo`040?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0d`3oool00?l0
oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0
oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0
oooom@3oool005P0oooo00H0oooO09a80000000000000000M02oooln0?ooo`030?noM0000000M;oo
03X0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0b0?ooo`040;md000000000000
04RLgcX0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0k0?ooo`030?noM0000000
M;oo03`0oooo00H0oooO09a80000000000000000M02ooolE0?ooo`00E`3oool0203ookl0M0000018
W03Oool0oooo0=nLB00004P0W=oo?@3oool00`3o_g@0000007Boo`0k0?ooo`030=nLB00000000000
00@0000000<007Bo0?ooo`3oool0<03oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0>P3o
ool00`3OW4P000000000000400000003001d_`3oool0oooo03/0oooo00<0okmd0000001d_ol0>`3o
ool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo503oool005L0oooo00<0_g@00000M02o
ool00`3oool00`2oM00007Bo0?ooo`0l0?ooo`030?noM0000000M;oo03`0oooo00<0gia804RLg`3o
ool00P3oool00`3ooml0W4Qd0;ooo`0a0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol0>P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo03`0oooo00<0okmd0000001d
_ol0>`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo01<0oooo001F0?ooo`030?oo
_`1d000007Bo00@0oooo00<0gia80000M02oool0=`3oool00`3OW4P0000000000005000000030000
B02Lgol0oooo03X0oooo00<0gia804RLg`3oool0=03oool0103ooml0W4P00018W03Oool20?ooo`03
0?oog`2LB00007Bo03/0oooo00<0gia804RLg`3oool0>`3oool00`3OW4P000000000000500000003
0000B02Lgol0oooo03L0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`0C0?ooo`00
EP3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo03L0oooo00<0omnL04Qd_`3oool0
0P3oool00`3o_g@0000007Boo`0n0?ooo`030=nLB01d_ol0oooo03<0oooo00<0oono07@00000M;l0
103oool00`2oM000001d0;ooo`0k0?ooo`030=nLB01d_ol0oooo03X0oooo00<0omnL04Qd_`3oool0
0P3oool00`3o_g@0000007Boo`0j0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol0
4`3oool004T0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`<0
oooo00@0oono07@0000007@0_ooo:P3oool00`2oM0000000000000070000000604RLg`3oool0oooo
0?ooo`3OW4P0M;oo0P3oool00`3o_g@0000007Boo`0]0?ooo`030;md00000000000000L0000000<0
B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`0c0?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000M02oool0>`3oool00`3ooml0W4Q809cOo`0k0?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0
000007Boo`0j0?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_ooo4`3oool005H0
oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0>@3oool01`3ookl0M01d0;oo
o`3oool0okmd0000001d_ol0?`3oool00`3ogi`0B01d0;ooo`0b0?ooo`030?oOW0180000B9cO00@0
oooo00<0gia80000B02Lgol0?03oool00`3ogi`0B01d0;ooo`0j0?ooo`070?oo_`1d07@0_ooo0?oo
o`3o_g@0000007Boo`0j0?ooo`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO01@0
oooo001F0?ooo`050?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`0i0?ooo`06
0?noM000M;l0oooo0?noM0000000M;oo@03oool00`2oM000B9cO0?ooo`0a0?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol0?@3oool00`2oM000B9cO0?ooo`0j0?ooo`060?noM000M;l0
oooo0?noM0000000M;oo>P3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3o
ool04`3oool005L0oooo00<0okmd00000018W=l0@03oool01@2oM000M;oo0?noM0000000M;oo0400
oooo00<0gia80000M02oool0<@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo03d0
oooo00<0gia80000M02oool0>`3oool01@2oM000M;oo0?noM0000000M;oo03/0oooo00<0okmd0000
0018W=l06@3oool005L0oooo00@0oooO09a8000004P0W=oo?`3oool01@3ookl0M01d0;noM0000000
M;oo0400oooo00<0okmd0000001d_ol0<P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo03h0oooo00<0okmd0000001d_ol0>`3oool01@3ookl0M01d0;noM0000000M;oo03/0oooo00@0
oooO09a8000004P0W=oo603oool005P0oooo00@0oono07@0000007@0_ooo?`3oool0103o_g@00000
0000001d_olj0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0<P3oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo03P0oooo00<0omnL09boo`3oool00`3oool00`2oM000
000007Boo`0l0?ooo`040?noM0000000000007Booc`0oooo00@0oono07@0000007@0_ooo5`3oool0
05T0oooo00@0oooO09a80000000007Bo?P3oool0103ooml0W4P00000001d_olk0?ooo`080;md001d
_ol0oooo0?ooo`3OW4P000000018W03Ooolc0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo>P3o
ool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo?03oool0103ooml0W4P00000001d_olm
0?ooo`040?oog`2LB0000000001d_aH0oooo001K0?ooo`050?oOW018000000000018W03Oool0?03o
ool00`3ogi`0B00007Boo`0l0?ooo`050;md00000000000000000000M;l0=P3oool0102oM0000000
00000000M;ll0?ooo`050;md00000000000000000000M;l0?`3oool00`3ogi`0B00007Boo`0o0?oo
o`050?oOW018000000000018W03Oool04`3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooo
m@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooo
m@3oool00?l0oooom@3oool00?l0oooom@3oool004X0ooooo`00002N000000d0oooo001:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`00
BP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2`3oool004X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00/0oooo001:0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`0;
0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool02`3oool003`0
oooo00@0_g@0000000000000B9cO2P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?oo
o`3oool02`3oool003X0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00T0oooo00<00000
0?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo00/0oooo000j0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?oo
o`3oool02`3oool003T0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`080?oo
o`030000003oool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`0;0?ooo`00>@3oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`03
0000003oool0oooo00/0oooo000i0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0
1`3oool4000000H0ooooI@0co`2:0?oooiX0o`001P3oool4000000d0oooo000i0?ooo`030?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol01`3oool00`000000oooo0?ooo`1/0?oooaP0<ol0H@3o
oolA0?l00:<0oooo00<000000?ooo`3oool02`3oool003T0oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`070?ooo`030000003oool0oooo08@0oooo1`0co`1E0?ooo`D0o`00]03oool0
0`000000oooo0?ooo`0;0?ooo`00>@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
00L0oooo00<000000?ooo`3oool0R`3oool403?o04h0oooo0`3o002i0?ooo`030000003oool0oooo
00/0oooo000j0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0203oool00`000000
oooo0?ooo`2?0?ooo`80<ol0BP3oool20?l00;`0oooo00<000000?ooo`3oool02`3oool003X0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`030000003oool0oooo0940oooo
0P0co`160?ooo`80o`00_P3oool00`000000oooo0?ooo`0;0?ooo`00>`3oool01P2oM00004RL0=oo
o`3oool0_g@0001d_`T0oooo00<000000?ooo`3oool0T`3oool203?o0480oooo0P3o00300?ooo`03
0000003oool0oooo00/0oooo000l0?ooo`040;md000000000000001d_`X0oooo00<000000?ooo`3o
ool0U@3oool203?o03l0oooo00<0o`000?ooo`3oool0`03oool00`000000oooo0?ooo`0;0?ooo`00
BP3oool00`000000oooo0?ooo`2G0?ooo`80<ol0?03oool00`3o0000oooo0?ooo`310?ooo`030000
003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo09T0oooo0P0co`0i0?ooo`030?l0003o
ool0oooo0<80oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0V`3oool0
0`0co`00oooo0?ooo`0e0?ooo`030?l0003oool0oooo0<<0oooo00<000000?ooo`3oool02`3oool0
04X0oooo0`00002L0?ooo`0303?o003oool0oooo03<0oooo00<0o`000?ooo`3oool0`P3oool30000
00d0oooo001:0?ooo`030000003oool0oooo09d0oooo00<0<ol00?ooo`3oool0<P3oool00`3o0000
oooo0?ooo`340?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo09h0oooo
00<0<ol00?ooo`3oool0<03oool00`3o0000oooo0?ooo`350?ooo`030000003oool0oooo00/0oooo
001:0?ooo`030000003oool0oooo09h0oooo00<0<ol00?ooo`3oool0;`3oool00`3o0000oooo0?oo
o`360?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo09l0oooo00<0<ol0
0?ooo`3oool0;P3oool00`3o0000oooo0?ooo`360?ooo`030000003oool0oooo00/0oooo001:0?oo
o`030000003oool0oooo0:00oooo00<0<ol00?ooo`3oool0;03oool00`3o0000oooo0?ooo`370?oo
o`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0:00oooo00<0<ol00?ooo`3o
ool0;03oool00`3o0000oooo0?ooo`370?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000
003oool0oooo0:40oooo00<0<ol00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`380?ooo`030000
003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0:80oooo00<0<ol00?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`380?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0
oooo0:80oooo00<0<ol00?ooo`3oool0:03oool00`3o0000oooo0?ooo`390?ooo`030000003oool0
oooo00/0oooo001:0?ooo`030000003oool0oooo0:<0oooo00<0<ol00?ooo`3oool09`3oool00`3o
0000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo001:0?ooo`<00000X`3oool00`0co`00
oooo0?ooo`0W0?ooo`030?l0003oool0oooo0<L0oooo0`00000=0?ooo`00BP3oool00`000000oooo
0?ooo`2T0?ooo`0303?o003oool0oooo02D0oooo00<0o`000?ooo`3oool0bP3oool00`000000oooo
0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2T0?ooo`0303?o003oool0oooo02D0oooo00<0
o`000?ooo`3oool0bP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2U
0?ooo`0303?o003oool0oooo02<0oooo00<0o`000?ooo`3oool0b`3oool00`000000oooo0?ooo`0;
0?ooo`00BP3oool00`000000oooo0?ooo`2U0?ooo`0303?o003oool0oooo02<0oooo00<0o`000?oo
o`3oool0b`3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2V0?ooo`03
03?o003oool0oooo0280oooo00<0o`000?ooo`3oool0b`3oool00`000000oooo0?ooo`0;0?ooo`00
BP3oool00`000000oooo0?ooo`2V0?ooo`0303?o003oool0oooo0240oooo00<0o`000?ooo`3oool0
c03oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2W0?ooo`0303?o003o
ool0oooo0200oooo00<0o`000?ooo`3oool0c03oool00`000000oooo0?ooo`0;0?ooo`00BP3oool0
0`000000oooo0?ooo`2W0?ooo`0303?o003oool0oooo0200oooo00<0o`000?ooo`3oool0c03oool0
0`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2X0?ooo`0303?o003oool0oooo
01h0oooo00<0o`000?ooo`3oool0c@3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000
oooo0?ooo`2X0?ooo`0303?o003oool0oooo01h0oooo00<0o`000?ooo`3oool0c@3oool00`000000
oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2X0?ooo`0303?o003oool0oooo01h0oooo
00<0o`000?ooo`3oool0c@3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool300000:T0oooo00<0
<ol00?ooo`3oool0703oool00`3o0000oooo0?ooo`3<0?ooo`<000003@3oool004X0oooo00<00000
0?ooo`3oool0Z@3oool00`0co`00oooo0?ooo`0L0?ooo`030?l0003oool0oooo0<h0oooo00<00000
0?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0ZP3oool00`0co`00oooo0?ooo`0K0?oo
o`030?l0003oool0oooo0<h0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3o
ool0ZP3oool00`0co`00oooo0?ooo`0K0?ooo`030?l0003oool0oooo0<h0oooo00<000000?ooo`3o
ool02`3oool004X0oooo00<000000?ooo`3oool0ZP3oool00`0co`00oooo0?ooo`0J0?ooo`030?l0
003oool0oooo0<l0oooo00<000000?ooo`3oool02`3oool002d0oooo00@0_g@0000000000000B9cO
103oool01@3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?ooo`3oool01P3oool00`000000
oooo0?ooo`2[0?ooo`0303?o003oool0oooo01T0oooo00<0o`000?ooo`3oool0c`3oool00`000000
oooo0?ooo`0;0?ooo`00:`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3O
W4P0000004RLg`020?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool01P3oool00`00
0000oooo0?ooo`2[0?ooo`0303?o003oool0oooo01T0oooo00<0o`000?ooo`3oool0c`3oool00`00
0000oooo0?ooo`0;0?ooo`00:`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0
oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`070?ooo`030000003oool0oooo0:/0
oooo00<0<ol00?ooo`3oool06@3oool00`3o0000oooo0?ooo`3?0?ooo`030000003oool0oooo00/0
oooo000Z0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02@3oool00`3OW4P0
B9cO0?ooo`0;0?ooo`030000003oool0oooo0:/0oooo00<0<ol00?ooo`3oool0603oool00`3o0000
oooo0?ooo`3@0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool02@3oool00`3OW4P0M;oo0?ooo`0:0?ooo`030000003oool0oooo0:`0oooo
00<0<ol00?ooo`3oool05`3oool00`3o0000oooo0?ooo`3@0?ooo`030000003oool0oooo00/0oooo
000Z0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02@3oool00`3ooml0W4Q809cO
o`0:0?ooo`030000003oool0oooo0:`0oooo00<0<ol00?ooo`3oool05`3oool00`3o0000oooo0?oo
o`3@0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030?oOW0180000B9cO00@0oooo00<0gia8
0000B02Lgol02P3oool00`3ogi`0B01d0;ooo`090?ooo`@00000Z`3oool00`0co`00oooo0?ooo`0G
0?ooo`030?l0003oool0oooo0<d0oooo1000000=0?ooo`00:P3oool00`3ogi`0B00004RLg`040?oo
o`030=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3oool0203oool00`000000oooo0?ooo`2/0?oo
o`0303?o003oool0oooo01H0oooo00<0o`000?ooo`3oool0d@3oool00`000000oooo0?ooo`0;0?oo
o`00:P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0gia80000M02o
ool0203oool00`000000oooo0?ooo`2/0?ooo`0303?o003oool0oooo01H0oooo00<0o`000?ooo`3o
ool0d@3oool00`000000oooo0?ooo`0;0?ooo`00:`3oool00`2oM00004RL0=ooo`020?ooo`030?oo
g`2LB00007Bo00`0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`2]0?ooo`0303?o
003oool0oooo01D0oooo00<0o`000?ooo`3oool0d@3oool00`000000oooo0?ooo`0;0?ooo`00:`3o
ool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0omnL09boo`3oool00`3o
ool00`2oM000000007Boo`080?ooo`030000003oool0oooo0:d0oooo00<0<ol00?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`3A0?ooo`030000003oool0oooo00/0oooo000/0?ooo`060;md0000B9`0
gooo0?ooo`2oM00007Bo203oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo203oool0
0`000000oooo0?ooo`2]0?ooo`0303?o003oool0oooo01@0oooo00<0o`000?ooo`3oool0dP3oool0
0`000000oooo0?ooo`0;0?ooo`00;@3oool0102oM000000000000000M;l:0?ooo`050;md00000000
000000000000M;l02P3oool00`000000oooo0?ooo`2]0?ooo`0303?o003oool0oooo01@0oooo00<0
o`000?ooo`3oool0dP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2^
0?ooo`0303?o003oool0oooo01<0oooo00<0o`000?ooo`3oool0dP3oool00`000000oooo0?ooo`0;
0?ooo`00BP3oool00`000000oooo0?ooo`2^0?ooo`0303?o003oool0oooo01<0oooo00<0o`000?oo
o`3oool0dP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2^0?ooo`03
03?o003oool0oooo0180oooo00<0o`000?ooo`3oool0d`3oool00`000000oooo0?ooo`0;0?ooo`00
BP3oool00`000000oooo0?ooo`2^0?ooo`0303?o003oool0oooo0180oooo00<0o`000?ooo`3oool0
d`3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool300000:l0oooo00<0<ol00?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`3A0?ooo`<000003@3oool004X0oooo00<000000?ooo`3oool0[`3oool0
0`0co`00oooo0?ooo`0A0?ooo`030?l0003oool0oooo0=<0oooo00<000000?ooo`3oool02`3oool0
04X0oooo00<000000?ooo`3oool0[`3oool00`0co`00oooo0?ooo`0@0?ooo`030?l0003oool0oooo
0=@0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0[`3oool00`0co`00
oooo0?ooo`0@0?ooo`030?l0003oool0oooo0=@0oooo00<000000?ooo`3oool02`3oool004X0oooo
00<000000?ooo`3oool0/03oool00`0co`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo0=@0oooo
00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0/03oool00`0co`00oooo0?oo
o`0?0?ooo`030?l0003oool0oooo0=@0oooo00<000000?ooo`3oool02`3oool004X0oooo00<00000
0?ooo`3oool0/03oool00`0co`00oooo0?ooo`0?0?ooo`030?l0003oool0oooo0=@0oooo00<00000
0?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0/03oool00`0co`00oooo0?ooo`0>0?oo
o`030?l0003oool0oooo0=D0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3o
ool0/@3oool00`0co`00oooo0?ooo`0=0?ooo`030?l0003oool0oooo0=D0oooo00<000000?ooo`3o
ool02`3oool004X0oooo00<000000?ooo`3oool0/@3oool00`0co`00oooo0?ooo`0=0?ooo`030?l0
003oool0oooo0=D0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0/@3o
ool00`0co`00oooo0?ooo`0=0?ooo`030?l0003oool0oooo0=D0oooo00<000000?ooo`3oool02`3o
ool004X0oooo0`00002a0?ooo`0303?o003oool0oooo00d0oooo00<0o`000?ooo`3oool0d`3oool3
000000d0oooo001:0?ooo`030000003oool0oooo0;80oooo00<0<ol00?ooo`3oool0303oool00`3o
0000oooo0?ooo`3E0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0;80
oooo00<0<ol00?ooo`3oool02`3oool00`3o0000oooo0?ooo`3F0?ooo`030000003oool0oooo00/0
oooo001:0?ooo`030000003oool0oooo0;80oooo00<0<ol00?ooo`3oool02`3oool00`3o0000oooo
0?ooo`3F0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0;80oooo00<0
<ol00?ooo`3oool02`3oool00`3o0000oooo0?ooo`3F0?ooo`030000003oool0oooo00/0oooo001:
0?ooo`030000003oool0oooo0;<0oooo00<0<ol00?ooo`3oool02P3oool00`3o0000oooo0?ooo`3F
0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0;<0oooo00<0<ol00?oo
o`3oool02P3oool00`3o0000oooo0?ooo`3F0?ooo`030000003oool0oooo00/0oooo001:0?ooo`03
0000003oool0oooo0;<0oooo00<0<ol00?ooo`3oool02P3oool00`3o0000oooo0?ooo`3F0?ooo`03
0000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0;<0oooo00<0<ol00?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`3G0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003o
ool0oooo0;<0oooo00<0<ol00?ooo`3oool02@3oool00`3o0000oooo0?ooo`3G0?ooo`030000003o
ool0oooo00/0oooo001:0?ooo`030000003oool0oooo0;@0oooo00<0<ol00?ooo`3oool0203oool0
0`3o0000oooo0?ooo`3G0?ooo`030000003oool0oooo00/0oooo001:0?ooo`<00000]03oool00`0c
o`00oooo0?ooo`080?ooo`030?l0003oool0oooo0=D0oooo0`00000=0?ooo`00BP3oool00`000000
oooo0?ooo`2d0?ooo`0303?o003oool0oooo00P0oooo00<0o`000?ooo`3oool0e`3oool00`000000
oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2d0?ooo`0303?o003oool0oooo00P0oooo
00<0o`000?ooo`3oool0e`3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?oo
o`2d0?ooo`0303?o003oool0oooo00L0oooo00<0o`000?ooo`3oool0f03oool00`000000oooo0?oo
o`0;0?ooo`00BP3oool00`000000oooo0?ooo`2d0?ooo`0303?o003oool0oooo00L0oooo00<0o`00
0?ooo`3oool0f03oool00`000000oooo0?ooo`0;0?ooo`00;@3oool0102oM000000000000018W=l4
0?ooo`030=nLB0000000B9cO00H0oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`2e
0?ooo`0303?o003oool0oooo00H0oooo00<0o`000?ooo`3oool0f03oool00`000000oooo0?ooo`0;
0?ooo`00:`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RL
g`060?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool0]@3oool00`0co`00oooo0?oo
o`060?ooo`030?l0003oool0oooo0=P0oooo00<000000?ooo`3oool02`3oool002/0oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0;0?ooo`030?noM0000000M;oo00T0oooo00<00000
0?ooo`3oool0]@3oool00`0co`00oooo0?ooo`060?ooo`030?l0003oool0oooo0=P0oooo00<00000
0?ooo`3oool02`3oool002X0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`06
0?ooo`030=nLB0000000000000D0000000<0001809cOo`3oool01P3oool00`000000oooo0?ooo`2e
0?ooo`0303?o003oool0oooo00D0oooo00<0o`000?ooo`3oool0f@3oool00`000000oooo0?ooo`0;
0?ooo`00:P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04Qd
_`3oool00P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo0;D0oooo00<0<ol00?oo
o`3oool01@3oool00`3o0000oooo0?ooo`3I0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`03
0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01P3oool01`3OW4P0M;oo0?ooo`3oool0okmd
0000001d_ol02@3oool00`000000oooo0?ooo`2e0?ooo`0303?o003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0f@3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool00`3ogi`0B00004RLg`040?oo
o`030=nLB00004P0W=oo00H0oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo00T0oooo1000
002e0?ooo`0303?o003oool0oooo00@0oooo00<0o`000?ooo`3oool0eP3oool4000000d0oooo000Z
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3oool01P3o_g@007Bo0?ooo`3o
_g@0000007Boo`T0oooo00<000000?ooo`3oool0]P3oool00`0co`00oooo0?ooo`040?ooo`030?l0
003oool0oooo0=T0oooo00<000000?ooo`3oool02`3oool002X0oooo00<0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`080?ooo`050;md001d_ol0okmd0000001d_ol02@3oool00`000000oooo
0?ooo`2f0?ooo`0303?o003oool0oooo00@0oooo00<0o`000?ooo`3oool0f@3oool00`000000oooo
0?ooo`0;0?ooo`00:`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0oooo00D0
oono07@0M02o_g@0000007Boo`090?ooo`030000003oool0oooo0;H0oooo00<0<ol00?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`3J0?ooo`030000003oool0oooo00/0oooo000[0?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol02P3oool0103o_g@000000000001d_ol90?ooo`030000
003oool0oooo0;H0oooo00<0<ol00?ooo`3oool00`3oool00`3o0000oooo0?ooo`3J0?ooo`030000
003oool0oooo00/0oooo000/0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2`3oool0103ooml0
W4P00000001d_ol90?ooo`030000003oool0oooo0;H0oooo00<0<ol00?ooo`3oool00`3oool00`3o
0000oooo0?ooo`3J0?ooo`030000003oool0oooo00/0oooo000]0?ooo`040;md000000000000001d
_`d0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`2g0?ooo`0303?o003oool0oooo
0080oooo00<0o`000?ooo`3oool0fP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000
oooo0?ooo`2g0?ooo`0303?o003oool0oooo0080oooo00<0o`000?ooo`3oool0fP3oool00`000000
oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2g0?ooo`0303?o003oool0oooo0080oooo
00<0o`000?ooo`3oool0fP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?oo
o`2g0?ooo`0503?o003oool0oooo0?ooo`3o0000g@3oool00`000000oooo0?ooo`0;0?ooo`00BP3o
ool00`000000oooo0?ooo`2g0?ooo`0503?o003oool0oooo0?ooo`3o0000g@3oool00`000000oooo
0?ooo`0;0?ooo`00BP3oool300000;L0oooo00D0<ol00?ooo`3oool0oooo0?l0003K0?ooo`<00000
3@3oool004X0oooo00<000000?ooo`3oool0^03oool0100co`00oooo0?ooo`3o003M0?ooo`030000
003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0;P0oooo00@0<ol00?ooo`3oool0o`00
g@3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2h0?ooo`0403?o003o
ool0oooo0?l00=d0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0^03o
ool00`0co`00oooo0?l0003N0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0
oooo0;P0oooo00<0<ol00?ooo`3o0000gP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`00
0000oooo0?ooo`2h0?ooo`0303?o003oool0o`000=h0oooo00<000000?ooo`3oool02`3oool004X0
oooo00<000000?ooo`3oool0^@3oool00`0co`00o`000?ooo`3M0?ooo`030000003oool0oooo00/0
oooo001:0?ooo`030000003oool0oooo0;T0oooo00<0<ol00?l0003oool0g@3oool00`000000oooo
0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2i0?ooo`0303?o003oool0oooo0=d0oooo00<0
00000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0^@3oool00`0co`00oooo0?ooo`3M
0?ooo`030000003oool0oooo00/0oooo000E0?ooo`030?oo_`1d000000000080000000L004RL0=oo
o`3ookl0M0000000000007@0_ooo02T0oooo0`00002i0?ooo`0303?o003oool0oooo0=/0oooo0`00
000=0?ooo`00503oool00`3o_g@0000000000004000000060000B02Lgol0oooO09a8000007@0_ooo
:@3oool00`000000oooo0?ooo`2i0?ooo`0303?o003oool0oooo0=d0oooo00<000000?ooo`3oool0
2`3oool001<0oooo00@0omnL04P00000B9`0gooo0`3oool01`3ookl0M0000000M02oool0_g@00000
M02oool0:@3oool00`000000oooo0?ooo`2i0?ooo`030?l0000co`00oooo0=d0oooo00<000000?oo
o`3oool02`3oool00180oooo00<0oooO09a80018W=l01`3oool01@3OW4P0B9cO0;md000007@0_ooo
02T0oooo00<000000?ooo`3oool0^@3oool00`3o0000<ol00?ooo`3M0?ooo`030000003oool0oooo
00/0oooo000B0?ooo`030?oOW018M;l0oooo00L0oooo00D0oono07@000000000001d0;ooo`0Y0?oo
o`030000003oool0oooo0;P0oooo00<0o`000?ooo`0co`00gP3oool00`000000oooo0?ooo`0;0?oo
o`004P3oool00`3o_g@0M;oo0?ooo`0e0?ooo`030000003oool0oooo0;P0oooo00<0o`000?ooo`0c
o`00gP3oool00`000000oooo0?ooo`0;0?ooo`004P3oool00`3o_g@0M;oo0?ooo`0e0?ooo`030000
003oool0oooo0;P0oooo00<0o`000?ooo`0co`00gP3oool00`000000oooo0?ooo`0;0?ooo`004P3o
ool00`3o_g@0M;oo0?ooo`0e0?ooo`030000003oool0oooo0;P0oooo00<0o`000?ooo`0co`00gP3o
ool00`000000oooo0?ooo`0;0?ooo`004P3oool00`3ogi`0B7Bo0?ooo`070?ooo`050?oo_`1d0000
00000000M02oool0:@3oool00`000000oooo0?ooo`2h0?ooo`040?l0003oool0oooo03?o0=d0oooo
00<000000?ooo`3oool02`3oool00180oooo00<0oooO09a80018W=l01`3oool01@3OW4P0B9cO0;md
000007@0_ooo02T0oooo00<000000?ooo`3oool0^03oool0103o0000oooo0?ooo`0co`3M0?ooo`03
0000003oool0oooo00/0oooo000C0?ooo`040?noM000000004RL0=ooo`<0oooo00L0oooO09a80000
07@0_ooo0;md000007@0_ooo02T0oooo00<000000?ooo`3oool0]`3oool01@3o0000oooo0?ooo`3o
ool0<ol00=d0oooo00<000000?ooo`3oool02`3oool001@0oooo00<0gia800000000000010000000
1P0004P0W=oo0?oog`2LB000001d0;ooobT0oooo0`00002g0?ooo`050?l0003oool0oooo0?ooo`0c
o`00f`3oool3000000d0oooo000E0?ooo`030?oOW018000000000080000000L007Bo0?ooo`3ookl0
M0000000000007@0_ooo02T0oooo00<000000?ooo`3oool0]`3oool01@3o0000oooo0?ooo`3oool0
<ol00=d0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0]`3oool01@3o
0000oooo0?ooo`3oool0<ol00=d0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?oo
o`3oool0]`3oool00`3o0000oooo0?ooo`020?ooo`0303?o003oool0oooo0=X0oooo00<000000?oo
o`3oool02`3oool004X0oooo00<000000?ooo`3oool0]`3oool00`3o0000oooo0?ooo`020?ooo`03
03?o003oool0oooo0=X0oooo00<000000?ooo`3oool02`3oool002d0oooo00@0_g@0000000000000
B9cO103oool00`3OW4P0000004RLg`030?ooo`060?oog`2LB00000000000000007@0_ooo2@3oool0
0`000000oooo0?ooo`2f0?ooo`030?l0003oool0oooo00<0oooo00<0<ol00?ooo`3oool0fP3oool0
0`000000oooo0?ooo`0;0?ooo`00:`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3o
ool00`3OW4P0000004RLg`020?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgol80?oo
o`030000003oool0oooo0;H0oooo00<0o`000?ooo`3oool00`3oool00`0co`00oooo0?ooo`3J0?oo
o`030000003oool0oooo00/0oooo000[0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3o
ool0]P3oool00`3o0000oooo0?ooo`030?ooo`0303?o003oool0oooo0=X0oooo00<000000?ooo`3o
ool02`3oool002X0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`03
0?oo_`1d000007Bo00@0oooo00<0gia80000M02oool01`3oool00`000000oooo0?ooo`2f0?ooo`03
0?l0003oool0oooo00<0oooo00<0<ol00?ooo`3oool0fP3oool00`000000oooo0?ooo`0;0?ooo`00
:P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018W=l0
103oool00`2oM000001809cOo`070?ooo`030000003oool0oooo0;H0oooo00<0o`000?ooo`3oool0
103oool00`0co`00oooo0?ooo`3I0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030?oOW018
0000B9cO00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0B00004RLg`030?ooo`040?oo_`1d
0000001d0;ooo`L0oooo00<000000?ooo`3oool0]P3oool00`3o0000oooo0?ooo`040?ooo`0303?o
003oool0oooo0=T0oooo00<000000?ooo`3oool02`3oool002X0oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`050?ooo`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO
00P0oooo1000002d0?ooo`030?l0003oool0oooo00D0oooo00<0<ol00?ooo`3oool0eP3oool40000
00d0oooo000Z0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool01@3ooml0
W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?ooo`2e0?oo
o`030?l0003oool0oooo00D0oooo00<0<ol00?ooo`3oool0f@3oool00`000000oooo0?ooo`0;0?oo
o`00:P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd00000018
W=l03@3oool00`000000oooo0?ooo`2e0?ooo`030?l0003oool0oooo00D0oooo00<0<ol00?ooo`3o
ool0f@3oool00`000000oooo0?ooo`0;0?ooo`00:`3oool00`2oM00004RL0=ooo`020?ooo`030?oo
g`2LB00007Bo00L0oooo00@0oooO09a8000004P0W=oo303oool00`000000oooo0?ooo`2e0?ooo`03
0?l0003oool0oooo00H0oooo00<0<ol00?ooo`3oool0f03oool00`000000oooo0?ooo`0;0?ooo`00
:`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00@0oono07@0000007@0
_ooo2`3oool00`000000oooo0?ooo`2e0?ooo`030?l0003oool0oooo00H0oooo00<0<ol00?ooo`3o
ool0f03oool00`000000oooo0?ooo`0;0?ooo`00;03oool01P2oM00004RL0=ooo`3oool0_g@0001d
_`X0oooo00@0oooO09a80000000007Bo2P3oool00`000000oooo0?ooo`2e0?ooo`030?l0003oool0
oooo00H0oooo00<0<ol00?ooo`3oool0f03oool00`000000oooo0?ooo`0;0?ooo`00;@3oool0102o
M000000000000000M;l=0?ooo`050?oOW018000000000018W03Oool01`3oool00`000000oooo0?oo
o`2d0?ooo`030?l0003oool0oooo00L0oooo00<0<ol00?ooo`3oool0f03oool00`000000oooo0?oo
o`0;0?ooo`00BP3oool00`000000oooo0?ooo`2d0?ooo`030?l0003oool0oooo00L0oooo00<0<ol0
0?ooo`3oool0f03oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2d0?oo
o`030?l0003oool0oooo00L0oooo00<0<ol00?ooo`3oool0f03oool00`000000oooo0?ooo`0;0?oo
o`00BP3oool00`000000oooo0?ooo`2d0?ooo`030?l0003oool0oooo00P0oooo00<0<ol00?ooo`3o
ool0e`3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2d0?ooo`030?l0
003oool0oooo00P0oooo00<0<ol00?ooo`3oool0e`3oool00`000000oooo0?ooo`0;0?ooo`00BP3o
ool300000;@0oooo00<0o`000?ooo`3oool0203oool00`0co`00oooo0?ooo`3E0?ooo`<000003@3o
ool004X0oooo00<000000?ooo`3oool0/`3oool00`3o0000oooo0?ooo`090?ooo`0303?o003oool0
oooo0=L0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0/`3oool00`3o
0000oooo0?ooo`090?ooo`0303?o003oool0oooo0=L0oooo00<000000?ooo`3oool02`3oool004X0
oooo00<000000?ooo`3oool0/`3oool00`3o0000oooo0?ooo`0:0?ooo`0303?o003oool0oooo0=H0
oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0/`3oool00`3o0000oooo
0?ooo`0:0?ooo`0303?o003oool0oooo0=H0oooo00<000000?ooo`3oool02`3oool004X0oooo00<0
00000?ooo`3oool0/`3oool00`3o0000oooo0?ooo`0:0?ooo`0303?o003oool0oooo0=H0oooo00<0
00000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0/P3oool00`3o0000oooo0?ooo`0;
0?ooo`0303?o003oool0oooo0=H0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?oo
o`3oool0/P3oool00`3o0000oooo0?ooo`0;0?ooo`0303?o003oool0oooo0=H0oooo00<000000?oo
o`3oool02`3oool004X0oooo00<000000?ooo`3oool0/P3oool00`3o0000oooo0?ooo`0;0?ooo`03
03?o003oool0oooo0=H0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0
/P3oool00`3o0000oooo0?ooo`0<0?ooo`0303?o003oool0oooo0=D0oooo00<000000?ooo`3oool0
2`3oool004X0oooo00<000000?ooo`3oool0/@3oool00`3o0000oooo0?ooo`0=0?ooo`0303?o003o
ool0oooo0=D0oooo00<000000?ooo`3oool02`3oool004X0oooo0`00002a0?ooo`030?l0003oool0
oooo00d0oooo00<0<ol00?ooo`3oool0d`3oool3000000d0oooo001:0?ooo`030000003oool0oooo
0;40oooo00<0o`000?ooo`3oool03@3oool00`0co`00oooo0?ooo`3E0?ooo`030000003oool0oooo
00/0oooo001:0?ooo`030000003oool0oooo0;40oooo00<0o`000?ooo`3oool03@3oool00`0co`00
oooo0?ooo`3E0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0;00oooo
00<0o`000?ooo`3oool03P3oool00`0co`00oooo0?ooo`3E0?ooo`030000003oool0oooo00/0oooo
001:0?ooo`030000003oool0oooo0;00oooo00<0o`000?ooo`3oool03`3oool00`0co`00oooo0?oo
o`3D0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0;00oooo00<0o`00
0?ooo`3oool03`3oool00`0co`00oooo0?ooo`3D0?ooo`030000003oool0oooo00/0oooo001:0?oo
o`030000003oool0oooo0;00oooo00<0o`000?ooo`3oool03`3oool00`0co`00oooo0?ooo`3D0?oo
o`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0:l0oooo00<0o`000?ooo`3o
ool0403oool00`0co`00oooo0?ooo`3D0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000
003oool0oooo0:l0oooo00<0o`000?ooo`3oool0403oool00`0co`00oooo0?ooo`3D0?ooo`030000
003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0:l0oooo00<0o`000?ooo`3oool04@3o
ool00`0co`00oooo0?ooo`3C0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0
oooo0:l0oooo00<0o`000?ooo`3oool04@3oool00`0co`00oooo0?ooo`3C0?ooo`030000003oool0
oooo00/0oooo001:0?ooo`<00000[P3oool00`3o0000oooo0?ooo`0B0?ooo`0303?o003oool0oooo
0=40oooo0`00000=0?ooo`00BP3oool00`000000oooo0?ooo`2^0?ooo`030?l0003oool0oooo0180
oooo00<0<ol00?ooo`3oool0d`3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo
0?ooo`2^0?ooo`030?l0003oool0oooo01<0oooo00<0<ol00?ooo`3oool0dP3oool00`000000oooo
0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2^0?ooo`030?l0003oool0oooo01<0oooo00<0
<ol00?ooo`3oool0dP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2^
0?ooo`030?l0003oool0oooo01<0oooo00<0<ol00?ooo`3oool0dP3oool00`000000oooo0?ooo`0;
0?ooo`00;@3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00<0oooo00H0omnL
04P00000000000000000B02Lgol90?ooo`030000003oool0oooo0:d0oooo00<0o`000?ooo`3oool0
503oool00`0co`00oooo0?ooo`3B0?ooo`030000003oool0oooo00/0oooo000[0?ooo`070?oog`2L
B00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0omnL04P00000
B9`0gooo0?ooo`3ogi`0B00007Boo`P0oooo00<000000?ooo`3oool0[@3oool00`3o0000oooo0?oo
o`0E0?ooo`0303?o003oool0oooo0=40oooo00<000000?ooo`3oool02`3oool002/0oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia8
0018W03Oool01`3oool00`000000oooo0?ooo`2]0?ooo`030?l0003oool0oooo01D0oooo00<0<ol0
0?ooo`3oool0d@3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool0103ooml0W4P00018W03Oool2
0?ooo`030?oog`2LB00007Bo00L0oooo00<0_g@00000M02oool00`3oool00`2oM00004RL0=ooo`07
0?ooo`030000003oool0oooo0:d0oooo00<0o`000?ooo`3oool05@3oool00`0co`00oooo0?ooo`3A
0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000
M02oool01P3oool00`3o_g@0001809cOo`020?ooo`030=nLB000000007Bo00P0oooo00<000000?oo
o`3oool0[03oool00`3o0000oooo0?ooo`0F0?ooo`0303?o003oool0oooo0=40oooo00<000000?oo
o`3oool02`3oool002X0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`070?ooo`07
0=nLB000M;l0oooo0;md00000000001d0;ooo`080?ooo`030000003oool0oooo0:`0oooo00<0o`00
0?ooo`3oool05`3oool00`0co`00oooo0?ooo`3@0?ooo`030000003oool0oooo00/0oooo000Z0?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0203oool01@3o_g@0000000000000B9`0
gooo00T0oooo1000002[0?ooo`030?l0003oool0oooo01L0oooo00<0<ol00?ooo`3oool0c@3oool4
000000d0oooo000Z0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3oool01@3o
gi`0B000000000000000B9cO00X0oooo00<000000?ooo`3oool0[03oool00`3o0000oooo0?ooo`0G
0?ooo`0303?o003oool0oooo0=00oooo00<000000?ooo`3oool02`3oool002X0oooo00<0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`060?ooo`070?oOW0180000001809cOo`3oool0gia8001d
_`090?ooo`030000003oool0oooo0:`0oooo00<0o`000?ooo`3oool05`3oool00`0co`00oooo0?oo
o`3@0?ooo`030000003oool0oooo00/0oooo000[0?ooo`030;md0000B9`0gooo0080oooo00<0oooO
09a80000M;l01`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo00P0oooo00<00000
0?ooo`3oool0Z`3oool00`3o0000oooo0?ooo`0I0?ooo`0303?o003oool0oooo0<l0oooo00<00000
0?ooo`3oool02`3oool002/0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?oo
o`030=nLB000B9`0gooo0080oooo00<0oooO09a80018W=l0203oool00`000000oooo0?ooo`2[0?oo
o`030?l0003oool0oooo01T0oooo00<0<ol00?ooo`3oool0c`3oool00`000000oooo0?ooo`0;0?oo
o`00;03oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL04P00018W=l00P3oool0
0`3o_g@0001809cOo`080?ooo`030000003oool0oooo0:/0oooo00<0o`000?ooo`3oool06@3oool0
0`0co`00oooo0?ooo`3?0?ooo`030000003oool0oooo00/0oooo000]0?ooo`040;md000000000000
001d_`X0oooo00H0oono07@00000000000000000B02Lgol90?ooo`030000003oool0oooo0:/0oooo
00<0o`000?ooo`3oool06@3oool00`0co`00oooo0?ooo`3?0?ooo`030000003oool0oooo00/0oooo
001:0?ooo`030000003oool0oooo0:X0oooo00<0o`000?ooo`3oool06P3oool00`0co`00oooo0?oo
o`3?0?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0:X0oooo00<0o`00
0?ooo`3oool06`3oool00`0co`00oooo0?ooo`3>0?ooo`030000003oool0oooo00/0oooo001:0?oo
o`030000003oool0oooo0:X0oooo00<0o`000?ooo`3oool06`3oool00`0co`00oooo0?ooo`3>0?oo
o`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0:T0oooo00<0o`000?ooo`3o
ool0703oool00`0co`00oooo0?ooo`3>0?ooo`030000003oool0oooo00/0oooo001:0?ooo`<00000
Z@3oool00`3o0000oooo0?ooo`0L0?ooo`0303?o003oool0oooo0<`0oooo0`00000=0?ooo`00BP3o
ool00`000000oooo0?ooo`2X0?ooo`030?l0003oool0oooo01h0oooo00<0<ol00?ooo`3oool0c@3o
ool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2X0?ooo`030?l0003oool0
oooo01h0oooo00<0<ol00?ooo`3oool0c@3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`00
0000oooo0?ooo`2X0?ooo`030?l0003oool0oooo01h0oooo00<0<ol00?ooo`3oool0c@3oool00`00
0000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2W0?ooo`030?l0003oool0oooo0200
oooo00<0<ol00?ooo`3oool0c03oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo
0?ooo`2W0?ooo`030?l0003oool0oooo0200oooo00<0<ol00?ooo`3oool0c03oool00`000000oooo
0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2V0?ooo`030?l0003oool0oooo0240oooo00<0
<ol00?ooo`3oool0c03oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2V
0?ooo`030?l0003oool0oooo0280oooo00<0<ol00?ooo`3oool0b`3oool00`000000oooo0?ooo`0;
0?ooo`00BP3oool00`000000oooo0?ooo`2U0?ooo`030?l0003oool0oooo02<0oooo00<0<ol00?oo
o`3oool0b`3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`2U0?ooo`03
0?l0003oool0oooo02<0oooo00<0<ol00?ooo`3oool0b`3oool00`000000oooo0?ooo`0;0?ooo`00
BP3oool00`000000oooo0?ooo`2T0?ooo`030?l0003oool0oooo02D0oooo00<0<ol00?ooo`3oool0
bP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool300000:@0oooo00<0o`000?ooo`3oool09@3o
ool00`0co`00oooo0?ooo`380?ooo`<000003@3oool004X0oooo00<000000?ooo`3oool0X`3oool0
0`3o0000oooo0?ooo`0W0?ooo`0303?o003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool0
04X0oooo00<000000?ooo`3oool0X`3oool00`3o0000oooo0?ooo`0W0?ooo`0303?o003oool0oooo
0<T0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0XP3oool00`3o0000
oooo0?ooo`0X0?ooo`0303?o003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool004X0oooo
00<000000?ooo`3oool0XP3oool00`3o0000oooo0?ooo`0Y0?ooo`0303?o003oool0oooo0<P0oooo
00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0X@3oool00`3o0000oooo0?oo
o`0Z0?ooo`0303?o003oool0oooo0<P0oooo00<000000?ooo`3oool02`3oool004X0oooo00<00000
0?ooo`3oool0X03oool00`3o0000oooo0?ooo`0/0?ooo`0303?o003oool0oooo0<L0oooo00<00000
0?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0X03oool00`3o0000oooo0?ooo`0/0?oo
o`0303?o003oool0oooo0<L0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3o
ool0W`3oool00`3o0000oooo0?ooo`0^0?ooo`0303?o003oool0oooo0<H0oooo00<000000?ooo`3o
ool02`3oool004X0oooo00<000000?ooo`3oool0WP3oool00`3o0000oooo0?ooo`0`0?ooo`0303?o
003oool0oooo0<D0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0WP3o
ool00`3o0000oooo0?ooo`0`0?ooo`0303?o003oool0oooo0<D0oooo00<000000?ooo`3oool02`3o
ool004X0oooo0`00002M0?ooo`030?l0003oool0oooo0380oooo00<0<ol00?ooo`3oool0`P3oool3
000000d0oooo001:0?ooo`030000003oool0oooo09`0oooo00<0o`000?ooo`3oool0=03oool00`0c
o`00oooo0?ooo`330?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo09/0
oooo00<0o`000?ooo`3oool0=P3oool00`0co`00oooo0?ooo`320?ooo`030000003oool0oooo00/0
oooo001:0?ooo`030000003oool0oooo09T0oooo0P3o000i0?ooo`0303?o003oool0oooo0<80oooo
00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0V03oool00`3o0000oooo0?oo
o`0j0?ooo`0303?o003oool0oooo0<40oooo00<000000?ooo`3oool02`3oool004X0oooo00<00000
0?ooo`3oool0UP3oool20?l003h0oooo00<0<ol00?ooo`3oool0`03oool00`000000oooo0?ooo`0;
0?ooo`00>`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00L0oooo00<000000?oo
o`3oool0U03oool20?l00440oooo00<0<ol00?ooo`3oool0_`3oool00`000000oooo0?ooo`0;0?oo
o`00?@3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0940oooo0`3o00140?ooo`80
<ol0_`3oool00`000000oooo0?ooo`0;0?ooo`00?@3oool00`2oM000001d0;ooo`0:0?ooo`030000
003oool0oooo08h0oooo0`3o00190?ooo`<0<ol0_03oool00`000000oooo0?ooo`0;0?ooo`00?@3o
ool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo08T0oooo1@3o001?0?ooo`@0<ol0^03o
ool00`000000oooo0?ooo`0;0?ooo`00?@3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0
oooo0880oooo1`3o001H0?ooo`H0<ol0/P3oool00`000000oooo0?ooo`0;0?ooo`00?@3oool00`2o
M000001d0;ooo`0:0?ooo`@000001P3ooomk0?l006D0ooooZ@0co`060?ooo`@000003@3oool003d0
oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3o
ool02`3oool003d0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oooiX0oooo
00<000000?ooo`3oool02`3oool003d0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?oo
o`3o0?oooiX0oooo00<000000?ooo`3oool02`3oool003d0oooo00<0_g@00000M02oool02P3oool0
0`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool02`3oool003d0oooo00<0_g@00000
M02oool02P3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool02`3oool003/0
oooo00D0gia8000000000000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooVP3oool00`00
0000oooo0?ooo`0;0?ooo`00?03oool0103ookl0M0000000M02oool:0?ooo`030000003oool0oooo
0?l0ooooVP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000
003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000oooo0?oo
o`0;0?ooo`00BP3oool300000?l0ooooV03oool3000000d0oooo001:0?ooo`030000003oool0oooo
0?l0ooooVP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooiX0
oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000
003oool0oooo00/0oooo001:0?ooo`030000003oool0oooo0?l0ooooVP3oool00`000000oooo0?oo
o`0;0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool02`3oool0
04X0oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`030000003oool0oooo00/0oooo001:0?ooo`03
0000003oool0oooo0?l0ooooVP3oool00`000000oooo0?ooo`0;0?ooo`00BP3oool00`000000oooo
0?ooo`3o0?oooiX0oooo00<000000?ooo`3oool02`3oool004X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo001:0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`00BP3ooooo0000
09h000003@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499.625}, {308.438, 0}} -> {-8.59234, -0.295532, \
0.0306378, 0.00452452}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 5\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(Fsol = \(NDSolve[{\(F'\)[z]/F[z] \[Equal] x1z[z]/\((1 + z)\), 
              F[zmax] \[Equal] 1}, 
            F[z], {z, 0, zmax}]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(FNsol = \(NDSolve[{\(F'\)[N]/F[N] \[Equal] \(-xx1[N]\), 
              F[nmin] \[Equal] 1}, 
            F[N], {N, nmin, 6}]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(FN[N_] := F[N] /. FNsol // Evaluate\), "\[IndentingNewLine]", 
    \(Clear[x1n, FNacc]\), "\[IndentingNewLine]", 
    \(x1n[N_] := 
      0 /; \((\(-6\) \[LessEqual] 
            N \[LessEqual] \(-1.7\))\)\), "\[IndentingNewLine]", 
    \(x1n[N_] := \(-1\) /; \((\(-1.7\) < N \[LessEqual] nmax)\)\), "\n", 
    \(FNacc[N_] := 
      Exp[\(-NIntegrate[x1n[Nn], {Nn, nmin, N}, AccuracyGoal \[Rule] 6, 
            MaxRecursion \[Rule] 20]\)]\), "\[IndentingNewLine]", 
    \(RN[N_] := \(6 \((2  h[z]^2 - \((1 + z)\) h[z] \(h'\)[z])\) /. 
          z \[Rule] \((Exp[\(-N\)] - 1)\)\) /. {om \[Rule] om0, 
          or \[Rule] or0}\), "\n", 
    \(fN[N_] := \((\(-6\) xx2[N] 
            FN[N] \((h[z]^2 /. 
                z \[Rule] \((Exp[\(-N\)] - 1)\))\))\) /. {om \[Rule] om0, 
          or \[Rule] or0}\), "\n", 
    \(fNacc[
        N_] := \((\(-6\) x2n[N] 
            FNacc[N] \((h[z]^2 /. 
                z \[Rule] \((Exp[\(-N\)] - 1)\))\))\) /. {om \[Rule] om0, 
          or \[Rule] or0}\), "\[IndentingNewLine]", 
    \(fF[N_] := 
      9\ Exp[LogF0] \(om0\/\(xb1 + 3\)\) 
        Exp[\(-\((xb1 + 3)\)\) N]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(data1 = 
        Table[{N, 
            Log[FN[N]]}, {N, \(-6\), \(-4\),  .01}];\)\), \
"\[IndentingNewLine]", 
    \(f1 = FindFit[data1, LogF0 - xb1\ N, {LogF0, xb1}, N]\), "\n", 
    \(\(ppp1 = 
        Plot[\((LogF0 - xb1\ N)\) /. f1, {N, \(-6\), \(-4\)}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(pp2 = 
        ListPlot[data1, PlotStyle \[Rule] {PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[ppp1, pp2, DisplayFunction \[Rule] $DisplayFunction, 
        Frame \[Rule] True, Axes \[Rule] False];\)\)}], "Input"],

Cell[BoxData[
    \({LogF0 \[Rule] 6.4012642467268425`*^-6, 
      xb1 \[Rule] \(-1.1662381748375118`*^-6\)}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.88095 0.47619 0.0982004 140037 [
[.02381 -0.0125 -14 -24.5625 ]
[.02381 -0.0125 14 0 ]
[.2619 -0.0125 -21.5313 -24.5625 ]
[.2619 -0.0125 21.5313 0 ]
[.5 -0.0125 -14 -24.5625 ]
[.5 -0.0125 14 0 ]
[.7381 -0.0125 -21.5313 -24.5625 ]
[.7381 -0.0125 21.5313 0 ]
[.97619 -0.0125 -14 -24.5625 ]
[.97619 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0982 -14.0625 -12.2813 ]
[-0.0125 .0982 0 12.2813 ]
[-0.0125 .23824 -69.5625 -12.2813 ]
[-0.0125 .23824 0 12.2813 ]
[-0.0125 .37827 -69.5625 -12.2813 ]
[-0.0125 .37827 0 12.2813 ]
[-0.0125 .51831 -69.5625 -12.2813 ]
[-0.0125 .51831 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -82.5313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -82.5313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0982 m
.00625 .0982 L
s
gsave
-0.0125 .0982 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .23824 m
.00625 .23824 L
s
gsave
-0.0125 .23824 -130.563 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
76.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
91.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
111.875 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
121.000 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .37827 m
.00625 .37827 L
s
gsave
-0.0125 .37827 -130.563 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
76.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
91.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
111.875 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
121.000 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .51831 m
.00625 .51831 L
s
gsave
-0.0125 .51831 -130.563 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
76.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
91.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
111.875 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
121.000 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12621 m
.00375 .12621 L
s
0 .15422 m
.00375 .15422 L
s
0 .18222 m
.00375 .18222 L
s
0 .21023 m
.00375 .21023 L
s
0 .26625 m
.00375 .26625 L
s
0 .29425 m
.00375 .29425 L
s
0 .32226 m
.00375 .32226 L
s
0 .35027 m
.00375 .35027 L
s
0 .40628 m
.00375 .40628 L
s
0 .43429 m
.00375 .43429 L
s
0 .4623 m
.00375 .4623 L
s
0 .4903 m
.00375 .4903 L
s
0 .07019 m
.00375 .07019 L
s
0 .04219 m
.00375 .04219 L
s
0 .01418 m
.00375 .01418 L
s
0 .54632 m
.00375 .54632 L
s
0 .57433 m
.00375 .57433 L
s
0 .60233 m
.00375 .60233 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0982 m
1 .0982 L
s
.99375 .23824 m
1 .23824 L
s
.99375 .37827 m
1 .37827 L
s
.99375 .51831 m
1 .51831 L
s
.125 Mabswid
.99625 .12621 m
1 .12621 L
s
.99625 .15422 m
1 .15422 L
s
.99625 .18222 m
1 .18222 L
s
.99625 .21023 m
1 .21023 L
s
.99625 .26625 m
1 .26625 L
s
.99625 .29425 m
1 .29425 L
s
.99625 .32226 m
1 .32226 L
s
.99625 .35027 m
1 .35027 L
s
.99625 .40628 m
1 .40628 L
s
.99625 .43429 m
1 .43429 L
s
.99625 .4623 m
1 .4623 L
s
.99625 .4903 m
1 .4903 L
s
.99625 .07019 m
1 .07019 L
s
.99625 .04219 m
1 .04219 L
s
.99625 .01418 m
1 .01418 L
s
.99625 .54632 m
1 .54632 L
s
.99625 .57433 m
1 .57433 L
s
.99625 .60233 m
1 .60233 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .02797 L
.10458 .04242 L
.14415 .05599 L
.18221 .06904 L
.22272 .08293 L
.26171 .09631 L
.30316 .11052 L
.34309 .12422 L
.3815 .13739 L
.42237 .15141 L
.46172 .1649 L
.49955 .17788 L
.53984 .1917 L
.57861 .20499 L
.61984 .21913 L
.65954 .23275 L
.69774 .24585 L
.73838 .25979 L
.77751 .27321 L
.81909 .28747 L
.85916 .30121 L
.89771 .31443 L
.93871 .3285 L
.97619 .34135 L
s
.02 w
.02381 .0982 Mdot
.02857 .0982 Mdot
.03333 .09821 Mdot
.0381 .09822 Mdot
.04286 .09823 Mdot
.04762 .09825 Mdot
.05238 .09827 Mdot
.05714 .0983 Mdot
.0619 .09833 Mdot
.06667 .09837 Mdot
.07143 .09841 Mdot
.07619 .09845 Mdot
.08095 .0985 Mdot
.08571 .09855 Mdot
.09048 .09861 Mdot
.09524 .09867 Mdot
.1 .09873 Mdot
.10476 .0988 Mdot
.10952 .09887 Mdot
.11429 .09895 Mdot
.11905 .09903 Mdot
.12381 .09912 Mdot
.12857 .09921 Mdot
.13333 .0993 Mdot
.1381 .0994 Mdot
.14286 .0995 Mdot
.14762 .09961 Mdot
.15238 .09972 Mdot
.15714 .09983 Mdot
.1619 .09995 Mdot
.16667 .10008 Mdot
.17143 .1002 Mdot
.17619 .10033 Mdot
.18095 .10047 Mdot
.18571 .10061 Mdot
.19048 .10075 Mdot
.19524 .1009 Mdot
.2 .10106 Mdot
.20476 .10121 Mdot
.20952 .10137 Mdot
.21429 .10154 Mdot
.21905 .10171 Mdot
.22381 .10188 Mdot
.22857 .10206 Mdot
.23333 .10224 Mdot
.2381 .10243 Mdot
.24286 .10262 Mdot
.24762 .10281 Mdot
.25238 .10301 Mdot
.25714 .10321 Mdot
.2619 .10342 Mdot
.26667 .10363 Mdot
.27143 .10385 Mdot
.27619 .10407 Mdot
.28095 .10429 Mdot
.28571 .10452 Mdot
.29048 .10475 Mdot
.29524 .10499 Mdot
.3 .10523 Mdot
.30476 .10548 Mdot
.30952 .10572 Mdot
.31429 .10598 Mdot
.31905 .10624 Mdot
.32381 .1065 Mdot
.32857 .10676 Mdot
.33333 .10703 Mdot
.3381 .10731 Mdot
.34286 .10759 Mdot
.34762 .10787 Mdot
.35238 .10816 Mdot
.35714 .10845 Mdot
.3619 .10874 Mdot
.36667 .10904 Mdot
.37143 .10935 Mdot
.37619 .10965 Mdot
.38095 .10997 Mdot
.38571 .11028 Mdot
.39048 .1106 Mdot
.39524 .11093 Mdot
.4 .11126 Mdot
.40476 .11159 Mdot
.40952 .11193 Mdot
.41429 .11227 Mdot
.41905 .11261 Mdot
.42381 .11296 Mdot
.42857 .11332 Mdot
.43333 .11367 Mdot
.4381 .11404 Mdot
.44286 .1144 Mdot
.44762 .11479 Mdot
.45238 .11521 Mdot
.45714 .11567 Mdot
.4619 .11615 Mdot
.46667 .11662 Mdot
.47143 .11709 Mdot
.47619 .11757 Mdot
.48095 .11809 Mdot
.48571 .11866 Mdot
.49048 .11923 Mdot
.49524 .11981 Mdot
.5 .12036 Mdot
.50476 .12097 Mdot
.50952 .12165 Mdot
.51429 .1224 Mdot
.51905 .12321 Mdot
.52381 .12405 Mdot
.52857 .12493 Mdot
.53333 .12582 Mdot
.5381 .12672 Mdot
.54286 .12762 Mdot
.54762 .12849 Mdot
.55238 .12934 Mdot
.55714 .13018 Mdot
.5619 .13114 Mdot
.56667 .13219 Mdot
.57143 .13334 Mdot
.57619 .13456 Mdot
.58095 .13583 Mdot
.58571 .13714 Mdot
.59048 .13847 Mdot
.59524 .1398 Mdot
.6 .14111 Mdot
.60476 .14238 Mdot
.60952 .14361 Mdot
.61429 .14485 Mdot
.61905 .14615 Mdot
.62381 .14751 Mdot
.62857 .14894 Mdot
.63333 .15043 Mdot
.6381 .15198 Mdot
.64286 .1536 Mdot
.64762 .15528 Mdot
.65238 .15702 Mdot
.65714 .15883 Mdot
.6619 .1607 Mdot
.66667 .16263 Mdot
.67143 .16463 Mdot
.67619 .16669 Mdot
.68095 .16881 Mdot
.68571 .17099 Mdot
.69048 .17324 Mdot
.69524 .17555 Mdot
.7 .17793 Mdot
.70476 .18036 Mdot
.70952 .18286 Mdot
.71429 .18543 Mdot
.71905 .18805 Mdot
.72381 .19074 Mdot
.72857 .19353 Mdot
.73333 .19644 Mdot
.7381 .19949 Mdot
.74286 .20266 Mdot
.74762 .20596 Mdot
.75238 .20938 Mdot
.75714 .21294 Mdot
.7619 .21662 Mdot
.76667 .22043 Mdot
.77143 .22437 Mdot
.77619 .22843 Mdot
.78095 .23263 Mdot
.78571 .23695 Mdot
.79048 .2414 Mdot
.79524 .24598 Mdot
.8 .25069 Mdot
.80476 .25552 Mdot
.80952 .26048 Mdot
.81429 .26559 Mdot
.81905 .27092 Mdot
.82381 .27648 Mdot
.82857 .28225 Mdot
.83333 .28825 Mdot
.8381 .29448 Mdot
.84286 .30093 Mdot
.84762 .30761 Mdot
.85238 .3145 Mdot
.85714 .32163 Mdot
.8619 .32897 Mdot
.86667 .33655 Mdot
.87143 .34434 Mdot
.87619 .35236 Mdot
.88095 .36061 Mdot
.88571 .3691 Mdot
.89048 .37796 Mdot
.89524 .38719 Mdot
.9 .3968 Mdot
.90476 .40677 Mdot
.90952 .41712 Mdot
.91429 .42785 Mdot
.91905 .43895 Mdot
.92381 .45042 Mdot
.92857 .46226 Mdot
.93333 .47448 Mdot
.9381 .48707 Mdot
.94286 .50003 Mdot
.94762 .51337 Mdot
.95238 .52708 Mdot
.95714 .5412 Mdot
.9619 .55587 Mdot
.96667 .57111 Mdot
.97143 .58693 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00D03oool01P3ooml0W4P0000000000000001d0;ooob<0oooo00H0_g@0
00000000000000000018W03Oool40?ooo`030=nLB0000000B9cO0080oooo00H0_g@0000000000000
00000018W03OoolS0?ooo`060;md00000000000000000000B9`0gooo:03oool00`3o_g@0000007Bo
o`030?ooo`030=nLB0000000B9cO0080oooo00H0_g@000000000000000000018W03OoolW0?ooo`03
0?noM0000000M;oo00H0oooo001?0?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02LgolQ
0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool00`3oool01`3OW4P0000004RLg`3o
ool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0Q0?ooo`030?oog`2LB000B9cO0080oooo
00<0omnL04Q8W03Oool09`3oool00`3o_g@0000007Boo`030?ooo`070=nLB0000000B9cO0?ooo`3o
oml0W4P004RLg`020?ooo`030?oOW018B9`0gooo02H0oooo00<0okmd0000001d_ol01P3oool004l0
oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`0V0?ooo`030?oOW018M;l0oooo00`0
oooo00<0omnL04Qd_`3oool09P3oool00`3ogi`0B7Bo0?ooo`0V0?ooo`030?noM0000000M;oo00d0
oooo00<0omnL04Qd_`3oool09@3oool00`3o_g@0000007Boo`060?ooo`00CP3oool00`3ookl0M000
001d_`040?ooo`030=nLB00007@0_ooo02H0oooo00<0oono07@0B02Lgol0303oool00`3ookl0M018
09cOo`0V0?ooo`030?oo_`1d04P0W=oo0240oooo00<0gia80000000000001@0000000`0004P0W=oo
0?ooo`0:0?ooo`030?oo_`1d04P0W=oo0200oooo00<0gia80000000000001@0000000`0004P0W=oo
0?ooo`030?ooo`00CP3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo02H0oooo00<0
oono07@0001d_ol0303oool00`3ookl0M00007Boo`0V0?ooo`030?oo_`1d0000M;oo0240oooo00<0
omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0=0?ooo`030?oo_`1d0000M;oo0200oooo00<0
omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`060?ooo`00@P3oool00`2oM000000000000007
0000000504RLg`3oool0omnL04P00018W=l00`3oool0103ookl0M0000000M02ooolC0?ooo`030;md
00000000000000L0000000<0B9cO0?ooo`3oool01P3oool00`3o_g@0000007Boo`0<0?ooo`030?no
M0000000M;oo01@0oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`050?ooo`030?no
M0000000M;oo01@0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3oool0gia807Bo
o`80oooo00<0okmd0000001d_ol03@3oool00`3o_g@0000007Boo`0D0?ooo`030;md000000000000
00L0000000D0B9cO0?ooo`3oool0gia807Boo`020?ooo`030?noM0000000M;oo00H0oooo001>0?oo
o`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO02H0oooo00@0omnL04P0000007@0
_ooo2`3oool0103ogi`0B0000000M02ooolU0?ooo`040?oOW0180000001d0;ooob80oooo00L0oono
07@0M02oool0oooo0?noM0000000M;oo00`0oooo00@0omnL04P0000007@0_ooo8@3oool01`3ookl0
M01d0;ooo`3oool0okmd0000001d_ol01P3oool004h0oooo00D0oooO09a8000007@0_mnL04P00002
0000000304RLg`3oool0oooo0240oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?oo
o`060?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0803oool0103Ogml0oooo
0?ooo`2oM0020000000304RLg`3oool0oooo0280oooo00H0okmd001d_`3oool0okmd0000001d_ol8
0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool08@3oool01P3o_g@007Bo0?oo
o`3o_g@0000007Boo`H0oooo001?0?ooo`030?noM0000000B9cO02L0oooo00<0okmd000000000000
0P0000000`00M;l0oooo0?ooo`070?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0
8@3oool00`3o_g@000000000000200000003001d_`3oool0oooo02@0oooo00D0_g@007Boo`3o_g@0
000007Boo`080?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool08`3oool01@2oM000
M;oo0?noM0000000M;oo00H0oooo001?0?ooo`040?oog`2LB000001809cOobH0oooo00D0oooO09a8
00000000001d0;ooo`0:0?ooo`050?oog`2LB00000000000M02oool0903oool01@3ooml0W4P00000
000007@0_ooo02L0oooo00D0oono07@0M02o_g@0000007Boo`080?ooo`050?oog`2LB00000000000
M02oool09P3oool01@3ookl0M01d0;noM0000000M;oo00H0oooo001@0?ooo`040?oo_`1d0000001d
0;ooobH0oooo00<0okmd001d_`3oool0303oool00`3o_g@007Bo0?ooo`0V0?ooo`030?noM000M;l0
oooo02T0oooo00@0okmd000000000000M;oo2@3oool00`3o_g@007Bo0?ooo`0X0?ooo`040?noM000
0000000007Boo`H0oooo001A0?ooo`040?oog`2LB0000000001d_bD0oooo00<0oooO09a800000000
0P0000000`0007@0_ooo0?ooo`070?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0
8@3oool00`3ooml0W4P000000002000000030000M02oool0oooo02@0oooo00@0oooO09a800000000
M;oo2@3oool00`3ooml0W4P000000002000000030000M02oool0oooo02<0oooo00@0oooO09a80000
0000M;oo1P3oool005<0oooo00D0omnL04P00000000004RL0=ooo`0S0?ooo`030?noM00000000000
0080000000<0M;oo0?ooo`3oool01`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo
0240oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0T0?ooo`030?oOW0180000M;oo
00X0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0S0?ooo`030?oOW0180000M;oo
00H0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo00180?ooolh000002P3oool0
04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`00B03oool00`000000oooo0?ooo`3:0?oo
o`030000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo0080oooo0P0000360?ooo`03
0000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo00@0oooo0P0000340?ooo`030000
003oool0oooo00P0oooo00180?ooo`030000003oool0oooo00H0oooo0P0000320?ooo`030000003o
ool0oooo00P0oooo00180?ooo`030000003oool0oooo00P0oooo0`00002o0?ooo`030000003oool0
oooo00P0oooo00180?ooo`030000003oool0oooo00/0oooo0`00002l0?ooo`030000003oool0oooo
00P0oooo00180?ooo`030000003oool0oooo00h0oooo0`00002i0?ooo`030000003oool0oooo00P0
oooo00180?ooo`030000003oool0oooo0140oooo0`00002f0?ooo`030000003oool0oooo00P0oooo
00180?ooo`030000003oool0oooo01@0oooo0P00002d0?ooo`030000003oool0oooo00P0oooo0018
0?ooo`030000003oool0oooo01H0oooo0`00002a0?ooo`030000003oool0oooo00P0oooo00180?oo
o`030000003oool0oooo01T0oooo0`00002^0?ooo`030000003oool0oooo00P0oooo00180?ooo`03
0000003oool0oooo01`0oooo1000002Z0?ooo`030000003oool0oooo00P0oooo000l0?ooo`040;md
00000000000004RLg`P0oooo00<000000?ooo`3oool0803oool400000:H0oooo00<000000?ooo`3o
ool0203oool003X0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00L0oooo00<000000?oo
o`3oool0903oool200000:@0oooo00<000000?ooo`3oool0203oool003X0oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`060?ooo`030000003oool0oooo02H0oooo0`00002Q0?ooo`03
0000003oool0oooo00P0oooo000i0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000
M;l01P3oool00`000000oooo0?ooo`0Y0?ooo`<00000WP3oool00`000000oooo0?ooo`080?ooo`00
>@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<000000?ooo`3oool0
;03oool2000009`0oooo00<000000?ooo`3oool0203oool003T0oooo00<0omnL04P00018W=l0103o
ool00`2oM000001d0;ooo`050?ooo`040000003oool0oooo0?ooob/000000P3oool3000009T0oooo
00<000000?ooo`3oool0203oool003T0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`050?ooo`80000000<0oooo000000000000@00000270?ooo`8000002P3oool003T0oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`030000003oool0oooo05400000N@3oool0
0`000000oooo0?ooo`080?ooo`00>@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
00D0oooo00@000000?ooo`3oool0ooooG000001]0?ooo`030000003oool0oooo00P0oooo000j0?oo
o`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01P3oool00`000000oooo0?ooo`0[0?oo
oc/00000I03oool00`000000oooo0?ooo`080?ooo`00>P3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo00H0oooo00<000000?ooo`3oool0?@3oool200000080oooo:`00001N0?ooo`03
0000003oool0oooo00P0oooo000k0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo1`3oool00`00
0000oooo0?ooo`0o0?ooo`<000003P3ooolR000005P0oooo00<000000?ooo`3oool0203oool003`0
oooo00@0_g@000000000000007Bo203oool00`000000oooo0?ooo`120?ooo`<000005`3ooolJ0000
05@0oooo00<000000?ooo`3oool0203oool004P0oooo00<000000?ooo`3oool0A@3oool4000001`0
oooo5000001A0?ooo`030000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo04T0oooo
1000000N0?oooa800000C@3oool00`000000oooo0?ooo`080?ooo`00B03oool00`000000oooo0?oo
o`1=0?ooo`<000008@3oool?000004X0oooo00<000000?ooo`3oool0203oool004P0oooo00<00000
0?ooo`3oool0D03oool300000280oooo3P0000170?ooo`030000003oool0oooo00P0oooo00180?oo
o`030000003oool0oooo05<0oooo0`00000R0?ooo`d00000A@3oool00`000000oooo0?ooo`080?oo
o`00B03oool00`000000oooo0?ooo`1F0?ooo`800000903oool<00000480oooo00<000000?ooo`3o
ool0203oool004P0oooo00<000000?ooo`3oool0F03oool3000002@0oooo2`0000100?ooo`030000
003oool0oooo00P0oooo00180?ooo`030000003oool0oooo05/0oooo0`00000T0?ooo`X00000?P3o
ool00`000000oooo0?ooo`080?ooo`00B03oool00`000000oooo0?ooo`1N0?ooo`800000903oool:
000003`0oooo00<000000?ooo`3oool0203oool004P0oooo00<000000?ooo`3oool0H03oool20000
02D0oooo2@00000j0?ooo`030000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo0680
oooo1000000S0?ooo`T00000>03oool00`000000oooo0?ooo`080?ooo`00B03oool00`000000oooo
0?ooo`1V0?ooo`@000008@3oool9000003H0oooo00<000000?ooo`3oool0203oool004P0oooo00<0
00000?ooo`3oool0JP3oool4000001l0oooo2000000e0?ooo`030000003oool0oooo00P0oooo0018
0?ooo`030000003oool0oooo06h0oooo0P00000O0?ooo`P00000<`3oool00`000000oooo0?ooo`08
0?ooo`00B03oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool700000380oooo00<000000?oo
o`3oool0203oool004P0oooo00<000000?ooo`3oool0L`3oool3000001d0oooo1`00000`0?ooo`03
0000003oool0oooo00P0oooo00040?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0
103oool00`2oM4P0W=oo0?ooo`060?ooo`030?noW01d_ml0oooo00@0oooo00<0okmd000000000000
0P0000000`00M;l0oooo0?ooo`030?ooo`040;md00000000000004RLgaT0oooo00<000000?ooo`3o
ool0MP3oool2000001`0oooo1`00000_0?ooo`030000003oool0oooo00P0oooo00060?ooo`030;md
000007@0_ooo00L0oooo00<0okmd0000B02Lgol01@3oool00`3o_g@0001809cOo`070?ooo`030;md
000007@0_ooo00@0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo01P0oooo00<000000?oo
o`3oool0N03oool3000001/0oooo1P00000^0?ooo`030000003oool0oooo00P0oooo00060?ooo`03
0;md000007@0_ooo00P0oooo00<0okmd0000B02Lgol00`3oool00`3o_g@0001809cOo`080?ooo`03
0;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0G0?ooo`03
0000003oool0oooo07/0oooo0`00000I0?ooo`H00000;@3oool00`000000oooo0?ooo`080?ooo`00
1P3oool00`2oM000001d0;ooo`090?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`090?oo
o`030;md000007@0_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0G
0?ooo`030000003oool0oooo07h0oooo0P00000I0?ooo`H00000:`3oool00`000000oooo0?ooo`08
0?ooo`001P3oool00`2oM000001d0;ooo`0:0?ooo`050?noM00004P0W9ad0000B02Lgol02P3oool0
0`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool05P3oool0
0`000000oooo0?ooo`200?ooo`<000005`3oool6000002X0oooo00<000000?ooo`3oool0203oool0
00H0oooo00<0_g@00000M02oool02`3oool00`3o_g@0001809cOo`0;0?ooo`030;md000007@0_ooo
00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0F0?ooo`030000003oool0oooo
08<0oooo0`00000E0?ooo`H00000:@3oool00`000000oooo0?ooo`080?ooo`001P3oool00`2oM000
001d0;ooo`0:0?ooo`050?noM00004P0W9ad0000B02Lgol02P3oool00`2oM000001d0;ooo`030?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol05P3oool2000008L0oooo0P00000D0?oo
o`H000009`3oool2000000X0oooo00060?ooo`030;md000007@0_ooo00T0oooo00L0okmd0000B02L
gol0oooo0?noM00004P0W=oo00T0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo01H0oooo00<000000?ooo`3oool0R03oool3000001<0oooo1@00000W
0?ooo`030000003oool0oooo00P0oooo00060?ooo`030;md000007@0_ooo00P0oooo00<0okmd0000
B02Lgol00`3oool00`3o_g@0001809cOo`080?ooo`030;md000007@0_ooo00<0oooo00<0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`050?oo_`1d000000000000M02oool01P3oool0
0`000000oooo0?ooo`2;0?ooo`@00000403oool5000002H0oooo00<000000?ooo`3oool0203oool0
00H0oooo00<0_g@00000M02oool01`3oool00`2oM000001809cOo`050?ooo`030?noM0000000B9cO
00L0oooo00<0_g@00000M02oool0103oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo
00/0oooo00L0oooO09a80000M;l0oooo0?noM000B9`0gooo00D0oooo00<000000?ooo`3oool0S`3o
ool4000000d0oooo1@00000U0?ooo`030000003oool0oooo00P0oooo00060?ooo`030;md000007@0
_ooo00L0oooo00<0oknL09cOo`3oool01P3oool00`3o_i`0W=oo0?ooo`060?ooo`030;md000007@0
_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0;0?ooo`070?oOW01807@0
_ooo0?ooo`3ooml0W4Q809cOo`050?ooo`030000003oool0oooo09<0oooo1000000:0?ooo`D00000
903oool00`000000oooo0?ooo`080?ooo`00103oool01@3OW4P000000000000007@0_ooo01L0oooo
00D0gia8000000000000001d0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo0P3oool0
0`3ookl0M000000000040000000:0000B02Lgol0oooo0?noM000B9`0gooo0?ooo`3ooml0W4P007Bo
o`D0oooo00<000000?ooo`3oool0U`3oool2000000T0oooo1@00000S0?ooo`030000003oool0oooo
00P0oooo00050?ooo`040?oo_`1d0000001d0;oooaP0oooo00@0oono07@0000007@0_ooo1P3oool0
102oM000000000000000M;l=0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M00007Boo`050?ooo`03
0000003oool0oooo09T0oooo0`0000070?ooo`D000008P3oool00`000000oooo0?ooo`080?ooo`00
?03oool01`3ogi`0B01d07Bo_`3oool0gia80000M02oool01@3oool00`000000oooo0?ooo`2L0?oo
o`<000001@3oool500000240oooo00<000000?ooo`3oool0203oool003`0oooo00<0oooO09a8001d
M7@00P0000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo09l0oooo0P0000040?ooo`@0
00008@3oool00`000000oooo0?ooo`080?ooo`00?@3oool00`3o_g@0001d0;ooo`080?ooo`030000
003oool0oooo0:40oooo0`0000020?ooo`@00000803oool00`000000oooo0?ooo`080?ooo`00?P3o
ool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo0:@0oooo1`00000O0?ooo`030000003o
ool0oooo00P0oooo000o0?ooo`040?oOW0180000001809cOo`D0oooo00<000000?ooo`3oool0Y`3o
ool5000001h0oooo00<000000?ooo`3oool0203oool004P0oooo00<000000?ooo`3oool0Z03oool5
000001d0oooo00<000000?ooo`3oool0203oool004P0oooo00<000000?ooo`3oool0Z@3oool60000
01/0oooo00<000000?ooo`3oool0203oool004P0oooo00<000000?ooo`3oool0ZP3oool400000003
0?ooo`000000000001T0oooo00<000000?ooo`3oool0203oool004P0oooo00<000000?ooo`3oool0
ZP3oool500000080oooo0`00000F0?ooo`030000003oool0oooo00P0oooo00180?ooo`030000003o
ool0oooo0:/0oooo100000050?ooo`<000004`3oool00`000000oooo0?ooo`080?ooo`00B03oool0
0`000000oooo0?ooo`2/0?ooo`@000001`3oool300000100oooo00<000000?ooo`3oool0203oool0
04P0oooo00<000000?ooo`3oool0[03oool4000000X0oooo0`00000=0?ooo`030000003oool0oooo
00P0oooo00180?ooo`030000003oool0oooo0:`0oooo1000000=0?ooo`<000002P3oool00`000000
oooo0?ooo`080?ooo`00B03oool00`000000oooo0?ooo`2]0?ooo`@000003`3oool4000000H0oooo
00<000000?ooo`3oool0203oool004P0oooo00<000000?ooo`3oool0[@3oool500000180oooo0`00
00030?ooo`030000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo0:h0oooo1000000H
0?ooo`030000003oool0oooo00P0oooo00020?ooo`030=nLB0000000000000D0000000<0M;oo0?oo
o`3oool00`3oool00`2oM4P0W=oo0?ooo`060?ooo`030?noW01d_ml0oooo00@0oooo00<0okmd0000
000000000P0000000`00M;l0oooo0?ooo`030?ooo`040;md00000000000004RLgaT0oooo00<00000
0?ooo`3oool0[`3oool4000001L0oooo00<000000?ooo`3oool0203oool000<0oooo00<0gia80000
00000000100000000`00M;l0oooo0?ooo`030?ooo`030?noM00004P0W=oo00D0oooo00<0okmd0000
B02Lgol01`3oool00`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d
_`0H0?ooo`030000003oool0oooo0:l0oooo1000000G0?ooo`030000003oool0oooo00P0oooo0004
0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01@3oool00`3o_g@0001809cOo`03
0?ooo`030?noM00004P0W=oo00P0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo01L0oooo00<000000?ooo`3oool0/03oool4000001H0oooo00<00000
0?ooo`3oool0203oool000D0oooo00<0gia804RLg`3oool02P3oool01`3o_g@0001809cOo`3oool0
okmd0000B02Lgol02@3oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0oooO09a80000M;l05`3oool00`000000oooo0?ooo`2`0?ooo`D000005@3oool00`000000oooo
0?ooo`080?ooo`001P3oool00`3OW4P0M;oo0?ooo`0:0?ooo`050?noM00004P0W9ad0000B02Lgol0
2P3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
5P3oool00`000000oooo0?ooo`2a0?ooo`@000005@3oool00`000000oooo0?ooo`080?ooo`001P3o
ool00`3ooml0W4Q809cOo`0;0?ooo`030?noM00004P0W=oo00/0oooo00<0_g@00000M02oool00`3o
ool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo01H0oooo00<000000?ooo`3oool0/P3o
ool4000001@0oooo00<000000?ooo`3oool0203oool000L0oooo00<0omnL04P0M02oool02@3oool0
1@3o_g@0001809bLM00004P0W=oo00X0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo01H0oooo0P00002c0?ooo`@000004`3oool2000000X0oooo0008
0?ooo`030;md0018W=l0oooo00L0oooo00L0okmd0000B02Lgol0oooo0?noM00004P0W=oo00T0oooo
00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01H0oooo
00<000000?ooo`3oool0/`3oool4000001<0oooo00<000000?ooo`3oool0203oool000P0oooo00<0
gia80000M02oool01P3oool00`3o_g@0001809cOo`030?ooo`030?noM00004P0W=oo00P0oooo00<0
_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00D0
oono07@000000000001d0;ooo`060?ooo`030000003oool0oooo0;<0oooo1000000C0?ooo`030000
003oool0oooo00P0oooo00080?ooo`030?noM0000000M;oo00D0oooo00<0_g@00000B02Lgol01@3o
ool00`3o_g@0000004RLg`070?ooo`030;md000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3o
ool00`3ooml0W4P0001d_`0;0?ooo`070?oog`2LB00007Bo0?ooo`3o_g@004RL0=ooo`050?ooo`03
0000003oool0oooo0;@0oooo1000000B0?ooo`030000003oool0oooo00P0oooo00020?ooo`030?oO
W02L_ol0oooo00<0oooo00<0_g@00000001d_ol01@3oool00`3o_i`0W=oo0?ooo`060?ooo`030?no
W02Lgol0oooo00H0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo00/0oooo00L0omnL04P0M02oool0oooo0?oog`2LB4P0W=oo00D0oooo00<000000?oo
o`3oool0]03oool400000180oooo00<000000?ooo`3oool0203oool000<0oooo00P0_g@007Boo`3o
ool0oooo0=nLB000000004RL0=oooaD0oooo00D0gia8000000000000001d0;ooo`050?ooo`060;md
0000B9`0gooo0?ooo`2oM00007Bo0P3oool00`3ookl0M000000000040000000:0000B02Lgol0oooo
0?noM000B9`0gooo0?ooo`3ooml0W4P007Boo`D0oooo00<000000?ooo`3oool0]@3oool400000140
oooo00<000000?ooo`3oool0203oool000@0oooo00D0_g@00000000000000000001d_`0H0?ooo`04
0?oo_`1d0000001d0;ooo`H0oooo00@0_g@000000000000007Bo3@3oool01`3o_g@004RL0=ooo`3o
ool0oono07@0001d_ol01@3oool00`000000oooo0?ooo`2e0?ooo`@000004@3oool00`000000oooo
0?ooo`080?ooo`00?03oool01`3ogi`0B01d07Bo_`3oool0gia80000M02oool01@3oool00`000000
oooo0?ooo`2f0?ooo`@00000403oool00`000000oooo0?ooo`080?ooo`00?03oool00`3ooml0W4P0
07AdM0020000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0]P3oool400000100oooo
00<000000?ooo`3oool0203oool003d0oooo00<0okmd0000M02oool0203oool00`000000oooo0?oo
o`2g0?ooo`<00000403oool00`000000oooo0?ooo`080?ooo`00?P3oool00`3OW4P0001809cOo`07
0?ooo`030000003oool0oooo0;L0oooo1000000?0?ooo`030000003oool0oooo00P0oooo000o0?oo
o`040?oOW0180000001809cOo`D0oooo00<000000?ooo`3oool0]`3oool4000000l0oooo00<00000
0?ooo`3oool0203oool004P0oooo00<000000?ooo`3oool0^03oool4000000h0oooo00<000000?oo
o`3oool0203oool004P0oooo00<000000?ooo`3oool0^03oool4000000h0oooo00<000000?ooo`3o
ool0203oool004P0oooo00<000000?ooo`3oool0^@3oool4000000d0oooo00<000000?ooo`3oool0
203oool004P0oooo00<000000?ooo`3oool0^@3oool4000000d0oooo00<000000?ooo`3oool0203o
ool004P0oooo00<000000?ooo`3oool0^P3oool3000000d0oooo00<000000?ooo`3oool0203oool0
04P0oooo00<000000?ooo`3oool0^P3oool4000000`0oooo00<000000?ooo`3oool0203oool004P0
oooo00<000000?ooo`3oool0^P3oool4000000`0oooo00<000000?ooo`3oool0203oool004P0oooo
00<000000?ooo`3oool0^`3oool4000000/0oooo00<000000?ooo`3oool0203oool004P0oooo00<0
00000?ooo`3oool0^`3oool4000000/0oooo00<000000?ooo`3oool0203oool004P0oooo00<00000
0?ooo`3oool0_03oool3000000/0oooo00<000000?ooo`3oool0203oool004P0oooo00<000000?oo
o`3oool0_03oool4000000X0oooo00<000000?ooo`3oool0203oool00080oooo00<0oooO09a80000
00000P0000000`00B9`0gooo0?ooo`060?ooo`030;mdB02Lgol0oooo00H0oooo00<0oknL07Bog`3o
ool0103oool00`3o_g@000000000000200000003001d_`3oool0oooo00<0oooo00@0_g@000000000
0000B9cO6@3oool00`000000oooo0?ooo`2l0?ooo`@000002P3oool00`000000oooo0?ooo`080?oo
o`000P3oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0W=oo1P3oool00`3o_g@0001809cO
o`050?ooo`030?noM00004P0W=oo00L0oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d
_`3oool0oooO09a80000M;l0603oool00`000000oooo0?ooo`2m0?ooo`@000002@3oool00`000000
oooo0?ooo`080?ooo`00203oool00`3o_g@004RL0=ooo`060?ooo`030?noM00004P0W=oo00<0oooo
00<0okmd0000B02Lgol0203oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol05`3oool00`000000oooo0?ooo`2m0?ooo`@000002@3oool00`000000oooo
0?ooo`080?ooo`00203oool00`3o_g@0001809cOo`070?ooo`070?noM00004P0W=oo0?ooo`3o_g@0
001809cOo`090?ooo`030;md000007@0_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3o
oml0W4P0001d_`0G0?ooo`030000003oool0oooo0;h0oooo0`0000090?ooo`030000003oool0oooo
00P0oooo00080?ooo`030;md000004P0W=oo00P0oooo00D0okmd0000B02LW7@0001809cOo`0:0?oo
o`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0F0?oo
o`030000003oool0oooo0;h0oooo100000080?ooo`030000003oool0oooo00P0oooo00070?ooo`04
0;md00000000001d0;ooo`T0oooo00<0okmd0000B02Lgol02`3oool00`2oM000001d0;ooo`030?oo
o`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool05P3oool00`000000oooo0?ooo`2n0?oo
o`@00000203oool00`000000oooo0?ooo`080?ooo`00103oool00`3ookl0M0000000000200000003
04RLg`3oool0oooo00L0oooo00D0okmd0000B02LW7@0001809cOo`0:0?ooo`030;md000007@0_ooo
00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0F0?ooo`800000`03oool30000
00L0oooo0P00000:0?ooo`001P3oool00`3o_g@0001809cOo`090?ooo`070?noM00004P0W=oo0?oo
o`3o_g@0001809cOo`090?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`0F0?ooo`030000003oool0oooo0;l0oooo100000070?ooo`030000003oool0
oooo00P0oooo00070?ooo`030?oOW018M;l0oooo00L0oooo00<0okmd0000B02Lgol00`3oool00`3o
_g@0001809cOo`080?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2o
M000001d0;ooo`0;0?ooo`050?oo_`1d000000000000M02oool01P3oool00`000000oooo0?ooo`2o
0?ooo`@000001`3oool00`000000oooo0?ooo`080?ooo`001`3oool00`3ooml0W4P004RLg`060?oo
o`030;md000004P0W=oo00D0oooo00<0okmd00000018W=l01`3oool00`2oM000001d0;ooo`040?oo
o`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l02`3oool01`3ooml0W4P0001d_`3oool0
okmd0018W03Oool01@3oool00`000000oooo0?ooo`300?ooo`<000001`3oool00`000000oooo0?oo
o`080?ooo`000P3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB00007Bo00H0oooo00<0oknL
09cOo`3oool01P3oool00`3o_i`0W=oo0?ooo`060?ooo`030;md000007@0_ooo00@0oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0;0?ooo`070?oOW01807@0_ooo0?ooo`3ooml0W4Q8
09cOo`050?ooo`030000003oool0oooo0<00oooo100000060?ooo`030000003oool0oooo00P0oooo
00030?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`0F0?ooo`050=nLB000000000000000
M02oool01@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`80oooo00<0oono07@0000000001000
00002P0004P0W=oo0?ooo`3o_g@004RL0=ooo`3oool0oooO09a8001d_ol50?ooo`030000003oool0
oooo0<00oooo100000060?ooo`030000003oool0oooo00P0oooo00040?ooo`050?oOW01800000000
00000018W=l0603oool0103ookl0M0000000M02oool60?ooo`040;md000000000000001d_`d0oooo
00L0okmd0018W03Oool0oooo0?oo_`1d0000M;oo00D0oooo00<000000?ooo`3oool0`@3oool30000
00H0oooo00<000000?ooo`3oool0203oool003`0oooo00L0omnL04P0M01d_kl0oooo0=nLB00007@0
_ooo00D0oooo00<000000?ooo`3oool0`@3oool4000000D0oooo00<000000?ooo`3oool0203oool0
03`0oooo00<0oooO09a8001dM7@00P0000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo
0<40oooo100000050?ooo`030000003oool0oooo00P0oooo000m0?ooo`030?noM00007@0_ooo00P0
oooo00<000000?ooo`3oool0`P3oool3000000D0oooo00<000000?ooo`3oool0203oool003h0oooo
00<0gia80000B02Lgol01`3oool00`000000oooo0?ooo`320?ooo`@00000103oool00`000000oooo
0?ooo`080?ooo`00?`3oool0103ogi`0B0000000B02Lgol50?ooo`030000003oool0oooo0<80oooo
100000040?ooo`030000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo0<<0oooo0`00
00040?ooo`030000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo0<<0oooo10000003
0?ooo`030000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo0<<0oooo100000030?oo
o`030000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo0<@0oooo0P0000040?ooo`03
0000003oool0oooo00P0oooo00180?ooo`030000003oool0oooo0<D0oooo0P0000030?ooo`030000
003oool0oooo00P0oooo00180?ooo`030000003oool0oooo0<@0oooo100000020?ooo`030000003o
ool0oooo00P0oooo00180?ooo`030000003oool0oooo0<@0oooo100000020?ooo`030000003oool0
oooo00P0oooo00180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`8000000`3oool00`000000oooo0?ooo`080?ooo`00B03oooo>000000X0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.78621, -2.03573*^-06, \
0.0102059, 3.47049*^-08}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tt1 = 
        Table[{\(fF[N] /. f1\) /. N \[Rule] nn, 
            fN[N] /. N \[Rule] 
                nn}, {nn, \(-6\), \(-4\),  .01}];\)\), "\[IndentingNewLine]", \

    \(Fit[tt1, {1, x}, x]\)}], "Input"],

Cell[BoxData[
    \(\(-1.507231608668476`\) + 1.0000001388801913`\ x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(data2 = 
        Table[{N, Log[FN[N]]}, {N, 2, 6,  .1}];\)\), "\[IndentingNewLine]", 
    \(f2 = FindFit[data2, LogF0 - xb1\ N, {LogF0, xb1}, N]\), "\n", 
    \(\(ppp1 = 
        Plot[\((LogF0 - xb1\ N)\) /. f2, {N, 2, 6}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(pp2 = 
        ListPlot[data2, PlotStyle \[Rule] {PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[ppp1, pp2, DisplayFunction \[Rule] $DisplayFunction, 
        Frame \[Rule] True, Axes \[Rule] False];\)\)}], "Input"],

Cell[BoxData[
    \({LogF0 \[Rule] 1.5752712555446846`, 
      xb1 \[Rule] \(-1.0206310716278977`\)}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.452381 0.238095 -0.49682 0.142893 [
[.02381 -0.0125 -7.03125 -24.5625 ]
[.02381 -0.0125 7.03125 0 ]
[.2619 -0.0125 -7.03125 -24.5625 ]
[.2619 -0.0125 7.03125 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07475 -14.0625 -12.2813 ]
[-0.0125 .07475 0 12.2813 ]
[-0.0125 .21764 -14.0625 -12.2813 ]
[-0.0125 .21764 0 12.2813 ]
[-0.0125 .36054 -14.0625 -12.2813 ]
[-0.0125 .36054 0 12.2813 ]
[-0.0125 .50343 -14.0625 -12.2813 ]
[-0.0125 .50343 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07475 m
.00625 .07475 L
s
gsave
-0.0125 .07475 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .21764 m
.00625 .21764 L
s
gsave
-0.0125 .21764 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .36054 m
.00625 .36054 L
s
gsave
-0.0125 .36054 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .50343 m
.00625 .50343 L
s
gsave
-0.0125 .50343 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .10333 m
.00375 .10333 L
s
0 .13191 m
.00375 .13191 L
s
0 .16049 m
.00375 .16049 L
s
0 .18906 m
.00375 .18906 L
s
0 .24622 m
.00375 .24622 L
s
0 .2748 m
.00375 .2748 L
s
0 .30338 m
.00375 .30338 L
s
0 .33196 m
.00375 .33196 L
s
0 .38911 m
.00375 .38911 L
s
0 .41769 m
.00375 .41769 L
s
0 .44627 m
.00375 .44627 L
s
0 .47485 m
.00375 .47485 L
s
0 .04617 m
.00375 .04617 L
s
0 .01759 m
.00375 .01759 L
s
0 .53201 m
.00375 .53201 L
s
0 .56059 m
.00375 .56059 L
s
0 .58916 m
.00375 .58916 L
s
0 .61774 m
.00375 .61774 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07475 m
1 .07475 L
s
.99375 .21764 m
1 .21764 L
s
.99375 .36054 m
1 .36054 L
s
.99375 .50343 m
1 .50343 L
s
.125 Mabswid
.99625 .10333 m
1 .10333 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .16049 m
1 .16049 L
s
.99625 .18906 m
1 .18906 L
s
.99625 .24622 m
1 .24622 L
s
.99625 .2748 m
1 .2748 L
s
.99625 .30338 m
1 .30338 L
s
.99625 .33196 m
1 .33196 L
s
.99625 .38911 m
1 .38911 L
s
.99625 .41769 m
1 .41769 L
s
.99625 .44627 m
1 .44627 L
s
.99625 .47485 m
1 .47485 L
s
.99625 .04617 m
1 .04617 L
s
.99625 .01759 m
1 .01759 L
s
.99625 .53201 m
1 .53201 L
s
.99625 .56059 m
1 .56059 L
s
.99625 .58916 m
1 .58916 L
s
.99625 .61774 m
1 .61774 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01996 m
.06244 .04362 L
.10458 .06943 L
.14415 .09367 L
.18221 .11698 L
.22272 .14179 L
.26171 .16568 L
.30316 .19106 L
.34309 .21552 L
.3815 .23905 L
.42237 .26408 L
.46172 .28819 L
.49955 .31136 L
.53984 .33604 L
.57861 .35979 L
.61984 .38504 L
.65954 .40936 L
.69774 .43276 L
.73838 .45765 L
.77751 .48162 L
.81909 .50709 L
.85916 .53163 L
.89771 .55525 L
.93871 .58036 L
.97619 .60332 L
s
.02 w
.02381 .01472 Mdot
.04762 .03046 Mdot
.07143 .04606 Mdot
.09524 .06153 Mdot
.11905 .07688 Mdot
.14286 .09212 Mdot
.16667 .10727 Mdot
.19048 .12234 Mdot
.21429 .13732 Mdot
.2381 .15224 Mdot
.2619 .1671 Mdot
.28571 .1819 Mdot
.30952 .19665 Mdot
.33333 .21136 Mdot
.35714 .22603 Mdot
.38095 .24065 Mdot
.40476 .25525 Mdot
.42857 .26982 Mdot
.45238 .28436 Mdot
.47619 .29887 Mdot
.5 .31337 Mdot
.52381 .32784 Mdot
.54762 .3423 Mdot
.57143 .35674 Mdot
.59524 .37116 Mdot
.61905 .38557 Mdot
.64286 .39998 Mdot
.66667 .41437 Mdot
.69048 .42875 Mdot
.71429 .44312 Mdot
.7381 .45748 Mdot
.7619 .47184 Mdot
.78571 .48619 Mdot
.80952 .50053 Mdot
.83333 .51487 Mdot
.85714 .52921 Mdot
.88095 .54354 Mdot
.90476 .55786 Mdot
.92857 .57219 Mdot
.95238 .5865 Mdot
.97619 .60082 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`007`3oool00`3OW4P00000000000050000000307Boo`3oool0oooo02h0oooo00<0oooO09a8
000000000P0000000`00B9`0gooo0?ooo`0g0?ooo`030?noM0000000M;oo0380oooo00H0_g@00000
0000000000000018W03Ooole0?ooo`060?oog`2LB00000000000000007@0_ooo4`3oool00200oooo
00<0gia8000000000000100000000`00M;l0oooo0?ooo`0^0?ooo`080?oOW018000004RL0=ooo`3o
ool0omnL04P0B02Lgolg0?ooo`030?noM0000000M;oo0340oooo00<0oooO09a80018W=l00P3oool0
0`3ogi`0B4RL0=ooo`0c0?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02LgolB0?ooo`00
8@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo03D0oooo00<0okmd0018W03Oool0
=P3oool00`3o_g@0000007Boo`0g0?ooo`030?oOW018M;l0oooo0380oooo00<0_g@00000M02oool0
0`3oool00`2oM00007Bo0?ooo`0A0?ooo`008P3oool00`3OW4P0B9cO0?ooo`0i0?ooo`030?noM000
04P0W=oo0340oooo00<0gia80000000000001@0000000`0004P0W=oo0?ooo`0d0?ooo`030?oo_`1d
04P0W=oo0340oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`0A0?ooo`008`3oool0
0`3OW4P0M;oo0?ooo`0h0?ooo`030;md000004P0W=oo0340oooo00<0omnL04Qd_`3oool00P3oool0
0`3o_g@0000007Boo`0g0?ooo`030?oo_`1d0000M;oo0340oooo00<0omnL04P00018W=l0103oool0
0`2oM000001809cOo`0A0?ooo`008`3oool00`3ooml0W4Q809cOo`0g0?ooo`040;md00000000001d
0;oooc80oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo03L0oooo00<0okmd0000001d_ol0
<@3oool00`3ogi`0B00004RLg`030?ooo`040?oo_`1d0000001d0;oooa40oooo000T0?ooo`030?oO
W01807@0_ooo03<0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0a0?ooo`070?oo
_`1d07@0_ooo0?ooo`3o_g@0000007Boo`0f0?ooo`040?oOW0180000001d0;oooc40oooo00T0oono
07@00000000004RL0=ooo`3oool0_g@000000018W=l04P3oool002D0oooo00<0_g@004RLg`3oool0
=03oool00`3o_g@0001809cOo`0e0?ooo`060?noM000M;l0oooo0?noM0000000M;oo<P3oool0103O
gml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo0300oooo00D0oooO09a8000007@0_mnL04P0
00020000000304RLg`3oool0oooo0140oooo000U0?ooo`030=nLB00007@0_ooo03D0oooo00<0omnL
04Qd_`3oool0=@3oool01@2oM000M;oo0?noM0000000M;oo0380oooo00<0okmd0000000000000P00
00000`00M;l0oooo0?ooo`0b0?ooo`030?noM0000000B9cO01L0oooo000U0?ooo`030?noM0000000
M;oo03D0oooo00<0oooO09a80018W=l0=@3oool01@3ookl0M01d0;noM0000000M;oo0380oooo00D0
oooO09a800000000001d0;ooo`0e0?ooo`040?oog`2LB000001809cOoaH0oooo000O0?ooo`030?oO
W02L_ol0oooo00<0oooo00<0_g@00000001d_ol0<03oool00`3ooml0W7BL0=ooo`020?ooo`030?oo
g`2LB00007Bo03H0oooo00@0okmd000000000000M;oo<`3oool00`3o_g@007Bo0?ooo`0g0?ooo`04
0?oo_`1d0000001d0;oooaD0oooo000P0?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03O
oola0?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`0f0?ooo`040?oog`2LB000000007Bo
oc<0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0c0?ooo`040?oog`2LB0000000
001d_a@0oooo000Q0?ooo`050;md00000000000000000000M;l0=03oool01@3ogi`0B00000000000
0000B9cO03P0oooo00<0omnL04P0001d_ol0=03oool00`3o_g@00000000000020000000307Boo`3o
ool0oooo03@0oooo00D0omnL04P00000000004RL0=ooo`0A0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`007P3ooooc000000l0oooo000N0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool001h0oooo00<00000
0?ooo`3oool00P3oool200000>/0oooo00<000000?ooo`3oool03@3oool001h0oooo0P0000020?oo
o`@00000j@3oool2000000l0oooo000N0?ooo`040000003oool0oooo0?ooo`@00000jP3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`@000000P3oool200000>D0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool01P3oool500000>@0oooo
00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool01`3oool400000>@0oooo00<0
00000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0203oool200000>D0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool02P3oool2000000030?ooo`0000000000
0>00oooo00<000000?ooo`3oool03@3oool001h0oooo0P00000=0?ooo`@00000gP3oool2000000l0
oooo000D0?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool0303oool400000=l0oooo
00<000000?ooo`3oool03@3oool001@0oooo00<0okmd0000001d_ol01`3oool00`000000oooo0?oo
o`0=0?ooo`@00000gP3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`3o_g@0000007Boo`07
0?ooo`030000003oool0oooo0140oooo00@000000?ooo`0000000000fP3oool00`000000oooo0?oo
o`0=0?ooo`003`3oool00`3OW4P0000000000005000000030000B02Lgol0oooo00@0oooo00<00000
0?ooo`3oool04P3oool400000=T0oooo00<000000?ooo`3oool03@3oool000l0oooo00<0omnL04Qd
_`3oool00P3oool00`3o_g@0000007Boo`070?ooo`030000003oool0oooo0180oooo1000003I0?oo
o`030000003oool0oooo00d0oooo000@0?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`07
0?ooo`030000003oool0oooo01<0oooo0P0000000`3oool000000?ooo`3G0?ooo`030000003oool0
oooo00d0oooo000@0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`070?ooo`<000005`3o
ool400000=80oooo0`00000?0?ooo`004@3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`L0oooo
00<000000?ooo`3oool0603oool400000=<0oooo00<000000?ooo`3oool03@3oool00180oooo00D0
_g@007Boo`3o_g@0000007Boo`070?ooo`030000003oool0oooo01P0oooo1000003C0?ooo`030000
003oool0oooo00d0oooo000B0?ooo`050?oo_`1d07@0_kmd0000001d_ol01`3oool00`000000oooo
0?ooo`0I0?ooo`80000000@0oooo000000000000oooo0P00003>0?ooo`030000003oool0oooo00d0
oooo000C0?ooo`040?noM0000000000007Boo`L0oooo00<000000?ooo`3oool07P3oool400000<d0
oooo00<000000?ooo`3oool03@3oool001<0oooo00@0oooO09a800000000M;oo1`3oool00`000000
oooo0?ooo`0N0?ooo`@00000c@3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`3ogi`0B000
07Boo`070?ooo`030000003oool0oooo01l0oooo1000003<0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`800000903oool300000<P0oooo0P00000?0?ooo`007P3oool00`000000oooo0?ooo`0S
0?ooo`@00000b03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`0S0?oo
o`H00000aP3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`0T0?ooo`80
00000`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo02X0oooo0P0000330?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo02T0oooo1@0000310?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0
oooo02T0oooo100000000`3oool000000?ooo`2o0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`800000:`3oool2000000<0oooo0`00002l0?ooo`8000003`3oool001h0oooo00<000000?ooo`3o
ool0;`3oool400000;`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
;`3oool500000;/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0<03o
ool200000080oooo0P00002i0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0
oooo03H0oooo0P00002g0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo
03D0oooo1000002f0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo03D0
oooo1@00002e0?ooo`030000003oool0oooo00d0oooo000N0?ooo`800000=`3oool200000080oooo
0`00002a0?ooo`8000003`3oool001h0oooo00<000000?ooo`3oool0>P3oool400000;40oooo00<0
00000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0>P3oool500000;00oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0>`3oool200000080oooo0P00002^0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0440oooo0P00002/0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0400oooo1000002[0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0400oooo1P00002Y0?ooo`030000003o
ool0oooo00d0oooo000N0?ooo`800000@P3oool2000000<0oooo00<000000?ooo`3oool0Y@3oool2
000000l0oooo000@0?ooo`060;md00000000000000000000B9`0gooo203oool00`000000oooo0?oo
o`170?ooo`800000YP3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`3ooml0W4P004RLg`02
0?ooo`030?oOW018B9`0gooo00L0oooo00<000000?ooo`3oool0AP3oool500000:@0oooo00<00000
0?ooo`3oool03@3oool001D0oooo00<0omnL04Qd_`3oool01P3oool00`000000oooo0?ooo`160?oo
o`@0000000<0oooo0000003oool0XP3oool00`000000oooo0?ooo`0=0?ooo`005@3oool00`3ookl0
M01809cOo`060?ooo`030000003oool0oooo04L0oooo0P0000030?ooo`<00000X03oool00`000000
oooo0?ooo`0=0?ooo`005@3oool00`3ookl0M00007Boo`060?ooo`030000003oool0oooo04`0oooo
1000002O0?ooo`030000003oool0oooo00d0oooo000E0?ooo`030?noM0000000M;oo00H0oooo00<0
00000?ooo`3oool0C03oool5000009h0oooo00<000000?ooo`3oool03@3oool001@0oooo00@0omnL
04P0000007@0_ooo1P3oool3000004d0oooo0P0000020?ooo`800000VP3oool3000000l0oooo000@
0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?oo
o`1C0?ooo`800000VP3oool00`000000oooo0?ooo`0=0?ooo`00403oool00`3o_g@0000000000002
00000003001d_`3oool0oooo00H0oooo00<000000?ooo`3oool0DP3oool4000009T0oooo00<00000
0?ooo`3oool03@3oool00100oooo00D0oooO09a800000000001d0;ooo`090?ooo`030000003oool0
oooo0580oooo1@00002H0?ooo`030000003oool0oooo00d0oooo000A0?ooo`030?noM000M;l0oooo
00X0oooo00<000000?ooo`3oool0D`3oool200000080oooo0`00002E0?ooo`030000003oool0oooo
00d0oooo000A0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool01@3oool00`000000
oooo0?ooo`1G0?ooo`@00000U03oool00`000000oooo0?ooo`0=0?ooo`004P3oool00`3o_g@00000
000000020000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0E`3oool5000009<0oooo
00<000000?ooo`3oool03@3oool001h0oooo0P00001I0?ooo`8000000P3oool200000900oooo0P00
000?0?ooo`007P3oool00`000000oooo0?ooo`1N0?ooo`800000S`3oool00`000000oooo0?ooo`0=
0?ooo`007P3oool00`000000oooo0?ooo`1M0?ooo`@00000SP3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1M0?ooo`H00000S03oool00`000000oooo0?ooo`0=0?ooo`00
7P3oool00`000000oooo0?ooo`1N0?ooo`8000000`3oool3000008T0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0H`3oool4000008P0oooo00<000000?ooo`3oool03@3o
ool001h0oooo00<000000?ooo`3oool0H`3oool5000008L0oooo00<000000?ooo`3oool03@3oool0
01h0oooo0P00001U0?ooo`8000000P3oool00`000000oooo0?ooo`230?ooo`8000003`3oool001h0
oooo00<000000?ooo`3oool0J@3oool3000008<0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0J@3oool400000880oooo00<000000?ooo`3oool03@3oool001h0oooo00<0
00000?ooo`3oool0J@3oool500000840oooo00<000000?ooo`3oool03@3oool001h0oooo00<00000
0?ooo`3oool0JP3oool200000080oooo0`00001n0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo06h0oooo1000001m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`80
0000K`3oool6000007X0oooo0P00000?0?ooo`007P3oool00`000000oooo0?ooo`1_0?ooo`800000
0`3oool2000007T0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0M@3o
ool2000007P0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0M03oool5
000007H0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0M03oool40000
00030?ooo`000000000007@0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0M@3oool2000000@0oooo0P00001b0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo07X0oooo1000001a0?ooo`030000003oool0oooo00d0oooo000N0?ooo`800000N`3o
ool6000006h0oooo0P00000?0?ooo`007P3oool00`000000oooo0?ooo`1k0?ooo`8000000`3oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00d0oooo000A0?ooo`060?oog`2LB0000000
0000000007@0_ooo1`3oool00`000000oooo0?ooo`210?ooo`800000K03oool00`000000oooo0?oo
o`0=0?ooo`00403oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo1P3oool00`000000
oooo0?ooo`200?ooo`@00000J`3oool00`000000oooo0?ooo`0=0?ooo`00403oool00`2oM000001d
0;ooo`030?ooo`030;md0000M;l0oooo00D0oooo00<000000?ooo`3oool0P03oool6000006T0oooo
00<000000?ooo`3oool03@3oool000l0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;oo
o`050?ooo`030000003oool0oooo0840oooo0P0000030?ooo`800000I`3oool00`000000oooo0?oo
o`0=0?ooo`003`3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo00D0oooo00<00000
0?ooo`3oool0Q@3oool4000006H0oooo00<000000?ooo`3oool03@3oool000l0oooo00<0omnL04P0
0018W=l00`3oool0103ookl0M0000000M02oool50?ooo`<00000Q@3oool5000006<0oooo0`00000?
0?ooo`003`3oool02@3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`060?ooo`030000
003oool0oooo08H0oooo0P0000020?ooo`800000H`3oool00`000000oooo0?ooo`0=0?ooo`003`3o
ool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo
0?ooo`2<0?ooo`800000H@3oool00`000000oooo0?ooo`0=0?ooo`00403oool00`3o_g@0000004RL
g`0;0?ooo`030000003oool0oooo08/0oooo1000001P0?ooo`030000003oool0oooo00d0oooo000@
0?ooo`040?oog`2LB000001809cOo`X0oooo00<000000?ooo`3oool0R`3oool6000005h0oooo00<0
00000?ooo`3oool03@3oool00140oooo00@0oono07@0000007@0_ooo2@3oool00`000000oooo0?oo
o`2<0?ooo`8000000`3oool3000005/0oooo00<000000?ooo`3oool03@3oool00180oooo00@0oooO
09a80000000007Bo203oool00`000000oooo0?ooo`2A0?ooo`@00000FP3oool00`000000oooo0?oo
o`0=0?ooo`00503oool01@3ogi`0B00000000000B9`0gooo00D0oooo0P00002B0?ooo`D00000F03o
ool2000000l0oooo000N0?ooo`030000003oool0oooo0980oooo0P0000020?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0U`3oool30000
05D0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0U`3oool4000005@0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0U`3oool5000005<0oooo
00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0V03oool200000080oooo0`00
001@0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo09`0oooo1000001?
0?ooo`030000003oool0oooo00d0oooo000N0?ooo`800000W@3oool5000004d0oooo0P00000?0?oo
o`007P3oool00`000000oooo0?ooo`2M0?ooo`8000000P3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0:80oooo0`00001:0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0:80oooo100000190?ooo`030000003o
ool0oooo00d0oooo000N0?ooo`030000003oool0oooo0:80oooo1@0000180?ooo`030000003oool0
oooo00d0oooo000N0?ooo`030000003oool0oooo0:<0oooo0P0000020?ooo`@00000A03oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`2X0?ooo`@00000@`3oool00`000000
oooo0?ooo`0=0?ooo`007P3oool200000:T0oooo100000120?ooo`8000003`3oool001h0oooo00<0
00000?ooo`3oool0Z@3oool2000000030?ooo`00000000000440oooo00<000000?ooo`3oool03@3o
ool001h0oooo00<000000?ooo`3oool0[P3oool3000003h0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0[P3oool4000003d0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0[P3oool5000003`0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0[`3oool200000080oooo0`00000i0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0;<0oooo1000000h0?ooo`030000003oool0oooo00d0oooo000N
0?ooo`800000]03oool4000003L0oooo0P00000?0?ooo`004P3oool00`3ogi`0B01d0;ooo`090?oo
o`030000003oool0oooo0;@0oooo0P0000000`3oool000000000000f0?ooo`030000003oool0oooo
00d0oooo000C0?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0^@3oool3000003<0
oooo00<000000?ooo`3oool03@3oool001<0oooo00<0okmd001d_`3oool0203oool00`000000oooo
0?ooo`2i0?ooo`@00000<P3oool00`000000oooo0?ooo`0=0?ooo`004`3oool00`3ookl0M01d0;oo
o`080?ooo`030000003oool0oooo0;T0oooo1@00000a0?ooo`030000003oool0oooo00d0oooo000D
0?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool0^P3oool200000080oooo00@00000
0?ooo`0000000000;@3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`3o_g@007Bo0?ooo`07
0?ooo`030000003oool0oooo0;l0oooo1000000/0?ooo`030000003oool0oooo00d0oooo000D0?oo
o`030?oo_`1d07@0_ooo00L0oooo0`00002o0?ooo`@00000:P3oool3000000l0oooo000E0?ooo`03
0;md001d_ol0oooo00H0oooo00<000000?ooo`3oool0`03oool2000000040?ooo`000000oooo0?oo
o`8000009`3oool00`000000oooo0?ooo`0=0?ooo`005@3oool00`3o_g@007Bo0?ooo`060?ooo`03
0000003oool0oooo0<@0oooo1@00000V0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030?oO
_`2ogol0oooo00<0oooo00<0oono07@0M02oool01P3oool00`000000oooo0?ooo`350?ooo`@00000
9P3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`3ooml0W4Qd0;ooo`040?ooo`030;md001d
_ol0oooo00D0oooo00<000000?ooo`3oool0aP3oool3000002H0oooo00<000000?ooo`3oool03@3o
ool00100oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`040?ooo`030000003oool0
oooo0<T0oooo1000000R0?ooo`030000003oool0oooo00d0oooo000@0?ooo`030?oOW01800000000
00@0000000<0001809cOo`3oool0103oool00`000000oooo0?ooo`3:0?ooo`@000008@3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool200000</0oooo1000000P0?ooo`8000003`3oool001h0oooo
00<000000?ooo`3oool0b`3oool2000000040?ooo`00000000000?ooo`800000703oool00`000000
oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`3@0?ooo`@000006`3oool00`000000oooo
0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`3@0?ooo`@000006`3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`3A0?ooo`80000000<0oooo0000000000006@3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`3F0?ooo`<000005P3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`3F0?ooo`@000005@3oool00`000000
oooo0?ooo`0=0?ooo`007P3oool200000=L0oooo1@00000C0?ooo`8000003`3oool001h0oooo00<0
00000?ooo`3oool0e`3oool200000080oooo00@000000?ooo`0000000000403oool00`000000oooo
0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`3L0?ooo`@000003`3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`3L0?ooo`@000003`3oool00`000000oooo0?ooo`0=
0?ooo`007P3oool00`000000oooo0?ooo`3M0?ooo`80000000<0oooo0000003oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`3Q0?ooo`<000002`3oool00`000000
oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`3Q0?ooo`@000002P3oool00`000000oooo
0?ooo`0=0?ooo`007P3oool200000>80oooo1@0000080?ooo`8000003`3oool001h0oooo00<00000
0?ooo`3oool0hP3oool200000080oooo00@000000?ooo`00000000001@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`3W0?ooo`@00000103oool00`000000oooo0?ooo`0=
0?ooo`007P3oool00`000000oooo0?ooo`3W0?ooo`@00000103oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`3X0?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`00
7P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0=0?ooo`007P3ooooc000000l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {1.36864, 2.67806, 0.0173799, \
0.0289591}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tt = 
        Table[{\(fF[N] /. f2\) /. N \[Rule] nn, fN[N] /. N \[Rule] nn}, {nn, 
            2, 6,  .1}];\)\), "\[IndentingNewLine]", 
    \(Fit[tt, {1, x}, x]\)}], "Input"],

Cell[BoxData[
    \(\(-16.561513502651923`\) + 0.9937774179490996`\ x\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{"(*", " ", 
      RowBox[{
        StyleBox["Numeric",
          FontColor->RGBColor[1, 0, 0]], " ", "-", " ", 
        StyleBox["Analytic",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[" ",
        FontColor->RGBColor[0, 0, 1]], "*)"}]], "Input"],

Cell[BoxData[{
    \(\(Fpr = 
        Plot[\((\(LogF0 - xb1\ N /. f1\) /. 
              N \[Rule] nn)\), {nn, \(-6\), \(-4\)}, PlotRange \[Rule] All, 
          Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.008], 
              Hue[0.3]}];\)\), "\[IndentingNewLine]", 
    \(\(Fpr1 = 
        Plot[\((\(LogF0 - xb1\ N /. f2\) /. N \[Rule] nn)\), {nn, 2, 6}, 
          PlotRange \[Rule] All, Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.01], Hue[0.3]}];\)\), "\n", 
    \(\(Fpr = Show[Fpr, Fpr1];\)\)}], "Input"],

Cell[BoxData[
    \(\(FFplot = 
        Plot[{Log[FN[N]], Log[FNacc[N]]}, {N, nmin, nmax}, 
          Frame \[Rule] True, FrameLabel \[Rule] {"\<N\>", "\<Log(F(N))\>"}, 
          PlotRange \[Rule] All, Axes \[Rule] False, 
          PlotStyle \[Rule] {Hue[0], Hue[ .7]}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig5logF = 
        Show[Fpr, FFplot, DisplayFunction \[Rule] $DisplayFunction, 
          FrameLabel \[Rule] {"\<N\>", "\<Log(F(N))\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig5_logF\>" <> "\<.m\>", fig5logF];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.0147151 0.076442 [
[.02381 -0.0125 -14 -24.5625 ]
[.02381 -0.0125 14 0 ]
[.18254 -0.0125 -14 -24.5625 ]
[.18254 -0.0125 14 0 ]
[.34127 -0.0125 -14 -24.5625 ]
[.34127 -0.0125 14 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.65873 -0.0125 -7.03125 -24.5625 ]
[.65873 -0.0125 7.03125 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -14.0625 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .1676 -14.0625 -12.2813 ]
[-0.0125 .1676 0 12.2813 ]
[-0.0125 .32048 -14.0625 -12.2813 ]
[-0.0125 .32048 0 12.2813 ]
[-0.0125 .47337 -14.0625 -12.2813 ]
[-0.0125 .47337 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -38.625 -44 ]
[-0.01875 .30902 -14.0625 44 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .1676 m
.00625 .1676 L
s
gsave
-0.0125 .1676 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .32048 m
.00625 .32048 L
s
gsave
-0.0125 .32048 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .47337 m
.00625 .47337 L
s
gsave
-0.0125 .47337 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05294 m
.00375 .05294 L
s
0 .09116 m
.00375 .09116 L
s
0 .12938 m
.00375 .12938 L
s
0 .20582 m
.00375 .20582 L
s
0 .24404 m
.00375 .24404 L
s
0 .28226 m
.00375 .28226 L
s
0 .3587 m
.00375 .3587 L
s
0 .39693 m
.00375 .39693 L
s
0 .43515 m
.00375 .43515 L
s
0 .51159 m
.00375 .51159 L
s
0 .54981 m
.00375 .54981 L
s
0 .58803 m
.00375 .58803 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -131.344 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 16.2813 translate
90 rotate
-105 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.375 23.000 moveto
(H) show
101.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.000 23.000 moveto
(H) show
119.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
134.125 23.000 moveto
(L) show
140.563 23.000 moveto
(L) show
147.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06349 .61428 m
.06349 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30159 .61428 m
.30159 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.46032 .61428 m
.46032 .61803 L
s
.53968 .61428 m
.53968 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.69841 .61428 m
.69841 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.93651 .61428 m
.93651 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1676 m
1 .1676 L
s
.99375 .32048 m
1 .32048 L
s
.99375 .47337 m
1 .47337 L
s
.125 Mabswid
.99625 .05294 m
1 .05294 L
s
.99625 .09116 m
1 .09116 L
s
.99625 .12938 m
1 .12938 L
s
.99625 .20582 m
1 .20582 L
s
.99625 .24404 m
1 .24404 L
s
.99625 .28226 m
1 .28226 L
s
.99625 .3587 m
1 .3587 L
s
.99625 .39693 m
1 .39693 L
s
.99625 .43515 m
1 .43515 L
s
.99625 .51159 m
1 .51159 L
s
.99625 .54981 m
1 .54981 L
s
.99625 .58803 m
1 .58803 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.2 1 0 r
.008 w
.02381 .01472 m
.03025 .01472 L
.03727 .01472 L
.04387 .01472 L
.05021 .01472 L
.05696 .01472 L
.06346 .01472 L
.07037 .01472 L
.07702 .01472 L
.08342 .01472 L
.09024 .01472 L
.09679 .01472 L
.1031 .01472 L
.10981 .01472 L
.11628 .01472 L
.12315 .01472 L
.12977 .01472 L
.13613 .01472 L
.1429 .01472 L
.14943 .01472 L
.15636 .01472 L
.16303 .01472 L
.16946 .01472 L
.17629 .01472 L
.18254 .01472 L
s
.01 w
.65873 .29117 m
.67161 .30383 L
.68565 .31764 L
.69884 .3306 L
.71153 .34307 L
.72503 .35635 L
.73803 .36913 L
.75185 .38271 L
.76516 .39579 L
.77796 .40838 L
.79158 .42177 L
.8047 .43466 L
.81731 .44706 L
.83074 .46026 L
.84366 .47297 L
.85741 .48648 L
.87064 .49949 L
.88337 .512 L
.89692 .52532 L
.90996 .53814 L
.92383 .55177 L
.93718 .5649 L
.95003 .57753 L
.9637 .59097 L
.97619 .60325 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.03053 .01472 L
.03279 .01472 L
.03527 .01472 L
.0379 .01472 L
.04262 .01472 L
.04749 .01472 L
.05205 .01472 L
.06244 .01472 L
.07305 .01472 L
.08274 .01472 L
.0881 .01472 L
.09394 .01472 L
.09946 .01472 L
.10212 .01472 L
.10458 .01472 L
.10966 .01472 L
.11515 .01472 L
.1251 .01472 L
.13415 .01472 L
.13871 .01472 L
.14371 .01472 L
.14895 .01472 L
.15391 .01472 L
.16322 .01472 L
.16842 .01472 L
.17324 .01472 L
.17848 .01472 L
.18413 .01472 L
.18916 .01472 L
.19376 .01472 L
.2028 .01472 L
.20759 .01472 L
.21283 .01472 L
.21827 .01472 L
.2234 .01472 L
.22833 .01472 L
.23367 .01472 L
.24301 .01472 L
.24831 .01472 L
.25391 .01472 L
.25916 .01472 L
.26396 .01472 L
.2734 .01473 L
.2786 .01473 L
.28354 .01473 L
Mistroke
.2923 .01474 L
.29725 .01475 L
.30185 .01476 L
.30694 .01477 L
.31244 .01478 L
.31729 .0148 L
.32241 .01482 L
.32704 .01484 L
.33211 .01487 L
.34103 .01494 L
.34629 .015 L
.35126 .01507 L
.36058 .01524 L
.36579 .01537 L
.37061 .01551 L
.37586 .01571 L
.38151 .01598 L
.38655 .01627 L
.39116 .0166 L
.40021 .01746 L
.40501 .01806 L
.41026 .01886 L
.4157 .01987 L
.42083 .02104 L
.43113 .02415 L
.44047 .02809 L
.45054 .03382 L
.46144 .04202 L
.48135 .06261 L
.50241 .09047 L
.54035 .14518 L
.58074 .19904 L
.61962 .24537 L
.66095 .29073 L
.70076 .33218 L
.73906 .37085 L
.77981 .41123 L
.81904 .44968 L
.85676 .48639 L
.89693 .52533 L
.93558 .56271 L
.97619 .60191 L
Mfstroke
.2 0 1 r
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06453 .01472 L
.06529 .01472 L
.06657 .01472 L
.06729 .01472 L
.06797 .01472 L
.06924 .01472 L
.0704 .01472 L
.07103 .01472 L
.07173 .01472 L
.073 .01472 L
Mistroke
.07376 .01472 L
.07448 .01472 L
.07513 .01472 L
.07583 .01472 L
.0766 .01472 L
.0774 .01472 L
.07809 .01472 L
.07885 .01472 L
.07956 .01472 L
.0802 .01472 L
.08095 .01472 L
.08166 .01472 L
.08291 .01472 L
.08362 .01472 L
.08427 .01472 L
.08544 .01472 L
.08669 .01472 L
.08787 .01472 L
.08896 .01472 L
.09016 .01472 L
.09148 .01472 L
.09214 .01472 L
.09285 .01472 L
.09413 .01472 L
.09483 .01472 L
.09548 .01472 L
.09619 .01472 L
.09695 .01472 L
.09821 .01472 L
.09893 .01472 L
.09961 .01472 L
.10086 .01472 L
.10201 .01472 L
.10333 .01472 L
.10458 .01472 L
.10572 .01472 L
.10694 .01472 L
.1081 .01472 L
.10916 .01472 L
.11033 .01472 L
.11162 .01472 L
.11227 .01472 L
.11297 .01472 L
.11422 .01472 L
.11491 .01472 L
.11554 .01472 L
.11624 .01472 L
.11698 .01472 L
.11822 .01472 L
.11892 .01472 L
Mistroke
.11958 .01472 L
.12081 .01472 L
.12194 .01472 L
.12323 .01472 L
.12446 .01472 L
.12562 .01472 L
.12668 .01472 L
.12789 .01472 L
.12903 .01472 L
.13009 .01472 L
.13107 .01472 L
.13214 .01472 L
.13327 .01472 L
.13441 .01472 L
.13564 .01472 L
.1368 .01472 L
.13785 .01472 L
.13909 .01472 L
.13979 .01472 L
.14043 .01472 L
.14162 .01472 L
.14288 .01472 L
.14402 .01472 L
.14526 .01472 L
.14656 .01472 L
.14777 .01472 L
.14891 .01472 L
.14994 .01472 L
.15113 .01472 L
.15226 .01472 L
.15348 .01472 L
.15478 .01472 L
.15589 .01472 L
.15711 .01472 L
.15842 .01472 L
.15915 .01472 L
.15982 .01472 L
.16113 .01472 L
.16236 .01472 L
.16352 .01472 L
.16456 .01472 L
.16577 .01472 L
.1669 .01472 L
.16796 .01472 L
.16893 .01472 L
.16999 .01472 L
.17111 .01472 L
.17225 .01472 L
.17347 .01472 L
.17462 .01472 L
Mistroke
.17566 .01472 L
.17689 .01472 L
.17758 .01472 L
.17823 .01472 L
.1794 .01472 L
.18065 .01472 L
.18185 .01472 L
.18316 .01472 L
.18441 .01472 L
.18556 .01472 L
.1867 .01472 L
.18773 .01472 L
.18893 .01472 L
.19005 .01472 L
.19128 .01472 L
.19258 .01472 L
.19369 .01472 L
.19491 .01472 L
.19623 .01472 L
.19696 .01472 L
.19763 .01472 L
.19894 .01472 L
.20017 .01472 L
.20122 .01472 L
.20238 .01472 L
.20359 .01472 L
.20472 .01472 L
.20578 .01472 L
.20675 .01472 L
.20781 .01472 L
.20894 .01472 L
.21008 .01472 L
.21129 .01472 L
.21244 .01472 L
.21349 .01472 L
.21472 .01472 L
.21541 .01472 L
.21605 .01472 L
.21723 .01472 L
.21847 .01472 L
.21968 .01472 L
.221 .01472 L
.22224 .01472 L
.2234 .01472 L
.22454 .01472 L
.22558 .01472 L
.22677 .01472 L
.2279 .01472 L
.22914 .01472 L
.23044 .01472 L
Mistroke
.23155 .01472 L
.23277 .01472 L
.23409 .01472 L
.23482 .01472 L
.2355 .01472 L
.2368 .01472 L
.23804 .01472 L
.23909 .01472 L
.24025 .01472 L
.24146 .01472 L
.2426 .01472 L
.24365 .01472 L
.24462 .01472 L
.24569 .01472 L
.24681 .01472 L
.24795 .01472 L
.24917 .01472 L
.25032 .01472 L
.25137 .01472 L
.2526 .01472 L
.25329 .01472 L
.25393 .01472 L
.2551 .01472 L
.25635 .01472 L
.25756 .01472 L
.25888 .01472 L
.26013 .01472 L
.26129 .01472 L
.26233 .01472 L
.26348 .01472 L
.26467 .01472 L
.2658 .01472 L
.26704 .01472 L
.26835 .01472 L
.26946 .01472 L
.27068 .01472 L
.272 .01472 L
.27274 .01472 L
.27341 .01472 L
.27472 .01472 L
.27595 .01472 L
.27701 .01472 L
.27817 .01472 L
.27938 .01472 L
.28052 .01472 L
.28158 .01472 L
.28255 .01472 L
.28367 .01472 L
.28474 .01472 L
.28588 .01472 L
Mistroke
.2871 .01472 L
.28825 .01472 L
.2893 .01472 L
.29053 .01472 L
.29122 .01472 L
.29186 .01472 L
.29303 .01472 L
.29427 .01472 L
.29549 .01472 L
.29618 .01472 L
.29682 .01472 L
.29799 .01472 L
.29923 .01472 L
.30034 .01472 L
.30138 .01472 L
.30252 .01472 L
.30375 .01472 L
.30499 .01472 L
.30569 .01472 L
.30634 .01472 L
.30765 .01472 L
.30839 .01472 L
.30906 .01472 L
.31026 .01472 L
.31156 .01472 L
.31278 .01472 L
.31392 .01472 L
.31497 .01472 L
.31611 .01472 L
.31718 .01472 L
.31816 .01472 L
.3193 .01472 L
.32055 .01472 L
.32173 .01472 L
.32282 .01472 L
.32406 .01472 L
.32522 .01472 L
.32626 .01472 L
.32739 .01472 L
.32862 .01472 L
.32992 .01472 L
.33103 .01472 L
.33225 .01472 L
.33356 .01472 L
.33477 .01472 L
.33541 .01472 L
.3361 .01472 L
.33683 .01472 L
.33751 .01472 L
.33876 .01472 L
Mistroke
.33991 .01472 L
.34123 .01472 L
.34249 .01472 L
.3436 .01472 L
.3448 .01472 L
.34592 .01472 L
.34694 .01472 L
.34814 .01472 L
.34945 .01472 L
.35067 .01472 L
.35181 .01472 L
.35302 .01472 L
.35431 .01472 L
.35554 .01472 L
.35665 .01472 L
.35796 .01472 L
.3587 .01472 L
.35939 .01472 L
.36064 .01472 L
.36128 .01472 L
.36198 .01472 L
.36266 .01472 L
.36337 .01472 L
.36465 .01472 L
.36536 .01472 L
.36602 .01472 L
.36675 .01472 L
.36753 .01472 L
.3682 .01772 L
.36893 .01842 L
.37026 .0197 L
.37274 .02209 L
.41363 .06165 L
.45301 .09941 L
.49087 .13587 L
.53119 .1747 L
.56999 .21199 L
.61124 .25181 L
.65097 .29008 L
.68919 .32689 L
.72987 .36607 L
.76902 .40378 L
.81063 .44386 L
.85073 .48248 L
.88931 .51964 L
.93034 .55915 L
.96985 .59721 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{506.5, 313.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007j0001>B000`400?l00000o`00003oo`3ooook
0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook0?ooo`00o`3ooook
0?ooo`00o`3ooook0?ooo`00o`3oool=0?ooo`060;md00000000000000000000B9`0gooo103oool0
0`3ookl0M01d0;ooo`3Q0?ooo`00o`3oool>0?ooo`030?oo_`1d07@0_ooo00D0oooo00@0oooO09a8
000007@0_oooh@3oool00?l0oooo3P3oool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000001d
0;ooon40oooo003o0?ooo`h0oooo00<0oooO09a8M02oool0103oool01@3OW4P000000000B018B7@0
_ooo0>40oooo003o0?ooo`h0oooo00<0oooO09a8M02oool00`3oool01P3o_g@000000000M02ooml0
W4Qd0;ooon40oooo003o0?ooo`h0oooo00<0oooO09a8M02oool00P3oool01`3ogi`0B0000000B02L
gol0oooO09a8M02oool0h@3oool00?l0oooo3P3oool0303ooml0W4Qd0;ooo`3oool0oono07@00000
0000M;oo0?ooo`3ooml0W4Qd0;ooon40oooo003o0?ooo`h0oooo00L0oooO09a8M02oool0oooO09a8
00000000B9cO0080oooo00<0oooO09a8M02oool0h@3oool00?l0oooo3P3oool01P3ooml0W4Qd0;oo
g`2LB0000000001d_`<0oooo00<0oooO09a8M02oool0h@3oool00?l0oooo3P3oool01P3ooml0W4Qd
07Ad0000000004RL0=ooo`<0oooo00<0oooO09a8M02oool0h@3oool00?l0oooo3P3oool01@3ooml0
W4P00000000007@0_ooo00@0oooo00<0oooO09a8M02oool0h@3oool00?l0oooo3P3oool0103OW4P0
00000000M02oool50?ooo`030?oo_`1d07@0_ooo0>40oooo003o0?ooo``0oooo00D0gia800000000
0000001809cOo`040?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0gP3oool00?l0
oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0
oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0
oooon`3oool00?l0oooon`3oool00540oooo00H0oooO09a80000000000000000M02ooolo0?ooo`03
0?noM0000000M;oo03X0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0c0?ooo`04
0;md00000000000004RLgc`0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0l0?oo
o`030?noM0000000M;oo03`0oooo00H0oooO09a80000000000000000M02ooolM0?ooo`00D03oool0
203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo?P3oool00`3o_g@0000007Boo`0k0?ooo`03
0=nLB0000000000000@0000000<007Bo0?ooo`3oool0<@3oool01`3ooml0W4P0001d_`3oool0oooO
09a80000M;l0?03oool00`3OW4P000000000000400000003001d_`3oool0oooo03`0oooo00<0okmd
0000001d_ol0>`3oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo703oool00500oooo
00<0_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`0m0?ooo`030?noM0000000M;oo03`0oooo
00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0b0?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol0?03oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo03d0oooo
00<0okmd0000001d_ol0>`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo01/0oooo
001?0?ooo`030?oo_`1d000007Bo00@0oooo00<0gia80000M02oool0>03oool00`3OW4P000000000
0005000000030000B02Lgol0oooo03X0oooo00<0gia804RLg`3oool0=@3oool0103ooml0W4P00018
W03Oool20?ooo`030?oog`2LB00007Bo03d0oooo00<0gia804RLg`3oool0?03oool00`3OW4P00000
00000005000000030000B02Lgol0oooo03L0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d
0;ooo`0K0?ooo`00C`3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo03P0oooo00<0
omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0n0?ooo`030=nLB01d_ol0oooo03@0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`0m0?ooo`030=nLB01d_ol0oooo03/0oooo00<0
omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`0j0?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000B02Lgol06`3oool00480oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3o
gi`0B00004RLg`<0oooo00@0oono07@0000007@0_ooo:`3oool00`2oM00000000000000700000006
04RLg`3oool0oooo0?ooo`3OW4P0M;oo0P3oool00`3o_g@0000007Boo`0]0?ooo`030;md00000000
000000L0000000<0B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`0d0?ooo`030?oOW0180000
B9cO00@0oooo00<0_g@00000M02oool0?@3oool00`3ooml0W4Q809cOo`0l0?ooo`070=nLB01d_ol0
oooo0?ooo`3o_g@0000007Boo`0j0?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0000007@0
_ooo6`3oool004l0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0>P3oool0
1`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0?`3oool00`3ogi`0B01d0;ooo`0c0?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol0?P3oool00`3ogi`0B01d0;ooo`0k0?ooo`070?oo
_`1d07@0_ooo0?ooo`3o_g@0000007Boo`0j0?ooo`090?oo_`1d000000000018W03Oool0oooo0;md
00000000B9cO01`0oooo001?0?ooo`050?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo
0?ooo`0j0?ooo`060?noM000M;l0oooo0?noM0000000M;oo@03oool00`2oM000B9cO0?ooo`0b0?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0?`3oool00`2oM000B9cO0?ooo`0k0?oo
o`060?noM000M;l0oooo0?noM0000000M;oo>P3oool01@3ooml0W4P00000M02ogi`0B00000800000
00<0B9cO0?ooo`3oool06`3oool00500oooo00<0okmd00000018W=l0@@3oool01@2oM000M;oo0?no
M0000000M;oo0400oooo00<0gia80000M02oool0<P3oool00`3ookl0M000001d_`040?ooo`030;md
000007@0_ooo03l0oooo00<0gia80000M02oool0?03oool01@2oM000M;oo0?noM0000000M;oo03/0
oooo00<0okmd00000018W=l08@3oool00500oooo00@0oooO09a8000004P0W=oo@03oool01@3ookl0
M01d0;noM0000000M;oo0400oooo00<0okmd0000001d_ol0<`3oool00`2oM00004RL0=ooo`020?oo
o`030?oog`2LB00007Bo0400oooo00<0okmd0000001d_ol0?03oool01@3ookl0M01d0;noM0000000
M;oo03/0oooo00@0oooO09a8000004P0W=oo803oool00540oooo00@0oono07@0000007@0_ooo@03o
ool0103o_g@000000000001d_olj0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0
<`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo03X0oooo00<0omnL09boo`3oool0
0`3oool00`2oM000000007Boo`0m0?ooo`040?noM0000000000007Booc`0oooo00@0oono07@00000
07@0_ooo7`3oool00580oooo00@0oooO09a80000000007Bo?`3oool0103ooml0W4P00000001d_olk
0?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03Ooold0?ooo`060;md0000B9`0gooo0?oo
o`2oM00007Bo?03oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo?@3oool0103ooml0
W4P00000001d_olm0?ooo`040?oog`2LB0000000001d_ah0oooo001D0?ooo`050?oOW01800000000
0018W03Oool0?@3oool00`3ogi`0B00007Boo`0l0?ooo`050;md00000000000000000000M;l0=`3o
ool0102oM000000000000000M;ln0?ooo`050;md00000000000000000000M;l0@03oool00`3ogi`0
B00007Boo`0o0?ooo`050?oOW018000000000018W03Oool06`3oool00?l0oooon`3oool00?l0oooo
n`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooo
n`3oool00?l0oooon`3oool00?l0oooon`3oool00?l0oooon`3oool003D0oooo00@0_g@000000000
0000B9cO2P3ooooo00000:<000005@3oool003<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB000
07Bo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01<0oooo000c0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00380
oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`080?ooo`030000003oool0oooo
0?l0ooooW`3oool00`000000oooo0?ooo`0C0?ooo`00<P3oool00`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooonO0?ooo`030000003oool0oooo01<0
oooo000b0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01`3oool00`000000oooo
0?ooo`060?ooodD0<ol0o`3ooomD0?ooo`030000003oool0oooo01<0oooo000b0?ooo`030?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol01`3oool4000000D0oooo00<0<ol003<0o`0c0?l0SP0c
0?l60?l00?h0oooo1000000E0?ooo`00<P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0
W=oo00L0oooo00<000000?ooo`3oool01P3ooom503?o04/0oooo0P0c0?l50?ooo`X0o`00m`3oool0
0`000000oooo0?ooo`0C0?ooo`00<P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
00L0oooo00<000000?ooo`3oool0U`3oool00`0c0?l0oooo0?ooo`0=0?ooo`@0o`00l`3oool00`00
0000oooo0?ooo`0C0?ooo`00<`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00P0
oooo00<000000?ooo`3oool0V03oool00`0c0?l0oooo0?ooo`0@0?ooo`@0o`00k`3oool00`000000
oooo0?ooo`0C0?ooo`00<`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo
00<000000?ooo`3oool0V@3oool00`0c0?l0oooo0?ooo`0C0?ooo`@0o`00j`3oool00`000000oooo
0?ooo`0C0?ooo`00=03oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00<000000?ooo`3o
ool0VP3oool00`0c0?l0oooo0?ooo`0F0?ooo`<0o`00j03oool00`000000oooo0?ooo`0C0?ooo`00
=@3oool0102oM000000000000000M;l:0?ooo`030000003oool0oooo09/0oooo00<0<`3o0?ooo`3o
ool0603oool00`3o0000oooo0?ooo`3U0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000
003oool0oooo09`0oooo00<0<`3o0?ooo`3oool0603oool20?l00>D0oooo00<000000?ooo`3oool0
4`3oool004<0oooo00<000000?ooo`3oool0W@3oool00`0c0?l0oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo0>80oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0WP3oool0
0`0c0?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo0>40oooo00<000000?ooo`3oool04`3oool0
04<0oooo00<000000?ooo`3oool0W`3oool00`0c0?l0oooo0?ooo`0I0?ooo`80o`00h@3oool00`00
0000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2P0?ooo`80<`3o6`3oool00`3o0000
oooo0?ooo`3N0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0:80oooo
00<0<`3o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`3M0?ooo`030000003oool0oooo01<0oooo
00130?ooo`030000003oool0oooo0:<0oooo00<0<`3o0?ooo`3oool06@3oool00`3o0000oooo0?oo
o`3L0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0:@0oooo00<0<`3o
0?ooo`3oool06@3oool00`3o0000oooo0?ooo`3K0?ooo`030000003oool0oooo01<0oooo00130?oo
o`030000003oool0oooo0:D0oooo00<0<`3o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`3J0?oo
o`030000003oool0oooo01<0oooo00130?ooo`800000Y`3oool00`0c0?l0oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo0=L0oooo0`00000E0?ooo`00@`3oool00`000000oooo0?ooo`2W0?ooo`0303<0
o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0f03oool00`000000oooo0?ooo`0C0?ooo`00@`3o
ool00`000000oooo0?ooo`2X0?ooo`0303<0o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0e`3o
ool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2Y0?ooo`0303<0o`3oool0
oooo01T0oooo00<0o`000?ooo`3oool0eP3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`00
0000oooo0?ooo`2Z0?ooo`0303<0o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2[0?ooo`0303<0o`3oool0oooo01T0
oooo00<0o`000?ooo`3oool0e03oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo
0?ooo`2/0?ooo`0303<0o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0e03oool00`000000oooo
0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2]0?ooo`0303<0o`3oool0oooo01P0oooo00<0
o`000?ooo`3oool0d`3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2^
0?ooo`0303<0o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0dP3oool00`000000oooo0?ooo`0C
0?ooo`00@`3oool00`000000oooo0?ooo`2_0?ooo`0303<0o`3oool0oooo01L0oooo00<0o`000?oo
o`3oool0dP3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2`0?ooo`03
03<0o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0d@3oool00`000000oooo0?ooo`0C0?ooo`00
@`3oool00`000000oooo0?ooo`2a0?ooo`80<`3o603oool00`3o0000oooo0?ooo`3@0?ooo`030000
003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0;<0oooo00<0<`3o0?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`3@0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0
oooo0;@0oooo00<0<`3o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`3?0?ooo`030000003oool0
oooo01<0oooo00130?ooo`030000003oool0oooo0;D0oooo00<0<`3o0?ooo`3oool05@3oool00`3o
0000oooo0?ooo`3>0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0;H0
oooo00<0<`3o0?ooo`3oool0503oool00`3o0000oooo0?ooo`3>0?ooo`030000003oool0oooo01<0
oooo00130?ooo`800000^03oool00`0c0?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0</0oooo
0`00000E0?ooo`00@`3oool00`000000oooo0?ooo`2h0?ooo`0303<0o`3oool0oooo01@0oooo00<0
o`000?ooo`3oool0c03oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2i
0?ooo`0303<0o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0c03oool00`000000oooo0?ooo`0C
0?ooo`00@`3oool00`000000oooo0?ooo`2j0?ooo`0303<0o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool0b`3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2k0?ooo`03
03<0o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0bP3oool00`000000oooo0?ooo`0C0?ooo`00
@`3oool00`000000oooo0?ooo`2l0?ooo`0303<0o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2m0?ooo`0303<0o`3o
ool0oooo0180oooo00<0o`000?ooo`3oool0b@3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool0
0`000000oooo0?ooo`2n0?ooo`0303<0o`3oool0oooo0180oooo00<0o`000?ooo`3oool0b03oool0
0`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`2o0?ooo`0303<0o`3oool0oooo
0180oooo00<0o`000?ooo`3oool0a`3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000
oooo0?ooo`300?ooo`0303<0o`3oool0oooo0180oooo00<0o`000?ooo`3oool0aP3oool00`000000
oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`310?ooo`0303<0o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0aP3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?oo
o`320?ooo`80<`3o4P3oool00`3o0000oooo0?ooo`350?ooo`030000003oool0oooo01<0oooo0013
0?ooo`030000003oool0oooo0<@0oooo00<0<`3o0?ooo`3oool0403oool00`3o0000oooo0?ooo`34
0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0<D0oooo00<0<`3o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`340?ooo`030000003oool0oooo01<0oooo00130?ooo`03
0000003oool0oooo0<H0oooo00<0<`3o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`330?ooo`03
0000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0<L0oooo00<0<`3o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`320?ooo`030000003oool0oooo01<0oooo00130?ooo`800000b@3o
ool00`0c0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0;l0oooo0`00000E0?ooo`00@`3oool0
0`000000oooo0?ooo`390?ooo`0303<0o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3:0?ooo`0303<0o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000
oooo0?ooo`3;0?ooo`0303<0o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0_`3oool00`000000
oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3<0?ooo`0303<0o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool0_P3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?oo
o`3=0?ooo`0303<0o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0_P3oool00`000000oooo0?oo
o`0C0?ooo`00@`3oool00`000000oooo0?ooo`3>0?ooo`0303<0o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool0_@3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3?0?oo
o`0303<0o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0_03oool00`000000oooo0?ooo`0C0?oo
o`00@`3oool00`000000oooo0?ooo`3@0?ooo`0303<0o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0_03oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3A0?ooo`0303<0
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0^`3oool00`000000oooo0?ooo`0C0?ooo`00<P3o
ool00`3OW4P00000000000050000000307Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0dP3o
ool00`0c0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0;X0oooo00<000000?ooo`3oool04`3o
ool003<0oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`060?ooo`030000003oool0
oooo0=80oooo00<0<`3o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`2i0?ooo`030000003oool0
oooo01<0oooo000d0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01`3oool00`00
0000oooo0?ooo`3C0?ooo`0303<0o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0C0?ooo`00=@3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030000003oool0oooo0=@0
oooo00<0<`3o0?ooo`3oool0303oool00`3o0000oooo0?ooo`2h0?ooo`030000003oool0oooo01<0
oooo000f0?ooo`030=nLB01d_ol0oooo00X0oooo00<000000?ooo`3oool0e@3oool00`0c0?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo0;L0oooo00<000000?ooo`3oool04`3oool003H0oooo00<0
oooO09a8B02Lgol02P3oool00`000000oooo0?ooo`3F0?ooo`0303<0o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0]P3oool00`000000oooo0?ooo`0C0?ooo`00=`3oool00`3ogi`0B01d0;ooo`09
0?ooo`@00000eP3oool00`0c0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0;<0oooo1000000E
0?ooo`00>03oool00`2oM000B9cO0?ooo`080?ooo`030000003oool0oooo0=P0oooo00<0<`3o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`2e0?ooo`030000003oool0oooo01<0oooo000h0?ooo`03
0=nLB00007@0_ooo00P0oooo00<000000?ooo`3oool0f@3oool00`0c0?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo0;@0oooo00<000000?ooo`3oool04`3oool003P0oooo00<0okmd0000001d_ol0
203oool00`000000oooo0?ooo`3J0?ooo`0303<0o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
/`3oool00`000000oooo0?ooo`0C0?ooo`00<P3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md0000
0000M;oo00P0oooo00<000000?ooo`3oool0f`3oool00`0c0?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo0;<0oooo00<000000?ooo`3oool04`3oool003<0oooo00P0_g@007Boo`3oool0oooo0=nL
B000000004RL0=ooo`P0oooo00<000000?ooo`3oool0g03oool00`0c0?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo0;80oooo00<000000?ooo`3oool04`3oool003@0oooo00D0_g@0000000000000
0000001d_`0:0?ooo`030000003oool0oooo0=d0oooo00<0<`3o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`2a0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0=h0oooo
0P0c0?l;0?ooo`030?l0003oool0oooo0;00oooo00<000000?ooo`3oool04`3oool004<0oooo00<0
00000?ooo`3oool0h03oool00`0c0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0;00oooo00<0
00000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0h@3oool00`0c0?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo0:l0oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?oo
o`3oool0hP3oool00`0c0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0:h0oooo00<000000?oo
o`3oool04`3oool004<0oooo00<000000?ooo`3oool0h`3oool00`0c0?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo0:d0oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0
i03oool00`0c0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0:d0oooo00<000000?ooo`3oool0
4`3oool004<0oooo00<000000?ooo`3oool0i@3oool00`0c0?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo0:`0oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0iP3oool2
03<0o`P0oooo00<0o`000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`00
0000oooo0?ooo`3X0?ooo`0303<0o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`0C0?ooo`00@`3oool200000>X0oooo00<0<`3o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`2W0?ooo`<000005@3oool004<0oooo00<000000?ooo`3oool0jP3oool00`0c0?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo0:T0oooo00<000000?ooo`3oool04`3oool001T0oooo00<0
oknL09cOo`3oool02P3oool00`3OW9`0_ooo0?ooo`0J0?ooo`030000003oool0oooo0>/0oooo00<0
<`3o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`2X0?ooo`030000003oool0oooo01<0oooo000I
0?ooo`030?noM01d_ol0oooo00X0oooo00<0_gAd0;ooo`3oool06P3oool00`000000oooo0?ooo`3/
0?ooo`0303<0o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0C
0?ooo`006@3oool00`3o_g@000000000000:000000030000M02oool0oooo01X0oooo00<000000?oo
o`3oool0k@3oool00`0c0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0:H0oooo00<000000?oo
o`3oool04`3oool001T0oooo00<0okmd0000000000002P0000000`0007@0_ooo0?ooo`0J0?ooo`03
0000003oool0oooo0>h0oooo00<0<`3o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`2U0?ooo`03
0000003oool0oooo01<0oooo000I0?ooo`030?noM01d_ol0oooo00X0oooo00<0_gAd0;ooo`3oool0
6P3oool00`000000oooo0?ooo`3_0?ooo`0303<0o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
Y03oool00`000000oooo0?ooo`0C0?ooo`006@3oool00`3o_i`0W=oo0?ooo`0:0?ooo`030;mdM02o
ool0oooo01X0oooo00<000000?ooo`3oool0l03oool00`0c0?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo0:@0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0_gAd0;ooo`3oool06P3oool0
0`000000oooo0?ooo`3a0?ooo`0303<0o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0X`3oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`2oM7@0_ooo0?ooo`0J0?ooo`030000003oool0oooo
0?80oooo00<0<`3o0?ooo`3oool0103oool00`3o0000oooo0?ooo`2R0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`030?oo_`1d07@0_ooo01/0oooo00<000000?ooo`3oool0l`3oool00`0c0?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo0:40oooo00<000000?ooo`3oool04`3oool002@0oooo
00@0okmd0000000007@0_ooo6`3oool00`000000oooo0?ooo`3d0?ooo`0303<0o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0X03oool00`000000oooo0?ooo`0C0?ooo`008`3oool00`2oM0000018
09cOo`0M0?ooo`030000003oool0oooo0?D0oooo00<0<`3o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`2O0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?H0oooo00<0
<`3o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`2O0?ooo`030000003oool0oooo01<0oooo0013
0?ooo`030000003oool0oooo0?L0oooo00<0<`3o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`2N
0?ooo`030000003oool0oooo01<0oooo000O0?ooo`030?oog`2LB00000000080000000<007Bo0?oo
o`3oool0703oool00`000000oooo0?ooo`3h0?ooo`0303<0o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0W@3oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`3o_g@000000000000400000003
0000M02oool0oooo01/0oooo0P00003j0?ooo`0303<0o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0VP3oool3000001D0oooo000M0?ooo`030?oo_`1d04P0W=oo00@0oooo00<0okmd00000000M;l0
703oool00`000000oooo0?ooo`3j0?ooo`0303<0o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
V`3oool00`000000oooo0?ooo`0C0?ooo`007@3oool00`3o_g@0M;oo0?ooo`050?ooo`030?oog`2L
B7@0_ooo01/0oooo00<000000?ooo`3oool0n`3oool00`0c0?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo09X0oooo00<000000?ooo`3oool04`3oool001d0oooo00<0okmd04RLg`3oool01P3oool0
0`2oM7@0_ooo0?ooo`0J0?ooo`030000003oool0oooo0?`0oooo00<0<`3o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo000M0?ooo`040?oo_`1d000004RL
0=ooo`@0oooo00<0okmd001d_`3oool06`3oool00`000000oooo0?ooo`3m0?ooo`0303<0o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0V03oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`3o
_g@0000000000004000000030000M02oool0oooo01/0oooo00<000000?ooo`3oool0oP3oool00`0c
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo09L0oooo00<000000?ooo`3oool04`3oool001l0
oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0
oooo00<0<`3o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`2F0?ooo`030000003oool0oooo01<0
oooo00130?ooo`030000003oool0oooo0?l0oooo0@3oool00`0c0?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo09D0oooo00<000000?ooo`3oool04`3oool002L0oooo00@0omnL04P000000000M;oo
603oool00`000000oooo0?ooo`3o0?ooo`80oooo00<0<`3o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`2D0?ooo`030000003oool0oooo01<0oooo000N0?ooo`0>0?oog`2LB000000000000000M;l0
oooO09a800000000B9bo09adW03Oool0gia80018W03OoolG0?ooo`030000003oool0oooo0?l0oooo
0`3oool00`0c0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo09<0oooo00<000000?ooo`3oool0
4`3oool001d0oooo00<0oooO09a8000000000`0000002@18M9`0_moo0=nLB00004P0W=oo0?ooo`3o
gi`0B01809cOo`0G0?ooo`030000003oool0oooo0?l0oooo103oool00`0c0?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo09<0oooo00<000000?ooo`3oool04`3oool001d0oooo00<0omnL04Qd_`3o
ool00P3oool02P3ogi`0B4RL0=ooo`3o_g@0001d0;ooo`3oool0oono07@0001d_olG0?ooo`030000
003oool0oooo0?l0oooo1@3oool00`0c0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0980oooo
00<000000?ooo`3oool04`3oool001d0oooo00<0oknL09cOo`3oool00`3oool02@3OW9`0_ooo0?no
M00004P0W=oo0?ooo`3ooml0W4P007Boo`0G0?ooo`030000003oool0oooo0?l0oooo1P3oool00`0c
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0940oooo00<000000?ooo`3oool04`3oool001d0
oooo00<0omnL04Q8W03Oool00P3oool02P3ooml0W7BL0=ooo`3o_g@0001809cOo`3oool0oono07@0
B02LgolG0?ooo`030000003oool0oooo0?l0oooo1`3oool00`0c0?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0900oooo00<000000?ooo`3oool04`3oool001h0oooo00<0_g@00000000000000P00
00002@18W=l0oooo0?noM00004P0W=oo0?ooo`3ogi`0B4RL0=ooo`0G0?ooo`030000003oool0oooo
0?l0oooo203oool00`0c0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo08l0oooo00<000000?oo
o`3oool04`3oool001h0oooo00D0_g@0000000000000000004RLg`020?ooo`060?oOW0180000M;oo
0?oog`2LB4P0W=oo603oool200000?l0oooo2P3oool00`0c0?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo08`0oooo0`00000E0?ooo`007P3oool00`2oM7@0_ooo0?ooo`050?ooo`040=nLB0000000
001809cOoaT0oooo00<000000?ooo`3oool0o`3oool:0?ooo`0303<0o`3oool0oooo0080oooo00<0
o`000?ooo`3oool0S@3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o
0?ooo`/0oooo00<0<`3o0?ooo`3oool00P3oool00`3o0000<ol00?ooo`2<0?ooo`030000003oool0
oooo01<0oooo00130?ooo`030000003oool0oooo0?l0oooo303oool01`0c0?l0oooo0?ooo`3oool0
<ol00?l0000co`00S03oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`3o_g@0000000000004
000000030000M02oool0oooo01/0oooo00<000000?ooo`3oool0o`3oool=0?ooo`0303<0o`3oool0
<ol00080<ol000<0o`0003?o003oool0RP3oool00`000000oooo0?ooo`0C0?ooo`00703oool00`3O
W4P0000000000008000000030000B02Lgol0oooo01T0oooo00<000000?ooo`3oool0o`3oool>0?oo
o`0303<0o`0co`00<ol00080<ol000<0o`0003?o003oool0R@3oool00`000000oooo0?ooo`0C0?oo
o`006`3oool0102oM00000000000001d_ol70?ooo`040;md00000000000004RLgaT0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`0303<0o`0co`00<ol00080<ol000<0o`0003?o003oool0R03oool0
0`000000oooo0?ooo`0C0?ooo`006P3oool00`2oM00007Bo0?ooo`0;0?ooo`030?oog`2LB000B9cO
01P0oooo00<000000?ooo`3oool0o`3oool@0?ooo`0303<0o`0co`00<ol00080<ol000<0o`0003?o
003oool0Q`3oool00`000000oooo0?ooo`0C0?ooo`006@3oool00`3o_g@0M;oo0?ooo`0>0?ooo`03
0=nLM02Lgol0oooo01H0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`0303<0o`0co`00<ol00080
<ol000<0o`0003?o003oool0QP3oool00`000000oooo0?ooo`0C0?ooo`006@3oool00`3o_i`0W=oo
0?ooo`0:0?ooo`030=nLW02oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`0303<0
o`0co`00<ol00080<ol000<0o`0003?o003oool0Q@3oool00`000000oooo0?ooo`0C0?ooo`006@3o
ool00`3o_g@0M;oo0?ooo`0:0?ooo`030;mdM02oool0oooo01X0oooo00<000000?ooo`3oool0o`3o
oolC0?ooo`0303<0o`0co`00<ol00080<ol000<0o`0003?o003oool0Q03oool00`000000oooo0?oo
o`0C0?ooo`006@3oool00`3o_g@000000000000:000000030000M02oool0oooo00h0oooo00<0okmd
0000001d_ol02@3oool00`000000oooo0?ooo`3o0?oooa@0oooo00<0<`3o03?o000co`000P0co`00
0`3o0000<ol00?ooo`230?ooo`030000003oool0oooo01<0oooo000I0?ooo`030?noM00000000000
00X0000000<0001d0;ooo`3oool03P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo
0?l0oooo5@3oool203<0o`<0<ol000<0o`0003?o003oool0PP3oool00`000000oooo0?ooo`0C0?oo
o`006@3oool00`3o_g@0M;oo0?ooo`030?ooo`030?oOW01dW=l0oooo00<0oooo00<0oooO09a8M02o
ool03`3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo0?l0oooo5`3oool0100c0?l0
<ol003?o003o000203?o0880oooo00<000000?ooo`3oool04`3oool001T0oooo00<0okmd07Boo`3o
ool00`3oool00`3ogi`0M9cO0?ooo`040?ooo`030=nLW02oool0oooo00T0oooo00<0gia800000000
00001@0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0oooo0?l0oooo603oool0100c0?l0
<ol003?o003o000203?o0840oooo00<000000?ooo`3oool04`3oool001T0oooo00<0okmd07Boo`3o
ool00`3oool00`3ogi`0M9cO0?ooo`0@0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d
_ol02@3oool00`000000oooo0?ooo`3o0?oooaT0oooo00@0<`3o03?o000co`00o`000P0co`200?oo
o`030000003oool0oooo01<0oooo000I0?ooo`030?noM01d_ol0oooo00<0oooo00<0okmd04RLg`3o
ool04@3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d_ol02@3oool400000?l0oooo6@3oool0
100c0?l0<ol003?o003o000203?o07`0oooo1000000E0?ooo`006@3oool01P3o_g@0M;oo0?ooo`3o
ool0oono07@000<0000000<0M;oo0?ooo`3oool03P3oool01`3ookl0M01d0;ooo`3oool0okmd0000
001d_ol02@3oool00`000000oooo0?ooo`3o0?oooa/0oooo00@0<`3o03?o000co`00o`000P0co`1n
0?ooo`030000003oool0oooo01<0oooo000I0?ooo`030?noM00007@0_ooo01P0oooo00H0okmd001d
_`3oool0okmd0000001d_ol90?ooo`030000003oool0oooo0?l0oooo703oool0100c0?l0<ol003?o
003o000203?o07d0oooo00<000000?ooo`3oool04`3oool001T0oooo00@0okmd000000000000B9cO
603oool01@2oM000M;oo0?noM0000000M;oo00T0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`04
03<0o`0co`00<ol00?l00080<ol0O03oool00`000000oooo0?ooo`0C0?ooo`00=@3oool01@3ookl0
M01d0;noM0000000M;oo00T0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`0403<0o`0co`00<ol0
0?l00080<ol0N`3oool00`000000oooo0?ooo`0C0?ooo`00=P3oool0103o_g@000000000001d_ol9
0?ooo`030000003oool0oooo0?l0oooo7`3oool0100c0?l0<ol003?o003o000203?o07X0oooo00<0
00000?ooo`3oool04`3oool001h0oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0>
0?ooo`040?oog`2LB000000007Boo`T0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`0403<0o`0c
o`00<ol00?l00080<ol0N@3oool00`000000oooo0?ooo`0C0?ooo`00703oool00`3OW4P000000000
0008000000030000B02Lgol0oooo00d0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?oo
o`3o0?ooob40oooo00@0<`3o03?o000co`00o`000P0co`1h0?ooo`030000003oool0oooo01<0oooo
000K0?ooo`040;md00000000000007Boo`L0oooo00@0_g@0000000000000B9cO6@3oool00`000000
oooo0?ooo`3o0?ooob80oooo00@0<`3o03?o000co`00o`000P0co`1g0?ooo`030000003oool0oooo
01<0oooo000J0?ooo`030;md0000M;l0oooo00/0oooo00<0oooO09a80018W=l0603oool00`000000
oooo0?ooo`3o0?ooob<0oooo00@0<`3o03?o000co`00o`000P0co`1f0?ooo`030000003oool0oooo
01<0oooo000I0?ooo`030?n?B018Z?l0oooo00h0oooo00<0giad09cOo`3oool05P3oool00`000000
oooo0?ooo`3o0?ooob@0oooo00@0<`3o03?o000co`00o`000P0co`1e0?ooo`030000003oool0oooo
01<0oooo000I0?ooo`030?noM01d_ol0oooo00X0oooo00<0gibL0;ooo`3oool06P3oool00`000000
oooo0?ooo`3o0?ooobD0oooo0P0c0?l0100co`00o`0003?o000co`1d0?ooo`030000003oool0oooo
01<0oooo000I0?ooo`030?noM000B9`0gooo00X0oooo00<0_gAd0;ooo`3oool06P3oool00`000000
oooo0?ooo`3o0?ooobH0oooo00@0<ol003<0o`0co`00o`000P0co`1c0?ooo`030000003oool0oooo
01<0oooo000I0?ooo`030?noM0000000000000X0000000<0001d0;ooo`3oool06P3oool00`000000
oooo0?ooo`3o0?ooobL0oooo00@0<ol003<0o`0co`00o`000P0co`1b0?ooo`030000003oool0oooo
01<0oooo000J0?ooo`040;md00000000001809cOo`P0oooo00<0_gAd0;ooo`3oool06P3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo00@0<ol003<0o`0co`00o`000P0co`1a0?ooo`030000003oool0
oooo01<0oooo000K0?ooo`040=nLB0000000000007Boo`L0oooo00<0gibL0;ooo`3oool06P3oool0
0`000000oooo0?ooo`3o0?ooobT0oooo00@0<ol003<0o`0co`00o`000P0co`1`0?ooo`030000003o
ool0oooo01<0oooo000L0?ooo`040?noM00000000000001d_b<0oooo0P00003o0?ooob/0oooo00@0
<ol003<0o`0co`00o`000P0co`1]0?ooo`<000005@3oool001d0oooo00D0omnL04P00000000004RL
0=ooo`0Q0?ooo`030000003oool0oooo0?l0oooo:`3oool0100co`00<`3o03?o003o000203?o06h0
oooo00<000000?ooo`3oool04`3oool001h0oooo00D0oono07@000000000001809cOo`0P0?ooo`03
0000003oool0oooo0?l0oooo;03oool0100co`00<`3o03?o003o000203?o06d0oooo00<000000?oo
o`3oool04`3oool001l0oooo00D0oooO09a800000000000007Boo`0O0?ooo`030000003oool0oooo
0?l0oooo;@3oool0100co`00<`3o03?o003o000203?o06`0oooo00<000000?ooo`3oool04`3oool0
01T0oooo00<0oknL09cOo`3oool01@3oool0102oM000000000000000M;lN0?ooo`030000003oool0
oooo0?l0oooo;P3oool0100co`00<`3o03?o003o000203?o06/0oooo00<000000?ooo`3oool04`3o
ool001T0oooo00<0okmd07Boo`3oool01P3oool01@3OW4P0000000000000B9`0gooo01`0oooo00<0
00000?ooo`3oool0o`3oool_0?ooo`0403?o000c0?l0<ol00?l00080<ol0JP3oool00`000000oooo
0?ooo`0C0?ooo`006@3oool00`3o_g@000000000000:000000030000B02Lgol0oooo01X0oooo00<0
00000?ooo`3oool0o`3oool`0?ooo`0403?o000c0?l0<ol00?l00080<ol0J@3oool00`000000oooo
0?ooo`0C0?ooo`006@3oool00`3o_g@0M;oo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo<@3o
ool0100co`00<`3o03?o003o000203?o06P0oooo00<000000?ooo`3oool04`3oool001T0oooo00<0
oknL09cOo`3oool09`3oool00`000000oooo0?ooo`3o0?oooc80oooo00@0<ol003<0o`0co`00o`00
0P0co`1W0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0oooo<`3o
ool0100co`00<`3o03?o003o000203?o06H0oooo00<000000?ooo`3oool04`3oool001T0oooo00<0
okmd07Boo`3oool03P3oool00`2oM4P0W=oo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo=03o
ool0100co`00<`3o03?o003o000203?o06D0oooo00<000000?ooo`3oool04`3oool001X0oooo00<0
_g@0001d_`3oool02`3oool00`3ooml0W4P007Boo`0H0?ooo`030000003oool0oooo0?l0oooo=@3o
ool0100co`00<`3o03<0o`3o000203?o06@0oooo00<000000?ooo`3oool04`3oool001/0oooo00@0
_g@0000000000000M;oo1`3oool0102oM000000000000018W=lI0?ooo`030000003oool0oooo0?l0
oooo=P3oool203?o000403<0o`3o0000<ol003?o06<0oooo00<000000?ooo`3oool04`3oool001`0
oooo00<0gia8000000000000200000000`0004P0W=oo0?ooo`0I0?ooo`030000003oool0oooo0?l0
oooo=`3oool203?o000403<0o`3o0000<ol003?o0680oooo00<000000?ooo`3oool04`3oool001h0
oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0K0?ooo`030000003oool0oooo0?l0
oooo>03oool203?o000403<0o`3o0000<ol003?o0640oooo00<000000?ooo`3oool04`3oool004<0
oooo00<000000?ooo`3oool0o`3oooli0?ooo`80<ol000@0<`3o0?l0000co`00<ol0H03oool00`00
0000oooo0?ooo`0C0?ooo`006@3oool00`3o_g@0M;oo0?ooo`0>0?ooo`030;mdB02Lgol0oooo01H0
oooo0P00003o0?oooc/0oooo0P0co`00100c0?l0o`0003?o000co`1M0?ooo`<000005@3oool001X0
oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P007Boo`0H0?ooo`030000003oool0oooo0?l0
oooo>`3oool203?o000403<0o`3o0000<ol003?o05h0oooo00<000000?ooo`3oool04`3oool001/0
oooo00@0_g@0000000000000M;oo1`3oool0102oM000000000000018W=lI0?ooo`030000003oool0
oooo0?l0oooo?03oool203?o000403<0o`3o0000<ol003?o05d0oooo00<000000?ooo`3oool04`3o
ool001`0oooo00<0gia8000000000000200000000`0004P0W=oo0?ooo`0I0?ooo`030000003oool0
oooo0?l0oooo?@3oool203?o000403<0o`3o0000<ol003?o05`0oooo00<000000?ooo`3oool04`3o
ool001h0oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0K0?ooo`030000003oool0
oooo0?l0oooo?P3oool203?o000403<0o`3o0000<ol003?o05/0oooo00<000000?ooo`3oool04`3o
ool004<0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`80<ol000@0<`3o0?l0000co`00<ol0FP3o
ool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oood00oooo0P0co`00
100c0?l0o`0003?o000co`1I0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0
oooo0?l0oooo@@3oool203?o000403<0o`3o0000<ol003?o05P0oooo00<000000?ooo`3oool04`3o
ool004<0oooo00<000000?ooo`3oool0o`3ooom20?ooo`80<ol000@0<`3o0?l0000co`00<ol0E`3o
ool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oood<0oooo0P0co`00
100c0?l0o`0003?o000co`1F0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0
oooo0?l0ooooA03oool203?o000403<0o`3o0000<ol003?o05D0oooo00<000000?ooo`3oool04`3o
ool004<0oooo00<000000?ooo`3oool0o`3ooom50?ooo`80<ol000@0<`3o0?l0000co`00<ol0E03o
ool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodH0oooo0P0co`00
100c0?l0o`0003?o000co`1C0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0
oooo0?l0ooooA`3oool203?o000403<0o`3o0000<ol003?o0580oooo00<000000?ooo`3oool04`3o
ool004<0oooo00<000000?ooo`3oool0o`3ooom80?ooo`80<ol000@0<`3o0?l0000co`00<ol0D@3o
ool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodT0oooo0P0co`00
0`0c0?l0o`0003?o000203?o04l0oooo00<000000?ooo`3oool04`3oool004<0oooo0P00003o0?oo
od/0oooo0P0co`000`0c0?l0o`0003?o000203?o04`0oooo0`00000E0?ooo`00@`3oool00`000000
oooo0?ooo`3o0?oood/0oooo0P0co`000`0c0?l0o`0003?o000203?o04d0oooo00<000000?ooo`3o
ool04`3oool004<0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`0303?o000c0?l0o`0000<0<ol0
C03oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<0
<ol003<0o`3o00000`0co`1;0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0
oooo0?l0ooooC`3oool00`0co`00<`3o0?l0000303?o04X0oooo00<000000?ooo`3oool04`3oool0
04<0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`0303?o000c0?l0o`0000<0<ol0B@3oool00`00
0000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooe40oooo00<0<ol003<0o`3o
00000`0co`180?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0oooo
DP3oool00`0co`00<`3o0?l0000303?o04L0oooo00<000000?ooo`3oool04`3oool004<0oooo00<0
00000?ooo`3oool0o`3ooomC0?ooo`0303?o000c0?l0o`0000<0<ol0AP3oool00`000000oooo0?oo
o`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooe@0oooo00<0<ol003<0o`3o00000`0co`15
0?ooo`030000003oool0oooo01<0oooo000d0?ooo`060?oog`2LB00000000000000007@0_ooo2@3o
ool00`000000oooo0?ooo`3o0?oooeD0oooo00<0<ol003<0o`3o00000`0co`140?ooo`030000003o
ool0oooo01<0oooo000c0?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgol80?ooo`03
0000003oool0oooo0?l0ooooEP3oool00`0co`00<`3o0?l0000303?o04<0oooo00<000000?ooo`3o
ool04`3oool003<0oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`070?ooo`030000
003oool0oooo0?l0ooooE`3oool00`0co`00<`3o03<0o`0303?o0480oooo00<000000?ooo`3oool0
4`3oool00380oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`070?ooo`030000003o
ool0oooo0?l0ooooF03oool203?o000403<0o`0co`00<ol003?o0440oooo00<000000?ooo`3oool0
4`3oool00380oooo00<0omnL04P00018W=l0103oool00`2oM000001809cOo`070?ooo`030000003o
ool0oooo0?l0ooooF@3oool203?o000403<0o`0co`00<ol003?o0400oooo00<000000?ooo`3oool0
4`3oool00380oooo00<0omnL04P00018W=l00`3oool0103ookl0M0000000M02oool70?ooo`030000
003oool0oooo0?l0ooooFP3oool203?o000403<0o`0co`00<ol003?o03l0oooo00<000000?ooo`3o
ool04`3oool00380oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l0203oool4
00000?l0ooooFP3oool203?o000403<0o`0co`00<ol003?o03/0oooo1000000E0?ooo`00<P3oool0
1@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?oooe`0oooo0P0co`00100c0?l0<ol003?o000co`0m0?ooo`030000003oool0oooo01<0oooo
000c0?ooo`030?noM0000000B9cO00d0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`80<ol000@0
<`3o03?o000co`00<ol0?03oool00`000000oooo0?ooo`0C0?ooo`00<`3oool0103ooml0W4P00000
B02Lgol<0?ooo`030000003oool0oooo0?l0ooooGP3oool203?o000403<0o`0co`00<ol003?o03/0
oooo00<000000?ooo`3oool04`3oool003@0oooo00@0oono07@0000007@0_ooo2`3oool00`000000
oooo0?ooo`3o0?oooel0oooo0P0co`00100c0?l0<ol003?o000co`0j0?ooo`030000003oool0oooo
01<0oooo000e0?ooo`040?oog`2LB0000000001d_`X0oooo00<000000?ooo`3oool0o`3ooomP0?oo
o`80<ol000@0<`3o03?o000co`00<ol0>@3oool00`000000oooo0?ooo`0C0?ooo`00=`3oool01@3o
gi`0B00000000000B9`0gooo00L0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`80<ol000@0<`3o
03?o000co`00<ol0>03oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o
0?ooof80oooo0P0co`00100c0?l0<ol003?o000co`0g0?ooo`030000003oool0oooo01<0oooo0013
0?ooo`030000003oool0oooo0?l0ooooH`3oool203?o000403<0o`0co`00<ol003?o03H0oooo00<0
00000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`80<ol000@0<`3o
03?o000co`00<ol0=@3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o
0?ooofD0oooo0P0co`00100c0?l0<ol003?o000co`0d0?ooo`030000003oool0oooo01<0oooo0013
0?ooo`030000003oool0oooo0?l0ooooIP3oool203?o000403<0o`0co`00<ol003?o03<0oooo00<0
00000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`80<ol00P0c0?l2
03?o0380oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0o`3ooomX0?oo
o`80<ol000@0o`0003<0o`0co`00<ol0<@3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`00
0000oooo0?ooo`3o0?ooofT0oooo0P0co`00103o0000<`3o03?o000co`0`0?ooo`030000003oool0
oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooJP3oool303?o000303<0o`0co`00<ol0
02l0oooo00<000000?ooo`3oool04`3oool004<0oooo0P00003o0?ooof`0oooo0`0co`000`0c0?l0
<ol003?o000/0?ooo`<000005@3oool004<0oooo00<000000?ooo`3oool0o`3ooom/0?ooo`<0<ol0
00<0<`3o03?o000co`00;@3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?oo
o`3o0?ooofd0oooo0`0co`000`0c0?l0<ol003?o000/0?ooo`030000003oool0oooo01<0oooo0013
0?ooo`030000003oool0oooo0?l0ooooKP3oool303?o000303<0o`0co`00<ol002/0oooo00<00000
0?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0o`3ooom_0?ooo`<0<ol000<0<`3o03?o
000co`00:P3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooog00
oooo0`0co`000`0c0?l0<ol003?o000Y0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000
003oool0oooo0?l0ooooL@3oool303?o000303<0o`0co`00<ol002P0oooo00<000000?ooo`3oool0
4`3oool004<0oooo00<000000?ooo`3oool0o`3ooomb0?ooo`<0<ol000<0<`3o03?o000co`009`3o
ool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooog<0oooo0`0co`00
0`0c0?l0<ol003?o000V0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo
0?l0ooooM03oool303?o000303<0o`0co`00<ol002D0oooo00<000000?ooo`3oool04`3oool004<0
oooo00<000000?ooo`3oool0o`3ooome0?ooo`<0<ol000<0<`3o03?o000co`00903oool00`000000
oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooogH0oooo0`0co`000`0c0?l0<ol0
03?o000S0?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooM`3o
ool303?o000303<0o`0co`00<ol00280oooo00<000000?ooo`3oool04`3oool004<0oooo00<00000
0?ooo`3oool0o`3ooomh0?ooo`<0<ol000<0<`3o03?o000co`008@3oool00`000000oooo0?ooo`0C
0?ooo`00@`3oool00`000000oooo0?ooo`3o0?ooogT0oooo0`0co`000`0c0?l0o`0003?o000P0?oo
o`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooNP3oool303?o0003
03<0o`3o0000<ol001l0oooo00<000000?ooo`3oool04`3oool004<0oooo0P00003o0?ooog`0oooo
0`0co`00100c0?l0o`0003?o000co`0K0?ooo`<000005@3oool004<0oooo00<000000?ooo`3oool0
o`3oooml0?ooo`<0<ol000@0<`3o0?l0000co`00<ol0703oool00`000000oooo0?ooo`0C0?ooo`00
@`3oool00`000000oooo0?ooo`3o0?ooogd0oooo0`0co`00100c0?l0o`0003?o000co`0K0?ooo`03
0000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooO`3oool203?o000403<0
o`3o0000<ol003?o01X0oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0
o`3ooon00?ooo`80<ol000@0<`3o0?l0000co`00<ol06@3oool00`000000oooo0?ooo`0C0?ooo`00
@`3oool00`000000oooo0?ooo`3o0?oooh40oooo0P0co`00100c0?l0o`0003?o000co`0H0?ooo`03
0000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooPP3oool203?o000403<0
o`3o0000<ol003?o01L0oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0
o`3ooon30?ooo`80<ol000@0<`3o0?l0000co`00<ol05P3oool00`000000oooo0?ooo`0C0?ooo`00
@`3oool00`000000oooo0?ooo`3o0?oooh@0oooo0P0co`00100c0?l0o`0003?o000co`0E0?ooo`03
0000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooQ@3oool203?o000403<0
o`3o0000<ol003?o01@0oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0
o`3ooon60?ooo`80<ol000@0<`3o0?l0000co`00<ol04`3oool00`000000oooo0?ooo`0C0?ooo`00
@`3oool00`000000oooo0?ooo`3o0?ooohL0oooo0P0co`00100c0?l0o`0003?o000co`0B0?ooo`03
0000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooR03oool203?o000403<0
o`3o0000<ol003?o0140oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0
o`3ooon90?ooo`80<ol000@0<`3o0?l0000co`00<ol0403oool00`000000oooo0?ooo`0C0?ooo`00
@`3oool00`000000oooo0?ooo`3o0?ooohX0oooo0P0co`00100c0?l0o`0003?o000co`0?0?ooo`03
0000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooR`3oool203?o000403<0
o`3o0000<ol003?o00h0oooo00<000000?ooo`3oool04`3oool004<0oooo0P00003o0?ooohd0oooo
0P0co`00100c0?l0o`0003?o000co`0;0?ooo`<000005@3oool004<0oooo00<000000?ooo`3oool0
o`3ooon=0?ooo`80<ol000@0<`3o0?l0000co`00<ol0303oool00`000000oooo0?ooo`0C0?ooo`00
@`3oool00`000000oooo0?ooo`3o0?ooohh0oooo0P0co`00100c0?l0o`0003?o000co`0;0?ooo`03
0000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooS`3oool203?o000403<0
o`3o0000<ol003?o00X0oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0
o`3ooon@0?ooo`80<ol000@0<`3o0?l0000co`00<ol02@3oool00`000000oooo0?ooo`0C0?ooo`00
@`3oool00`000000oooo0?ooo`3o0?oooi40oooo0P0co`0203<0o`80<ol0203oool00`000000oooo
0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooi80oooo0`0co`000`0c0?l0<ol003?o
00070?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo0?l0ooooT`3oool4
03?o00P0oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool0o`3ooonD0?oo
o`80<ol02@3oool00`000000oooo0?ooo`0C0?ooo`00@`3oool00`000000oooo0?ooo`3o0?oooil0
oooo00<000000?ooo`3oool04`3oool004<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01<0oooo00130?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`00@`3ooooo00000:<000005@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 505.5}, {312.063, 0}} -> {-8.33671, -1.89715, \
0.0302154, 0.0313708}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 6\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(x2n[
        N_] := \(- .5\) /; \((\(-6\) \[LessEqual] 
            N \[LessEqual] \(-1.7\))\)\), "\[IndentingNewLine]", 
    \(x2n[N_] := 0 /; \((\(-1.7\) < N \[LessEqual] nmax)\)\)}], "Input"],

Cell[BoxData[
    RowBox[{"(*", " ", 
      RowBox[{
        StyleBox["Numeric",
          FontColor->RGBColor[1, 0, 0]], " ", "-", " ", 
        StyleBox["Semi",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["-",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["analytic",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[" ",
        FontColor->RGBColor[0, 0, 1]], "*)"}]], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Note\ that\ f[R]\ below\ is\ in\ units\ H\_0^2\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(pr = 
        ParametricPlot[{Log[
              RN[nn]], \((\(Log[\((fF[N] - 1.507231608668476)\)] /. f1\) /. 
                N \[Rule] nn)\)}, {nn, \(-6\), \(-4\)}, 
          PlotRange \[Rule] All, Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.008], 
              Hue[0.3]}];\)\), "\[IndentingNewLine]", 
    \(\(pr1 = 
        ParametricPlot[{Log[
              RN[nn]], \((\(Log[\(-\((fF[N] - 16.561513502651923)\)\)] /. 
                  f2\) /. N \[Rule] nn)\)}, {nn, 2, 6}, 
          PlotRange \[Rule] All, Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.008], Hue[0.3]}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pr4 = 
        ParametricPlot[{{Log[RN[N]], Log[fN[N]]}, {Log[RN[N]], 
              Log[fNacc[N]]}}, {N, nmin, \(-1.8\)}, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Log(R)\>", "\<Log(f(R))\>"}, 
          PlotRange \[Rule] All, Axes \[Rule] False, 
          PlotStyle \[Rule] {Hue[0], Hue[ .7]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.380837 0.0758343 -0.23094 0.0466206 [
[.07417 -0.0125 -7.03125 -24.5625 ]
[.07417 -0.0125 7.03125 0 ]
[.22584 -0.0125 -7.03125 -24.5625 ]
[.22584 -0.0125 7.03125 0 ]
[.37751 -0.0125 -12.0625 -24.5625 ]
[.37751 -0.0125 12.0625 0 ]
[.52917 -0.0125 -12.0625 -24.5625 ]
[.52917 -0.0125 12.0625 0 ]
[.68084 -0.0125 -12.0625 -24.5625 ]
[.68084 -0.0125 12.0625 0 ]
[.83251 -0.0125 -12.0625 -24.5625 ]
[.83251 -0.0125 12.0625 0 ]
[.98418 -0.0125 -12.0625 -24.5625 ]
[.98418 -0.0125 12.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -31.4063 -49.125 ]
[.5 -0.0125 31.4063 -24.5625 ]
[-0.0125 .04878 -14.0625 -12.2813 ]
[-0.0125 .04878 0 12.2813 ]
[-0.0125 .14202 -14.0625 -12.2813 ]
[-0.0125 .14202 0 12.2813 ]
[-0.0125 .23527 -24.125 -12.2813 ]
[-0.0125 .23527 0 12.2813 ]
[-0.0125 .32851 -24.125 -12.2813 ]
[-0.0125 .32851 0 12.2813 ]
[-0.0125 .42175 -24.125 -12.2813 ]
[-0.0125 .42175 0 12.2813 ]
[-0.0125 .51499 -24.125 -12.2813 ]
[-0.0125 .51499 0 12.2813 ]
[-0.0125 .60823 -24.125 -12.2813 ]
[-0.0125 .60823 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -48.6875 -42.2813 ]
[-0.01875 .30902 -24.125 42.2813 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07417 0 m
.07417 .00625 L
s
gsave
.07417 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.22584 0 m
.22584 .00625 L
s
gsave
.22584 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.37751 0 m
.37751 .00625 L
s
gsave
.37751 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.52917 0 m
.52917 .00625 L
s
gsave
.52917 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.68084 0 m
.68084 .00625 L
s
gsave
.68084 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.83251 0 m
.83251 .00625 L
s
gsave
.83251 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.98418 0 m
.98418 .00625 L
s
gsave
.98418 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
1.000 setlinewidth
grestore
.125 Mabswid
.11209 0 m
.11209 .00375 L
s
.15 0 m
.15 .00375 L
s
.18792 0 m
.18792 .00375 L
s
.26375 0 m
.26375 .00375 L
s
.30167 0 m
.30167 .00375 L
s
.33959 0 m
.33959 .00375 L
s
.41542 0 m
.41542 .00375 L
s
.45334 0 m
.45334 .00375 L
s
.49126 0 m
.49126 .00375 L
s
.56709 0 m
.56709 .00375 L
s
.60501 0 m
.60501 .00375 L
s
.64293 0 m
.64293 .00375 L
s
.71876 0 m
.71876 .00375 L
s
.75668 0 m
.75668 .00375 L
s
.79459 0 m
.79459 .00375 L
s
.87043 0 m
.87043 .00375 L
s
.90835 0 m
.90835 .00375 L
s
.94626 0 m
.94626 .00375 L
s
.03625 0 m
.03625 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -92.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.375 23.000 moveto
(H) show
101.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.375 23.000 moveto
(L) show
121.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04878 m
.00625 .04878 L
s
gsave
-0.0125 .04878 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .14202 m
.00625 .14202 L
s
gsave
-0.0125 .14202 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
0 .23527 m
.00625 .23527 L
s
gsave
-0.0125 .23527 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .32851 m
.00625 .32851 L
s
gsave
-0.0125 .32851 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
0 .42175 m
.00625 .42175 L
s
gsave
-0.0125 .42175 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
0 .51499 m
.00625 .51499 L
s
gsave
-0.0125 .51499 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
0 .60823 m
.00625 .60823 L
s
gsave
-0.0125 .60823 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07209 m
.00375 .07209 L
s
0 .0954 m
.00375 .0954 L
s
0 .11871 m
.00375 .11871 L
s
0 .16534 m
.00375 .16534 L
s
0 .18865 m
.00375 .18865 L
s
0 .21196 m
.00375 .21196 L
s
0 .25858 m
.00375 .25858 L
s
0 .28189 m
.00375 .28189 L
s
0 .3052 m
.00375 .3052 L
s
0 .35182 m
.00375 .35182 L
s
0 .37513 m
.00375 .37513 L
s
0 .39844 m
.00375 .39844 L
s
0 .44506 m
.00375 .44506 L
s
0 .46837 m
.00375 .46837 L
s
0 .49168 m
.00375 .49168 L
s
0 .5383 m
.00375 .5383 L
s
0 .56161 m
.00375 .56161 L
s
0 .58492 m
.00375 .58492 L
s
0 .02547 m
.00375 .02547 L
s
0 .00216 m
.00375 .00216 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -139.688 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
103.281 16.2813 translate
90 rotate
-103.281 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.375 23.000 moveto
(H) show
101.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
110.688 23.000 moveto
(H) show
117.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
130.688 23.000 moveto
(L) show
137.125 23.000 moveto
(L) show
143.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07417 .61178 m
.07417 .61803 L
s
.22584 .61178 m
.22584 .61803 L
s
.37751 .61178 m
.37751 .61803 L
s
.52917 .61178 m
.52917 .61803 L
s
.68084 .61178 m
.68084 .61803 L
s
.83251 .61178 m
.83251 .61803 L
s
.98418 .61178 m
.98418 .61803 L
s
.125 Mabswid
.11209 .61428 m
.11209 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.18792 .61428 m
.18792 .61803 L
s
.26375 .61428 m
.26375 .61803 L
s
.30167 .61428 m
.30167 .61803 L
s
.33959 .61428 m
.33959 .61803 L
s
.41542 .61428 m
.41542 .61803 L
s
.45334 .61428 m
.45334 .61803 L
s
.49126 .61428 m
.49126 .61803 L
s
.56709 .61428 m
.56709 .61803 L
s
.60501 .61428 m
.60501 .61803 L
s
.64293 .61428 m
.64293 .61803 L
s
.71876 .61428 m
.71876 .61803 L
s
.75668 .61428 m
.75668 .61803 L
s
.79459 .61428 m
.79459 .61803 L
s
.87043 .61428 m
.87043 .61803 L
s
.90835 .61428 m
.90835 .61803 L
s
.94626 .61428 m
.94626 .61803 L
s
.03625 .61428 m
.03625 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04878 m
1 .04878 L
s
.99375 .14202 m
1 .14202 L
s
.99375 .23527 m
1 .23527 L
s
.99375 .32851 m
1 .32851 L
s
.99375 .42175 m
1 .42175 L
s
.99375 .51499 m
1 .51499 L
s
.99375 .60823 m
1 .60823 L
s
.125 Mabswid
.99625 .07209 m
1 .07209 L
s
.99625 .0954 m
1 .0954 L
s
.99625 .11871 m
1 .11871 L
s
.99625 .16534 m
1 .16534 L
s
.99625 .18865 m
1 .18865 L
s
.99625 .21196 m
1 .21196 L
s
.99625 .25858 m
1 .25858 L
s
.99625 .28189 m
1 .28189 L
s
.99625 .3052 m
1 .3052 L
s
.99625 .35182 m
1 .35182 L
s
.99625 .37513 m
1 .37513 L
s
.99625 .39844 m
1 .39844 L
s
.99625 .44506 m
1 .44506 L
s
.99625 .46837 m
1 .46837 L
s
.99625 .49168 m
1 .49168 L
s
.99625 .5383 m
1 .5383 L
s
.99625 .56161 m
1 .56161 L
s
.99625 .58492 m
1 .58492 L
s
.99625 .02547 m
1 .02547 L
s
.99625 .00216 m
1 .00216 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.97619 .60332 m
.93743 .57949 L
.89515 .5535 L
.85545 .52909 L
.81727 .50562 L
.77663 .48063 L
.73751 .45658 L
.69593 .43102 L
.65587 .40639 L
.61733 .3827 L
.57633 .35749 L
.53685 .33322 L
.49889 .30989 L
.45847 .28504 L
.41958 .26112 L
.37823 .23569 L
.33841 .2112 L
.30013 .18764 L
.25941 .16256 L
.22024 .1384 L
.17869 .11271 L
.13877 .08792 L
.10054 .06398 L
.0602 .03838 L
.02381 .01472 L
s
.2 0 1 r
.97619 .60332 m
.93743 .57949 L
.89515 .5535 L
.85545 .52909 L
.81727 .50562 L
.77663 .48063 L
.73751 .45658 L
.69593 .43102 L
.65587 .40639 L
.61733 .3827 L
.57633 .35749 L
.53685 .33322 L
.49889 .30989 L
.45847 .28504 L
.41958 .26113 L
.37823 .2357 L
.33841 .21121 L
.30013 .18766 L
.25941 .1626 L
.22024 .13848 L
.17869 .11286 L
.13877 .08819 L
.10054 .06448 L
.0602 .03931 L
.02381 .01639 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{439.375, 271.563},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006g00013b000`400?l00000o`00003oo`3ooonh
0?ooo`00o`3ooonh0?ooo`00j`3oool00`3o_g@0000000000002000000030000M02oool0oooo00L0
oooo00<0gia804RLg`3oool03@3oool00`3OW4P0B9cO0?ooo`2Z0?ooo`00jP3oool00`3OW4P00000
07Boo`030?ooo`030?oo_`1dB9`0gooo00H0oooo00<0okmd04RLg`3oool03`3oool00`3OW4P0M;oo
0?ooo`2Y0?ooo`00jP3oool00`3o_g@004RL0=ooo`040?ooo`030?oOW02L_ol0oooo00@0oooo00<0
okmd0018W03Oool0403oool00`3ooml0W4P007Boo`2Y0?ooo`00j`3oool00`3OW7@0W=oo0?ooo`03
0?ooo`030?oOW01dW=l0oooo00<0oooo00<0oooO09a8001d_ol04P3oool00`3o_g@0001d0;ooo`2X
0?ooo`00e03oool00`3ooml0W4P0000000070000000607Boo`3oool0oooo0?ooo`3ogi`0B0000P00
00000`0007@0_ooo0?ooo`020?ooo`030=nLB0000000000000@0000000<0B9cO0?ooo`3oool00P3o
ool01P3o_g@0001d0;ooo`3oool0oooO09a800@0000000D0B9cO0?ooo`3oool0oooo0;md00020000
00070000B02Lgol0oooo0?ooo`3ookl0M00007Boo`2X0?ooo`00eP3oool00`3ogi`0B000001d_`04
0?ooo`0?0;md0000M;l0oooo0?ooo`3o_g@000000018W03Oool0oooo0?noM00004P0W=oo0?ooo`3o
oml0W4P000D0000000<004RL0=ooo`3oool00`3oool00`2oM00004RL0=ooo`030?ooo`040?oo_`1d
000004RL0=ooo`<0oooo00@0okmd0000000004P0W=oo103oool00`3ooml0W4P0001d_`2X0?ooo`00
eP3oool00`3ogi`0B00004RLg`040?ooo`070?oog`2LM9`0gooo0?oog`2LB000001809cOo`030?oo
o`060;md0000B9`0gooo0?ooo`3OW4P0B9cO2@3oool00`3ooml0W4P0001d_`040?ooo`030?oo_`1d
000007Bo00<0oooo00@0oono07@0000007@0_ooo1P3oool00`2oM000001d0;ooo`2W0?ooo`00eP3o
ool00`3ogi`0B00004RLg`050?ooo`050?noW02Lgol0omnL04P00000M;l0103oool00`3OW4P00018
09cOo`020?ooo`050;md0000000000000000001d_ol01@3oool00`3ookl0M00004RLg`040?ooo`03
0?oo_`1d000007Bo0080oooo00@0oooO09a800000000M;oo1`3oool00`3OW4P0001d0;ooo`2W0?oo
o`00eP3oool00`3ogi`0B00004RLg`070?ooo`030?noM0000000B9cO00@0oooo00/0gia80000001d
_ol0oooo0?noM0000000M;oo0?ooo`3OW4P0000007Boo`040?ooo`030?oOW0180000B9cO00@0oooo
00<0oono07@00000M;l00P3oool00`3OW4P0000004RLg`080?ooo`030=nLB00004P0W=oo0:L0oooo
003F0?ooo`030?oOW0180000B9cO00L0oooo00<0omnL04P00018W=l0103oool02`2oM000001809cO
o`3ooml0W4P00018W03Oool0oooo0?oOW0180000B9cO00@0oooo00<0omnL04P00018W=l0103oool0
203ookl0M000001d_`3oool0okmd00000000B9`0gooo203oool00`3OW4P0001809cOo`2W0?ooo`00
eP3oool00`3ogi`0B00004RLg`070?ooo`030?oog`2LB00007Bo00<0oooo00L0oono07@0000007@0
_ooo0?oo_`1d000007Bo0080oooo00<0omnL04P0001d_ol0103oool00`3ookl0M00004RLg`040?oo
o`030?oo_`1d0000000000<0000000<0B9cO0?ooo`3oool01`3oool00`3OW4P0001809cOo`2W0?oo
o`00eP3oool00`3ogi`0B00004RLg`080?ooo`080?oOW0180000M;oo0?ooo`3ooml0W4P00000001d
_ol20?ooo`050=nLB00004P0W=oo0?ooo`2oM0000P0000001`00B9`0gooo0?ooo`3oool0oono07@0
0000M;l0103oool00`3ookl0M000001d_`020?ooo`040?oo_`1d0000000004RLg`L0oooo00<0_g@0
0000M02oool0Y`3oool00=H0oooo00<0omnL04P00018W=l02@3oool01P3ookl0M000000000000000
001809cOo`@0oooo00D0gia800000000000004RL0=ooo`060?ooo`030;md0000B9`0gooo00<0oooo
00<0oono07@00000M;l00`3oool0103ookl0M0000000001d_ol50?ooo`030?oog`2LB00007Bo0:P0
oooo003F0?ooo`030?oOW0180000B9cO01h0oooo00<0okmd0000M02oool00`3oool00`3ookl0M000
001d_`040?ooo`030;md00000000B9cO00D0oooo00<0oono07@0001d_ol0Z03oool00=H0oooo00<0
omnL04P00018W=l07P3oool00`3ooml0W4P007Boo`030?ooo`030?oo_`1d000007Bo00<0oooo00@0
oooO09a800000000M;oo1@3oool00`3o_g@0001d0;ooo`2X0?ooo`00eP3oool00`3ogi`0B00004RL
g`0O0?ooo`030?noM000B9`0gooo0080oooo00<0oono07@00000M;l00`3oool0102oM00000000018
W03Oool40?ooo`030?oog`2LB000M;oo0:T0oooo003D0?ooo`030?oog`2LB000000000<0000000<0
M;oo0?ooo`3oool0703oool0103o_g@004RL0=oog`2LB00700000003001d_`3oool0oooo00<0oooo
00<0oooO09a80018W=l0ZP3oool00?X0oooo00<0omnL07BLg`3oool03@3oool00`3OW7@0W=oo0?oo
o`2Z0?ooo`00o`3ooonh0?ooo`00o`3ooonh0?ooo`00o`3ooonh0?ooo`00o`3ooonh0?ooo`00o`3o
oonh0?ooo`00o`3ooonh0?ooo`00o`3ooonh0?ooo`00o`3ooonh0?ooo`00o`3ooonh0?ooo`00o`3o
oonh0?ooo`00o`3ooonh0?ooo`00H03oool01P3ooml0W4P0000000000000001d0;ooobd0oooo00H0
omnL04P00000000000000000B02LgolX0?ooo`030?noM000000000000080000000<007Bo0?ooo`3o
ool00`3oool0102oM000000000000018W=lU0?ooo`030?noM000000000000080000000@007Bo0?oo
o`3oool0gia81`0000000`1d_ol0oooo0?ooo`0P0?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool01@3oool00`3o_g@0000007Boo`0S0?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool00P3oool01P3ooml0W4P0000000000000001d0;ooob<0oooo00<0okmd000000000000
0P0000000`00M;l0oooo0?ooo`020?ooo`060?oOW018000000000000000004P0W=oo6@3oool005l0
oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOob/0oooo00P0omnL04P00000B9`0gooo
0?ooo`3ogi`0B00007BoobT0oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3oool0
oooO09a80000M;l09P3oool00`2oM000001d0;ooo`040?ooo`030=nLB0000000000000@0000000<0
07Bo0?ooo`3oool08P3oool00`2oM000001d0;ooo`080?ooo`030?noM0000000M;oo02D0oooo00<0
_g@00000M02oool0103oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo903oool00`2o
M000001d0;ooo`040?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0001d_olH0?ooo`00G`3o
ool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo02X0oooo00<0_g@00000M02oool00`3o
ool00`3OW4P004RL0=ooo`0X0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`0U0?ooo`030;md000007@0_ooo00D0oooo00<0gia804RLg`3oool00P3o
ool00`3ooml0W4Qd0;ooo`0S0?ooo`030;md000007@0_ooo00P0oooo00<0okmd0000001d_ol09@3o
ool00`2oM000001d0;ooo`040?ooo`030;md000007@0_ooo00<0oooo00<0_g@0001d_`3oool08`3o
ool00`2oM000001d0;ooo`040?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03Oool05`3o
ool005h0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`0Z0?ooo`030;md000007@0
_ooo00<0oooo00<0_g@00018W03Oool0:03oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0oooO09a80000M;l09@3oool00`2oM000001d0;ooo`060?ooo`030=nLB018
W=l0oooo02L0oooo00<0_g@00000M02oool00`3oool00`3OW4P0000000000005000000030000B02L
gol0oooo0280oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030=nLB000
07@0_ooo02<0oooo00<0_g@00000M02oool0103oool00`2oM000001d0;ooo`030?ooo`030;md0000
B9`0gooo01L0oooo001N0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol0:P3oool0
0`3o_g@0001809cOo`020?ooo`030=nLB000000007Bo02T0oooo00<0_g@00000M02oool00`3oool0
0`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02@0oooo00<0_g@00000M02oool01`3oool0
0`3OW4P0M;oo0?ooo`0V0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04Qd_`3oool00P3oool0
0`3o_g@0000007Boo`0U0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool0
0`2oM000001809cOo`0S0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool0
0`3OW4P00000001d_`0H0?ooo`00GP3oool00`3ogi`0B00004RLg`030?ooo`040?oo_`1d0000001d
0;ooob/0oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo02T0oooo00<0_g@00000M02oool0
0`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo02@0oooo00<0_g@00000M02oool0
1`3oool00`3ooml0W4Q809cOo`0V0?ooo`030;md000007@0_ooo00@0oooo00L0gia807Boo`3oool0
oooo0?noM0000000M;oo02D0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`030?oo
o`040?oo_`1d0000001d0;ooob<0oooo00<0_g@00000M02oool01@3oool01`3OW4P007Bo0?ooo`2o
M00000000000M02oool0603oool005h0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@00000
0018W=l0;@3oool01@3o_g@0000000000000B9`0gooo02X0oooo00<0_g@00000M02oool00`3oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02@0oooo00<0_g@00000M02oool0203oool0
0`3ogi`0B01d0;ooo`0U0?ooo`030;md000007@0_ooo00@0oooo00L0oono07@0M02oool0oooo0?no
M0000000M;oo02D0oooo00<0_g@00000M02oool00`3oool02@3ookl0M00000000000B9`0gooo0?oo
o`2oM000000004RLg`0T0?ooo`030;md000007@0_ooo00H0oooo00D0okmd00000000000004RL0=oo
o`0I0?ooo`00GP3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool0:`3o
ool01@3ogi`0B000000000000000B9cO02/0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo02@0oooo00<0_g@00000M02oool02@3oool00`2oM000B9cO
0?ooo`0T0?ooo`030;md000007@0_ooo00D0oooo00H0okmd001d_`3oool0okmd0000001d_olU0?oo
o`030;md000007@0_ooo00<0oooo00D0oooO09a8000007@0_mnL04P000020000000304RLg`3oool0
oooo02<0oooo00<0_g@00000M02oool01@3oool01@3ogi`0B000000000000000B9cO01X0oooo001O
0?ooo`030?noM0000000B9cO0300oooo00L0omnL04P0000004P0W=oo0?ooo`3OW4P007Bo02X0oooo
00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02@0oooo
00<0_g@00000M02oool02@3oool00`3OW4P0001d0;ooo`0T0?ooo`030;md000007@0_ooo00H0oooo
00D0_g@007Boo`3o_g@0000007Boo`0U0?ooo`030;md000007@0_ooo00@0oooo00<0okmd00000018
W=l0:@3oool00`2oM000001d0;ooo`040?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`0I
0?ooo`00G`3oool0103ooml0W4P00000B02Lgol_0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO
09a8001d_ol0:@3oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0gooo0080oooo00<0oooO
09a80000M;l09@3oool00`2oM000001d0;ooo`090?ooo`030?noM0000000M;oo02@0oooo00<0_g@0
0000M02oool01P3oool01@3ookl0M01d0;noM0000000M;oo02D0oooo00<0_g@00000M02oool0103o
ool0103ooml0W4P00000B02LgolX0?ooo`030;md000007@0_ooo00@0oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P007Boo`0H0?ooo`00H03oool0103ookl0M0000000M02oool^0?ooo`030=nL
B000B9`0gooo0080oooo00<0oooO09a80018W=l0:@3oool00`2oM000001d0;ooo`040?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol09@3oool00`2oM000001d0;ooo`030?ooo`030?oO
W02L_ol0oooo00<0oooo00<0_g@00000001d_ol0903oool00`2oM000001d0;ooo`070?ooo`040?no
M0000000000007BoobD0oooo00<0_g@00000M02oool01@3oool0103ookl0M0000000M02ooolW0?oo
o`030;md000007@0_ooo00@0oooo00<0gia80018W03Oool00P3oool00`3ooml0W4P004RLg`0H0?oo
o`00H@3oool0103ooml0W4P000000000M;l]0?ooo`030?oOW0180000B9cO0080oooo00<0okmd0000
B02Lgol09`3oool01@3OW4P000000000000007@0_ooo00D0oooo00H0_g@00018W03Oool0oooo0;md
0000M;lT0?ooo`050=nLB000000000000000M02oool0103oool0202oM000M;oo0?ooo`3oool0gia8
00000000B9`0gooo8P3oool01@3OW4P000000000000007@0_ooo00L0oooo00@0oooO09a800000000
M;oo8`3oool01@3OW4P000000000000007@0_ooo00H0oooo00@0oooO09a80000000007Bo903oool0
1@3OW4P000000000000007@0_ooo00@0oooo00<0omnL04P00018W=l00P3oool00`3o_g@0001809cO
o`0H0?ooo`00H`3oool01@3ogi`0B00000000000B9`0gooo02/0oooo00H0oono07@0000000000000
0000B02LgolY0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00@0_g@000000000000007Bo9P3oool0
103ookl0M0000000M02oool50?ooo`050;md00000000000000000000M;l09@3oool0103ookl0M000
0000M02oool80?ooo`030?oOW0180000M;oo02@0oooo00@0oono07@0000007@0_ooo203oool01@3o
gi`0B00000000000B9`0gooo0280oooo00@0oono07@0000007@0_ooo1@3oool01P3ookl0M0000000
00000000001809cOoaT0oooo003o0?oookP0oooo003o0?oookP0oooo003o0?oookP0oooo003o0?oo
okP0oooo003o0?oookP0oooo003o0?oookP0oooo003o0?oookP0oooo003o0?oookP0oooo003o0?oo
okP0oooo001:0?ooool00000D`00000K0?ooo`00BP3oool3000000X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool010000000oooo0?ooo`3oool2000001/0oooo001:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo
001:0?ooo`030000003oool0oooo0?l0ooooC`3oool00`000000oooo0?ooo`0I0?ooo`00BP3oool0
0`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool06@3oool004X0
oooo00<000000?ooo`3oool01@3oool00`0c0?l0o`000?l0003o0?ooodL0oooo00<000000?ooo`3o
ool06@3oool004X0oooo00<000000?ooo`3oool01P3oool203<0o`80o`00o`3ooom50?ooo`030000
003oool0oooo01T0oooo001:0?ooo`030000003oool0oooo00P0oooo0P0c0?l00`3o0000oooo0?oo
o`3o0?oood80oooo00<000000?ooo`3oool06@3oool004X0oooo0`00000:0?ooo`0303<0o`3o0000
o`000?l0oooo@@3oool2000001/0oooo001:0?ooo`030000003oool0oooo00/0oooo0P0c0?l00`3o
0000oooo0?ooo`3o0?ooocl0oooo00<000000?ooo`3oool06@3oool003`0oooo00H0oooO09a80000
000000000000M02oool80?ooo`030000003oool0oooo00d0oooo00<0<`3o0?l0003o0000o`3ooolo
0?ooo`030000003oool0oooo01T0oooo000k0?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000
B02Lgol70?ooo`030000003oool0oooo00h0oooo0P0c0?l20?l00?l0oooo?@3oool00`000000oooo
0?ooo`0I0?ooo`00>`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo00H0oooo00<0
00000?ooo`3oool0403oool203<0o`030?l0003oool0oooo0?l0oooo>P3oool00`000000oooo0?oo
o`0I0?ooo`00>P3oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0_ooo00H0oooo00<00000
0?ooo`3oool04P3oool00`0c0?l0o`000?l0003o0?ooocX0oooo00<000000?ooo`3oool06@3oool0
03X0oooo00<0omnL04P00018W=l0103oool00`2oM000001809cOo`060?ooo`030000003oool0oooo
01<0oooo0P0c0?l00`3o0000oooo0?ooo`3o0?ooocL0oooo00<000000?ooo`3oool06@3oool003X0
oooo00<0omnL04P00018W=l00`3oool0103ookl0M0000000M02oool60?ooo`030000003oool0oooo
01D0oooo0P0c0?l00`3o0000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool06@3oool003X0
oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l01`3oool3000001L0oooo00<0
<`3o0?l0003oool0o`3ooolc0?ooo`<000006`3oool003X0oooo00D0oooO09a8000007@0_mnL04P0
00020000000304RLg`3oool0oooo00H0oooo00<000000?ooo`3oool0603oool203<0ool0oooo=@3o
ool00`000000oooo0?ooo`0I0?ooo`00>`3oool00`3o_g@0000004RLg`0<0?ooo`030000003oool0
oooo01X0oooo00<0<`3o0?l0003oool0o`3ooolb0?ooo`030000003oool0oooo01T0oooo000k0?oo
o`040?oog`2LB000001809cOo`/0oooo00<000000?ooo`3oool06`3oool203<0ool0oooo<P3oool0
0`000000oooo0?ooo`0I0?ooo`00?03oool0103ookl0M0000000M02oool:0?ooo`030000003oool0
oooo01d0oooo0P0c0?oo0?oooc00oooo00<000000?ooo`3oool06@3oool003d0oooo00@0oooO09a8
0000000007Bo2@3oool00`000000oooo0?ooo`0O0?ooo`0303<0o`3oool0oooo0?l0oooo;@3oool0
0`000000oooo0?ooo`0I0?ooo`00?`3oool01@3ogi`0B00000000000B9`0gooo00H0oooo00<00000
0?ooo`3oool0803oool203<0ool0oooo;@3oool00`000000oooo0?ooo`0I0?ooo`00BP3oool00`00
0000oooo0?ooo`0R0?ooo`80<`3oo`3oool[0?ooo`030000003oool0oooo01T0oooo001:0?ooo`<0
0000903oool00`0c0?l0oooo0?ooo`3o0?ooobL0oooo0P00000K0?ooo`00BP3oool00`000000oooo
0?ooo`0U0?ooo`80<`3oo`3ooolX0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003o
ool0oooo02L0oooo00<0<`3o0?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo01T0oooo001:
0?ooo`030000003oool0oooo02P0oooo0P0c0?oo0?ooobD0oooo00<000000?ooo`3oool06@3oool0
04X0oooo00<000000?ooo`3oool0:P3oool203<0ool0oooo8`3oool00`000000oooo0?ooo`0I0?oo
o`00BP3oool00`000000oooo0?ooo`0/0?ooo`0303<0o`3oool0oooo0?l0oooo803oool00`000000
oooo0?ooo`0I0?ooo`00BP3oool00`000000oooo0?ooo`0]0?ooo`80<`3oo`3ooolP0?ooo`030000
003oool0oooo01T0oooo001:0?ooo`<00000;`3oool203<0ool0oooo7@3oool2000001/0oooo001:
0?ooo`030000003oool0oooo0340oooo0P0c0?oo0?oooa`0oooo00<000000?ooo`3oool06@3oool0
04X0oooo00<000000?ooo`3oool0<`3oool00`0c0?l0oooo0?ooo`3o0?oooaT0oooo00<000000?oo
o`3oool06@3oool004X0oooo00<000000?ooo`3oool0=03oool203<0ool0oooo6@3oool00`000000
oooo0?ooo`0I0?ooo`00BP3oool00`000000oooo0?ooo`0f0?ooo`80<`3oo`3ooolG0?ooo`030000
003oool0oooo01T0oooo001:0?ooo`030000003oool0oooo03P0oooo0P0c0?oo0?oooaD0oooo00<0
00000?ooo`3oool06@3oool004X0oooo00<000000?ooo`3oool0>P3oool00`0c0?l0oooo0?ooo`3o
0?oooa80oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?ooo`3oool0>`3oool203<0
ool0oooo4P3oool00`000000oooo0?ooo`0I0?ooo`00BP3oool3000003d0oooo00<0<`3o0?ooo`3o
ool0o`3oool>0?ooo`8000006`3oool004X0oooo00<000000?ooo`3oool0?P3oool203<0ool0oooo
3`3oool00`000000oooo0?ooo`0I0?ooo`00?03oool01P3ogi`0B000000000000000001809cOo`P0
oooo00<000000?ooo`3oool0@03oool00`0c0?l0oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3o
ool06@3oool003/0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`L0oooo00<00000
0?ooo`3oool0@@3oool203<0ool0oooo303oool00`000000oooo0?ooo`0I0?ooo`00>`3oool00`2o
M000001d0;ooo`030?ooo`030=nLB000B9`0gooo00H0oooo00<000000?ooo`3oool0@`3oool203<0
ool0oooo2P3oool00`000000oooo0?ooo`0I0?ooo`00>`3oool00`2oM000001d0;ooo`030?ooo`03
0;md0000B9`0gooo00H0oooo00<000000?ooo`3oool0A@3oool00`0c0?l0oooo0?ooo`3o0?ooo`L0
oooo00<000000?ooo`3oool06@3oool003/0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P00000
001d_`070?ooo`030000003oool0oooo04H0oooo0P0c0?oo0?ooo`L0oooo00<000000?ooo`3oool0
6@3oool003`0oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo00L0oooo00<000000?ooo`3o
ool0B03oool00`0c0?l0oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool06@3oool003d0oooo
00D0okmd00000000000004RL0=ooo`080?ooo`<00000B@3oool203<0ool0oooo0P3oool3000001/0
oooo000l0?ooo`050?oOW0180000000000000018W=l02@3oool00`000000oooo0?ooo`1;0?ooo`80
<`3oo`3oool20?ooo`030000003oool0oooo01T0oooo000k0?ooo`070?oOW0180000001809cOo`3o
ool0gia8001d_`080?ooo`030000003oool0oooo04d0oooo00<0<`3o0?ooo`3oool0oP3oool00`00
0000oooo0?ooo`0I0?ooo`00>`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo00L0
oooo00<000000?ooo`3oool0CP3oool203<0ooh0oooo00<000000?ooo`3oool06@3oool003/0oooo
00<0gia80018W03Oool00P3oool00`3ooml0W4P004RLg`070?ooo`030000003oool0oooo0500oooo
00<0<`3o0?ooo`3oool0n`3oool00`000000oooo0?ooo`0I0?ooo`00>`3oool00`3ogi`0B00004RL
g`020?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0D@3oool203<0oo/0oooo00<0
00000?ooo`3oool06@3oool003`0oooo00H0oono07@00000000000000000B02Lgol80?ooo`030000
003oool0oooo05<0oooo0P0c0?oi0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003o
ool0oooo05D0oooo00<0<`3o0?ooo`3oool0mP3oool00`000000oooo0?ooo`0I0?ooo`00BP3oool3
000005H0oooo0P0c0?oe0?ooo`8000006`3oool004X0oooo00<000000?ooo`3oool0F03oool00`0c
0?l0o`000?ooo`3c0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003oool0oooo05T0
oooo0P0c0?oc0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003oool0oooo05/0oooo
00<0<`3o0?l0003oool0l03oool00`000000oooo0?ooo`0I0?ooo`00BP3oool00`000000oooo0?oo
o`1L0?ooo`0303<0o`3o0000oooo0>l0oooo00<000000?ooo`3oool06@3oool004X0oooo00<00000
0?ooo`3oool0G@3oool203<0o`030?l0003oool0oooo0>`0oooo00<000000?ooo`3oool06@3oool0
04X0oooo00<000000?ooo`3oool0G`3oool00`0c0?l0o`000?l0003/0?ooo`030000003oool0oooo
01T0oooo001:0?ooo`030000003oool0oooo0600oooo0P0c0?l00`3o0000oooo0?ooo`3Y0?ooo`03
0000003oool0oooo01T0oooo001:0?ooo`<00000HP3oool00`0c0?l0o`000?l0003X0?ooo`800000
6`3oool001P0oooo00<0oknL09cOo`3oool02P3oool00`3OW9`0_ooo0?ooo`0R0?ooo`030000003o
ool0oooo06<0oooo0P0c0?l20?l00>L0oooo00<000000?ooo`3oool06@3oool001P0oooo00<0okmd
07Boo`3oool02P3oool00`2oM7@0_ooo0?ooo`0R0?ooo`030000003oool0oooo06D0oooo0P0c0?l0
0`3o0000oooo0?ooo`3T0?ooo`030000003oool0oooo01T0oooo000H0?ooo`030?noM00000000000
00X0000000<0001d0;ooo`3oool08P3oool00`000000oooo0?ooo`1W0?ooo`80<`3o00<0o`000?oo
o`3oool0hP3oool00`000000oooo0?ooo`0I0?ooo`00603oool00`3o_g@000000000000:00000003
0000M02oool0oooo0280oooo00<000000?ooo`3oool0J@3oool203<0on<0oooo00<000000?ooo`3o
ool06@3oool001P0oooo00<0okmd07Boo`3oool02P3oool00`2oM7@0_ooo0?ooo`0R0?ooo`030000
003oool0oooo06/0oooo0P0c0?oQ0?ooo`030000003oool0oooo01T0oooo000H0?ooo`030?noW02L
gol0oooo00X0oooo00<0_gAd0;ooo`3oool08P3oool00`000000oooo0?ooo`1]0?ooo`80<`3og`3o
ool00`000000oooo0?ooo`0I0?ooo`009@3oool00`2oM7@0_ooo0?ooo`0R0?ooo`030000003oool0
oooo06l0oooo00<0<`3o0?ooo`3oool0g03oool00`000000oooo0?ooo`0I0?ooo`009@3oool00`2o
M7@0_ooo0?ooo`0R0?ooo`<00000L03oool203<0om/0oooo0P00000K0?ooo`00903oool00`3ookl0
M01d0;ooo`0S0?ooo`030000003oool0oooo0780oooo00<0<`3o0?ooo`3oool0f@3oool00`000000
oooo0?ooo`0I0?ooo`008`3oool0103o_g@000000000M02oool;0?ooo`030?noM000000000000080
000000<007Bo0?ooo`3oool00`3oool0102oM000000000000018W=l90?ooo`030000003oool0oooo
07<0oooo0P0c0?oI0?ooo`030000003oool0oooo01T0oooo000R0?ooo`030;md000004P0W=oo00l0
oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0203oool0
0`000000oooo0?ooo`1e0?ooo`0303<0o`3oool0oooo0=H0oooo00<000000?ooo`3oool06@3oool0
03@0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo
00L0oooo00<000000?ooo`3oool0MP3oool203<0omH0oooo00<000000?ooo`3oool06@3oool003@0
oooo00<0_g@00000M02oool00`3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo
00L0oooo00<000000?ooo`3oool0N03oool203<0om@0oooo00<000000?ooo`3oool06@3oool001h0
oooo00<0oooO09a8000000000P0000000`00M;l0oooo0?ooo`0>0?ooo`030;md000007@0_ooo00<0
oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030000003oool0oooo07X0
oooo00<0<`3o0?ooo`3oool0d@3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`3o_g@00000
00000004000000030000M02oool0oooo00d0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B000
04RLg`040?ooo`030;md000007@0_ooo00H0oooo00<000000?ooo`3oool0N`3oool203<0om40oooo
00<000000?ooo`3oool06@3oool001`0oooo00<0oono07@0B02Lgol0103oool00`3o_g@00000001d
_`0>0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`060?ooo`<00000O@3oool00`0c0?l0oooo0?ooo`3<0?ooo`<000006`3oool001`0oooo00<0okmd
07Boo`3oool01@3oool00`3ooml0W4Qd0;ooo`0=0?ooo`030;md000007@0_ooo00<0oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`030000003oool0oooo07h0oooo0P0c0?o>
0?ooo`030000003oool0oooo01T0oooo000L0?ooo`030?noM018W=l0oooo00H0oooo00<0_gAd0;oo
o`3oool0303oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000
M02oool01P3oool00`000000oooo0?ooo`200?ooo`80<`3oc03oool00`000000oooo0?ooo`0I0?oo
o`00703oool0103ookl0M0000018W03Oool40?ooo`030?noM000M;l0oooo00d0oooo00<0_g@00000
M02oool0103oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<000000?oo
o`3oool0PP3oool203<0olX0oooo00<000000?ooo`3oool06@3oool001d0oooo00<0okmd00000000
0000100000000`0007@0_ooo0?ooo`0=0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`070?ooo`030000003oool0oooo08@0oooo00<0<`3o0?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0I0?ooo`007P3oool00`3ookl0M000000000020000000304RL
g`3oool0oooo00`0oooo00D0gia8000000000000001d0;ooo`050?ooo`060;md0000B9`0gooo0?oo
o`2oM00007Bo203oool00`000000oooo0?ooo`250?ooo`80<`3oa`3oool00`000000oooo0?ooo`0I
0?ooo`00<`3oool0103ookl0M0000000M02oool60?ooo`040;md000000000000001d_`T0oooo00<0
00000?ooo`3oool0Q`3oool203<0olD0oooo00<000000?ooo`3oool06@3oool002H0oooo00@0omnL
04P000000000M;oo803oool3000008T0oooo0P0c0?o20?ooo`8000006`3oool001d0oooo00h0oooO
09a8000000000000001d_`3ooml0W4P000000018W;l0W7BL0=ooo`3OW4P004RL0=oooal0oooo00<0
00000?ooo`3oool0R`3oool00`0c0?l0oooo0?ooo`300?ooo`030000003oool0oooo01T0oooo000L
0?ooo`030?oog`2LB000000000<0000000T0B7BL0;oOo`3OW4P0001809cOo`3oool0omnL04P0B02L
gol07`3oool00`000000oooo0?ooo`2<0?ooo`80<`3o`03oool00`000000oooo0?ooo`0I0?ooo`00
703oool00`3ogi`0B7Bo0?ooo`020?ooo`0:0?oOW018B9`0gooo0?noM00007@0_ooo0?ooo`3ookl0
M00007Booal0oooo00<000000?ooo`3oool0SP3oool203<0okh0oooo00<000000?ooo`3oool06@3o
ool001`0oooo00<0oknL09cOo`3oool00`3oool02@3OW9`0_ooo0?noM00004P0W=oo0?ooo`3ooml0
W4P007Boo`0O0?ooo`030000003oool0oooo0900oooo00<0<`3o0?ooo`3oool0^`3oool00`000000
oooo0?ooo`0I0?ooo`00703oool00`3ogi`0B4RL0=ooo`020?ooo`0:0?oog`2LM9`0gooo0?noM000
04P0W=oo0?ooo`3ookl0M01809cOoal0oooo00<000000?ooo`3oool0T@3oool203<0ok/0oooo00<0
00000?ooo`3oool06@3oool001d0oooo00<0_g@00000000000000P0000002@18W=l0oooo0?noM000
04P0W=oo0?ooo`3ogi`0B4RL0=ooo`0O0?ooo`030000003oool0oooo09<0oooo00<0<`3o0?ooo`3o
ool0^03oool00`000000oooo0?ooo`0I0?ooo`007@3oool01@2oM0000000000000000000B9cO0080
oooo00H0omnL04P0001d_ol0oooO09a8B02LgolP0?ooo`030000003oool0oooo09@0oooo0P0c0?nh
0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030;mdM02oool0oooo00D0oooo00@0gia80000
000004P0W=oo8@3oool3000009H0oooo0P0c0?ne0?ooo`8000006`3oool004X0oooo00<000000?oo
o`3oool0V03oool00`0c0?l0oooo0?ooo`2c0?ooo`030000003oool0oooo01T0oooo001:0?ooo`03
0000003oool0oooo09T0oooo0P0c0?nc0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030?no
M0000000000000@0000000<0001d0;ooo`3oool08`3oool00`000000oooo0?ooo`2K0?ooo`0303<0
o`3oool0oooo0;00oooo00<000000?ooo`3oool06@3oool001/0oooo00<0gia80000000000002000
00000`0004P0W=oo0?ooo`0Q0?ooo`030000003oool0oooo09`0oooo0P0c0?n`0?ooo`030000003o
ool0oooo01T0oooo000J0?ooo`040;md00000000000007Boo`L0oooo00@0_g@0000000000000B9cO
8@3oool00`000000oooo0?ooo`2N0?ooo`0303<0o`3oool0oooo0:d0oooo00<000000?ooo`3oool0
6@3oool001T0oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P004RLg`0P0?ooo`030000003o
ool0oooo09l0oooo00<0<`3o0?ooo`3oool0[03oool00`000000oooo0?ooo`0I0?ooo`00603oool0
0`3o_g@0M;oo0?ooo`0>0?ooo`030=nLM02Lgol0oooo01h0oooo00<000000?ooo`3oool0X03oool2
03<0oj`0oooo00<000000?ooo`3oool06@3oool004X0oooo0`00002R0?ooo`0303<0o`3oool0oooo
0:P0oooo0P00000K0?ooo`00703oool00`3o_g@0M;oo0?ooo`060?ooo`030=nLW02oool0oooo0280
oooo00<000000?ooo`3oool0X`3oool203<0ojT0oooo00<000000?ooo`3oool06@3oool001`0oooo
00<0okmd07Boo`3oool01@3oool00`3ooml0W4Qd0;ooo`0;0?ooo`030?noM0000000000000800000
00@007Bo0?ooo`3oool0gia81`0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo0:D0
oooo00<0<`3o0?ooo`3oool0YP3oool00`000000oooo0?ooo`0I0?ooo`006@3oool00`3ookl0M000
00000009000000030000M02oool0oooo00`0oooo00<0_g@00000M02oool0103oool00`3OW4P00000
0000000400000003001d_`3oool0oooo00D0oooo00<000000?ooo`3oool0YP3oool203<0ojH0oooo
00<000000?ooo`3oool06@3oool001P0oooo00<0omnL04P0000000002P0000000`0007@0_ooo0?oo
o`0<0?ooo`030;md000007@0_ooo00D0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;oo
o`060?ooo`030000003oool0oooo0:P0oooo0P0c0?nT0?ooo`030000003oool0oooo01T0oooo000H
0?ooo`060;mdM02oool0oooo0?ooo`3o_g@0M;oo1`3oool00`2oM7@0_ooo0?ooo`0<0?ooo`030;md
000007@0_ooo00H0oooo00<0gia804RLg`3oool02P3oool00`000000oooo0?ooo`2Z0?ooo`0303<0
o`3oool0oooo0:40oooo00<000000?ooo`3oool06@3oool001L0oooo00<0oono07Ad_`3oool00P3o
ool00`3o_g@0M;oo0?ooo`060?ooo`030=nLW02oool0oooo00`0oooo00<0_g@00000M02oool01`3o
ool00`3OW4P0M;oo0?ooo`090?ooo`030000003oool0oooo0:/0oooo0P0c0?nQ0?ooo`030000003o
ool0oooo01T0oooo000G0?ooo`030?oo_`1d07@0_ooo01X0oooo00<0_g@00000M02oool01`3oool0
0`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo0:d0oooo00<0<`3o0?ooo`3oool0WP3oool0
0`000000oooo0?ooo`0I0?ooo`005`3oool0103ooml0W4P00000B02LgolI0?ooo`030;md000007@0
_ooo00P0oooo00<0omnL04P0M02oool0203oool300000:h0oooo0P0c0?nL0?ooo`<000006`3oool0
01P0oooo00<0okmd0000B02Lgol06@3oool00`2oM000001d0;ooo`090?ooo`030;md0018W=l0oooo
00L0oooo00<000000?ooo`3oool0/03oool203<0oi`0oooo00<000000?ooo`3oool06@3oool003@0
oooo00<0_g@00000M02oool02@3oool00`3OW4P0001d0;ooo`070?ooo`030000003oool0oooo0;80
oooo00<0<`3o0?ooo`3oool0V@3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`3o_g@00000
00000004000000030000M02oool0oooo00d0oooo00<0_g@00000M02oool02@3oool00`3o_g@00000
07Boo`070?ooo`030000003oool0oooo0;<0oooo0P0c0?nI0?ooo`030000003oool0oooo01T0oooo
000K0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool02`3oool00`2oM000001d0;oo
o`030?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol01`3oool00`000000oooo0?oo
o`2e0?ooo`80<`3oU`3oool00`000000oooo0?ooo`0I0?ooo`006P3oool0102oM00000000000001d
_ol70?ooo`040;md00000000000004RLg`T0oooo00D0gia8000000000000001d0;ooo`040?ooo`08
0;md001d_ol0oooo0?ooo`3OW4P000000018W03Oool70?ooo`030000003oool0oooo0;L0oooo0P0c
0?nE0?ooo`030000003oool0oooo01T0oooo000I0?ooo`030;md0000M;l0oooo00/0oooo00<0oooO
09a80018W=l02@3oool0103ookl0M0000000M02oool50?ooo`050;md00000000000000000000M;l0
2@3oool00`000000oooo0?ooo`2i0?ooo`0303<0o`3oool0oooo0980oooo00<000000?ooo`3oool0
6@3oool001P0oooo00<0okmd07Boo`3oool03P3oool00`3OW7@0W=oo0?ooo`0N0?ooo`030000003o
ool0oooo0;X0oooo0P0c0?nB0?ooo`030000003oool0oooo01T0oooo000H0?ooo`030?noW02Lgol0
oooo00X0oooo00<0gibL0;ooo`3oool08P3oool300000;`0oooo0P0c0?n?0?ooo`8000006`3oool0
01P0oooo00<0okmd07Boo`3oool02P3oool00`2oM7@0_ooo0?ooo`0R0?ooo`030000003oool0oooo
0;h0oooo0P0c0?n>0?ooo`030000003oool0oooo01T0oooo000H0?ooo`030?noM0000000000000X0
000000<0001d0;ooo`3oool08P3oool00`000000oooo0?ooo`300?ooo`0303<0o`3oool0oooo08/0
oooo00<000000?ooo`3oool06@3oool001P0oooo00<0okmd0000000000002P0000000`0007@0_ooo
0?ooo`0R0?ooo`030000003oool0oooo0<40oooo0P0c0?n;0?ooo`030000003oool0oooo01T0oooo
000H0?ooo`030?noM01d_ol0oooo00<0oooo00<0oooO09adW03Oool0103oool00`2oM7@0_ooo0?oo
o`0R0?ooo`030000003oool0oooo0<<0oooo0P0c0?n90?ooo`030000003oool0oooo01T0oooo000H
0?ooo`030?noM01d_ol0oooo00<0oooo00<0oono07@0M02oool0103oool00`3OW9`0_ooo0?ooo`0R
0?ooo`030000003oool0oooo0<D0oooo00<0<`3o0?ooo`3oool0QP3oool00`000000oooo0?ooo`0I
0?ooo`00603oool00`3o_g@0B9cO0?ooo`030?ooo`040?noM0000000000007BoobP0oooo00<00000
0?ooo`3oool0aP3oool203<0ohH0oooo00<000000?ooo`3oool06@3oool001P0oooo00<0omnL04P0
001d_ol00P3oool00`3ogi`0B00007AdM00200000003001d_`3oool0oooo02D0oooo00<000000?oo
o`3oool0b03oool00`0c0?l0oooo0?ooo`230?ooo`030000003oool0oooo01T0oooo000I0?ooo`03
0;md0000000000000080000000L004RL0=ooo`3ookl0M0000000000007@0_ooo02D0oooo0`000039
0?ooo`80<`3oPP3oool2000001/0oooo000J0?ooo`050;md0000000000000018W03Oool00`3oool0
102oM000000000000018W=lT0?ooo`030000003oool0oooo0</0oooo0P0c0?n10?ooo`030000003o
ool0oooo01T0oooo000S0?ooo`040?noM0000000001d0;ooob<0oooo00<000000?ooo`3oool0c@3o
ool00`0c0?l0oooo0?ooo`1n0?ooo`030000003oool0oooo01T0oooo000T0?ooo`030?oOW01807@0
_ooo02<0oooo00<000000?ooo`3oool0cP3oool203<0ogh0oooo00<000000?ooo`3oool06@3oool0
02D0oooo00<0_gAd0;ooo`3oool08P3oool00`000000oooo0?ooo`3@0?ooo`80<`3oO03oool00`00
0000oooo0?ooo`0I0?ooo`009@3oool00`3OW9`0_ooo0?ooo`0R0?ooo`030000003oool0oooo0=80
oooo00<0<`3o0?ooo`3oool0N@3oool00`000000oooo0?ooo`0I0?ooo`00603oool00`3o_g@0M;oo
0?ooo`0>0?ooo`030;mdB02Lgol0oooo01h0oooo00<000000?ooo`3oool0d`3oool203<0ogT0oooo
00<000000?ooo`3oool06@3oool001T0oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P007Bo
o`0P0?ooo`030000003oool0oooo0=D0oooo00<0<`3o0?ooo`3oool0MP3oool00`000000oooo0?oo
o`0I0?ooo`006P3oool0102oM00000000000001d_ol70?ooo`040;md00000000000004RLgb40oooo
0`00003F0?ooo`80<`3oM@3oool2000001/0oooo000K0?ooo`030=nLB0000000000000P0000000<0
001809cOo`3oool08@3oool00`000000oooo0?ooo`3H0?ooo`80<`3oM03oool00`000000oooo0?oo
o`0I0?ooo`007@3oool00`3o_g@0000000000004000000030000M02oool0oooo00/0oooo00<0okmd
0000000000000P0000000`00M;l0oooo0?ooo`050?ooo`030?noM0000000M;oo00P0oooo00<00000
0?ooo`3oool0fP3oool00`0c0?l0oooo0?ooo`1a0?ooo`030000003oool0oooo01T0oooo000d0?oo
o`030;md000007@0_ooo00P0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`3K0?oo
o`80<`3oL@3oool00`000000oooo0?ooo`0I0?ooo`00603oool00`3o_g@0M;oo0?ooo`0>0?ooo`03
0;mdB02Lgol0oooo00P0oooo00<0_g@00000M02oool0203oool00`3o_g@0000007Boo`080?ooo`03
0000003oool0oooo0=d0oooo00<0<`3o0?ooo`3oool0KP3oool00`000000oooo0?ooo`0I0?ooo`00
6@3oool00`2oM00007Bo0?ooo`0;0?ooo`030?oog`2LB000M;oo00X0oooo00<0_g@00000M02oool0
0`3oool00`3OW4P0000000000005000000030000B02Lgol0oooo00D0oooo00<000000?ooo`3oool0
gP3oool203<0ofh0oooo00<000000?ooo`3oool06@3oool001X0oooo00@0_g@0000000000000M;oo
1`3oool0102oM000000000000018W=l;0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04Qd_`3o
ool00P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo0>00oooo00<0<`3o0?ooo`3o
ool0J`3oool00`000000oooo0?ooo`0I0?ooo`006`3oool00`3OW4P0000000000008000000030000
B02Lgol0oooo00/0oooo00<0_g@00000M02oool0103oool01`3OW4P0M;oo0?ooo`3oool0okmd0000
001d_ol0203oool300000>40oooo0P0c0?mY0?ooo`<000006`3oool001d0oooo00<0okmd00000000
0000100000000`0007@0_ooo0?ooo`0=0?ooo`030;md000007@0_ooo00@0oooo00L0oono07@0M02o
ool0oooo0?noM0000000M;oo00P0oooo00<000000?ooo`3oool0h`3oool203<0ofT0oooo00<00000
0?ooo`3oool06@3oool003@0oooo00<0_g@00000M02oool01@3oool01P3o_g@007Bo0?ooo`3o_g@0
000007Boo`P0oooo00<000000?ooo`3oool0i@3oool00`0c0?l0oooo0?ooo`1V0?ooo`030000003o
ool0oooo01T0oooo000d0?ooo`030;md000007@0_ooo00H0oooo00D0_g@007Boo`3o_g@0000007Bo
o`080?ooo`030000003oool0oooo0>H0oooo0P0c0?mV0?ooo`030000003oool0oooo01T0oooo000d
0?ooo`030;md000007@0_ooo00H0oooo00D0oono07@0M02o_g@0000007Boo`080?ooo`030000003o
ool0oooo0>P0oooo00<0<`3o0?ooo`3oool0H`3oool00`000000oooo0?ooo`0I0?ooo`00=03oool0
0`2oM000001d0;ooo`070?ooo`040?noM0000000000007Boo`P0oooo00<000000?ooo`3oool0j@3o
ool203<0of<0oooo00<000000?ooo`3oool06@3oool00380oooo00D0gia8000000000000001d0;oo
o`070?ooo`040?oog`2LB000000007Boo`P0oooo00<000000?ooo`3oool0j`3oool203<0of40oooo
00<000000?ooo`3oool06@3oool003<0oooo00@0oono07@0000007@0_ooo203oool00`3ogi`0B000
07Boo`080?ooo`030000003oool0oooo0>d0oooo0P0c0?mO0?ooo`030000003oool0oooo01T0oooo
001:0?ooo`<00000k`3oool00`0c0?l0oooo0?ooo`1K0?ooo`8000006`3oool004X0oooo00<00000
0?ooo`3oool0l03oool203<0oe`0oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?oo
o`3oool0lP3oool203<0oeX0oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?ooo`3o
ool0m03oool203<0oeP0oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?ooo`3oool0
mP3oool00`0c0?l0oooo0?ooo`1E0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003o
ool0oooo0?L0oooo0P0c0?mE0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003oool0
oooo0?T0oooo0P0c0?mC0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003oool0oooo
0?/0oooo00<0<`3o0?ooo`3oool0D03oool00`000000oooo0?ooo`0I0?ooo`00BP3oool300000?`0
oooo0P0c0?m?0?ooo`8000006`3oool004X0oooo00<000000?ooo`3oool0oP3oool00`0c0?l0oooo
0?ooo`1=0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003oool0oooo0?l0oooo0P0c
0?m=0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003oool0oooo0?l0oooo0P3oool2
03<0od/0oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?ooo`3oool0o`3oool40?oo
o`0303<0o`3oool0oooo04P0oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?ooo`3o
ool0o`3oool50?ooo`80<`3oB03oool00`000000oooo0?ooo`0I0?ooo`00BP3oool00`000000oooo
0?ooo`3o0?ooo`L0oooo00<0<`3o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0I0?ooo`00BP3o
ool00`000000oooo0?ooo`3o0?ooo`P0oooo0P0c0?m50?ooo`030000003oool0oooo01T0oooo001:
0?ooo`<00000o`3oool:0?ooo`0303<0o`3oool0oooo0440oooo0P00000K0?ooo`00BP3oool00`00
0000oooo0?ooo`3o0?ooo`/0oooo0P0c0?m20?ooo`030000003oool0oooo01T0oooo000b0?ooo`03
0?noM000000000000080000000<007Bo0?ooo`3oool00P3oool01P3ooml0W4P0000000000000001d
0;ooo`P0oooo00<000000?ooo`3oool0o`3oool=0?ooo`80<`3o@03oool00`000000oooo0?ooo`0I
0?ooo`00=03oool00`2oM000001d0;ooo`040?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000
B02Lgol70?ooo`030000003oool0oooo0?l0oooo3`3oool00`0c0?l0oooo0?ooo`0m0?ooo`030000
003oool0oooo01T0oooo000d0?ooo`030;md000007@0_ooo00@0oooo00<0_g@00000M02oool00`3o
ool00`2oM00007Bo0?ooo`060?ooo`030000003oool0oooo0?l0oooo403oool203<0ocd0oooo00<0
00000?ooo`3oool06@3oool003@0oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`04
0?ooo`030=nLB00007@0_ooo00H0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`0303<0o`3oool0
oooo03X0oooo00<000000?ooo`3oool06@3oool003@0oooo00<0_g@00000M02oool00`3oool00`3o
gi`0B00004RLg`040?ooo`030;md000004P0W=oo00H0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`80<`3o>P3oool00`000000oooo0?ooo`0I0?ooo`00=03oool00`2oM000001d0;ooo`030?ooo`03
0?oOW0180000B9cO00<0oooo00@0oono07@0000007@0_ooo1P3oool00`000000oooo0?ooo`3o0?oo
oaD0oooo0P0c0?lh0?ooo`030000003oool0oooo01T0oooo000d0?ooo`030;md000007@0_ooo00<0
oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l01`3oool300000?l0oooo5`3o
ool00`0c0?l0oooo0?ooo`0c0?ooo`<000006`3oool003@0oooo00<0_g@00000M02oool00`3oool0
1@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?oooaP0oooo0P0c0?le0?ooo`030000003oool0oooo01T0oooo000d0?ooo`030;md000007@0
_ooo00@0oooo00<0okmd00000018W=l0303oool00`000000oooo0?ooo`3o0?oooaX0oooo00<0<`3o
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0I0?ooo`00=03oool00`2oM000001d0;ooo`040?oo
o`040?oog`2LB000001809cOo`/0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`80<`3o<P3oool0
0`000000oooo0?ooo`0I0?ooo`00=03oool00`2oM000001d0;ooo`050?ooo`040?oo_`1d0000001d
0;ooo`X0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`80<`3o<03oool00`000000oooo0?ooo`0I
0?ooo`00<P3oool01@3OW4P000000000000007@0_ooo00H0oooo00@0oooO09a80000000007Bo2@3o
ool00`000000oooo0?ooo`3o0?oooal0oooo00<0<`3o0?ooo`3oool0;@3oool00`000000oooo0?oo
o`0I0?ooo`00<`3oool0103ookl0M0000000M02oool80?ooo`050?oOW018000000000018W03Oool0
1P3oool00`000000oooo0?ooo`3o0?ooob00oooo0P0c0?l]0?ooo`030000003oool0oooo01T0oooo
001:0?ooo`030000003oool0oooo0?l0oooo8P3oool203<0ob/0oooo00<000000?ooo`3oool06@3o
ool004X0oooo0`00003o0?ooob@0oooo00<0<`3o0?ooo`3oool09`3oool2000001/0oooo001:0?oo
o`030000003oool0oooo0?l0oooo9@3oool203<0obP0oooo00<000000?ooo`3oool06@3oool004X0
oooo00<000000?ooo`3oool0o`3ooolW0?ooo`0303<0o`3oool0oooo02D0oooo00<000000?ooo`3o
ool06@3oool004X0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`80<`3o9@3oool00`000000oooo
0?ooo`0I0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooobX0oooo0P0c0?lS0?ooo`030000003o
ool0oooo01T0oooo001:0?ooo`030000003oool0oooo0?l0oooo;03oool00`0c0?l0oooo0?ooo`0P
0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003oool0oooo0?l0oooo;@3oool203<0
ob00oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?ooo`3oool0o`3oool_0?ooo`03
03<0o`3oool0oooo01d0oooo00<000000?ooo`3oool06@3oool004X0oooo0`00003o0?oooc00oooo
0P0c0?lL0?ooo`8000006`3oool004X0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`0303<0o`3o
ool0oooo01X0oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?ooo`3oool0o`3ooolc
0?ooo`80<`3o6P3oool00`000000oooo0?ooo`0I0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oo
ocD0oooo0P0c0?lH0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000003oool0oooo0?l0
oooo=`3oool00`0c0?l0oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo001:0?ooo`030000
003oool0oooo0?l0oooo>03oool203<0oaD0oooo00<000000?ooo`3oool06@3oool004X0oooo00<0
00000?ooo`3oool0o`3ooolj0?ooo`0303<0o`3oool0oooo0180oooo00<000000?ooo`3oool06@3o
ool004X0oooo0`00003o0?oooc/0oooo0P0c0?lA0?ooo`8000006`3oool004X0oooo00<000000?oo
o`3oool0o`3ooolm0?ooo`80<`3o403oool00`000000oooo0?ooo`0I0?ooo`00<P3oool00`3o_g@0
00000000000200000003001d_`3oool0oooo0080oooo00H0omnL04P00000000000000000B02Lgol8
0?ooo`030000003oool0oooo0?l0oooo?`3oool00`0c0?l0oooo0?ooo`0=0?ooo`030000003oool0
oooo01T0oooo000d0?ooo`030;md000007@0_ooo00@0oooo00P0omnL04P00000B9`0gooo0?ooo`3o
gi`0B00007Boo`L0oooo00<000000?ooo`3oool0o`3ooom00?ooo`80<`3o3@3oool00`000000oooo
0?ooo`0I0?ooo`00=03oool00`2oM000001d0;ooo`040?ooo`030;md000007@0_ooo00<0oooo00<0
gia80018W03Oool01P3oool00`000000oooo0?ooo`3o0?oood80oooo00<0<`3o0?ooo`3oool02P3o
ool00`000000oooo0?ooo`0I0?ooo`00=03oool00`2oM000001d0;ooo`040?ooo`030;md000007@0
_ooo00<0oooo00<0_g@00018W03Oool01P3oool00`000000oooo0?ooo`3o0?oood<0oooo0P0c0?l:
0?ooo`030000003oool0oooo01T0oooo000d0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000
B02Lgol00P3oool00`3OW4P00000001d_`070?ooo`030000003oool0oooo0?l0ooooA@3oool203<0
o`P0oooo00<000000?ooo`3oool06@3oool003@0oooo00<0_g@00000M02oool01@3oool01`3OW4P0
07Bo0?ooo`2oM00000000000M02oool01`3oool00`000000oooo0?ooo`3o0?ooodL0oooo00<0<`3o
0?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`00=03oool00`2oM000001d0;ooo`060?oo
o`050?noM000000000000018W03Oool0203oool300000?l0ooooC@3oool3000001/0oooo000d0?oo
o`030;md000007@0_ooo00D0oooo00D0omnL04P000000000000004RLg`090?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`00=03oool00`2o
M000001d0;ooo`040?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`080?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01T0oooo000d0?ooo`030;md000007@0_ooo00@0oooo00<0gia80000B02Lgol00P3oool0
0`3ooml0W4P007Boo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo000d0?ooo`030;md000007@0_ooo
00@0oooo00<0gia80018W03Oool00P3oool00`3ooml0W4P004RLg`070?ooool00000D`00000K0?oo
o`00<P3oool01@3OW4P000000000000007@0_ooo00@0oooo00<0omnL04P00018W=l00P3oool00`3o
_g@0001809cOo`3o0?ooogD0oooo000c0?ooo`040?oo_`1d0000001d0;ooo`D0oooo00H0oono07@0
0000000000000000B02Lgooo0?ooogH0oooo003o0?oookP0oooo003o0?oookP0oooo003o0?oookP0
oooo003o0?oookP0oooo003o0?oookP0oooo003o0?oookP0oooo0000\
\>"],
  ImageRangeCache->{{{0, 438.375}, {270.563, 0}} -> {2.09268, 1.55818, \
0.0391355, 0.0636588}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig6f = 
        Show[pr, pr4, DisplayFunction \[Rule] $DisplayFunction, 
          FrameLabel \[Rule] {"\<Log(R)\>", "\<Log(f(R))\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig6_f\>" <> "\<.m\>", fig6f];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.380837 0.0758343 -0.23094 0.0466206 [
[.07417 -0.0125 -7.03125 -24.5625 ]
[.07417 -0.0125 7.03125 0 ]
[.22584 -0.0125 -7.03125 -24.5625 ]
[.22584 -0.0125 7.03125 0 ]
[.37751 -0.0125 -12.0625 -24.5625 ]
[.37751 -0.0125 12.0625 0 ]
[.52917 -0.0125 -12.0625 -24.5625 ]
[.52917 -0.0125 12.0625 0 ]
[.68084 -0.0125 -12.0625 -24.5625 ]
[.68084 -0.0125 12.0625 0 ]
[.83251 -0.0125 -12.0625 -24.5625 ]
[.83251 -0.0125 12.0625 0 ]
[.98418 -0.0125 -12.0625 -24.5625 ]
[.98418 -0.0125 12.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -31.4063 -49.125 ]
[.5 -0.0125 31.4063 -24.5625 ]
[-0.0125 .04878 -14.0625 -12.2813 ]
[-0.0125 .04878 0 12.2813 ]
[-0.0125 .14202 -14.0625 -12.2813 ]
[-0.0125 .14202 0 12.2813 ]
[-0.0125 .23527 -24.125 -12.2813 ]
[-0.0125 .23527 0 12.2813 ]
[-0.0125 .32851 -24.125 -12.2813 ]
[-0.0125 .32851 0 12.2813 ]
[-0.0125 .42175 -24.125 -12.2813 ]
[-0.0125 .42175 0 12.2813 ]
[-0.0125 .51499 -24.125 -12.2813 ]
[-0.0125 .51499 0 12.2813 ]
[-0.0125 .60823 -24.125 -12.2813 ]
[-0.0125 .60823 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -48.6875 -42.2813 ]
[-0.01875 .30902 -24.125 42.2813 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07417 0 m
.07417 .00625 L
s
gsave
.07417 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.22584 0 m
.22584 .00625 L
s
gsave
.22584 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.37751 0 m
.37751 .00625 L
s
gsave
.37751 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.52917 0 m
.52917 .00625 L
s
gsave
.52917 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.68084 0 m
.68084 .00625 L
s
gsave
.68084 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.83251 0 m
.83251 .00625 L
s
gsave
.83251 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.98418 0 m
.98418 .00625 L
s
gsave
.98418 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
1.000 setlinewidth
grestore
.125 Mabswid
.11209 0 m
.11209 .00375 L
s
.15 0 m
.15 .00375 L
s
.18792 0 m
.18792 .00375 L
s
.26375 0 m
.26375 .00375 L
s
.30167 0 m
.30167 .00375 L
s
.33959 0 m
.33959 .00375 L
s
.41542 0 m
.41542 .00375 L
s
.45334 0 m
.45334 .00375 L
s
.49126 0 m
.49126 .00375 L
s
.56709 0 m
.56709 .00375 L
s
.60501 0 m
.60501 .00375 L
s
.64293 0 m
.64293 .00375 L
s
.71876 0 m
.71876 .00375 L
s
.75668 0 m
.75668 .00375 L
s
.79459 0 m
.79459 .00375 L
s
.87043 0 m
.87043 .00375 L
s
.90835 0 m
.90835 .00375 L
s
.94626 0 m
.94626 .00375 L
s
.03625 0 m
.03625 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -92.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.375 23.000 moveto
(H) show
101.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.375 23.000 moveto
(L) show
121.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04878 m
.00625 .04878 L
s
gsave
-0.0125 .04878 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .14202 m
.00625 .14202 L
s
gsave
-0.0125 .14202 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
0 .23527 m
.00625 .23527 L
s
gsave
-0.0125 .23527 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .32851 m
.00625 .32851 L
s
gsave
-0.0125 .32851 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
0 .42175 m
.00625 .42175 L
s
gsave
-0.0125 .42175 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
0 .51499 m
.00625 .51499 L
s
gsave
-0.0125 .51499 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
0 .60823 m
.00625 .60823 L
s
gsave
-0.0125 .60823 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07209 m
.00375 .07209 L
s
0 .0954 m
.00375 .0954 L
s
0 .11871 m
.00375 .11871 L
s
0 .16534 m
.00375 .16534 L
s
0 .18865 m
.00375 .18865 L
s
0 .21196 m
.00375 .21196 L
s
0 .25858 m
.00375 .25858 L
s
0 .28189 m
.00375 .28189 L
s
0 .3052 m
.00375 .3052 L
s
0 .35182 m
.00375 .35182 L
s
0 .37513 m
.00375 .37513 L
s
0 .39844 m
.00375 .39844 L
s
0 .44506 m
.00375 .44506 L
s
0 .46837 m
.00375 .46837 L
s
0 .49168 m
.00375 .49168 L
s
0 .5383 m
.00375 .5383 L
s
0 .56161 m
.00375 .56161 L
s
0 .58492 m
.00375 .58492 L
s
0 .02547 m
.00375 .02547 L
s
0 .00216 m
.00375 .00216 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -139.688 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
103.281 16.2813 translate
90 rotate
-103.281 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.375 23.000 moveto
(H) show
101.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
110.688 23.000 moveto
(H) show
117.125 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
130.688 23.000 moveto
(L) show
137.125 23.000 moveto
(L) show
143.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07417 .61178 m
.07417 .61803 L
s
.22584 .61178 m
.22584 .61803 L
s
.37751 .61178 m
.37751 .61803 L
s
.52917 .61178 m
.52917 .61803 L
s
.68084 .61178 m
.68084 .61803 L
s
.83251 .61178 m
.83251 .61803 L
s
.98418 .61178 m
.98418 .61803 L
s
.125 Mabswid
.11209 .61428 m
.11209 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.18792 .61428 m
.18792 .61803 L
s
.26375 .61428 m
.26375 .61803 L
s
.30167 .61428 m
.30167 .61803 L
s
.33959 .61428 m
.33959 .61803 L
s
.41542 .61428 m
.41542 .61803 L
s
.45334 .61428 m
.45334 .61803 L
s
.49126 .61428 m
.49126 .61803 L
s
.56709 .61428 m
.56709 .61803 L
s
.60501 .61428 m
.60501 .61803 L
s
.64293 .61428 m
.64293 .61803 L
s
.71876 .61428 m
.71876 .61803 L
s
.75668 .61428 m
.75668 .61803 L
s
.79459 .61428 m
.79459 .61803 L
s
.87043 .61428 m
.87043 .61803 L
s
.90835 .61428 m
.90835 .61803 L
s
.94626 .61428 m
.94626 .61803 L
s
.03625 .61428 m
.03625 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04878 m
1 .04878 L
s
.99375 .14202 m
1 .14202 L
s
.99375 .23527 m
1 .23527 L
s
.99375 .32851 m
1 .32851 L
s
.99375 .42175 m
1 .42175 L
s
.99375 .51499 m
1 .51499 L
s
.99375 .60823 m
1 .60823 L
s
.125 Mabswid
.99625 .07209 m
1 .07209 L
s
.99625 .0954 m
1 .0954 L
s
.99625 .11871 m
1 .11871 L
s
.99625 .16534 m
1 .16534 L
s
.99625 .18865 m
1 .18865 L
s
.99625 .21196 m
1 .21196 L
s
.99625 .25858 m
1 .25858 L
s
.99625 .28189 m
1 .28189 L
s
.99625 .3052 m
1 .3052 L
s
.99625 .35182 m
1 .35182 L
s
.99625 .37513 m
1 .37513 L
s
.99625 .39844 m
1 .39844 L
s
.99625 .44506 m
1 .44506 L
s
.99625 .46837 m
1 .46837 L
s
.99625 .49168 m
1 .49168 L
s
.99625 .5383 m
1 .5383 L
s
.99625 .56161 m
1 .56161 L
s
.99625 .58492 m
1 .58492 L
s
.99625 .02547 m
1 .02547 L
s
.99625 .00216 m
1 .00216 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.2 1 0 r
.008 w
.97619 .60332 m
.95773 .59197 L
.9376 .5796 L
.9187 .56797 L
.90051 .5568 L
.88116 .5449 L
.86253 .53345 L
.84273 .52127 L
.82365 .50954 L
.8053 .49826 L
.78578 .48626 L
.76698 .4747 L
.7489 .46359 L
.72965 .45176 L
.71113 .44037 L
.69144 .42826 L
.67247 .4166 L
.65422 .40538 L
.6348 .39344 L
.61611 .38195 L
.59624 .36974 L
.5771 .35797 L
.55868 .34665 L
.53909 .3346 L
.52119 .32359 L
s
1 0 0 r
.5 Mabswid
.97619 .60332 m
.93743 .57949 L
.89515 .5535 L
.85545 .52909 L
.81727 .50562 L
.77663 .48063 L
.73751 .45658 L
.69593 .43102 L
.65587 .40639 L
.61733 .3827 L
.57633 .35749 L
.53685 .33322 L
.49889 .30989 L
.45847 .28504 L
.41958 .26112 L
.37823 .23569 L
.33841 .2112 L
.30013 .18764 L
.25941 .16256 L
.22024 .1384 L
.17869 .11271 L
.13877 .08792 L
.10054 .06398 L
.0602 .03838 L
.02381 .01472 L
s
.2 0 1 r
.97619 .60332 m
.93743 .57949 L
.89515 .5535 L
.85545 .52909 L
.81727 .50562 L
.77663 .48063 L
.73751 .45658 L
.69593 .43102 L
.65587 .40639 L
.61733 .3827 L
.57633 .35749 L
.53685 .33322 L
.49889 .30989 L
.45847 .28504 L
.41958 .26113 L
.37823 .2357 L
.33841 .21121 L
.30013 .18766 L
.25941 .1626 L
.22024 .13848 L
.17869 .11286 L
.13877 .08819 L
.10054 .06448 L
.0602 .03931 L
.02381 .01639 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{710.188, 438.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;60001]R000`400?l00000o`00003oo`3ooooo
0?ooolP0oooo003o0?ooool0oooob03oool00?l0ooooN03oool00`3o_g@000000000000200000003
0000M02oool0oooo00L0oooo00<0gia804RLg`3oool03@3oool00`3OW4P0B9cO0?ooo`3o0?ooobh0
oooo003o0?ooogL0oooo00<0gia80000001d_ol00`3oool00`3ookl0M4RL0=ooo`060?ooo`030?no
M018W=l0oooo00l0oooo00<0gia807Boo`3oool0o`3oool]0?ooo`00o`3ooomg0?ooo`030?noM000
B9`0gooo00@0oooo00<0omnL09boo`3oool0103oool00`3o_g@004RL0=ooo`0@0?ooo`030?oog`2L
B000M;oo0?l0oooo;@3oool00?l0ooooN03oool00`3OW7@0W=oo0?ooo`030?ooo`030?oOW01dW=l0
oooo00<0oooo00<0oooO09a8001d_ol04P3oool00`3o_g@0001d0;ooo`3o0?ooob`0oooo003o0?oo
of40oooo00<0oooO09a8000000001`0000001P1d_ol0oooo0?ooo`3oool0omnL04P00080000000<0
001d0;ooo`3oool00P3oool00`3OW4P00000000000040000000304RLg`3oool0oooo0080oooo00H0
okmd0000M02oool0oooo0?oog`2LB0040000000504RLg`3oool0oooo0?ooo`2oM0000P0000001`00
04P0W=oo0?ooo`3oool0oono07@0001d_ol0o`3oool/0?ooo`00o`3ooomS0?ooo`030?oOW0180000
07Bo00@0oooo00l0_g@0001d_`3oool0oooo0?noM000000004RL0=ooo`3oool0okmd0000B02Lgol0
oooo0?oog`2LB0001@0000000`00B9`0gooo0?ooo`030?ooo`030;md0000B9`0gooo00<0oooo00@0
oono07@00000B9`0gooo0`3oool0103o_g@000000000B02Lgol40?ooo`030?oog`2LB00007Bo0?l0
oooo;03oool00?l0ooooH`3oool00`3ogi`0B00004RLg`040?ooo`070?oog`2LM9`0gooo0?oog`2L
B000001809cOo`030?ooo`060;md0000B9`0gooo0?ooo`3OW4P0B9cO2@3oool00`3ooml0W4P0001d
_`040?ooo`030?oo_`1d000007Bo00<0oooo00@0oono07@0000007@0_ooo1P3oool00`2oM000001d
0;ooo`3o0?ooob/0oooo003o0?ooof<0oooo00<0omnL04P00018W=l01@3oool01@3o_i`0W=oo0?oO
W018000007Bo00@0oooo00<0gia80000B02Lgol00P3oool01@2oM0000000000000000000M;oo00D0
oooo00<0oono07@00018W=l0103oool00`3ookl0M000001d_`020?ooo`040?oog`2LB000000007Bo
o`L0oooo00<0gia80000M02oool0o`3oool[0?ooo`00o`3ooomS0?ooo`030?oOW0180000B9cO00L0
oooo00<0okmd00000018W=l0103oool02`3OW4P0000007Boo`3oool0okmd0000001d_ol0oooo0=nL
B0000000M;oo00@0oooo00<0omnL04P00018W=l0103oool00`3ookl0M000001d_`020?ooo`030=nL
B0000000B9cO00P0oooo00<0gia80000B02Lgol0o`3oool[0?ooo`00o`3ooomS0?ooo`030?oOW018
0000B9cO00L0oooo00<0omnL04P00018W=l0103oool02`2oM000001809cOo`3ooml0W4P00018W03O
ool0oooo0?oOW0180000B9cO00@0oooo00<0omnL04P00018W=l0103oool0203ookl0M000001d_`3o
ool0okmd00000000B9`0gooo203oool00`3OW4P0001809cOo`3o0?ooob/0oooo003o0?ooof<0oooo
00<0omnL04P00018W=l01`3oool00`3ooml0W4P0001d_`030?ooo`070?oo_`1d0000001d0;ooo`3o
okl0M000001d_`020?ooo`030?oOW0180000M;oo00@0oooo00<0oono07@00018W=l0103oool00`3o
okl0M000000000030000000304RLg`3oool0oooo00L0oooo00<0gia80000B02Lgol0o`3oool[0?oo
o`00o`3ooomS0?ooo`030?oOW0180000B9cO00P0oooo00P0omnL04P0001d_ol0oooo0?oog`2LB000
000007Boo`80oooo00D0gia80000B02Lgol0oooo0;md0002000000070018W03Oool0oooo0?ooo`3o
okl0M000001d_`040?ooo`030?oo_`1d000007Bo0080oooo00@0oono07@000000000B9cO1`3oool0
0`2oM000001d0;ooo`3o0?ooob/0oooo003o0?ooof<0oooo00<0omnL04P00018W=l02@3oool01P3o
okl0M000000000000000001809cOo`@0oooo00D0gia800000000000004RL0=ooo`060?ooo`030;md
0000B9`0gooo00<0oooo00<0oono07@00000M;l00`3oool0103ookl0M0000000001d_ol50?ooo`03
0?oog`2LB00007Bo0?l0oooo;03oool00?l0ooooH`3oool00`3ogi`0B00004RLg`0N0?ooo`030?no
M00007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000000004RLg`050?ooo`030?oo
_`1d0000M;oo0?l0oooo;03oool00?l0ooooH`3oool00`3ogi`0B00004RLg`0N0?ooo`030?oog`2L
B000M;oo00<0oooo00<0oono07@00000M;l00`3oool0103ooml0W4P00000001d_ol50?ooo`030?no
M00007@0_ooo0?l0oooo;03oool00?l0ooooH`3oool00`3ogi`0B00004RLg`0O0?ooo`030?noM000
B9`0gooo0080oooo00<0oono07@00000M;l00`3oool0102oM00000000018W03Oool40?ooo`030?oo
g`2LB000M;oo0?l0oooo;@3oool00?l0ooooH@3oool00`3ooml0W4P0000000030000000307Boo`3o
ool0oooo01`0oooo00@0okmd0018W03Ooml0W4P01`0000000`00M;l0oooo0?ooo`030?ooo`030?oo
g`2LB000B9cO0?l0oooo;P3oool00?l0ooooQ`3oool00`3ogi`0M9cO0?ooo`0=0?ooo`030=nLM02L
gol0oooo0?l0oooo;P3oool00?l0ooooo`3oooo80?ooo`00o`3ooooo0?ooolP0oooo003o0?ooool0
oooob03oool00?l0ooooo`3oooo80?ooo`00o`3ooooo0?ooolP0oooo003o0?ooool0oooob03oool0
0?l0ooooo`3oooo80?ooo`00o`3ooooo0?ooolP0oooo003o0?ooool0oooob03oool00?l0ooooo`3o
ooo80?ooo`00o`3ooooo0?ooolP0oooo001j0?ooo`060?oog`2LB00000000000000007@0_oooEP3o
ool01P3ogi`0B000000000000000001809cOoe40oooo00<0okmd0000000000000P0000000`00M;l0
oooo0?ooo`030?ooo`040;md00000000000004RLgdd0oooo00<0okmd0000000000000P0000001000
M;l0oooo0?ooo`3OW4P70000000307Boo`3oool0oooo04T0oooo00<0okmd0000000000000P000000
0`00M;l0oooo0?ooo`050?ooo`030?noM0000000M;oo04`0oooo00<0okmd0000000000000P000000
0`00M;l0oooo0?ooo`020?ooo`060?oog`2LB00000000000000007@0_oooC03oool00`3o_g@00000
0000000200000003001d_`3oool0oooo0080oooo00H0omnL04P00000000000000000B02LgolI0?oo
o`00N@3oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=ooE03oool0203ogi`0B0000018
W03Oool0oooo0?oOW0180000M;ooDP3oool00`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo
0?ooo`3ooml0W4P0001d_`1>0?ooo`030;md000007@0_ooo00@0oooo00<0gia80000000000001000
00000`00M;l0oooo0?ooo`1;0?ooo`030;md000007@0_ooo00P0oooo00<0okmd0000001d_ol0CP3o
ool00`2oM000001d0;ooo`040?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgom=0?oo
o`030;md000007@0_ooo00@0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007BooaP0oooo
001i0?ooo`030;md000007@0_ooo00<0oooo00<0_g@0001d_`3oool0D`3oool00`2oM000001d0;oo
o`030?ooo`030=nLB000B9`0gooo0540oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo04d0oooo00<0_g@00000M02oool01@3oool00`3OW4P0B9cO0?oo
o`020?ooo`030?oog`2LB7@0_ooo04`0oooo00<0_g@00000M02oool0203oool00`3o_g@0000007Bo
o`1>0?ooo`030;md000007@0_ooo00@0oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo0?oo
o`1<0?ooo`030;md000007@0_ooo00@0oooo00<0_g@00000M02oool00`3oool00`3OW4P004RL0=oo
o`0G0?ooo`00N03oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0_ooo05<0oooo00<0_g@0
0000M02oool00`3oool00`2oM00004RL0=ooo`1A0?ooo`030;md000007@0_ooo00<0oooo00@0oooO
09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`1=0?ooo`030;md000007@0_ooo00H0oooo00<0
gia804RLg`3oool0D03oool00`2oM000001d0;ooo`030?ooo`030=nLB0000000000000D0000000<0
001809cOo`3oool0B`3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0
gia80000M02oool0C03oool00`2oM000001d0;ooo`040?ooo`030;md000007@0_ooo00<0oooo00<0
_g@00018W03Oool05`3oool007P0oooo00<0omnL04P00018W=l0103oool00`2oM000001809cOo`1C
0?ooo`030?noM00004P0W=oo0080oooo00<0gia800000000M;l0DP3oool00`2oM000001d0;ooo`03
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0C03oool00`2oM000001d0;ooo`07
0?ooo`030=nLB01d_ol0oooo04l0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B7Bo0?ooo`02
0?ooo`030?noM0000000M;oo04h0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`04
0?ooo`030;md000004P0W=oo04`0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`02
0?ooo`030=nLB000000007Bo01P0oooo001h0?ooo`030?oOW0180000B9cO00<0oooo00@0oono07@0
000007@0_oooE03oool01`3OW4P007Bo0?ooo`2oM00000000000M02oool0DP3oool00`2oM000001d
0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0C03oool00`2oM000001d
0;ooo`070?ooo`030?oog`2LB4P0W=oo04l0oooo00<0_g@00000M02oool0103oool01`3OW4P0M;oo
0?ooo`3oool0okmd0000001d_ol0CP3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO
00<0oooo00@0oono07@0000007@0_oooC03oool00`2oM000001d0;ooo`050?ooo`070=nLB000M;l0
oooo0;md00000000001d0;ooo`0H0?ooo`00N03oool02@3ookl0M00000000000B9`0gooo0?ooo`2o
M000000004RLg`1F0?ooo`050?noM000000000000018W03Oool0D`3oool00`2oM000001d0;ooo`03
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0C03oool00`2oM000001d0;ooo`08
0?ooo`030?oOW01807@0_ooo04h0oooo00<0_g@00000M02oool0103oool01`3ookl0M01d0;ooo`3o
ool0okmd0000001d_ol0CP3oool00`2oM000001d0;ooo`030?ooo`090?oo_`1d000000000018W03O
ool0oooo0;md00000000B9cO04d0oooo00<0_g@00000M02oool01P3oool01@3o_g@0000000000000
B9`0gooo01T0oooo001h0?ooo`050?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?oo
o`1D0?ooo`050?oOW0180000000000000018W=l0E03oool00`2oM000001d0;ooo`030?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol0C03oool00`2oM000001d0;ooo`090?ooo`030;md
0018W=l0oooo04d0oooo00<0_g@00000M02oool01@3oool01P3o_g@007Bo0?ooo`3o_g@0000007Bo
odh0oooo00<0_g@00000M02oool00`3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO
0?ooo`3oool0C03oool00`2oM000001d0;ooo`050?ooo`050?oOW0180000000000000018W=l06P3o
ool007T0oooo00<0okmd00000018W=l0F@3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l0
D`3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
C03oool00`2oM000001d0;ooo`090?ooo`030=nLB00007@0_ooo04d0oooo00<0_g@00000M02oool0
1P3oool01@2oM000M;oo0?noM0000000M;oo04h0oooo00<0_g@00000M02oool0103oool00`3o_g@0
000004RLg`1B0?ooo`030;md000007@0_ooo00@0oooo00L0omnL04P0000004P0W=oo0?ooo`3OW4P0
07Bo01T0oooo001i0?ooo`040?oog`2LB000001809cOoeP0oooo00<0gia80000B02Lgol00P3oool0
0`3ooml0W4P007Boo`1B0?ooo`030;md000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3oool0
0`3ooml0W4P0001d_`1=0?ooo`030;md000007@0_ooo00T0oooo00<0okmd0000001d_ol0C@3oool0
0`2oM000001d0;ooo`060?ooo`050?oo_`1d07@0_kmd0000001d_ol0CP3oool00`2oM000001d0;oo
o`040?ooo`040?oog`2LB000001809cOoe40oooo00<0_g@00000M02oool0103oool00`3OW4P00018
09cOo`020?ooo`030?oog`2LB000M;oo01P0oooo001j0?ooo`040?oo_`1d0000001d0;oooeL0oooo
00<0gia80018W03Oool00P3oool00`3ooml0W4P004RLg`1B0?ooo`030;md000007@0_ooo00@0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1=0?ooo`030;md000007@0_ooo00<0oooo
00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`1=0?ooo`030;md000007@0_ooo00L0oooo
00@0okmd000000000000M;ooCP3oool00`2oM000001d0;ooo`050?ooo`040?oo_`1d0000001d0;oo
oe00oooo00<0_g@00000M02oool0103oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO
01P0oooo001k0?ooo`040?oog`2LB0000000001d_eH0oooo00<0omnL04P00018W=l00P3oool00`3o
_g@0001809cOo`1@0?ooo`050=nLB000000000000000M02oool01@3oool01P2oM00004RL0=ooo`3o
ool0_g@0001d_d`0oooo00D0gia8000000000000001d0;ooo`040?ooo`080;md001d_ol0oooo0?oo
o`3OW4P000000018W03Ooom;0?ooo`050=nLB000000000000000M02oool01`3oool0103ooml0W4P0
0000001d_om<0?ooo`050=nLB000000000000000M02oool01P3oool0103ooml0W4P000000000M;m=
0?ooo`050=nLB000000000000000M02oool0103oool00`3ogi`0B00004RLg`020?ooo`030?noM000
04P0W=oo01P0oooo001m0?ooo`050?oOW018000000000018W03Oool0E03oool01P3ookl0M0000000
00000000001809cOoe80oooo00@0oono07@0000007@0_ooo1P3oool0102oM000000000000000M;m>
0?ooo`040?oo_`1d0000001d0;ooo`D0oooo00D0_g@00000000000000000001d_`1>0?ooo`040?oo
_`1d0000001d0;ooo`P0oooo00<0omnL04P0001d_ol0C@3oool0103ookl0M0000000M02oool80?oo
o`050?oOW018000000000018W03Oool0B`3oool0103ookl0M0000000M02oool50?ooo`060?oo_`1d
000000000000000004P0W=oo6@3oool00?l0ooooo`3oooo80?ooo`00o`3ooooo0?ooolP0oooo003o
0?ooool0oooob03oool00?l0ooooo`3oooo80?ooo`00o`3ooooo0?ooolP0oooo003o0?ooool0oooo
b03oool00?l0ooooo`3oooo80?ooo`00o`3ooooo0?ooolP0oooo003o0?ooool0oooob03oool00?l0
ooooo`3oooo80?ooo`00o`3ooooo0?ooolP0oooo003o0?ooool0oooob03oool00500ooooo`00003o
0000064000005`3oool00500oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00500oooo0`00000C0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool3000001L0oooo001@0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool0
0`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool00`00
0000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool00`000000
oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0ooooG@3oool00`000000oooo
0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0?l0ooooo`3o
oom?0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo00/0oooo00<0<`3o
0?l0003o0000o`3ooooo0?ooodl0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?oo
o`3oool0303oool203<0o`030?l0003oool0oooo0?l0ooooo`3ooom<0?ooo`030000003oool0oooo
01D0oooo001@0?ooo`030000003oool0oooo00h0oooo00<0<`3o0?l0003o0000o`3ooooo0?oood`0
oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool03`3oool203<0o`030?l0
003oool0oooo0?l0ooooo`3ooom90?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003o
ool0oooo0140oooo0P0c0?l00`3o0000oooo0?ooo`3o0?ooool0ooooA`3oool00`000000oooo0?oo
o`0E0?ooo`00D03oool00`000000oooo0?ooo`0C0?ooo`0303<0o`3o0000oooo0?l0ooooo`3ooom7
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`<00000503oool203<0ool0ooooo`3ooom50?oo
o`<000005`3oool00500oooo00<000000?ooo`3oool05P3oool00`0c0?l0o`000?ooo`3o0?ooool0
ooooA03oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`0G0?ooo`80<`3o
o`3ooooo0?oood@0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool06@3o
ool00`0c0?l0o`000?ooo`3o0?ooool0oooo@@3oool00`000000oooo0?ooo`0E0?ooo`00D03oool0
0`000000oooo0?ooo`0J0?ooo`80<`3oo`3ooooo0?oood40oooo00<000000?ooo`3oool05@3oool0
0500oooo00<000000?ooo`3oool0703oool203<0ool0ooooo`3ooolo0?ooo`030000003oool0oooo
01D0oooo001@0?ooo`030000003oool0oooo01h0oooo00<0<`3o0?ooo`3oool0o`3ooooo0?oooc`0
oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool07`3oool203<0ool0oooo
o`3oooll0?ooo`030000003oool0oooo01D0oooo000n0?ooo`060?oog`2LB00000000000000007@0
_ooo303oool00`000000oooo0?ooo`0Q0?ooo`0303<0o`3oool0oooo0?l0ooooo`3oooli0?ooo`03
0000003oool0oooo01D0oooo000m0?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgol;
0?ooo`030000003oool0oooo0280oooo0P0c0?oo0?ooool0oooo>@3oool00`000000oooo0?ooo`0E
0?ooo`00?@3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo00X0oooo00<000000?oo
o`3oool0903oool203<0ool0ooooo`3ooolg0?ooo`030000003oool0oooo01D0oooo000l0?ooo`03
0?oo_`1d000007Bo00@0oooo00<0gia80000M02oool02P3oool00`000000oooo0?ooo`0V0?ooo`03
03<0o`3oool0oooo0?l0ooooo`3ooold0?ooo`030000003oool0oooo01D0oooo000l0?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000B02Lgol02P3oool00`000000oooo0?ooo`0W0?ooo`80<`3o
o`3ooooo0?oooc@0oooo00<000000?ooo`3oool05@3oool003`0oooo00<0omnL04P00018W=l00`3o
ool0103ookl0M0000000M02oool:0?ooo`030000003oool0oooo02T0oooo0P0c0?oo0?ooool0oooo
<P3oool00`000000oooo0?ooo`0E0?ooo`00?03oool02@3ookl0M00000000000B9`0gooo0?ooo`2o
M000000004RLg`0;0?ooo`@00000:P3oool00`0c0?l0oooo0?ooo`3o0?ooool0oooo:`3oool50000
01L0oooo000l0?ooo`050?oog`2LB000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`0:0?oo
o`030000003oool0oooo02`0oooo0P0c0?oo0?ooool0oooo;`3oool00`000000oooo0?ooo`0E0?oo
o`00?@3oool00`3o_g@0000004RLg`0@0?ooo`030000003oool0oooo02h0oooo0P0c0?oo0?ooool0
oooo;@3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool0103ooml0W4P00000B02Lgol?0?ooo`03
0000003oool0oooo0300oooo00<0<`3o0?ooo`3oool0o`3ooooo0?ooobX0oooo00<000000?ooo`3o
ool05@3oool003h0oooo00@0oono07@0000007@0_ooo3P3oool00`000000oooo0?ooo`0a0?ooo`80
<`3oo`3ooooo0?ooobX0oooo00<000000?ooo`3oool05@3oool003l0oooo00@0oooO09a800000000
07Bo3@3oool00`000000oooo0?ooo`0c0?ooo`80<`3oo`3ooooo0?ooobP0oooo00<000000?ooo`3o
ool05@3oool00440oooo00D0omnL04P00000000004RL0=ooo`0:0?ooo`030000003oool0oooo03D0
oooo00<0<`3o0?ooo`3oool0o`3ooooo0?ooobD0oooo00<000000?ooo`3oool05@3oool00500oooo
00<000000?ooo`3oool0=P3oool203<0ool0ooooo`3ooolU0?ooo`030000003oool0oooo01D0oooo
001@0?ooo`030000003oool0oooo03P0oooo0P0c0?oo0?ooool0oooo8`3oool00`000000oooo0?oo
o`0E0?ooo`00D03oool00`000000oooo0?ooo`0j0?ooo`0303<0o`3oool0oooo0?l0ooooo`3ooolP
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo03/0oooo0P0c0?oo0?oo
ool0oooo803oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`0m0?ooo`03
03<0o`3oool0oooo0?l0ooooo`3ooolM0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000
003oool0oooo03h0oooo0P0c0?oo0?ooool0oooo7@3oool00`000000oooo0?ooo`0E0?ooo`00D03o
ool00`000000oooo0?ooo`100?ooo`0303<0o`3oool0oooo0?l0ooooo`3ooolJ0?ooo`030000003o
ool0oooo01D0oooo001@0?ooo`<00000@@3oool203<0ool0ooooo`3ooolH0?ooo`<000005`3oool0
0500oooo00<000000?ooo`3oool0@`3oool00`0c0?l0oooo0?ooo`3o0?ooool0oooo5`3oool00`00
0000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`140?ooo`80<`3oo`3ooooo0?oooaL0
oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0AP3oool203<0ool0oooo
o`3ooolE0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo04P0oooo00<0
<`3o0?ooo`3oool0o`3ooooo0?oooa80oooo00<000000?ooo`3oool05@3oool00500oooo00<00000
0?ooo`3oool0B@3oool203<0ool0ooooo`3ooolB0?ooo`030000003oool0oooo01D0oooo001@0?oo
o`030000003oool0oooo04/0oooo00<0<`3o0?ooo`3oool0o`3ooooo0?ooo`l0oooo00<000000?oo
o`3oool05@3oool00500oooo00<000000?ooo`3oool0C03oool203<0ool0ooooo`3oool?0?ooo`03
0000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo04h0oooo00<0<`3o0?ooo`3oool0
o`3ooooo0?ooo``0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0C`3o
ool203<0ool0ooooo`3oool<0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0
oooo0540oooo00<0<`3o0?ooo`3oool0o`3ooooo0?ooo`T0oooo00<000000?ooo`3oool05@3oool0
0500oooo00<000000?ooo`3oool0DP3oool203<0ool0ooooo`3oool90?ooo`030000003oool0oooo
01D0oooo001@0?ooo`030000003oool0oooo05@0oooo00<0<`3o0?ooo`3oool0o`3ooooo0?ooo`H0
oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0E@3oool203<0ool0oooo
o`3oool60?ooo`030000003oool0oooo01D0oooo001@0?ooo`<00000E`3oool203<0ool0ooooo`3o
ool20?ooo`<000005`3oool00500oooo00<000000?ooo`3oool0F@3oool00`0c0?l0oooo0?ooo`3o
0?ooool0oooo0@3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`1J0?oo
o`80<`3oo`3ooooo0?ooo`40oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3o
ool0G03oool00`0c0?l0oooo0?ooo`3o0?ooood0oooo00<000000?ooo`3oool05@3oool00500oooo
00<000000?ooo`3oool0G@3oool203<0ool0ooooo@3oool00`000000oooo0?ooo`0E0?ooo`00D03o
ool00`000000oooo0?ooo`1O0?ooo`80<`3oo`3ooook0?ooo`030000003oool0oooo01D0oooo001@
0?ooo`030000003oool0oooo0640oooo00<0<`3o0?ooo`3oool0o`3ooooh0?ooo`030000003oool0
oooo01D0oooo001@0?ooo`030000003oool0oooo0680oooo0P0c0?oo0?ooooP0oooo00<000000?oo
o`3oool05@3oool00500oooo00<000000?ooo`3oool0I03oool00`0c0?l0oooo0?ooo`3o0?ooooD0
oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0I@3oool203<0ool0oooo
m@3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`1W0?ooo`80<`3oo`3o
oooc0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo06T0oooo00<0<`3o
0?ooo`3oool0o`3oooo`0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo
06X0oooo0P0c0?oo0?oooo00oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3o
ool0K03oool203<0ool0ooookP3oool00`000000oooo0?ooo`0E0?ooo`00D03oool3000006h0oooo
00<0<`3o0?ooo`3oool0o`3ooooY0?ooo`<000005`3oool00500oooo00<000000?ooo`3oool0K`3o
ool203<0ool0ooooj`3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`1a
0?ooo`80<`3oo`3ooooY0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo
07<0oooo00<0<`3o0?ooo`3oool0o`3ooooV0?ooo`030000003oool0oooo01D0oooo001@0?ooo`03
0000003oool0oooo07@0oooo0P0c0?oo0?ooonH0oooo00<000000?ooo`3oool05@3oool00500oooo
00<000000?ooo`3oool0MP3oool203<0ool0ooooi03oool00`000000oooo0?ooo`0E0?ooo`00D03o
ool00`000000oooo0?ooo`1h0?ooo`0303<0o`3oool0oooo0?l0ooooh@3oool00`000000oooo0?oo
o`0E0?ooo`00D03oool00`000000oooo0?ooo`1i0?ooo`80<`3oo`3ooooQ0?ooo`030000003oool0
oooo01D0oooo001@0?ooo`030000003oool0oooo07/0oooo0P0c0?oo0?oooml0oooo00<000000?oo
o`3oool05@3oool003h0oooo00H0omnL04P00000000000000000B02Lgol<0?ooo`030000003oool0
oooo07d0oooo00<0<`3o0?ooo`3oool0o`3ooooL0?ooo`030000003oool0oooo01D0oooo000m0?oo
o`080?oOW018000004RL0=ooo`3oool0omnL04P0001d_ol;0?ooo`030000003oool0oooo07h0oooo
0P0c0?oo0?ooom`0oooo00<000000?ooo`3oool05@3oool003d0oooo00<0_g@00000M02oool00`3o
ool00`3OW4P004RL0=ooo`0:0?ooo`030000003oool0oooo0800oooo0P0c0?oo0?ooomX0oooo00<0
00000?ooo`3oool05@3oool003d0oooo00<0_g@00000M02oool00`3oool00`2oM00004RL0=ooo`0:
0?ooo`030000003oool0oooo0880oooo00<0<`3o0?ooo`3oool0o`3ooooG0?ooo`030000003oool0
oooo01D0oooo000m0?ooo`030?noM00004P0W=oo0080oooo00<0gia800000000M;l02`3oool00`00
0000oooo0?ooo`230?ooo`80<`3oo`3ooooG0?ooo`030000003oool0oooo01D0oooo000n0?ooo`07
0=nLB000M;l0oooo0;md00000000001d0;ooo`0;0?ooo`@00000Q03oool00`0c0?l0oooo0?ooo`3o
0?ooom00oooo1@00000G0?ooo`00?`3oool01@3o_g@0000000000000B9`0gooo00`0oooo00<00000
0?ooo`3oool0QP3oool203<0ool0ooooe03oool00`000000oooo0?ooo`0E0?ooo`00?P3oool01@3o
gi`0B000000000000000B9cO00d0oooo00<000000?ooo`3oool0R03oool203<0ool0oooodP3oool0
0`000000oooo0?ooo`0E0?ooo`00?@3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l0303o
ool00`000000oooo0?ooo`2:0?ooo`0303<0o`3oool0oooo0?l0ooooc`3oool00`000000oooo0?oo
o`0E0?ooo`00?@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo00/0oooo00<00000
0?ooo`3oool0R`3oool203<0ool0ooooc`3oool00`000000oooo0?ooo`0E0?ooo`00?@3oool00`3O
W4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO00/0oooo00<000000?ooo`3oool0S@3oool00`0c
0?l0oooo0?ooo`3o0?oool`0oooo00<000000?ooo`3oool05@3oool003d0oooo00<0omnL04P00018
W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030000003oool0oooo08h0oooo0P0c0?oo0?oool`0
oooo00<000000?ooo`3oool05@3oool003h0oooo00H0oono07@00000000000000000B02Lgol<0?oo
o`030000003oool0oooo0900oooo0P0c0?oo0?ooolX0oooo00<000000?ooo`3oool05@3oool00500
oooo00<000000?ooo`3oool0TP3oool00`0c0?l0oooo0?ooo`3o0?ooolL0oooo00<000000?ooo`3o
ool05@3oool00500oooo00<000000?ooo`3oool0T`3oool203<0ool0ooooa`3oool00`000000oooo
0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`2E0?ooo`0303<0o`3oool0oooo0?l0ooooa03o
ool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`2F0?ooo`80<`3oo`3oooo4
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo09P0oooo0P0c0?oo0?oo
ol80oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0VP3oool00`0c0?l0
oooo0?ooo`3o0?oookl0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0
V`3oool203<0ool0oooo_`3oool00`000000oooo0?ooo`0E0?ooo`00D03oool3000009d0oooo0P0c
0?oo0?oook/0oooo0`00000G0?ooo`00D03oool00`000000oooo0?ooo`2O0?ooo`0303<0o`3oool0
oooo0?l0oooo^P3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`2P0?oo
o`80<`3oo`3ooonj0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0:80
oooo0P0c0?oo0?oookP0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0
Y03oool00`0c0?l0oooo0?ooo`3o0?oookD0oooo00<000000?ooo`3oool05@3oool00500oooo00<0
00000?ooo`3oool0Y@3oool203<0ool0oooo]@3oool00`000000oooo0?ooo`0E0?ooo`00D03oool0
0`000000oooo0?ooo`2W0?ooo`80<`3oo`3ooonc0?ooo`030000003oool0oooo01D0oooo001@0?oo
o`030000003oool0oooo0:T0oooo00<0<`3o0?ooo`3oool0o`3ooon`0?ooo`030000003oool0oooo
01D0oooo001@0?ooo`030000003oool0oooo0:X0oooo0P0c0?oo0?oook00oooo00<000000?ooo`3o
ool05@3oool00500oooo00<000000?ooo`3oool0[03oool203<0ool0oooo[P3oool00`000000oooo
0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`2^0?ooo`0303<0o`3oool0oooo0?l0ooooZ`3o
ool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`2_0?ooo`80<`3oo`3ooon[
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0;40oooo0P0c0?oo0?oo
ojT0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0/`3oool00`0c0?l0
oooo0?ooo`3o0?ooojH0oooo00<000000?ooo`3oool05@3oool00500oooo0`00002d0?ooo`80<`3o
o`3ooonT0?ooo`<000005`3oool00500oooo00<000000?ooo`3oool0]P3oool203<0ool0ooooY03o
ool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`2h0?ooo`0303<0o`3oool0
oooo0?l0ooooX@3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`2i0?oo
o`80<`3oo`3ooonQ0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0;/0
oooo0P0c0?oo0?oooil0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0
_@3oool00`0c0?l0oooo0?ooo`3o0?oooi`0oooo00<000000?ooo`3oool05@3oool00500oooo00<0
00000?ooo`3oool0_P3oool203<0ool0ooooW03oool00`000000oooo0?ooo`0E0?ooo`00D03oool0
0`000000oooo0?ooo`300?ooo`0303<0o`3oool0oooo0?l0ooooV@3oool00`000000oooo0?ooo`0E
0?ooo`00D03oool00`000000oooo0?ooo`310?ooo`80<`3oo`3ooonI0?ooo`030000003oool0oooo
01D0oooo001@0?ooo`030000003oool0oooo0<<0oooo0P0c0?oo0?oooiL0oooo00<000000?ooo`3o
ool05@3oool00500oooo00<000000?ooo`3oool0a@3oool00`0c0?l0oooo0?ooo`3o0?oooi@0oooo
00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0aP3oool203<0ool0ooooU03o
ool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`380?ooo`80<`3oo`3ooonB
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0<X0oooo00<0<`3o0?oo
o`3oool0o`3ooon?0?ooo`030000003oool0oooo01D0oooo001@0?ooo`<00000b`3oool203<0ool0
ooooS@3oool3000001L0oooo001@0?ooo`030000003oool0oooo0<d0oooo00<0<`3o0?ooo`3oool0
o`3ooon<0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0<h0oooo0P0c
0?oo0?oooh`0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0d03oool2
03<0ool0ooooRP3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3B0?oo
o`0303<0o`3oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000
oooo0?ooo`3C0?ooo`80<`3oo`3ooon70?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000
003oool0oooo0=D0oooo00<0<`3o0?ooo`3oool0o`3ooon40?ooo`030000003oool0oooo01D0oooo
001@0?ooo`030000003oool0oooo0=H0oooo0P0c0?oo0?oooh@0oooo00<000000?ooo`3oool05@3o
ool003@0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`030?ooo`040;md00000000
000004RLg`d0oooo00<000000?ooo`3oool0f03oool203<0ool0ooooPP3oool00`000000oooo0?oo
o`0E0?ooo`00=P3oool00`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0
001d_`0<0?ooo`030000003oool0oooo0=X0oooo00<0<`3o0?ooo`3oool0o`3ooomo0?ooo`030000
003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`0;0?ooo`030000003oool0oooo0=/0oooo0P0c0?oo0?ooogl0oooo00<0
00000?ooo`3oool05@3oool003H0oooo00<0_g@00000M02oool00`3oool0103ooml0W4P00018W03O
ool20?ooo`030?oog`2LB00007Bo00/0oooo00<000000?ooo`3oool0g@3oool00`0c0?l0oooo0?oo
o`3o0?ooog`0oooo00<000000?ooo`3oool05@3oool003H0oooo00<0_g@00000M02oool00`3oool0
0`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0gP3oool2
03<0ool0ooooO03oool00`000000oooo0?ooo`0E0?ooo`00=P3oool00`2oM000001d0;ooo`030?oo
o`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3P0?oo
o`80<`3oo`3ooomj0?ooo`030000003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00<0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`@00000h@3oool00`0c0?l0
oooo0?ooo`3o0?ooog<0oooo1@00000G0?ooo`00=P3oool00`2oM000001d0;ooo`030?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol02P3oool00`000000oooo0?ooo`3S0?ooo`80<`3o
o`3ooomg0?ooo`030000003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00<0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0>D0oooo00<0
<`3o0?ooo`3oool0o`3ooomd0?ooo`030000003oool0oooo01D0oooo000f0?ooo`030;md000007@0
_ooo00@0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0;0?ooo`030000003oool0
oooo0>H0oooo0P0c0?oo0?ooog@0oooo00<000000?ooo`3oool05@3oool003H0oooo00<0_g@00000
M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00/0oooo00<000000?oo
o`3oool0j03oool203<0ool0ooooLP3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3o_i`0
W=oo0?ooo`0:0?ooo`030=nLW02oool0oooo00/0oooo00D0gia8000000000000001d0;ooo`050?oo
o`060;md0000B9`0gooo0?ooo`2oM00007Bo303oool00`000000oooo0?ooo`3Z0?ooo`0303<0o`3o
ool0oooo0?l0ooooK`3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3o_g@0M;oo0?ooo`0:
0?ooo`030;mdM02oool0oooo00`0oooo00@0oono07@0000007@0_ooo1P3oool0102oM00000000000
0000M;l=0?ooo`030000003oool0oooo0>/0oooo0P0c0?oo0?ooofl0oooo00<000000?ooo`3oool0
5@3oool001T0oooo00<0okmd0000000000002P0000000`0007@0_ooo0?ooo`0W0?ooo`030000003o
ool0oooo0>d0oooo00<0<`3o0?ooo`3oool0o`3ooom/0?ooo`030000003oool0oooo01D0oooo000I
0?ooo`030?noM0000000000000X0000000<0001d0;ooo`3oool09`3oool00`000000oooo0?ooo`3^
0?ooo`80<`3oo`3ooom/0?ooo`030000003oool0oooo01D0oooo000I0?ooo`030?noM01d_ol0oooo
00X0oooo00<0_gAd0;ooo`3oool09`3oool00`000000oooo0?ooo`3`0?ooo`0303<0o`3oool0oooo
0?l0ooooJ@3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3o_i`0W=oo0?ooo`0:0?ooo`03
0;mdM02oool0oooo02L0oooo00<000000?ooo`3oool0l@3oool203<0ool0ooooJ@3oool00`000000
oooo0?ooo`0E0?ooo`009P3oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003oool0oooo0?<0oooo
00<0<`3o0?ooo`3oool0o`3ooomV0?ooo`030000003oool0oooo01D0oooo000V0?ooo`030;mdM02o
ool0oooo02L0oooo00<000000?ooo`3oool0m03oool203<0ool0ooooIP3oool00`000000oooo0?oo
o`0E0?ooo`009@3oool00`3ookl0M01d0;ooo`0X0?ooo`030000003oool0oooo0?H0oooo0P0c0?oo
0?ooof@0oooo00<000000?ooo`3oool05@3oool002@0oooo00@0okmd0000000007@0_ooo:03oool3
00000?P0oooo00<0<`3o0?ooo`3oool0o`3ooomO0?ooo`<000005`3oool002<0oooo00<0_g@00000
B02Lgol0:P3oool00`000000oooo0?ooo`3i0?ooo`80<`3oo`3ooomQ0?ooo`030000003oool0oooo
01D0oooo001@0?ooo`030000003oool0oooo0?/0oooo00<0<`3o0?ooo`3oool0o`3ooomN0?ooo`03
0000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?`0oooo0P0c0?oo0?oooeh0oooo
00<000000?ooo`3oool05@3oool001l0oooo00<0oooO09a8000000000P0000000`00M;l0oooo0?oo
o`0Y0?ooo`030000003oool0oooo0?h0oooo0P0c0?oo0?oooe`0oooo00<000000?ooo`3oool05@3o
ool001h0oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0X0?ooo`030000003oool0
oooo0?l0oooo0@3oool00`0c0?l0oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool05@3oool0
01d0oooo00<0oono07@0B02Lgol0103oool00`3o_g@00000001d_`0Y0?ooo`030000003oool0oooo
0?l0oooo0P3oool203<0ool0ooooF@3oool00`000000oooo0?ooo`0E0?ooo`007@3oool00`3o_g@0
M;oo0?ooo`050?ooo`030?oog`2LB7@0_ooo02P0oooo00<000000?ooo`3oool0o`3oool40?ooo`80
<`3oo`3ooomG0?ooo`030000003oool0oooo01D0oooo000M0?ooo`030?noM018W=l0oooo00H0oooo
00<0_gAd0;ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo0P0c0?oo0?oooeD0oooo
00<000000?ooo`3oool05@3oool001d0oooo00@0oono07@00000B9`0gooo103oool00`3o_g@007Bo
0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo203oool00`0c0?l0oooo0?ooo`3o0?oooe80oooo
00<000000?ooo`3oool05@3oool001h0oooo00<0okmd000000000000100000000`0007@0_ooo0?oo
o`0X0?ooo`030000003oool0oooo0?l0oooo2@3oool203<0ool0ooooDP3oool00`000000oooo0?oo
o`0E0?ooo`007`3oool00`3ookl0M000000000020000000304RLg`3oool0oooo02T0oooo00<00000
0?ooo`3oool0o`3oool;0?ooo`80<`3oo`3ooom@0?ooo`030000003oool0oooo01D0oooo001@0?oo
o`030000003oool0oooo0?l0oooo3@3oool00`0c0?l0oooo0?ooo`3o0?ooodd0oooo00<000000?oo
o`3oool05@3oool002L0oooo00@0omnL04P000000000M;oo9@3oool00`000000oooo0?ooo`3o0?oo
o`h0oooo0P0c0?oo0?ooodd0oooo00<000000?ooo`3oool05@3oool001h0oooo00h0oooO09a80000
00000000001d_`3ooml0W4P000000018W;l0W7BL0=ooo`3OW4P004RL0=ooob@0oooo0`00003o0?oo
oa00oooo0P0c0?oo0?ooodT0oooo0`00000G0?ooo`007@3oool00`3ooml0W4P00000000300000009
04QdW02ogol0gia80000B02Lgol0oooo0?oOW01804P0W=oo02@0oooo00<000000?ooo`3oool0o`3o
oolB0?ooo`80<`3oo`3ooom90?ooo`030000003oool0oooo01D0oooo000M0?ooo`030?oOW018M;l0
oooo0080oooo00X0omnL04Q8W03Oool0okmd0000M02oool0oooo0?oo_`1d0000M;oo903oool00`00
0000oooo0?ooo`3o0?oooa@0oooo00<0<`3o0?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo
01D0oooo000M0?ooo`030?noW02Lgol0oooo00<0oooo00T0gibL0;ooo`3o_g@0001809cOo`3oool0
oooO09a8001d_ol0903oool00`000000oooo0?ooo`3o0?oooaD0oooo0P0c0?oo0?ooodH0oooo00<0
00000?ooo`3oool05@3oool001d0oooo00<0omnL04Q8W03Oool00P3oool02P3ooml0W7BL0=ooo`3o
_g@0001809cOo`3oool0oono07@0B02LgolT0?ooo`030000003oool0oooo0?l0oooo5`3oool00`0c
0?l0oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool05@3oool001h0oooo00<0_g@000000000
00000P0000002@18W=l0oooo0?noM00004P0W=oo0?ooo`3ogi`0B4RL0=ooo`0T0?ooo`030000003o
ool0oooo0?l0oooo603oool203<0ool0oooo@`3oool00`000000oooo0?ooo`0E0?ooo`007P3oool0
1@2oM0000000000000000000B9cO0080oooo00H0omnL04P0001d_ol0oooO09a8B02LgolU0?ooo`03
0000003oool0oooo0?l0oooo6P3oool203<0ool0oooo@@3oool00`000000oooo0?ooo`0E0?ooo`00
7P3oool00`2oM7@0_ooo0?ooo`050?ooo`040=nLB0000000001809cOobH0oooo00<000000?ooo`3o
ool0o`3ooolL0?ooo`0303<0o`3oool0oooo0?l0oooo?P3oool00`000000oooo0?ooo`0E0?ooo`00
D03oool00`000000oooo0?ooo`3o0?oooad0oooo0P0c0?oo0?oooch0oooo00<000000?ooo`3oool0
5@3oool00500oooo00<000000?ooo`3oool0o`3ooolO0?ooo`0303<0o`3oool0oooo0?l0oooo>`3o
ool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooob00oooo0P0c0?oo
0?oooc/0oooo00<000000?ooo`3oool05@3oool001h0oooo00<0okmd000000000000100000000`00
07@0_ooo0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo8P3oool203<0ool0oooo>@3oool00`00
0000oooo0?ooo`0E0?ooo`00703oool00`3OW4P0000000000008000000030000B02Lgol0oooo02H0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`0303<0o`3oool0oooo0?l0oooo=P3oool00`000000
oooo0?ooo`0E0?ooo`006`3oool0102oM00000000000001d_ol70?ooo`040;md00000000000004RL
gbH0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`80<`3oo`3ooolf0?ooo`030000003oool0oooo
01D0oooo000J0?ooo`030;md0000M;l0oooo00/0oooo00<0oooO09a80018W=l09@3oool300000?l0
oooo9`3oool00`0c0?l0oooo0?ooo`3o0?oooc40oooo0`00000G0?ooo`006@3oool00`3o_g@0M;oo
0?ooo`0>0?ooo`030=nLM02Lgol0oooo02<0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`80<`3o
o`3ooolc0?ooo`030000003oool0oooo01D0oooo000M0?ooo`030?noM01d_ol0oooo00H0oooo00<0
gibL0;ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooobX0oooo0P0c0?oo0?oooc40oooo00<0
00000?ooo`3oool05@3oool001d0oooo00<0okmd07Boo`3oool01@3oool00`3ooml0W4Qd0;ooo`0X
0?ooo`030000003oool0oooo0?l0oooo;03oool00`0c0?l0oooo0?ooo`3o0?ooobh0oooo00<00000
0?ooo`3oool05@3oool001X0oooo00<0oono07@0000000002@0000000`0007@0_ooo0?ooo`0W0?oo
o`030000003oool0oooo0?l0oooo;@3oool203<0ool0oooo;P3oool00`000000oooo0?ooo`0E0?oo
o`006@3oool00`3ogi`0B0000000000:000000030000M02oool0oooo02L0oooo00<000000?ooo`3o
ool0o`3oool_0?ooo`80<`3oo`3oool/0?ooo`030000003oool0oooo01D0oooo000I0?ooo`060;md
M02oool0oooo0?ooo`3o_g@0M;oo1`3oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003oool0oooo
0?l0oooo<@3oool00`0c0?l0oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool05@3oool001P0
oooo00<0oono07Ad_`3oool00P3oool00`3o_g@0M;oo0?ooo`060?ooo`030=nLW02oool0oooo02L0
oooo00<000000?ooo`3oool0o`3ooolb0?ooo`80<`3oo`3ooolY0?ooo`030000003oool0oooo01D0
oooo000H0?ooo`030?oo_`1d07@0_ooo03D0oooo00<000000?ooo`3oool0o`3ooold0?ooo`80<`3o
o`3ooolW0?ooo`030000003oool0oooo01D0oooo000H0?ooo`040?oog`2LB000001809cOoaP0oooo
00<0okmd0000000000000P0000001000M;l0oooo0?ooo`3OW4P70000000307Boo`3oool0oooo00T0
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`0303<0o`3oool0oooo0?l0oooo903oool00`000000
oooo0?ooo`0E0?ooo`006@3oool00`3o_g@0001809cOo`0J0?ooo`030;md000007@0_ooo00@0oooo
00<0gia8000000000000100000000`00M;l0oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo
=`3oool203<0o`80<ol0o`3ooolR0?ooo`030000003oool0oooo01D0oooo000f0?ooo`030;md0000
07@0_ooo00D0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0:0?ooo`030000003o
ool0oooo0?l0oooo>@3oool0100c0?l0<ol003?o000co`3o0?ooob00oooo00<000000?ooo`3oool0
5@3oool001h0oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0>0?ooo`030;md0000
07@0_ooo00H0oooo00<0gia804RLg`3oool03P3oool00`000000oooo0?ooo`3o0?ooocP0oooo0P0c
o`0203<0o`<0<ol0o`3ooolN0?ooo`030000003oool0oooo01D0oooo000L0?ooo`030=nLB0000000
000000P0000000<0001809cOo`3oool0303oool00`2oM000001d0;ooo`070?ooo`030=nLB01d_ol0
oooo00d0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`@0<ol00P0c0?l303?o0?l0oooo703oool0
0`000000oooo0?ooo`0E0?ooo`006`3oool0102oM00000000000001d_ol70?ooo`040;md00000000
000004RLg``0oooo00<0_g@00000M02oool01`3oool00`3ooml0W4Q809cOo`0=0?ooo`030000003o
ool0oooo0?l0oooo>@3oool503?o000303<0o`0co`00<ol00080<ol0o`3ooolJ0?ooo`030000003o
ool0oooo01D0oooo000J0?ooo`030;md0000M;l0oooo00/0oooo00<0oooO09a80018W=l02`3oool0
0`2oM000001d0;ooo`080?ooo`030?oOW01807@0_ooo00`0oooo1000003o0?ooocX0oooo100co`02
03<0o`<0<ol0o`3ooolE0?ooo`D000005`3oool001T0oooo00<0okmd07Boo`3oool03P3oool00`3O
W7@0W=oo0?ooo`090?ooo`030;md000007@0_ooo00T0oooo00<0_g@004RLg`3oool02`3oool00`00
0000oooo0?ooo`3o0?ooocd0oooo100co`0203<0o`<0<ol0o`3ooolG0?ooo`030000003oool0oooo
01D0oooo000f0?ooo`030;md000007@0_ooo00T0oooo00<0gia80000M02oool02`3oool00`000000
oooo0?ooo`3o0?ooocl0oooo100co`00100c0?l0<ol003?o000co`3o0?oooaH0oooo00<000000?oo
o`3oool05@3oool001T0oooo00<0oknL09cOo`3oool02P3oool00`3OW9`0_ooo0?ooo`0=0?ooo`03
0;md000007@0_ooo00T0oooo00<0okmd0000001d_ol02`3oool00`000000oooo0?ooo`3o0?oood40
oooo0`0co`0203<0o`<0<ol0o`3ooolD0?ooo`030000003oool0oooo01D0oooo000I0?ooo`030?no
M01d_ol0oooo00X0oooo00<0_gAd0;ooo`3oool03@3oool00`2oM000001d0;ooo`030?ooo`030?oO
W02L_ol0oooo00<0oooo00<0_g@00000001d_ol02`3oool00`000000oooo0?ooo`3o0?oood<0oooo
0`0co`00100c0?l0<ol003?o000co`3o0?oooa<0oooo00<000000?ooo`3oool05@3oool001T0oooo
00<0okmd0000000000002P0000000`0007@0_ooo0?ooo`0;0?ooo`050=nLB000000000000000M02o
ool0103oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo2`3oool00`000000oooo0?oo
o`3o0?ooodD0oooo0P0co`0203<0o`80<ol0o`3ooolB0?ooo`030000003oool0oooo01D0oooo000I
0?ooo`030?noM0000000000000X0000000<0001d0;ooo`3oool0303oool0103ookl0M0000000M02o
ool50?ooo`050;md00000000000000000000M;l03@3oool00`000000oooo0?ooo`3o0?ooodL0oooo
0P0co`0203<0o`80<ol0o`3oool@0?ooo`030000003oool0oooo01D0oooo000I0?ooo`030?noM01d
_ol0oooo00<0oooo00<0oooO09adW03Oool0103oool00`2oM7@0_ooo0?ooo`0W0?ooo`030000003o
ool0oooo0?l0ooooB03oool303?o000303<0o`0co`00<ol00?l0oooo3`3oool00`000000oooo0?oo
o`0E0?ooo`006@3oool00`3o_g@0M;oo0?ooo`030?ooo`030?oo_`1d07@0_ooo00@0oooo00<0gibL
0;ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooodT0oooo0`0co`0203<0o`0303?o003oool0
oooo0?l0oooo303oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3o_g@0B9cO0?ooo`030?oo
o`040?noM0000000000007Boobd0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`<0<ol000<0<`3o
03?o000co`00o`3oool<0?ooo`030000003oool0oooo01D0oooo000I0?ooo`030?oOW0180000M;oo
0080oooo00<0omnL04P0001dM7@00P0000000`00M;l0oooo0?ooo`0Z0?ooo`030000003oool0oooo
0?l0ooooC03oool303?o0080<`3o0P0co`3o0?ooo`X0oooo00<000000?ooo`3oool05@3oool001X0
oooo00<0_g@00000000000000P0000001`00B9`0gooo0?oo_`1d000000000000M02oool0:P3oool0
0`000000oooo0?ooo`3o0?ooodd0oooo100co`0203<0o`80<ol0o`3oool80?ooo`030000003oool0
oooo01D0oooo000K0?ooo`050;md0000000000000018W03Oool00`3oool0102oM000000000000018
W=lY0?ooo`030000003oool0oooo0?l0ooooC`3oool403?o000403<0o`0co`00<ol003?o0?l0oooo
1P3oool00`000000oooo0?ooo`0E0?ooo`00903oool0103o_g@000000000M02ooolX0?ooo`030000
003oool0oooo0?l0ooooD03oool403?o0080<`3o0`0co`3o0?ooo`@0oooo00<000000?ooo`3oool0
5@3oool002D0oooo00<0omnL04P0M02oool0:03oool300000?l0ooooDP3oool403?o000303<0o`0c
o`00<ol000<0<ol0oP3oool3000001L0oooo000V0?ooo`030;mdM02oool0oooo02L0oooo00<00000
0?ooo`3oool0o`3ooomC0?ooo`@0<ol00P0c0?l403?o0?l0oooo00<000000?ooo`3oool05@3oool0
01T0oooo00<0okmd07Boo`3oool02P3oool01P3OW9`0_ooo0?ooo`3oool0_gA809cOob@0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`@0<ol00P0c0?l303?o0?h0oooo00<000000?ooo`3oool05@3o
ool001X0oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P007Boo`0U0?ooo`030000003oool0
oooo0?l0ooooE`3oool403?o000303<0o`0co`00<ol00080<ol0o03oool00`000000oooo0?ooo`0E
0?ooo`006`3oool0102oM00000000000001d_ol70?ooo`040;md00000000000004RLgbH0oooo00<0
00000?ooo`3oool0o`3ooomI0?ooo`<0<ol00P0c0?l303?o0?/0oooo00<000000?ooo`3oool05@3o
ool001`0oooo00<0gia8000000000000200000000`0004P0W=oo0?ooo`0V0?ooo`030000003oool0
oooo0?l0ooooG03oool203?o0080<`3o0P0co`3j0?ooo`030000003oool0oooo01D0oooo000N0?oo
o`030?noM0000000000000@0000000<0001d0;ooo`3oool0:03oool00`000000oooo0?ooo`3o0?oo
oeh0oooo0P0co`00100c0?l0<ol003?o000co`3h0?ooo`030000003oool0oooo01D0oooo001@0?oo
o`030000003oool0oooo0?l0ooooG`3oool203?o0080<`3o0P0co`3g0?ooo`030000003oool0oooo
01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooH03oool303?o0080<`3o00<0<ol00?ooo`3o
ool0m03oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3o_g@0M;oo0?ooo`0>0?ooo`030;md
B02Lgol0oooo02<0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`<0<ol000<0<`3o03?o000co`00
m03oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`2oM00007Bo0?ooo`0;0?ooo`030?oog`2L
B000M;oo02D0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`<0<ol00P0c0?l00`0co`00oooo0?oo
o`3a0?ooo`030000003oool0oooo01D0oooo000K0?ooo`040;md00000000000007Boo`L0oooo00@0
_g@0000000000000B9cO9P3oool00`000000oooo0?ooo`3o0?ooof@0oooo100co`0203<0o`0303?o
003oool0oooo0>l0oooo00<000000?ooo`3oool05@3oool001`0oooo00<0gia80000000000002000
00000`0004P0W=oo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooIP3oool403?o000303<0o`0c
o`00<ol00>l0oooo00<000000?ooo`3oool05@3oool001h0oooo00<0okmd00000000000010000000
0`0007@0_ooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooI`3oool403?o0080<`3o00<0<ol0
0?ooo`3oool0k03oool00`000000oooo0?ooo`0E0?ooo`00D03oool300000?l0ooooJ@3oool403?o
0080<`3o00<0<ol00?ooo`3oool0j03oool3000001L0oooo001@0?ooo`030000003oool0oooo0?l0
ooooJ`3oool403?o000303<0o`0co`00<ol00>X0oooo00<000000?ooo`3oool05@3oool00500oooo
00<000000?ooo`3oool0o`3ooom/0?ooo`@0<ol00P0c0?l203?o0>P0oooo00<000000?ooo`3oool0
5@3oool00500oooo00<000000?ooo`3oool0o`3ooom^0?ooo`@0<ol00P0c0?l00`0co`00oooo0?oo
o`3U0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooL03oool4
03?o000303<0o`0co`00<ol00>D0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?oo
o`3oool0o`3ooomb0?ooo`<0<ol00P0c0?l203?o0><0oooo00<000000?ooo`3oool05@3oool00500
oooo00<000000?ooo`3oool0o`3ooomc0?ooo`@0<ol000<0<`3o03?o000co`00hP3oool00`000000
oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooogD0oooo0`0co`0203<0o`80<ol0
h03oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooogL0oooo0`0c
o`00100c0?l0<ol003?o000co`3N0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003o
ool0oooo0?l0ooooN03oool303?o0080<`3o0`0co`3L0?ooo`030000003oool0oooo01D0oooo001@
0?ooo`030000003oool0oooo0?l0ooooNP3oool303?o000403<0o`0co`00<ol003?o0=/0oooo00<0
00000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3oooml0?ooo`80<ol00P0c0?l3
03?o0=T0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3ooomn0?oo
o`80<ol00P0c0?l203?o0=P0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3o
ool0o`3ooomo0?ooo`<0<ol000@0<`3o03?o000co`00<ol0eP3oool00`000000oooo0?ooo`0E0?oo
o`00D03oool300000?l0ooooP@3oool203?o0080<`3o0`0co`3B0?ooo`<000005`3oool00500oooo
00<000000?ooo`3oool0o`3ooon20?ooo`<0<ol000@0<`3o03?o000co`00<ol0d`3oool00`000000
oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?oooh@0oooo0P0co`0203<0o`<0<ol0
d@3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooohH0oooo0P0c
o`00100c0?l0<ol003?o000co`3@0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003o
ool0oooo0?l0ooooQ`3oool203?o0080<`3o0`0co`3>0?ooo`030000003oool0oooo01D0oooo001@
0?ooo`030000003oool0oooo0?l0ooooR@3oool203?o000303<0o`0co`00<ol00080<ol0c03oool0
0`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooohX0oooo0P0co`0203<0
o`<0<ol0b`3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?oooh`0
oooo0P0co`0203<0o`<0<ol0b@3oool00`000000oooo0?ooo`0E0?ooo`00=03oool00`3o_g@00000
0000000200000003001d_`3oool0oooo00D0oooo00<0okmd0000001d_ol0303oool00`000000oooo
0?ooo`3o0?ooohh0oooo0P0co`000`0c0?l0<ol003?o000203?o0<L0oooo00<000000?ooo`3oool0
5@3oool003H0oooo00<0_g@00000M02oool0203oool00`3o_g@0000007Boo`0<0?ooo`030000003o
ool0oooo0?l0ooooS`3oool203?o0080<`3o100co`350?ooo`030000003oool0oooo01D0oooo000f
0?ooo`030;md000007@0_ooo00P0oooo00<0okmd0000001d_ol0303oool00`000000oooo0?ooo`3o
0?oooi40oooo0P0co`0203<0o`<0<ol0a03oool00`000000oooo0?ooo`0E0?ooo`00=P3oool00`2o
M000001d0;ooo`030?ooo`030=nLB0000000000000D0000000<0001809cOo`3oool02@3oool00`00
0000oooo0?ooo`3o0?oooi<0oooo0P0co`000`0c0?l0<ol003?o000203?o0<80oooo00<000000?oo
o`3oool05@3oool003H0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B7Bo0?ooo`020?ooo`03
0?noM0000000M;oo00`0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`0303?o000c0?l0<`3o00<0
<ol0`@3oool00`000000oooo0?ooo`0E0?ooo`00=P3oool00`2oM000001d0;ooo`040?ooo`070=nL
B01d_ol0oooo0?ooo`3o_g@0000007Boo`0<0?ooo`030000003oool0oooo0?l0ooooUP3oool203?o
0080<`3o0`0co`2o0?ooo`030000003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00@0
oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo00`0oooo1000003o0?oooiL0oooo0P0co`00
0`0c0?l0<ol003?o000203?o0;T0oooo1@00000G0?ooo`00=P3oool00`2oM000001d0;ooo`050?oo
o`060?noM000M;l0oooo0?noM0000000M;oo303oool00`000000oooo0?ooo`3o0?oooiT0oooo0P0c
o`0203<0o`<0<ol0_03oool00`000000oooo0?ooo`0E0?ooo`00=P3oool00`2oM000001d0;ooo`06
0?ooo`050;md001d_ol0okmd0000001d_ol0303oool00`000000oooo0?ooo`3o0?oooi/0oooo0P0c
o`0203<0o`<0<ol0^P3oool00`000000oooo0?ooo`0E0?ooo`00=P3oool00`2oM000001d0;ooo`06
0?ooo`050?oo_`1d07@0_kmd0000001d_ol0303oool00`000000oooo0?ooo`3o0?oooid0oooo0P0c
o`00100c0?l0<ol003?o000co`2i0?ooo`030000003oool0oooo01D0oooo000f0?ooo`030;md0000
07@0_ooo00L0oooo00@0okmd000000000000M;oo303oool00`000000oooo0?ooo`3o0?oooih0oooo
0P0co`0203<0o`<0<ol0]`3oool00`000000oooo0?ooo`0E0?ooo`00=03oool01@3OW4P000000000
000007@0_ooo00L0oooo00@0oooO09a800000000M;oo303oool00`000000oooo0?ooo`3o0?oooj00
oooo0P0co`0203<0o`<0<ol0]@3oool00`000000oooo0?ooo`0E0?ooo`00=@3oool0103ookl0M000
0000M02oool80?ooo`030?oOW0180000M;oo00`0oooo00<000000?ooo`3oool0o`3ooonQ0?ooo`<0
<ol000@0<`3o03?o000co`00<ol0]03oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000
oooo0?ooo`3o0?oooj<0oooo0P0co`0203<0o`<0<ol0/P3oool00`000000oooo0?ooo`0E0?ooo`00
D03oool00`000000oooo0?ooo`3o0?ooojD0oooo0P0co`0203<0o`<0<ol0/03oool00`000000oooo
0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooojH0oooo0`0co`000`0c0?l0<ol003?o
000203?o0:h0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3ooonX
0?ooo`80<ol00P0c0?l303?o0:d0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?oo
o`3oool0o`3ooonZ0?ooo`80<ol00P0c0?l303?o0:/0oooo00<000000?ooo`3oool05@3oool00500
oooo00<000000?ooo`3oool0o`3ooon/0?ooo`80<ol000@0<`3o03?o000co`00<ol0ZP3oool00`00
0000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooojd0oooo0P0co`0203<0o`<0
<ol0Z03oool00`000000oooo0?ooo`0E0?ooo`00D03oool300000?l0oooo[`3oool203?o0080<`3o
0`0co`2T0?ooo`<000005`3oool00500oooo00<000000?ooo`3oool0o`3ooon`0?ooo`<0<ol000@0
<`3o03?o000co`00<ol0Y@3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?oo
o`3o0?oook80oooo0P0co`0203<0o`<0<ol0X`3oool00`000000oooo0?ooo`0E0?ooo`00D03oool0
0`000000oooo0?ooo`3o0?oook@0oooo0P0co`0203<0o`80<ol0XP3oool00`000000oooo0?ooo`0E
0?ooo`00D03oool00`000000oooo0?ooo`3o0?oookD0oooo0`0co`00100c0?l0<ol003?o000co`2P
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0oooo]`3oool203?o
0080<`3o0`0co`2N0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0
oooo^03oool303?o0080<`3o0P0co`2M0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000
003oool0oooo0?l0oooo^P3oool303?o000403<0o`0co`00<ol003?o09/0oooo00<000000?ooo`3o
ool05@3oool00500oooo00<000000?ooo`3oool0o`3ooonl0?ooo`80<ol00P0c0?l303?o09T0oooo
00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3ooonm0?ooo`<0<ol000<0
<`3o03?o000co`000P0co`2G0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0
oooo0?l0oooo_`3oool203?o0080<`3o0`0co`2F0?ooo`030000003oool0oooo01D0oooo001@0?oo
o`030000003oool0oooo0?l0oooo`@3oool203?o0080<`3o0`0co`2D0?ooo`030000003oool0oooo
01D0oooo001@0?ooo`030000003oool0oooo0?l0oooo``3oool203?o000403<0o`0co`00<ol003?o
09<0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3oooo40?ooo`80
<ol00P0c0?l303?o0940oooo00<000000?ooo`3oool05@3oool00500oooo0`00003o0?ooolH0oooo
0P0co`000`0c0?l0<ol003?o000203?o08d0oooo0`00000G0?ooo`00D03oool00`000000oooo0?oo
o`3o0?ooolL0oooo0P0co`0203<0o`<0<ol0SP3oool00`000000oooo0?ooo`0E0?ooo`00D03oool0
0`000000oooo0?ooo`3o0?ooolT0oooo0P0co`0203<0o`<0<ol0S03oool00`000000oooo0?ooo`0E
0?ooo`00D03oool00`000000oooo0?ooo`3o0?oool/0oooo0P0co`00100c0?l0<ol003?o000co`2;
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooc03oool203?o
0080<`3o0`0co`290?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0
oooocP3oool203?o000403<0o`0co`00<ol003?o08P0oooo00<000000?ooo`3oool05@3oool00500
oooo00<000000?ooo`3oool0o`3oooo?0?ooo`80<ol00P0c0?l303?o08H0oooo00<000000?ooo`3o
ool05@3oool00500oooo00<000000?ooo`3oool0o`3ooooA0?ooo`80<ol00P0c0?l303?o08@0oooo
00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3ooooB0?ooo`<0<ol000@0
<`3o03?o000co`00<ol0P`3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?oo
o`3o0?ooom@0oooo0P0co`0203<0o`<0<ol0P@3oool00`000000oooo0?ooo`0E0?ooo`00D03oool0
0`000000oooo0?ooo`3o0?ooomH0oooo0P0co`00100c0?l0<ol003?o000co`200?ooo`030000003o
ool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooe`3oool203?o0080<`3o0`0co`1n
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0oooof@3oool203?o
0080<`3o0P0co`1m0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0
oooofP3oool303?o000403<0o`0co`00<ol003?o07/0oooo00<000000?ooo`3oool05@3oool00500
oooo00<000000?ooo`3oool0o`3ooooL0?ooo`80<ol00P0c0?l203?o07X0oooo00<000000?ooo`3o
ool05@3oool00500oooo0`00003o0?ooomd0oooo0`0co`00100c0?l0<ol003?o000co`1f0?ooo`<0
00005`3oool00500oooo00<000000?ooo`3oool0o`3ooooO0?ooo`80<ol00P0c0?l203?o07L0oooo
00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3ooooP0?ooo`<0<ol00P0c
0?l203?o07D0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3ooooR
0?ooo`<0<ol000@0<`3o03?o000co`00<ol0L`3oool00`000000oooo0?ooo`0E0?ooo`00D03oool0
0`000000oooo0?ooo`3o0?ooon<0oooo0`0co`0203<0o`<0<ol0L@3oool00`000000oooo0?ooo`0E
0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooonD0oooo0`0co`00100c0?l0<ol003?o000co`1`
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooiP3oool303?o
0080<`3o0`0co`1^0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0
ooooj03oool303?o0080<`3o0`0co`1/0?ooo`030000003oool0oooo01D0oooo000d0?ooo`030?no
M000000000000080000000<007Bo0?ooo`3oool00P3oool01P3ooml0W4P0000000000000001d0;oo
o``0oooo00<000000?ooo`3oool0o`3ooooY0?ooo`@0<ol000<0<`3o03?o000co`000P0co`1Z0?oo
o`030000003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00@0oooo00P0oono07@00000
B9`0gooo0?ooo`3OW4P0001809cOo`/0oooo00<000000?ooo`3oool0o`3oooo[0?ooo`<0<ol00P0c
0?l303?o06T0oooo00<000000?ooo`3oool05@3oool003H0oooo00<0_g@00000M02oool0103oool0
0`2oM000001d0;ooo`030?ooo`030;md0000M;l0oooo00X0oooo00<000000?ooo`3oool0o`3oooo]
0?ooo`<0<ol00P0c0?l303?o06L0oooo00<000000?ooo`3oool05@3oool003H0oooo00<0_g@00000
M02oool00`3oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0_ooo00X0oooo00<000000?oo
o`3oool0o`3oooo_0?ooo`<0<ol000<0<`3o03?o000co`000P0co`1U0?ooo`030000003oool0oooo
01D0oooo000f0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000
001809cOo`0:0?ooo`030000003oool0oooo0?l0ooool@3oool203?o0080<`3o0`0co`1T0?ooo`03
0000003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0
0`3oool0103ookl0M0000000M02oool:0?ooo`030000003oool0oooo0?l0ooool`3oool203?o0080
<`3o0`0co`1R0?ooo`030000003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00<0oooo
00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l02`3oool400000?l0oooom03oool2
03?o0080<`3o0`0co`1L0?ooo`D000005`3oool003H0oooo00<0_g@00000M02oool00`3oool01@3o
oml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool02P3oool00`000000oooo0?ooo`3o
0?ooooH0oooo0`0co`000`0c0?l0<ol003?o000203?o05h0oooo00<000000?ooo`3oool05@3oool0
03H0oooo00<0_g@00000M02oool0103oool00`3o_g@0000004RLg`0@0?ooo`030000003oool0oooo
0?l0oooon03oool203?o0080<`3o0`0co`1M0?ooo`030000003oool0oooo01D0oooo000f0?ooo`03
0;md000007@0_ooo00@0oooo00@0oooO09a8000004P0W=oo3`3oool00`000000oooo0?ooo`3o0?oo
ooX0oooo0P0co`0203<0o`<0<ol0F`3oool00`000000oooo0?ooo`0E0?ooo`00=P3oool00`2oM000
001d0;ooo`050?ooo`040?oo_`1d0000001d0;ooo`h0oooo00<000000?ooo`3oool0o`3ooool0?oo
o`80<ol000@0<`3o03?o000co`00<ol0FP3oool00`000000oooo0?ooo`0E0?ooo`00=03oool01@3O
W4P000000000000007@0_ooo00H0oooo00@0oooO09a80000000007Bo3@3oool00`000000oooo0?oo
o`3o0?ooood0oooo0P0co`0203<0o`<0<ol0F03oool00`000000oooo0?ooo`0E0?ooo`00=@3oool0
103ookl0M0000000M02oool80?ooo`050?oOW018000000000018W03Oool02P3oool00`000000oooo
0?ooo`3o0?ooool0oooo0P0co`0203<0o`80<ol0E`3oool00`000000oooo0?ooo`0E0?ooo`00D03o
ool00`000000oooo0?ooo`3o0?ooool0oooo0@3oool303?o0080<`3o0P0co`1E0?ooo`030000003o
ool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooo`3oool30?ooo`<0<ol000<0<`3o
03?o000co`00E03oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?oo
ool0oooo103oool303?o0080<`3o0P0co`1B0?ooo`030000003oool0oooo01D0oooo001@0?ooo`03
0000003oool0oooo0?l0ooooo`3oool60?ooo`<0<ol000<0<`3o03?o000co`00D@3oool00`000000
oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo1`3oool303?o0080<`3o
0P0co`1?0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooo`3o
ool90?ooo`<0<ol00P0c0?l00`0co`00oooo0?ooo`1<0?ooo`030000003oool0oooo01D0oooo001@
0?ooo`030000003oool0oooo0?l0ooooo`3oool:0?ooo`@0<ol000<0<`3o03?o000co`00C03oool0
0`000000oooo0?ooo`0E0?ooo`00D03oool300000?l0ooooo`3oool<0?ooo`<0<ol00P0c0?l203?o
04P0oooo0`00000G0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo3@3oool403?o0003
03<0o`0co`00<ol004T0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`l0oooo0`0co`0203<0o`80<ol0A`3oool00`000000oooo0?ooo`0E0?ooo`00D03o
ool00`000000oooo0?ooo`3o0?ooool0oooo4@3oool303?o0080<`3o00<0<ol00?ooo`3oool0A03o
ool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo4P3oool4
03?o000303<0o`0co`00<ol004@0oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?oo
o`3oool0o`3ooooo0?oooa@0oooo0`0co`0203<0o`80<ol0@P3oool00`000000oooo0?ooo`0E0?oo
o`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo5@3oool403?o000303<0o`0co`00<ol00440
oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo
0`0co`0203<0o`80<ol0?`3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?oo
o`3o0?ooool0oooo6@3oool303?o0080<`3o0P0co`0m0?ooo`030000003oool0oooo01D0oooo001@
0?ooo`030000003oool0oooo0?l0ooooo`3ooolJ0?ooo`@0<ol000@0<`3o03?o000co`00<ol0>`3o
ool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo703oool3
03?o0080<`3o0P0co`0j0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo
0?l0ooooo`3ooolN0?ooo`<0<ol000@0<`3o03?o000co`00<ol0>03oool00`000000oooo0?ooo`0E
0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo803oool203?o0080<`3o0P0co`0g0?oo
o`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`<0
<ol00P0c0?l203?o03D0oooo00<000000?ooo`3oool05@3oool00500oooo0`00003o0?ooool0oooo
8`3oool303?o000403<0o`0co`00<ol003?o0340oooo0`00000G0?ooo`00D03oool00`000000oooo
0?ooo`3o0?ooool0oooo903oool303?o0080<`3o0P0co`0b0?ooo`030000003oool0oooo01D0oooo
001@0?ooo`030000003oool0oooo0?l0ooooo`3ooolV0?ooo`<0<ol000@0<`3o03?o000co`00<ol0
<03oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo:03o
ool203?o0080<`3o0P0co`0_0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0
oooo0?l0ooooo`3ooolY0?ooo`<0<ol000@0<`3o03?o000co`00<ol0;@3oool00`000000oooo0?oo
o`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo:`3oool203?o0080<`3o0P0co`0/
0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooo`3oool/0?oo
o`<0<ol000@0<`3o03?o000co`00<ol0:P3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`00
0000oooo0?ooo`3o0?ooool0oooo;P3oool203?o0080<`3o0`0co`0X0?ooo`030000003oool0oooo
01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooo`3oool_0?ooo`<0<ol00P0c0?l203?o02L0
oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3ooooo0?oooc40oooo
0`0co`00100c0?l0<ol003?o000co`0U0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000
003oool0oooo0?l0ooooo`3ooolc0?ooo`80<ol00P0c0?l303?o02<0oooo00<000000?ooo`3oool0
5@3oool00500oooo00<000000?ooo`3oool0o`3ooooo0?oooc@0oooo0`0co`000`0c0?l0<ol003?o
000203?o0240oooo00<000000?ooo`3oool05@3oool00500oooo00<000000?ooo`3oool0o`3ooooo
0?ooocH0oooo0P0co`0203<0o`@0<ol07`3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`00
0000oooo0?ooo`3o0?ooool0oooo=`3oool303?o0080<`3o100co`0M0?ooo`030000003oool0oooo
01D0oooo001@0?ooo`<00000o`3ooooo0?ooocT0oooo0`0co`000`0c0?l0<ol003?o000303?o01T0
oooo0`00000G0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool303?o0080<`3o
100co`0J0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000003oool0oooo0?l0ooooo`3o
ooll0?ooo`<0<ol00P0c0?l403?o01P0oooo00<000000?ooo`3oool05@3oool00500oooo00<00000
0?ooo`3oool0o`3ooooo0?oooch0oooo0`0co`0203<0o`<0<ol05`3oool00`000000oooo0?ooo`0E
0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0oooo@03oool303?o000303<0o`0co`00<ol0
0080<ol05@3oool00`000000oooo0?ooo`0E0?ooo`00D03oool00`000000oooo0?ooo`3o0?ooool0
oooo@P3oool203?o0080<`3o0`0co`0D0?ooo`030000003oool0oooo01D0oooo001@0?ooo`030000
003oool0oooo0?l0ooooo`3ooom40?ooo`80<ol00P0c0?l303?o0180oooo00<000000?ooo`3oool0
5@3oool00500oooo00<000000?ooo`3oool0o`3ooooo0?ooodH0oooo0P0co`000`0c0?l0<ol003?o
000203?o0100oooo00<000000?ooo`3oool05@3oool003@0oooo00<0okmd0000000000000P000000
0`00M;l0oooo0?ooo`020?ooo`060?oOW018000000000000000004P0W=oo303oool00`000000oooo
0?ooo`3o0?ooool0ooooA`3oool203?o0080<`3o0`0co`0?0?ooo`030000003oool0oooo01D0oooo
000f0?ooo`030;md000007@0_ooo00@0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Bo
o`/0oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo0P0co`0203<0o`<0<ol03@3oool00`00
0000oooo0?ooo`0E0?ooo`00=P3oool00`2oM000001d0;ooo`040?ooo`030;md000007@0_ooo00<0
oooo00<0gia80018W03Oool02P3oool00`000000oooo0?ooo`3o0?ooool0ooooB`3oool203?o0080
<`3o0P0co`0<0?ooo`030000003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00@0oooo
00<0_g@00000M02oool00`3oool00`2oM00004RL0=ooo`0:0?ooo`030000003oool0oooo0?l0oooo
o`3ooom<0?ooo`<0<ol000<0<`3o03?o000co`002`3oool00`000000oooo0?ooo`0E0?ooo`00=P3o
ool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0gia800000000M;l02`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool303?o00`0oooo00<000000?ooo`3oool05@3o
ool003H0oooo00<0_g@00000M02oool01@3oool01`3OW4P007Bo0?ooo`2oM00000000000M02oool0
2`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool203?o00`0oooo00<000000?ooo`3oool0
5@3oool003H0oooo00<0_g@00000M02oool01P3oool01@3o_g@0000000000000B9`0gooo00`0oooo
1000003o0?ooool0ooooF03oool5000001L0oooo000f0?ooo`030;md000007@0_ooo00D0oooo00D0
omnL04P000000000000004RLg`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`030000
003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00@0oooo00L0omnL04P0000004P0W=oo
0?ooo`3OW4P007Bo00`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01D0oooo000f0?ooo`030;md000007@0_ooo00@0oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P007Boo`0;0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0E0?ooo`00=P3oool00`2oM000001d0;ooo`040?ooo`030=nLB000
B9`0gooo0080oooo00<0oooO09a80018W=l02`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`00=03oool0
1@3OW4P000000000000007@0_ooo00@0oooo00<0omnL04P00018W=l00P3oool00`3o_g@0001809cO
o`0;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01D0oooo000e0?ooo`040?oo_`1d0000001d0;ooo`D0oooo00H0
oono07@00000000000000000B02Lgol<0?ooool00000o`00001Q000001L0oooo003o0?ooool0oooo
b03oool00?l0ooooo`3oooo80?ooo`00o`3ooooo0?ooolP0oooo003o0?ooool0oooob03oool00?l0
ooooo`3oooo80?ooo`00o`3ooooo0?ooolP0oooo0000\
\>"],
  ImageRangeCache->{{{0, 709.188}, {437.938, 0}} -> {3.28073, 2.94829, \
0.021739, 0.0353613}}]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 717}},
CellGrouping->Manual,
WindowSize->{1272, 683},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 154, 4, 35, "Input"],

Cell[CellGroupData[{
Cell[1933, 59, 109, 2, 35, "Input"],
Cell[2045, 63, 202, 4, 30, "Input"],
Cell[2250, 69, 1382, 28, 333, "Input"],
Cell[3635, 99, 583, 10, 171, "Input"],
Cell[4221, 111, 59, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4317, 117, 89, 2, 32, "Input"],
Cell[4409, 121, 83, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[4517, 126, 366, 6, 50, "Input"],
Cell[4886, 134, 61833, 1620, 313, 24301, 1152, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[66768, 1760, 89, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[66882, 1766, 1766, 34, 190, "Input"],
Cell[68651, 1802, 242741, 7208, 532, 112678, 5597, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[311441, 9016, 89, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[311555, 9022, 1046, 20, 150, "Input"],
Cell[312604, 9044, 112681, 3847, 295, 58074, 3168, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[425334, 12897, 89, 2, 32, "Input"],
Cell[425426, 12901, 850, 24, 30, "Input"],

Cell[CellGroupData[{
Cell[426301, 12929, 493, 9, 70, "Input"],
Cell[426797, 12940, 70084, 1977, 318, 28259, 1456, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[496930, 14923, 89, 2, 32, "Input"],
Cell[497022, 14927, 1504, 30, 243, "Input"],

Cell[CellGroupData[{
Cell[498551, 14961, 605, 13, 110, "Input"],
Cell[499159, 14976, 122, 2, 29, "Output"],
Cell[499284, 14980, 45131, 1344, 186, 20719, 1038, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[544452, 16329, 231, 6, 50, "Input"],
Cell[544686, 16337, 82, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[544805, 16343, 569, 11, 110, "Input"],
Cell[545377, 16356, 114, 2, 29, "Output"],
Cell[545494, 16360, 31379, 938, 186, 13583, 714, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[576910, 17303, 199, 4, 50, "Input"],
Cell[577112, 17309, 83, 1, 29, "Output"]
}, Open  ]],
Cell[577210, 17313, 287, 8, 30, "Input"],
Cell[577500, 17323, 676, 13, 70, "Input"],
Cell[578179, 17338, 332, 6, 50, "Input"],

Cell[CellGroupData[{
Cell[578536, 17348, 272, 5, 50, "Input"],
Cell[578811, 17355, 68451, 1894, 322, 26648, 1373, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[647311, 19255, 89, 2, 32, "Input"],
Cell[647403, 19259, 215, 4, 50, "Input"],
Cell[647621, 19265, 418, 12, 30, "Input"],
Cell[648042, 19279, 119, 2, 35, "Input"],
Cell[648164, 19283, 783, 15, 90, "Input"],

Cell[CellGroupData[{
Cell[648972, 19302, 346, 6, 50, "Input"],
Cell[649321, 19310, 63735, 1604, 280, 23336, 1101, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[713093, 20919, 264, 5, 50, "Input"],
Cell[713360, 20926, 84216, 1880, 447, 23742, 1129, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

