(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    864483,      25540]*)
(*NotebookOutlinePosition[    865213,      25565]*)
(*  CellTagsIndexPosition[    865169,      25561]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\( (*\ 
        This\ file\ creates\ the\ curve\ for\ the\ radiation\ initial\ \
conditions\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ This\ part\ solves\ the\ ODE\ system\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(Off[General::"\<spell1\>", 
      NIntegrate::"\<slwcon\>"]; $TextStyle = {FontFamily \[Rule] \
"\<Times\>", FontSize \[Rule] 20}; 
    SetDirectory["\<D:\mathfiles\>"];\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(h[z_] := \@\(om\ \((1 + z)\)^3 + or \((1 + z)\)^4 + 1 - om - or\)\), "\n\
", 
    \(\(tt = 
        2 - \((1 + z)\) \(h'\)[z]/h[z] /. z \[Rule] \((Exp[\(-n\)] - 1)\) // 
          Simplify;\)\), "\[IndentingNewLine]", 
    \(\(eqns = {\(-1\) - x3[N] - 3  x2[N] + x1[N]^2 - x1[N]\ x3[N] + 
              x4[N] \[Equal] \(x1'\)[N], 
          4\ x3[N] - 2\ x3[N]\^2 - \(x3'\)[N] - 
              x2[N] \((2  x3[N] - 4 - x1[N])\) \[Equal] \(x2'\)[
              N], \(-2\) x3[N] x4[N] + x1[N] x4[N] \[Equal] \(x4'\)[
              N]};\)\), "\n", 
    \(x3[N_] := \(\(tt /. n \[Rule] N\) /. om \[Rule] om0\) /. 
        or \[Rule] or0\), "\n", 
    \(\(\(R[z_] := 
      6 \((2  h[z]^2 - \((1 + z)\) h[z] \(h'\)[z])\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(nmin = \(-30\);\)\), "\n", 
    \(\(nmax = 6;\)\), "\[IndentingNewLine]", 
    \(\(om0 = 0.30;\)\), "\n", 
    \(\(or0 = 10^\((\(-4\))\);\)\), "\n", 
    \(\(x3min = x3[nmin];\)\), "\n", 
    \(\(x1min = 0;\)\), "\n", 
    \(\(x2min = 0;\)\), "\[IndentingNewLine]", 
    \(\(x4min = 1;\)\), "\[IndentingNewLine]", 
    \(Print["\<Nrm = \>", \(-Log[om0/or0]\)]\), "\n", 
    \(\(\(Print["\<Nm\[CapitalLambda] = \>", \(-1\)/3 
         Log[\((1 - om0 - or0)\)/om0]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(nsol = \(NDSolve[\((Flatten[{eqns, x1[nmin] \[Equal] x1min, 
                  x2[nmin] \[Equal] x2min, x4[nmin] \[Equal] x4min}])\), {x1[
                N], x2[N], x4[N]}, {N, nmin, nmax}, 
            MaxStepFraction \[Rule] 1/10]\)[\([1]\)];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Nrm = "\[InvisibleSpace]\(-8.006367567650246`\)\),
      SequenceForm[ "Nrm = ", -8.0063675676502459],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Nm\[CapitalLambda] = \
"\[InvisibleSpace]\(-0.2823849976797643`\)\),
      SequenceForm[ "Nm\[CapitalLambda] = ", -.28238499767976433],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(xx1[N_] := x1[N] /. nsol // Evaluate\), "\n", 
    \(xx2[N_] := x2[N] /. nsol // Evaluate\), "\[IndentingNewLine]", 
    \(xx4[N_] := x4[N] /. nsol // Evaluate\), "\[IndentingNewLine]", 
    \(x1z[z_] := xx1[N] /. N \[Rule] \(-Log[1 + z]\)\), "\n", 
    \(x2z[z_] := xx2[N] /. N \[Rule] \(-Log[1 + z]\)\), "\n", 
    \(x3z[z_] := x3[N] /. N \[Rule] \(-Log[1 + z]\)\), "\n", 
    \(x4z[z_] := 
      x4[N] /. N \[Rule] \(-Log[1 + z]\)\), "\[IndentingNewLine]", 
    \(\(zmax = \((\(-1\) + \[ExponentialE]\^\(-N\) /. 
            N \[Rule] nmin)\);\)\)}], "Input"],

Cell[BoxData[
    \(\(flnm = "\<figs_rad\>";\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 1\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(\(weff[N_] := \(-\((1/3)\)\) \((2  x3[N] - 1)\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig1weff = 
        Plot[weff[N], {N, nmin, nmax}, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(w\_eff\)(N)\>\""}, 
          PlotRange \[Rule] All, Axes \[Rule] False, 
          PlotStyle \[Rule] Hue[0]];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig1_weff\>" <> "\<.m\>", fig1weff];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.456168 0.441453 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -28 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .10301 -43.0625 -12.2813 ]
[-0.0125 .10301 0 12.2813 ]
[-0.0125 .1913 -43.0625 -12.2813 ]
[-0.0125 .1913 0 12.2813 ]
[-0.0125 .27959 -43.0625 -12.2813 ]
[-0.0125 .27959 0 12.2813 ]
[-0.0125 .36788 -43.0625 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .45617 -14.0625 -12.2813 ]
[-0.0125 .45617 0 12.2813 ]
[-0.0125 .54446 -29.125 -12.2813 ]
[-0.0125 .54446 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -31.9063 ]
[-0.01875 .30902 -43.0625 31.9063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .1913 m
.00625 .1913 L
s
gsave
-0.0125 .1913 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .27959 m
.00625 .27959 L
s
gsave
-0.0125 .27959 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .45617 m
.00625 .45617 L
s
gsave
-0.0125 .45617 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .54446 m
.00625 .54446 L
s
gsave
-0.0125 .54446 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03679 m
.00375 .03679 L
s
0 .05886 m
.00375 .05886 L
s
0 .08093 m
.00375 .08093 L
s
0 .12508 m
.00375 .12508 L
s
0 .14715 m
.00375 .14715 L
s
0 .16922 m
.00375 .16922 L
s
0 .21337 m
.00375 .21337 L
s
0 .23544 m
.00375 .23544 L
s
0 .25751 m
.00375 .25751 L
s
0 .30166 m
.00375 .30166 L
s
0 .32373 m
.00375 .32373 L
s
0 .3458 m
.00375 .3458 L
s
0 .38995 m
.00375 .38995 L
s
0 .41202 m
.00375 .41202 L
s
0 .4341 m
.00375 .4341 L
s
0 .47824 m
.00375 .47824 L
s
0 .50031 m
.00375 .50031 L
s
0 .52239 m
.00375 .52239 L
s
0 .56653 m
.00375 .56653 L
s
0 .5886 m
.00375 .5886 L
s
0 .61068 m
.00375 .61068 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -148.25 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
92.9063 16.2813 translate
90 rotate
-92.9063 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
77.500 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(eff) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.250 23.000 moveto
(H) show
101.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.375 23.000 moveto
(L) show
122.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .1913 m
1 .1913 L
s
.99375 .27959 m
1 .27959 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .54446 m
1 .54446 L
s
.125 Mabswid
.99625 .03679 m
1 .03679 L
s
.99625 .05886 m
1 .05886 L
s
.99625 .08093 m
1 .08093 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14715 m
1 .14715 L
s
.99625 .16922 m
1 .16922 L
s
.99625 .21337 m
1 .21337 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .25751 m
1 .25751 L
s
.99625 .30166 m
1 .30166 L
s
.99625 .32373 m
1 .32373 L
s
.99625 .3458 m
1 .3458 L
s
.99625 .38995 m
1 .38995 L
s
.99625 .41202 m
1 .41202 L
s
.99625 .4341 m
1 .4341 L
s
.99625 .47824 m
1 .47824 L
s
.99625 .50031 m
1 .50031 L
s
.99625 .52239 m
1 .52239 L
s
.99625 .56653 m
1 .56653 L
s
.99625 .5886 m
1 .5886 L
s
.99625 .61068 m
1 .61068 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07295 .60332 L
.08265 .60332 L
.08804 .60332 L
.09308 .60332 L
.09858 .60332 L
.10458 .60332 L
.10996 .60332 L
.11496 .60332 L
.12013 .60332 L
.12483 .60332 L
.13379 .60332 L
.14335 .60332 L
.14823 .60332 L
.15338 .60332 L
.1626 .60332 L
.16773 .60332 L
.17252 .60332 L
.17774 .60332 L
.18342 .60332 L
.18885 .60332 L
.19387 .60332 L
.19858 .60332 L
.20377 .60332 L
.21277 .60332 L
.2177 .60332 L
.22233 .60332 L
.23216 .60332 L
.2371 .60332 L
.24251 .60332 L
.2521 .60332 L
.26101 .60332 L
.26606 .60332 L
.27154 .60332 L
.27636 .60332 L
.28147 .60332 L
.29114 .60332 L
.30006 .60332 L
.3095 .60332 L
.31479 .60332 L
.31963 .60332 L
.32903 .60331 L
Mistroke
.33795 .60331 L
.34299 .60331 L
.34756 .60331 L
.35248 .60331 L
.35779 .60331 L
.36727 .6033 L
.37619 .60329 L
.38572 .60328 L
.39113 .60327 L
.39617 .60327 L
.40635 .60324 L
.41205 .60322 L
.41725 .6032 L
.42207 .60318 L
.42719 .60315 L
.43637 .60307 L
.44147 .60302 L
.44625 .60296 L
.45146 .60289 L
.45714 .60278 L
.467 .60254 L
.47238 .60237 L
.47737 .60217 L
.48633 .60172 L
.49588 .60103 L
.50123 .60053 L
.50615 .59997 L
.51145 .59925 L
.51727 .59829 L
.52707 .59614 L
.53743 .59294 L
.54762 .58855 L
.55692 .58319 L
.56765 .57505 L
.57783 .56522 L
.61612 .51537 L
.63548 .49216 L
.64651 .48205 L
.65687 .47472 L
.66672 .46948 L
.67575 .46588 L
.68566 .46299 L
.69113 .46176 L
.69611 .46083 L
.70564 .45945 L
.71582 .45841 L
.72526 .45772 L
.73418 .45722 L
.74389 .45671 L
.74878 .4564 L
Mistroke
.7516 .45617 L
.75417 .45592 L
.75876 .4553 L
.76129 .45482 L
.7637 .45424 L
.76591 .45356 L
.76796 .45276 L
.77022 .45166 L
.77262 .45016 L
.77523 .44801 L
.77798 .44499 L
.78033 .44161 L
.78291 .43679 L
.78569 .42995 L
.78867 .4202 L
.79148 .40811 L
.79404 .39413 L
.79901 .35761 L
.80441 .30317 L
.81422 .18356 L
.81875 .13407 L
.82363 .09225 L
.82642 .07402 L
.82898 .06062 L
.83159 .04982 L
.83401 .04191 L
.83637 .03582 L
.8389 .03075 L
.8417 .0265 L
.84425 .02361 L
.84691 .02133 L
.84979 .0195 L
.85251 .01824 L
.85502 .01737 L
.85747 .01673 L
.8597 .01628 L
.86228 .01589 L
.86473 .0156 L
.86698 .0154 L
.86907 .01526 L
.87136 .01513 L
.8738 .01503 L
.87649 .01495 L
.87938 .01488 L
.88212 .01484 L
.88464 .01481 L
.88691 .01479 L
.88941 .01477 L
.89202 .01476 L
.89444 .01475 L
Mistroke
.89706 .01474 L
.89947 .01473 L
.90212 .01473 L
.90493 .01472 L
.90737 .01472 L
.90965 .01472 L
.91216 .01472 L
.91485 .01472 L
.91723 .01472 L
.91982 .01472 L
.92227 .01472 L
.92455 .01472 L
.9268 .01472 L
.92885 .01472 L
.9312 .01472 L
.93343 .01472 L
.93583 .01472 L
.93808 .01472 L
.94054 .01472 L
.94318 .01472 L
.94595 .01472 L
.94858 .01472 L
.95093 .01472 L
.95349 .01472 L
.9557 .01472 L
.95814 .01472 L
.96069 .01472 L
.96309 .01472 L
.96531 .01472 L
.96736 .01472 L
.9696 .01472 L
.97196 .01472 L
.97415 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{485.563, 300.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007U0001;2000`400?l00000o`00003oo`3ooooV
0?ooo`00o`3ooooV0?ooo`00o`3ooooV0?ooo`00o`3ooooV0?ooo`00o`3ooooV0?ooo`00o`3ooooV
0?ooo`00o`3ooooV0?ooo`00o`3ooolA0?ooo`060;md00000000000000000000B9`0gooo103oool0
0`3ookl0M01d0;ooo`380?ooo`00o`3ooolB0?ooo`030?oo_`1d07@0_ooo00D0oooo00@0oooO09a8
000007@0_ooob03oool00?l0oooo4P3oool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000001d
0;ooolP0oooo003o0?oooa80oooo00<0oooO09a8M02oool0103oool01@3OW4P000000000B018B7@0
_ooo0<P0oooo003o0?oooa80oooo00<0oooO09a8M02oool00`3oool01P3o_g@000000000M02ooml0
W4Qd0;ooolP0oooo003o0?oooa80oooo00<0oooO09a8M02oool00P3oool01`3ogi`0B0000000B02L
gol0oooO09a8M02oool0b03oool00?l0oooo4P3oool0303ooml0W4Qd0;ooo`3oool0oono07@00000
0000M;oo0?ooo`3ooml0W4Qd0;ooolP0oooo003o0?oooa80oooo00L0oooO09a8M02oool0oooO09a8
00000000B9cO0080oooo00<0oooO09a8M02oool0b03oool00?l0oooo4P3oool01P3ooml0W4Qd0;oo
g`2LB0000000001d_`<0oooo00<0oooO09a8M02oool0b03oool00?l0oooo4P3oool01P3ooml0W4Qd
07Ad0000000004RL0=ooo`<0oooo00<0oooO09a8M02oool0b03oool00?l0oooo4P3oool01@3ooml0
W4P00000000007@0_ooo00@0oooo00<0oooO09a8M02oool0b03oool00?l0oooo4P3oool0103OW4P0
00000000M02oool50?ooo`030?oo_`1d07@0_ooo0<P0oooo003o0?oooa00oooo00D0gia800000000
0000001809cOo`040?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0a@3oool00?l0
ooooiP3oool00?l0ooooiP3oool00?l0ooooiP3oool00?l0ooooiP3oool00?l0ooooiP3oool00?l0
ooooiP3oool00?l0ooooiP3oool00?l0ooooiP3oool00?l0ooooiP3oool00?l0ooooiP3oool00?l0
ooooiP3oool005L0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`040;md
00000000000004RLgb@0oooo00<0gia80000000000001@000000101d_ol0oooo0?ooo`2oM0030000
00030018W03Oool0oooo0280oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`020?oo
o`040;md00000000000004RLgbH0oooo00<0okmd0000000000000P0000001@00M;l0oooo0?ooo`3o
ool0_g@000<0000000<004RL0=ooo`3oool0903oool00`3o_g@000000000000200000003001d_`3o
ool0oooo00<0oooo00@0_g@0000000000000B9cO:P3oool01P2oM000000000000000000004RL0=oo
obT0oooo00@0_g@0000000000000B9cO;`3oool01P2oM000000000000000000004RL0=oooaT0oooo
001G0?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0B02Lgol30?ooo`070?oog`2LB00007Bo
0?ooo`3ooml0W4P0001d_`0T0?ooo`030=nLB0000000000000@0000000D007Bo0?ooo`3ooml0W4P0
04RLg`020?ooo`030?oOW018B9`0gooo02<0oooo00<0gia8000000000000100000002P00M;l0oooo
0?ooo`3ooml0W4P0001d_`3oool0oooO09a80000M;lW0?ooo`030;md000007@0_ooo00<0oooo00<0
oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0V0?ooo`030;md000007@0_ooo00@0oooo00L0
oooO09a80000M;l0oooo0?oog`2LB00007Bo02P0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0
B4RL0=ooo`0V0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0]0?ooo`030?oog`2LB000
B9cO0080oooo00<0omnL04Q8W03Oool0603oool005d0oooo00<0okmd0018W03Oool00P3oool00`3o
_g@0001809cOo`020?ooo`030?oOW0180000M;oo02@0oooo00<0gia804RLg`3oool00P3oool00`3o
oml0W4Qd0;ooo`060?ooo`030?oOW018M;l0oooo02<0oooo00<0gia804RLg`3oool00P3oool01`3o
oml0W4Qd0;ooo`3oool0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0V0?ooo`030;md0000
07@0_ooo00T0oooo00<0omnL04Qd_`3oool09@3oool00`2oM000001d0;ooo`040?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol0;@3oool00`3ogi`0B7Bo0?ooo`0U0?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol0<P3oool00`3ogi`0B7Bo0?ooo`0G0?ooo`00G@3oool0
203o_g@0001809cOo`3oool0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0U0?ooo`03
0=nLB018W=l0oooo00X0oooo00<0oono07@0B02Lgol0903oool00`3OW4P0B9cO0?ooo`040?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l09P3oool00`2oM000001d0;ooo`090?oo
o`030?oo_`1d04P0W=oo02D0oooo00<0_g@00000M02oool00`3oool0103ooml0W4P00018W03Oool2
0?ooo`030?oog`2LB00007Bo02d0oooo00<0oono07@0B02Lgol0903oool0103ooml0W4P00018W03O
ool20?ooo`030?oog`2LB00007Bo0380oooo00<0oono07@0B02Lgol05`3oool005d0oooo00L0_g@0
0000B02Lgol0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool09@3oool00`3OW4P0M;oo
0?ooo`090?ooo`030?oo_`1d0000M;oo02D0oooo00<0gia807Boo`3oool00`3oool00`3ookl0M000
001d_`040?ooo`030;md000007@0_ooo02D0oooo00<0_g@00000M02oool02@3oool00`3ookl0M000
07Boo`0U0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`0/0?ooo`030?oo_`1d0000M;oo02@0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`0a0?ooo`030?oo_`1d0000M;oo01L0oooo001:0?ooo`030;md00000000000000L0000000<0
B9cO0?ooo`3oool01@3oool0202oM00000000000M02oool0oooo0?oOW0180000B9cO103oool00`2o
M000001d0;ooo`0D0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool00`3o
oml0W4Q809cOo`090?ooo`030?noM0000000M;oo01@0oooo00<0_g@00000000000001`0000000`18
W=l0oooo0?ooo`040?ooo`030?oog`2LB4P0W=oo00<0oooo00<0omnL04P00018W=l0103oool00`2o
M000001d0;ooo`0D0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool00`2o
M000001d0;ooo`090?ooo`030?noM0000000M;oo01@0oooo00<0_g@00000000000001`0000000`18
W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2o
M000001d0;ooo`0I0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool01P3oool00`3o
_g@0000007Boo`0T0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0<@3oool00`3o
_g@0000007Boo`0G0?ooo`00F@3oool00`3ookl0M000000000020000000604RLg`3oool0oooo0?oO
W0180000B9cO103oool00`3OW4P0001809cOo`0V0?ooo`030?oOW01807@0_ooo00L0oooo00@0omnL
04P0000007@0_ooo9P3oool00`3ogi`0B01d0;ooo`020?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol09@3oool00`2oM000001d0;ooo`080?ooo`040?oOW0180000001d0;ooobD0oooo
00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02/0oooo
00@0omnL04P0000007@0_ooo903oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo0300
oooo00@0omnL04P0000007@0_ooo5`3oool005/0oooo00<0okmd0000B02Lgol00`3oool00`3ogi`0
B00004RLg`040?ooo`030=nLB00004P0W=oo02L0oooo00<0_g@004RLg`3oool00P3oool0103Ogml0
oooo0?ooo`2oM0020000000304RLg`3oool0oooo02H0oooo00L0_g@004RLg`3oool0oooo0?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol09@3oool00`2oM000001d0;ooo`040?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool0903oool00`2oM000001d0;ooo`030?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol09`3oool0103Ogml0oooo0?ooo`2oM00200000003
04RLg`3oool0oooo02<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0/0?ooo`04
0=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool05P3oool005`0oooo00<0omnL04Qd_`3o
ool00P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02L0oooo00<0gia80000M02o
ool00P3oool00`3o_g@000000000000200000003001d_`3oool0oooo02L0oooo00L0gia80000M02o
ool0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool09@3oool00`2oM000001d0;ooo`04
0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool09@3oool00`2oM000001d0;ooo`03
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool09`3oool00`3o_g@0000000000002
00000003001d_`3oool0oooo02@0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0/
0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool05`3oool005`0oooo00<0oooO09a8
0018W=l00`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo02P0oooo00<0okmd0000
001d_ol00P3oool01@3ooml0W4P00000000007@0_ooo02X0oooo00<0okmd0000001d_ol00P3oool0
0`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo02H0oooo00<0_g@00000M02oool0103oool0
1@3ooml0W4P00000000007@0_ooo02P0oooo00<0_g@00000M02oool0103oool00`2oM00004RL0=oo
o`020?ooo`030?oog`2LB00007Bo02P0oooo00D0oooO09a800000000001d0;ooo`0X0?ooo`030;md
0000B9`0gooo0080oooo00<0oooO09a80000M;l0;@3oool01@3ooml0W4P00000000007@0_ooo01X0
oooo001G0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l00`3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo0280oooo00<0omnL09boo`3oool00`3oool00`2oM0000000
07Boo`030?ooo`030?noM000M;l0oooo02D0oooo00<0omnL09boo`3oool00`3oool00`2oM0000000
07Boo`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol09P3oool00`2oM000001d
0;ooo`050?ooo`030?noM000M;l0oooo02T0oooo00<0_g@00000M02oool0103oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo02T0oooo00<0okmd001d_`3oool0:@3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo02h0oooo00<0okmd001d_`3oool06`3oool005P0oooo00L0
omnL04Q8W03Oool0oooo0=nLB0000000M;oo00@0oooo00H0_g@00018W03Oool0oooo0;md0000M;lT
0?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03Oool30?ooo`030?oog`2LB00000000080
000000<0001d0;ooo`3oool08@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0`3o
ool01P2oM00004RL0=ooo`3oool0_g@0001d_bD0oooo00D0gia8000000000000001d0;ooo`050?oo
o`030?oog`2LB00000000080000000<0001d0;ooo`3oool08P3oool01@3OW4P000000000000007@0
_ooo00D0oooo00H0_g@00018W03Oool0oooo0;md0000M;lZ0?ooo`030?oog`2LB000000000800000
00<0001d0;ooo`3oool09@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_bl0oooo00<0oooO09a8
000000000P0000000`0007@0_ooo0?ooo`0F0?ooo`00F@3oool01@3ogi`0B000000000000000B9cO
00H0oooo00@0_g@000000000000007Bo9P3oool01@2oM000000000000000000007Bo00H0oooo00<0
okmd0000000000000P0000000`1d_ol0oooo0?ooo`0Q0?ooo`050;md00000000000000000000M;l0
1P3oool0102oM000000000000000M;lW0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00<0okmd0000
000000000P0000000`1d_ol0oooo0?ooo`0R0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00@0_g@0
00000000000007Bo;03oool00`3o_g@00000000000020000000307Boo`3oool0oooo02D0oooo00@0
_g@000000000000007Bo<@3oool00`3o_g@00000000000020000000307Boo`3oool0oooo01D0oooo
003o0?ooonH0oooo003o0?ooonH0oooo003o0?ooonH0oooo003o0?ooonH0oooo003o0?ooonH0oooo
003o0?ooonH0oooo003o0?ooonH0oooo003o0?ooonH0oooo003o0?ooonH0oooo003o0?ooonH0oooo
001A0?ooool00000SP0000070?ooo`00@P3oool00`3o_g@000000000000200000003001d_`3oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00140?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00140?ooo`030;md000007@0_ooo00X0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01@3oool004@0oooo00<0_g@00000M02oool02P3oool00`000000oooo
0?ooo`3o0?ooohX0oooo00<000000?ooo`3oool01@3oool004@0oooo00<0_g@00000M02oool02P3o
ool00`000000oooo0?ooo`3o0?ooohX0oooo00<000000?ooo`3oool01@3oool003<0oooo00<0_g@0
0000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo00X0oooo0`00003o
0?oooeL0oooo:`3o00060?ooo`<000001`3oool004@0oooo00<0_g@00000M02oool02P3oool00`00
0000oooo0?ooo`3o0?oooe40oooo1`3o000b0?ooo`030000003oool0oooo00D0oooo00140?ooo`03
0;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`80o`00>@3oool00`000000
oooo0?ooo`050?ooo`00A03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0oooo
CP3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo00D0oooo00140?ooo`030;md0000
07@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030?l0003oool0oooo03X0oooo00<0
00000?ooo`3oool01@3oool004@0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o
0?oood`0oooo00<0o`000?ooo`3oool0>`3oool00`000000oooo0?ooo`050?ooo`00@P3oool01@3O
W4P000000000000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`030?l0003oool0
oooo03`0oooo00<000000?ooo`3oool01@3oool004<0oooo00@0oono07@0000007@0_ooo2P3oool0
0`000000oooo0?ooo`3o0?oood/0oooo00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`05
0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooodX0oooo00<0o`000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`050?ooo`00D@3oool200000?l0ooooB`3oool00`3o0000oooo0?ooo`0l0?ooo`80
00001`3oool00540oooo00<000000?ooo`3oool0o`3ooom90?ooo`030?l0003oool0oooo03h0oooo
00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom90?ooo`030?l0003o
ool0oooo03h0oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom9
0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?oo
o`3oool0o`3ooom80?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool01@3oool00540
oooo00<000000?ooo`3oool0o`3ooom80?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3o
ool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom80?ooo`030?l0003oool0oooo03l0oooo
00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom70?ooo`030?l0003o
ool0oooo0400oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom7
0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool01@3oool00540oooo0P00003o0?oo
odP0oooo00<0o`000?ooo`3oool0?`3oool2000000L0oooo001A0?ooo`030000003oool0oooo0?l0
ooooA`3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000
003oool0oooo0?l0ooooA`3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo00D0oooo
001A0?ooo`030000003oool0oooo0?l0ooooAP3oool00`3o0000oooo0?ooo`110?ooo`030000003o
ool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0ooooAP3oool00`3o0000oooo0?ooo`11
0?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0ooooAP3oool00`3o
0000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0
ooooAP3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000
003oool0oooo0?l0ooooAP3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo
001A0?ooo`030000003oool0oooo0?l0ooooAP3oool00`3o0000oooo0?ooo`110?ooo`030000003o
ool0oooo00D0oooo001A0?ooo`800000o`3ooom70?ooo`030?l0003oool0oooo0400oooo0P000007
0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooodD0oooo00<0o`000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`050?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooodD0oooo00<0o`000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`050?ooo`00=03oool0102oM000000000000018W=l40?ooo`03
0=nLB0000000B9cO00<0oooo00H0omnL04P00000000000000000B02Lgol90?ooo`030000003oool0
oooo0?l0ooooA@3oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo000b0?oo
o`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0
omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`P0oooo00<000000?ooo`3oool0o`3ooom50?oo
o`030?l0003oool0oooo0480oooo00<000000?ooo`3oool01@3oool00380oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03O
ool01`3oool00`000000oooo0?ooo`3o0?ooodD0oooo00<0o`000?ooo`3oool0@P3oool00`000000
oooo0?ooo`050?ooo`00<@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00L0
oooo00<0_g@00000M02oool00`3oool00`2oM00004RL0=ooo`070?ooo`030000003oool0oooo0?l0
ooooA@3oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo000a0?ooo`030?oo
_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@0001809cOo`020?ooo`030=nL
B000000007Bo00P0oooo00<000000?ooo`3oool0o`3ooom50?ooo`030?l0003oool0oooo0480oooo
00<000000?ooo`3oool01@3oool002@0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?oo
o`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool01`3oool01`3OW4P007Bo0?ooo`2oM0000000
0000M02oool0203oool300000?l0ooooA@3oool00`3o0000oooo0?ooo`100?ooo`<000001`3oool0
0340oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`080?ooo`050?noM00000000000
0018W03Oool02@3oool00`000000oooo0?ooo`3o0?oood@0oooo00<0o`000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`050?ooo`00<@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
00L0oooo00D0omnL04P000000000000004RLg`0:0?ooo`030000003oool0oooo0?l0ooooA03oool0
0`3o0000oooo0?ooo`130?ooo`030000003oool0oooo00D0oooo000a0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool01P3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l02@3o
ool00`000000oooo0?ooo`3o0?oood@0oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?oo
o`050?ooo`00<P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<0gia8
0000B02Lgol00P3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo0?l0ooooA03oool0
0`3o0000oooo0?ooo`130?ooo`030000003oool0oooo00D0oooo000b0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO
00P0oooo00<000000?ooo`3oool0o`3ooom40?ooo`030?l0003oool0oooo04<0oooo00<000000?oo
o`3oool01@3oool003<0oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`030?oOW0180000
B9cO0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`3o0?oood@0oooo00<0o`00
0?ooo`3oool0@`3oool00`000000oooo0?ooo`050?ooo`00=03oool0102oM000000000000000M;l:
0?ooo`060?oo_`1d000000000000000004P0W=oo2@3oool00`000000oooo0?ooo`3o0?oood@0oooo
00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`050?ooo`00D@3oool00`000000oooo0?oo
o`3o0?oood@0oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`050?ooo`00D@3oool2
00000?l0ooooA03oool00`3o0000oooo0?ooo`130?ooo`8000001`3oool00540oooo00<000000?oo
o`3oool0o`3ooom30?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool00540
oooo00<000000?ooo`3oool0o`3ooom30?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3o
ool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom30?ooo`030?l0003oool0oooo04@0oooo
00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom30?ooo`030?l0003o
ool0oooo04@0oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom3
0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?oo
o`3oool0o`3ooom30?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool00540
oooo00<000000?ooo`3oool0o`3ooom30?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3o
ool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom30?ooo`030?l0003oool0oooo04@0oooo
00<000000?ooo`3oool01@3oool00540oooo0P00003o0?oood<0oooo00<0o`000?ooo`3oool0A03o
ool2000000L0oooo001A0?ooo`030000003oool0oooo0?l0oooo@P3oool00`3o0000oooo0?ooo`15
0?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0oooo@P3oool00`3o
0000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0
oooo@P3oool00`3o0000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000
003oool0oooo0?l0oooo@P3oool00`3o0000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo
001A0?ooo`030000003oool0oooo0?l0oooo@P3oool00`3o0000oooo0?ooo`150?ooo`030000003o
ool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0oooo@P3oool00`3o0000oooo0?ooo`15
0?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0oooo@P3oool00`3o
0000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0
oooo@P3oool00`3o0000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo001A0?ooo`800000
o`3ooom30?ooo`030?l0003oool0oooo04@0oooo0P0000070?ooo`00D@3oool00`000000oooo0?oo
o`3o0?oood40oooo00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`050?ooo`00D@3oool0
0`000000oooo0?ooo`3o0?oood40oooo00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`05
0?ooo`00=03oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00<0oooo00H0oooO
09a80000000000000000M02oool90?ooo`030000003oool0oooo0?l0oooo@@3oool00`3o0000oooo
0?ooo`160?ooo`030000003oool0oooo00D0oooo000b0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0
W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0
001809cOo`P0oooo00<000000?ooo`3oool0o`3ooom10?ooo`030?l0003oool0oooo04H0oooo00<0
00000?ooo`3oool01@3oool00380oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`07
0?ooo`030;md000007@0_ooo00<0oooo00<0_g@0001d_`3oool01`3oool00`000000oooo0?ooo`3o
0?oood40oooo00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`050?ooo`00<@3oool0103o
oml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0oono07@00000M;l0103oool0
0`3OW4P0001d0;ooo`070?ooo`030000003oool0oooo0?l0oooo@@3oool00`3o0000oooo0?ooo`16
0?ooo`030000003oool0oooo00D0oooo000a0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000
M02oool01@3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo00L0oooo00<000000?oo
o`3oool0o`3ooom10?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3oool01@3oool002@0
oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@0
0000M02oool01@3oool00`3ogi`0B00004RLg`030?ooo`040?oo_`1d0000001d0;ooo`L0oooo0`00
003o0?oood40oooo00<0o`000?ooo`3oool0A03oool3000000L0oooo000a0?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol01@3oool02@3ookl0M00000000000B9`0gooo0?ooo`2oM000
000004RLg`080?ooo`030000003oool0oooo0?l0oooo@@3oool00`3o0000oooo0?ooo`160?ooo`03
0000003oool0oooo00D0oooo000a0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
1@3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool01`3oool00`000000
oooo0?ooo`3o0?oood40oooo00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`050?ooo`00
<@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd00000018W=l0
3@3oool00`000000oooo0?ooo`3o0?oood00oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo
0?ooo`050?ooo`00<P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00@0
oooO09a8000004P0W=oo303oool00`000000oooo0?ooo`3o0?oood00oooo00<0o`000?ooo`3oool0
A`3oool00`000000oooo0?ooo`050?ooo`00<P3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo00P0oooo00@0oono07@0000007@0_ooo2`3oool00`000000oooo0?ooo`3o0?oood00oooo
00<0o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`050?ooo`00<`3oool01P2oM00004RL0=oo
o`3oool0_g@0001d_`X0oooo00@0oooO09a80000000007Bo2P3oool00`000000oooo0?ooo`3o0?oo
od00oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`050?ooo`00=03oool0102oM000
000000000000M;l=0?ooo`050?oOW018000000000018W03Oool01`3oool00`000000oooo0?ooo`3o
0?oood00oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`050?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?oood00oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`050?oo
o`00D@3oool200000?l0oooo@@3oool00`3o0000oooo0?ooo`160?ooo`8000001`3oool00540oooo
00<000000?ooo`3oool0o`3ooom00?ooo`030?l0003oool0oooo04L0oooo00<000000?ooo`3oool0
1@3oool00540oooo00<000000?ooo`3oool0o`3ooom00?ooo`030?l0003oool0oooo04L0oooo00<0
00000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom00?ooo`030?l0003oool0
oooo04L0oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooom00?oo
o`030?l0003oool0oooo04L0oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3o
ool0o`3ooom00?ooo`030?l0003oool0oooo04L0oooo00<000000?ooo`3oool01@3oool00540oooo
00<000000?ooo`3oool0o`3ooolo0?ooo`030?l0003oool0oooo04P0oooo00<000000?ooo`3oool0
1@3oool00540oooo00<000000?ooo`3oool0o`3ooolo0?ooo`030?l0003oool0oooo04P0oooo00<0
00000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooolo0?ooo`030?l0003oool0
oooo04P0oooo00<000000?ooo`3oool01@3oool000l0oooo00<0okmd04RLg`3oool0?`3oool20000
0?l0oooo@03oool00`3o0000oooo0?ooo`170?ooo`8000001`3oool000l0oooo00D0okmd00000000
000004RL0=ooo`0m0?ooo`030000003oool0oooo0?l0oooo?`3oool00`3o0000oooo0?ooo`180?oo
o`030000003oool0oooo00D0oooo000?0?ooo`030?noM0000000000000<0000000<004RL0=ooo`3o
ool0>@3oool00`000000oooo0?ooo`3o0?ooocl0oooo00<0o`000?ooo`3oool0B03oool00`000000
oooo0?ooo`050?ooo`004`3oool00`3ogi`0B00000000002000000030018W03Oool0oooo03H0oooo
00<000000?ooo`3oool0o`3ooolo0?ooo`030?l0003oool0oooo04P0oooo00<000000?ooo`3oool0
1@3oool001H0oooo00@0omnL04P0000007@0_ooo=`3oool00`000000oooo0?ooo`3o0?ooocl0oooo
00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`050?ooo`00503oool0103ooml0W4P00000
B02Lgoli0?ooo`030000003oool0oooo0?l0oooo?`3oool00`3o0000oooo0?ooo`180?ooo`030000
003oool0oooo00D0oooo000?0?ooo`070?noM01d_ol0oooo0?oog`2LB000001809cOo`0k0?ooo`03
0000003oool0oooo0?l0oooo?`3oool00`3o0000oooo0?ooo`180?ooo`030000003oool0oooo00D0
oooo000?0?ooo`050?noM000000000000000B02Lgol0?@3oool00`000000oooo0?ooo`3o0?ooocl0
oooo00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`050?ooo`003`3oool00`3o_g@00000
00000003000000030018W03Oool0oooo03T0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`030?l0
003oool0oooo04P0oooo00<000000?ooo`3oool01@3oool001<0oooo00<0_g@00000000000000P00
00000`0007@0_ooo0?ooo`0f0?ooo`800000o`3ooolo0?ooo`030?l0003oool0oooo04P0oooo0P00
00070?ooo`005P3oool0103OW4P000000000M02ooolg0?ooo`030000003oool0oooo0?l0oooo?P3o
ool00`3o0000oooo0?ooo`190?ooo`030000003oool0oooo00D0oooo000C0?ooo`040?oo_`1d0000
000004RLgcX0oooo00<000000?ooo`3oool0o`3oooln0?ooo`030?l0003oool0oooo04T0oooo00<0
00000?ooo`3oool01@3oool000l0oooo00H0okmd07Boo`3OW4P000000000M02ooolO0?ooo`040;md
00000000000004RLg`@0oooo00<0gia800000018W=l01P3oool00`3o_g@0000007Boo`090?ooo`03
0000003oool0oooo0?l0oooo?P3oool00`3o0000oooo0?ooo`190?ooo`030000003oool0oooo00D0
oooo000?0?ooo`030?noM0000000B9cO0200oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo
00<0oooo00<0gia800000018W=l01P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo
0?l0oooo?P3oool00`3o0000oooo0?ooo`190?ooo`030000003oool0oooo00D0oooo000?0?ooo`03
0?noM01d_ol0oooo0200oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0;0?ooo`03
0?noM0000000M;oo00T0oooo00<000000?ooo`3oool0o`3oooln0?ooo`030?l0003oool0oooo04T0
oooo00<000000?ooo`3oool01@3oool00340oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0
W4P0001d_`060?ooo`030=nLB0000000000000D0000000<0001809cOo`3oool01P3oool00`000000
oooo0?ooo`3o0?oooch0oooo00<0o`000?ooo`3oool0B@3oool00`000000oooo0?ooo`050?ooo`00
5P3oool01P2oM000000000000000000004RL0=oooaD0oooo00<0oono07@00000M;l0103oool00`2o
M000001d0;ooo`050?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol02@3oool00`00
0000oooo0?ooo`3o0?oooch0oooo00<0o`000?ooo`3oool0B@3oool00`000000oooo0?ooo`050?oo
o`005@3oool01`3o_g@0M;oo0=nLW02oool0oono07@00000M;l0203oool00`2oM000000000000007
0000000604RLg`3oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`060?ooo`070=nL
B01d_ol0oooo0?ooo`3o_g@0000007Boo`090?ooo`<00000o`3oooln0?ooo`030?l0003oool0oooo
04L0oooo0`0000070?ooo`005@3oool0202oW9`0gooo0=nLW02oool0oooo0?oOW01807@0_ooo503o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00L0oono07@0M02oool0oooo
0?noM0000000M;oo00T0oooo00<000000?ooo`3oool0o`3oooln0?ooo`030?l0003oool0oooo04T0
oooo00<000000?ooo`3oool01@3oool001D0oooo00P0giad09cOo`3OW9`0_ooo0?ooo`3o_g@004RL
0=oooa@0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`060?noM000M;l0
oooo0?noM0000000M;oo2@3oool00`000000oooo0?ooo`3o0?oooch0oooo00<0o`000?ooo`3oool0
B@3oool00`000000oooo0?ooo`050?ooo`005@3oool01`3ooml0W4P00000M02oool0gia80000B02L
gol05@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00D0_g@007Boo`3o
_g@0000007Boo`090?ooo`030000003oool0oooo0?l0oooo?P3oool00`3o0000oooo0?ooo`190?oo
o`030000003oool0oooo00D0oooo000b0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000
M;l02@3oool01@3ookl0M01d0;noM0000000M;oo00T0oooo00<000000?ooo`3oool0o`3ooolm0?oo
o`030?l0003oool0oooo04X0oooo00<000000?ooo`3oool01@3oool001D0oooo00<0_ibL0=ooo`3o
ool00`3oool00`3OW9`0_ooo0?ooo`0D0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol02P3oool0103o_g@000000000001d_ol90?ooo`030000003oool0oooo0?l0oooo?@3oool00`3o
0000oooo0?ooo`1:0?ooo`030000003oool0oooo00D0oooo000B0?ooo`030?noM0000000000000H0
000000<0001d0;ooo`3oool05@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0oooO
09a800000000M;oo2@3oool00`000000oooo0?ooo`3o0?ooocd0oooo00<0o`000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`050?ooo`004@3oool01P3ooml0W9bo0?ooo`3oool0_ibL0=ooo`@0oooo
00<0gibL0;ooo`3oool05P3oool0102oM000000000000000M;l=0?ooo`030?oOW0180000M;oo00T0
oooo00<000000?ooo`3oool0o`3ooolm0?ooo`030?l0003oool0oooo04X0oooo00<000000?ooo`3o
ool01@3oool00140oooo00H0oono07A8W03Oool0oooo0;nLW03Ooolj0?ooo`030000003oool0oooo
0?l0oooo?@3oool00`3o0000oooo0?ooo`1:0?ooo`030000003oool0oooo00D0oooo000B0?ooo`03
0;md0000M;l0oooo03`0oooo0P00003o0?oooch0oooo00<0o`000?ooo`3oool0B@3oool2000000L0
oooo000E0?ooo`030;nLW03Oool0oooo00<0oooo00<0gibL0;ooo`3oool0<`3oool00`000000oooo
0?ooo`3o0?ooocd0oooo00<0o`000?ooo`3oool0BP3oool00`000000oooo0?ooo`050?ooo`004P3o
ool00`3o_g@0000000000006000000030000M02oool0oooo03<0oooo00<000000?ooo`3oool0o`3o
oolm0?ooo`030?l0003oool0oooo04X0oooo00<000000?ooo`3oool01@3oool00140oooo00H0oooO
09bL_`3oool0oooo0;nLW03Oool40?ooo`030=nLW02oool0oooo03<0oooo00<000000?ooo`3oool0
o`3ooolm0?ooo`030?l0003oool0oooo04X0oooo00<000000?ooo`3oool01@3oool00140oooo00H0
oono07A8W03Oool0oooo0;nLW03Ooolj0?ooo`030000003oool0oooo0?l0oooo?@3oool00`3o0000
oooo0?ooo`1:0?ooo`030000003oool0oooo00D0oooo000B0?ooo`030;md0000M;l0oooo03`0oooo
00<000000?ooo`3oool0o`3ooolm0?ooo`030?l0003oool0oooo04X0oooo00<000000?ooo`3oool0
1@3oool00540oooo00<000000?ooo`3oool0o`3ooolm0?ooo`030?l0003oool0oooo04X0oooo00<0
00000?ooo`3oool01@3oool00100oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0g
0?ooo`030000003oool0oooo0?l0oooo?03oool00`3o0000oooo0?ooo`1;0?ooo`030000003oool0
oooo00D0oooo000>0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool0=@3oool00`00
0000oooo0?ooo`3o0?oooc`0oooo00<0o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`050?oo
o`003@3oool0102oM00000000000001d_ol70?ooo`040;md00000000000004RLgcD0oooo0P00003o
0?ooocd0oooo00<0o`000?ooo`3oool0BP3oool2000000L0oooo000<0?ooo`030;md0000M;l0oooo
00/0oooo00<0oooO09a80018W=l0=03oool00`000000oooo0?ooo`3o0?oooc`0oooo00<0o`000?oo
o`3oool0B`3oool00`000000oooo0?ooo`050?ooo`002`3oool00`3o_g@0M;oo0?ooo`0>0?ooo`03
0=nLM02Lgol0oooo0380oooo00<000000?ooo`3oool0o`3oooll0?ooo`030?l0003oool0oooo04/0
oooo00<000000?ooo`3oool01@3oool000/0oooo00<0oknL09cOo`3oool0@`3oool00`000000oooo
0?ooo`3o0?oooc`0oooo00<0o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`050?ooo`002`3o
ool00`3o_g@0M;oo0?ooo`0:0?ooo`030=nLW02oool0oooo03H0oooo00<000000?ooo`3oool0o`3o
ooll0?ooo`030?l0003oool0oooo04/0oooo00<000000?ooo`3oool01@3oool000/0oooo00<0okmd
0018W03Oool02P3oool00`2oM7@0_ooo0?ooo`0f0?ooo`030000003oool0oooo0?l0oooo?03oool0
0`3o0000oooo0?ooo`1;0?ooo`030000003oool0oooo00D0oooo000;0?ooo`030?noM00000000000
00X0000000<0001d0;ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?oooc`0oooo00<0o`000?oo
o`3oool0B`3oool00`000000oooo0?ooo`050?ooo`00303oool0102oM00000000000B02Lgol80?oo
o`030;mdM02oool0oooo03H0oooo00<000000?ooo`3oool0o`3oooll0?ooo`030?l0003oool0oooo
04/0oooo00<000000?ooo`3oool01@3oool000d0oooo00@0gia8000000000000M;oo1`3oool00`3O
W9`0_ooo0?ooo`0f0?ooo`030000003oool0oooo0?l0oooo>`3oool00`3o0000oooo0?ooo`1<0?oo
o`030000003oool0oooo00D0oooo000>0?ooo`040?noM00000000000001d_cl0oooo0P00003o0?oo
oc`0oooo00<0o`000?ooo`3oool0B`3oool2000000L0oooo000?0?ooo`050?oOW018000000000018
W03Oool0?@3oool00`000000oooo0?ooo`3o0?oooc/0oooo00<0o`000?ooo`3oool0C03oool00`00
0000oooo0?ooo`050?ooo`00403oool01@3ookl0M0000000000004P0W=oo03`0oooo00<000000?oo
o`3oool0o`3ooolk0?ooo`030?l0003oool0oooo04`0oooo00<000000?ooo`3oool01@3oool00140
oooo00D0oooO09a800000000000007Boo`0N0?ooo`040;md00000000000004RLg`@0oooo00D0gia8
00000018W=l0oooo0=nLB0070000000307Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0o`3o
oolk0?ooo`030?l0003oool0oooo04`0oooo00<000000?ooo`3oool01@3oool000/0oooo00<0oknL
09cOo`3oool01@3oool0102oM000000000000000M;lK0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0
W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00<0gia8000000000000100000000`00M;l0
oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo>`3oool00`3o0000oooo0?ooo`1<0?ooo`03
0000003oool0oooo00D0oooo000;0?ooo`030?noM01d_ol0oooo00H0oooo00D0gia8000000000000
04RL0=ooo`0I0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`3OW4P0
B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`03
0?l0003oool0oooo04`0oooo00<000000?ooo`3oool01@3oool000/0oooo00<0okmd000000000000
2P0000000`0004P0W=oo0?ooo`0F0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000
M;l02@3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo>`3oool00`3o0000
oooo0?ooo`1<0?ooo`030000003oool0oooo00D0oooo000;0?ooo`030?noM01d_ol0oooo02<0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`090?ooo`030=nLB01d_ol0oooo00X0oooo
00<000000?ooo`3oool0o`3ooolk0?ooo`030?l0003oool0oooo04`0oooo00<000000?ooo`3oool0
1@3oool000/0oooo00<0oknL09cOo`3oool05P3oool00`2oM0000000000000070000000604RLg`3o
ool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`090?ooo`030?oog`2LB4P0W=oo00X0
oooo0`00003o0?ooocX0oooo00<0o`000?ooo`3oool0B`3oool3000000L0oooo000;0?ooo`030?no
M01d_ol0oooo00h0oooo00<0_gA809cOo`3oool04P3oool00`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo00X0oooo00<0omnL04P0M02oool02@3oool00`000000oooo0?ooo`3o0?ooocX0oooo
00<0o`000?ooo`3oool0C@3oool00`000000oooo0?ooo`050?ooo`00303oool00`2oM00007Bo0?oo
o`0;0?ooo`030?oog`2LB000M;oo01@0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`0;0?ooo`030;md0018W=l0oooo00P0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`030?l0003o
ool0oooo04d0oooo00<000000?ooo`3oool01@3oool000d0oooo00@0_g@0000000000000M;oo1`3o
ool0102oM000000000000018W=lE0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
2`3oool00`3OW4P0001d0;ooo`080?ooo`030000003oool0oooo0?l0oooo>P3oool00`3o0000oooo
0?ooo`1=0?ooo`030000003oool0oooo00D0oooo000>0?ooo`030=nLB0000000000000P0000000<0
001809cOo`3oool05P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00`0oooo00<0
okmd0000001d_ol0203oool00`000000oooo0?ooo`3o0?ooocX0oooo00<0o`000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`050?ooo`00403oool00`3o_g@0000000000004000000030000M02oool0
oooo01P0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`060?ooo`030?oOW02L_ol0
oooo00<0oooo00<0_g@00000001d_ol0203oool00`000000oooo0?ooo`3o0?ooocX0oooo00<0o`00
0?ooo`3oool0C@3oool00`000000oooo0?ooo`050?ooo`00<`3oool01P2oM00004RL0=ooo`3oool0
_g@0001d_`P0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo`P0oooo00<000000?oo
o`3oool0o`3ooolj0?ooo`030?l0003oool0oooo04d0oooo00<000000?ooo`3oool01@3oool003@0
oooo00@0_g@000000000000007Bo2P3oool01@2oM000000000000000000007Bo00X0oooo00<00000
0?ooo`3oool0o`3ooolj0?ooo`030?l0003oool0oooo04d0oooo00<000000?ooo`3oool01@3oool0
0540oooo00<000000?ooo`3oool0o`3oooli0?ooo`030?l0003oool0oooo04h0oooo00<000000?oo
o`3oool01@3oool00540oooo0P00003o0?ooocX0oooo00<0o`000?ooo`3oool0C@3oool2000000L0
oooo001A0?ooo`030000003oool0oooo0?l0oooo>@3oool00`3o0000oooo0?ooo`1>0?ooo`030000
003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0oooo>@3oool00`3o0000oooo0?oo
o`1>0?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0oooo>@3oool0
0`3o0000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo
0?l0oooo>@3oool00`3o0000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo001A0?ooo`03
0000003oool0oooo0?l0oooo>03oool00`3o0000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0
oooo001A0?ooo`030000003oool0oooo0?l0oooo>03oool00`3o0000oooo0?ooo`1?0?ooo`030000
003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0oooo>03oool00`3o0000oooo0?oo
o`1?0?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?l0oooo>03oool0
0`3o0000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo001A0?ooo`800000o`3oooli0?oo
o`030?l0003oool0oooo04h0oooo0P0000070?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooocL0
oooo00<0o`000?ooo`3oool0D03oool00`000000oooo0?ooo`050?ooo`00D@3oool00`000000oooo
0?ooo`3o0?ooocL0oooo00<0o`000?ooo`3oool0D03oool00`000000oooo0?ooo`050?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?ooocL0oooo00<0o`000?ooo`3oool0D03oool00`000000oooo0?oo
o`050?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooocL0oooo00<0o`000?ooo`3oool0D03oool0
0`000000oooo0?ooo`050?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooocH0oooo00<0o`000?oo
o`3oool0D@3oool00`000000oooo0?ooo`050?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooocH0
oooo00<0o`000?ooo`3oool0D@3oool00`000000oooo0?ooo`050?ooo`00D@3oool00`000000oooo
0?ooo`3o0?ooocH0oooo00<0o`000?ooo`3oool0D@3oool00`000000oooo0?ooo`050?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?ooocD0oooo00<0o`000?ooo`3oool0DP3oool00`000000oooo0?oo
o`050?ooo`00D@3oool200000?l0oooo=P3oool00`3o0000oooo0?ooo`1A0?ooo`8000001`3oool0
0540oooo00<000000?ooo`3oool0o`3ooold0?ooo`030?l0003oool0oooo05<0oooo00<000000?oo
o`3oool01@3oool00540oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030?l0003oool0oooo05@0
oooo00<000000?ooo`3oool01@3oool004<0oooo00@0_g@0000000000000B9cO2P3oool00`000000
oooo0?ooo`3o0?oooc<0oooo00<0o`000?ooo`3oool0E03oool00`000000oooo0?ooo`050?ooo`00
@@3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l02@3oool00`000000oooo0?ooo`3o0?oo
oc80oooo00<0o`000?ooo`3oool0E@3oool00`000000oooo0?ooo`050?ooo`00@@3oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00<000000?ooo`3oool0o`3ooola0?ooo`03
0?l0003oool0oooo05H0oooo00<000000?ooo`3oool01@3oool00400oooo00@0oooO09a80000B9`0
gooo0P3oool00`3ooml0W4P0001d_`080?ooo`030000003oool0oooo0?l0oooo<03oool00`3o0000
oooo0?ooo`1G0?ooo`030000003oool0oooo00D0oooo00100?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool01`3oool00`000000oooo0?ooo`3o0?ooobh0oooo0P3o001J0?ooo`030000
003oool0oooo00D0oooo00100?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01`3o
ool300000?l0oooo9`3oool70?l005X0oooo0`0000070?ooo`00@03oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`h0o`00H`3oool0
0`000000oooo0?ooo`050?ooo`00@03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
00L0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`L0o`00L@3oool00`000000oooo0?ooo`050?oo
o`00@03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00L0oooo00<000000?ooo`3o
ool0o`3oool=0?ooo`D0o`00N03oool00`000000oooo0?ooo`050?ooo`00@@3oool00`2oM00004RL
0=ooo`020?ooo`030?oog`2LB00007Bo00P0oooo00<000000?ooo`3oool0o`3oool:0?ooo`<0o`00
O@3oool00`000000oooo0?ooo`050?ooo`00@@3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo00P0oooo00<000000?ooo`3oool0o`3oool80?ooo`80o`00P03oool00`000000oooo0?oo
o`050?ooo`00@P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00<000000?ooo`3oool0
o`3oool60?ooo`80o`00PP3oool00`000000oooo0?ooo`050?ooo`00@`3oool0102oM00000000000
0000M;l:0?ooo`030000003oool0oooo0?l0oooo103oool20?l008@0oooo00<000000?ooo`3oool0
1@3oool00540oooo00<000000?ooo`3oool0o`3oool20?ooo`80o`00QP3oool00`000000oooo0?oo
o`050?ooo`00D@3oool200000?l0oooo0P3oool00`3o0000oooo0?ooo`250?ooo`8000001`3oool0
0540oooo00<000000?ooo`3oool0oP3oool20?l008T0oooo00<000000?ooo`3oool01@3oool00540
oooo00<000000?ooo`3oool0o@3oool00`3o0000oooo0?ooo`290?ooo`030000003oool0oooo00D0
oooo001A0?ooo`030000003oool0oooo0?`0oooo00<0o`000?ooo`3oool0RP3oool00`000000oooo
0?ooo`050?ooo`00D@3oool00`000000oooo0?ooo`3k0?ooo`030?l0003oool0oooo08/0oooo00<0
00000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0nP3oool00`3o0000oooo0?ooo`2<
0?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0?T0oooo00<0o`000?oo
o`3oool0S@3oool00`000000oooo0?ooo`050?ooo`00D@3oool00`000000oooo0?ooo`3h0?ooo`03
0?l0003oool0oooo08h0oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0
m`3oool00`3o0000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo001A0?ooo`800000m`3o
ool00`3o0000oooo0?ooo`2?0?ooo`8000001`3oool00540oooo00<000000?ooo`3oool0m@3oool0
0`3o0000oooo0?ooo`2A0?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo
0?D0oooo00<0o`000?ooo`3oool0T@3oool00`000000oooo0?ooo`050?ooo`00D@3oool00`000000
oooo0?ooo`3d0?ooo`030?l0003oool0oooo0980oooo00<000000?ooo`3oool01@3oool00540oooo
00<000000?ooo`3oool0l`3oool00`3o0000oooo0?ooo`2C0?ooo`030000003oool0oooo00D0oooo
001A0?ooo`030000003oool0oooo0?80oooo00<0o`000?ooo`3oool0U03oool00`000000oooo0?oo
o`050?ooo`00D@3oool00`000000oooo0?ooo`3a0?ooo`030?l0003oool0oooo09D0oooo00<00000
0?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0l03oool00`3o0000oooo0?ooo`2F0?oo
o`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0>l0oooo00<0o`000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`050?ooo`00D@3oool200000?00oooo00<0o`000?ooo`3oool0
UP3oool2000000L0oooo001A0?ooo`030000003oool0oooo0>h0oooo00<0o`000?ooo`3oool0V03o
ool00`000000oooo0?ooo`050?ooo`00D@3oool00`000000oooo0?ooo`3]0?ooo`030?l0003oool0
oooo09T0oooo00<000000?ooo`3oool01@3oool003@0oooo00@0_g@0000000000000B9cO103oool0
1@3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?oo
o`3/0?ooo`030?l0003oool0oooo09X0oooo00<000000?ooo`3oool01@3oool00380oooo00L0oooO
09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool00`3OW4P00000
0000000400000003001d_`3oool0oooo00H0oooo00<000000?ooo`3oool0k03oool00`3o0000oooo
0?ooo`2J0?ooo`030000003oool0oooo00D0oooo000b0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol0203oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00L0oooo00<0
00000?ooo`3oool0j`3oool00`3o0000oooo0?ooo`2K0?ooo`030000003oool0oooo00D0oooo000a
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02@3oool00`3OW4P0B9cO0?oo
o`0;0?ooo`030000003oool0oooo0>X0oooo00<0o`000?ooo`3oool0W03oool00`000000oooo0?oo
o`050?ooo`00<@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00T0oooo00<0gia8
07Boo`3oool02P3oool00`000000oooo0?ooo`3Y0?ooo`030?l0003oool0oooo09d0oooo00<00000
0?ooo`3oool01@3oool00340oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`090?oo
o`030?oog`2LB4P0W=oo00X0oooo0`00003Y0?ooo`030?l0003oool0oooo09/0oooo0`0000070?oo
o`00<@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00X0oooo00<0omnL04P0M02o
ool02@3oool00`000000oooo0?ooo`3X0?ooo`030?l0003oool0oooo09h0oooo00<000000?ooo`3o
ool01@3oool00340oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0;0?ooo`030;md
0018W=l0oooo00P0oooo00<000000?ooo`3oool0i`3oool00`3o0000oooo0?ooo`2O0?ooo`030000
003oool0oooo00D0oooo000a0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02`3o
ool00`3OW4P0001d0;ooo`080?ooo`030000003oool0oooo0>H0oooo00<0o`000?ooo`3oool0X03o
ool00`000000oooo0?ooo`050?ooo`00<P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo00`0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`3V0?ooo`030?l0003oool0
oooo0:00oooo00<000000?ooo`3oool01@3oool00380oooo00<0okmd0000B02Lgol00P3oool00`3o
gi`0B00007Boo`060?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`00
0000oooo0?ooo`3U0?ooo`030?l0003oool0oooo0:40oooo00<000000?ooo`3oool01@3oool003<0
oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`080;md001d_ol0oooo0?ooo`3OW4P00000
0018W03Oool80?ooo`030000003oool0oooo0>@0oooo00<0o`000?ooo`3oool0XP3oool00`000000
oooo0?ooo`050?ooo`00=03oool0102oM000000000000000M;l:0?ooo`050;md0000000000000000
0000M;l02P3oool00`000000oooo0?ooo`3S0?ooo`030?l0003oool0oooo0:<0oooo00<000000?oo
o`3oool01@3oool00540oooo00<000000?ooo`3oool0h`3oool00`3o0000oooo0?ooo`2S0?ooo`03
0000003oool0oooo00D0oooo001A0?ooo`800000h`3oool00`3o0000oooo0?ooo`2S0?ooo`800000
1`3oool00540oooo00<000000?ooo`3oool0h@3oool00`3o0000oooo0?ooo`2U0?ooo`030000003o
ool0oooo00D0oooo001A0?ooo`030000003oool0oooo0=l0oooo0P3o002X0?ooo`030000003oool0
oooo00D0oooo001A0?ooo`030000003oool0oooo0=h0oooo00<0o`000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`050?ooo`00D@3oool00`000000oooo0?ooo`3M0?ooo`030?l0003oool0oooo0:T0
oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?ooo`3oool0g03oool00`3o0000oooo
0?ooo`2Z0?ooo`030000003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0=/0oooo00<0
o`000?ooo`3oool0Z`3oool00`000000oooo0?ooo`050?ooo`00D@3oool00`000000oooo0?ooo`3J
0?ooo`030?l0003oool0oooo0:`0oooo00<000000?ooo`3oool01@3oool00540oooo00<000000?oo
o`3oool0f03oool20?l00:l0oooo00<000000?ooo`3oool01@3oool00540oooo0P00003G0?ooo`80
o`00/03oool2000000L0oooo001A0?ooo`030000003oool0oooo0=@0oooo0P3o002c0?ooo`030000
003oool0oooo00D0oooo001A0?ooo`030000003oool0oooo0=40oooo0`3o002e0?ooo`030000003o
ool0oooo00D0oooo001A0?ooo`030000003oool0oooo0<d0oooo103o002h0?ooo`030000003oool0
oooo00D0oooo001A0?ooo`030000003oool0oooo0<H0oooo1`3o002l0?ooo`030000003oool0oooo
00D0oooo001A0?ooo`030000003oool0oooo0;00oooo5P3o00330?ooo`030000003oool0oooo00D0
oooo001A0?ooo`030000003oool0oooo00H0ooooZP3o003I0?ooo`030000003oool0oooo00D0oooo
001A0?ooo`030000003oool0oooo0?l0ooooRP3oool00`000000oooo0?ooo`050?ooo`00D@3oool0
0`000000oooo0?ooo`3o0?ooohX0oooo00<000000?ooo`3oool01@3oool00540oooo0P0000070?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool03`3oool2000000L0oooo001A0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`00
D@3ooooo000008h000001`3oool00001\
\>"],
  ImageRangeCache->{{{0, 484.563}, {299.125, 0}} -> {-38.6704, -1.34232, \
0.0953372, 0.00571328}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 2\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig2x1 = 
        Plot[xx1[N], {N, nmin, nmax}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_1\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(fig2x2 = 
        Plot[xx2[N], {N, nmin, nmax}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_2\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(fig2x3 = 
        Plot[x3[N], {N, nmin, nmax}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_3\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(fig2x4 = 
        Plot[xx4[N], {N, nmin, nmax}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_4\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{fig2x1, fig2x2}, {fig2x3, fig2x4}}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] \(-0.05\)];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x1\>" <> "\<.m\>", 
        fig2x1];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x2\>" <> "\<.m\>", 
        fig2x2];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x3\>" <> "\<.m\>", 
        fig2x3];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x4\>" <> "\<.m\>", fig2x4];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.51221 0.316563 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.0147151 0.294302 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -14.0625 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .16187 -29.125 -12.2813 ]
[-0.0125 .16187 0 12.2813 ]
[-0.0125 .30902 -14.0625 -12.2813 ]
[-0.0125 .30902 0 12.2813 ]
[-0.0125 .45617 -29.125 -12.2813 ]
[-0.0125 .45617 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -24.5938 ]
[-0.01875 .30902 -29.125 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .16187 m
.00625 .16187 L
s
gsave
-0.0125 .16187 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .45617 m
.00625 .45617 L
s
gsave
-0.0125 .45617 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03793 .01472 L
.04262 .01472 L
.0522 .01472 L
.05746 .01472 L
.06244 .01472 L
.06754 .01472 L
.07295 .01472 L
.08265 .01472 L
.08804 .01472 L
.09308 .01472 L
.09858 .01472 L
.10458 .01472 L
.10996 .01472 L
.11496 .01472 L
.12013 .01472 L
.12483 .01472 L
.13379 .01472 L
.14335 .01472 L
.14823 .01472 L
.15338 .01472 L
.1626 .01472 L
.16773 .01472 L
.17252 .01472 L
.17774 .01472 L
.18342 .01472 L
.18885 .01472 L
.19387 .01472 L
.19858 .01472 L
.20377 .01472 L
.21277 .01472 L
.2177 .01472 L
.22233 .01472 L
.23216 .01472 L
.2371 .01472 L
.24251 .01472 L
.2521 .01472 L
.26101 .01472 L
.26606 .01472 L
.27154 .01472 L
.27636 .01472 L
.28147 .01472 L
.29114 .01472 L
.30006 .01472 L
.3095 .01472 L
.31479 .01472 L
.31963 .01472 L
.32903 .01472 L
Mistroke
.33795 .01472 L
.34299 .01472 L
.34756 .01472 L
.35248 .01473 L
.35779 .01473 L
.36727 .01473 L
.37619 .01474 L
.38572 .01475 L
.39113 .01476 L
.39617 .01477 L
.40635 .01479 L
.41205 .01481 L
.41725 .01483 L
.42207 .01486 L
.42719 .01489 L
.43637 .01496 L
.44147 .01501 L
.44625 .01507 L
.45146 .01515 L
.45714 .01525 L
.467 .01549 L
.47238 .01566 L
.47737 .01586 L
.48633 .01632 L
.49588 .017 L
.50123 .0175 L
.50615 .01806 L
.51145 .01878 L
.51727 .01975 L
.52707 .02189 L
.53743 .02509 L
.54762 .02948 L
.55692 .03485 L
.56765 .04298 L
.57783 .05281 L
.61612 .10267 L
.63548 .12587 L
.64651 .13599 L
.65687 .14332 L
.66672 .14856 L
.67575 .15215 L
.68566 .15505 L
.69113 .15627 L
.69611 .1572 L
.70564 .15858 L
.71582 .15962 L
.72526 .16031 L
.73418 .16081 L
.74389 .16132 L
.74878 .16164 L
Mistroke
.7516 .16186 L
.75417 .16212 L
.75876 .16273 L
.76129 .16321 L
.7637 .16379 L
.76591 .16448 L
.76796 .16527 L
.77022 .16637 L
.77262 .16787 L
.77523 .17002 L
.77798 .17304 L
.78033 .17643 L
.78291 .18124 L
.78569 .18808 L
.78867 .19783 L
.79148 .20993 L
.79404 .2239 L
.79901 .26042 L
.80441 .31487 L
.81422 .43448 L
.81875 .48397 L
.82363 .52579 L
.82642 .54402 L
.82898 .55741 L
.83159 .56822 L
.83401 .57613 L
.83637 .58222 L
.8389 .58728 L
.8417 .59153 L
.84425 .59443 L
.84691 .59671 L
.84979 .59853 L
.85251 .59979 L
.85502 .60066 L
.85747 .6013 L
.8597 .60175 L
.86228 .60215 L
.86473 .60243 L
.86698 .60263 L
.86907 .60278 L
.87136 .6029 L
.8738 .603 L
.87649 .60308 L
.87938 .60315 L
.88212 .6032 L
.88464 .60323 L
.88691 .60325 L
.88941 .60326 L
.89202 .60328 L
.89444 .60329 L
Mistroke
.89706 .6033 L
.89947 .6033 L
.90212 .60331 L
.90493 .60331 L
.90737 .60331 L
.90965 .60331 L
.91216 .60331 L
.91485 .60332 L
.91723 .60332 L
.91982 .60332 L
.92227 .60332 L
.92455 .60332 L
.9268 .60332 L
.92885 .60332 L
.9312 .60332 L
.93343 .60332 L
.93583 .60332 L
.93808 .60332 L
.94054 .60332 L
.94318 .60332 L
.94595 .60332 L
.94858 .60332 L
.95093 .60332 L
.95349 .60332 L
.9557 .60332 L
.95814 .60332 L
.96069 .60332 L
.96309 .60332 L
.96531 .60332 L
.96736 .60332 L
.9696 .60332 L
.97196 .60332 L
.97415 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.48779 0.0147151 0.97619 0.316563 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.0147151 0.588604 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -14.0625 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .13244 -29.125 -12.2813 ]
[-0.0125 .13244 0 12.2813 ]
[-0.0125 .25016 -29.125 -12.2813 ]
[-0.0125 .25016 0 12.2813 ]
[-0.0125 .36788 -29.125 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .4856 -29.125 -12.2813 ]
[-0.0125 .4856 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -24.5938 ]
[-0.01875 .30902 -29.125 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.03279 .60332 L
.0379 .60332 L
.04014 .60332 L
.04142 .60332 L
.04262 .60332 L
.04376 .60332 L
.04484 .60332 L
.04609 .60332 L
.04723 .60332 L
.0496 .60332 L
.05092 .60332 L
.05212 .60332 L
.05344 .60332 L
.05468 .60332 L
.05706 .60332 L
.05841 .60332 L
.05965 .60332 L
.06111 .60332 L
.06244 .60332 L
.06488 .60332 L
.06622 .60332 L
.0675 .60332 L
.06976 .60332 L
.07221 .60332 L
.0735 .60332 L
.07491 .60332 L
.07629 .60332 L
.07778 .60332 L
.07917 .60332 L
.08044 .60332 L
.08293 .60332 L
.0842 .60332 L
.08554 .60332 L
.08797 .60332 L
.08945 .60332 L
.09086 .60332 L
.09348 .60332 L
.09482 .60332 L
.09625 .60332 L
.09881 .60332 L
.10023 .60331 L
.10155 .60331 L
.10302 .60331 L
.10458 .60331 L
.10594 .60331 L
Mistroke
.10716 .60331 L
.10956 .6033 L
.1109 .60329 L
.11236 .60329 L
.11361 .60328 L
.11499 .60327 L
.11749 .60325 L
.11886 .60324 L
.12014 .60322 L
.12242 .60318 L
.1237 .60315 L
.12487 .60312 L
.12724 .60303 L
.12943 .60292 L
.13184 .60275 L
.13305 .60263 L
.13439 .60248 L
.13663 .60214 L
.13781 .60191 L
.13904 .60162 L
.14132 .60093 L
.1434 .60005 L
.14464 .59938 L
.14599 .5985 L
.14717 .59757 L
.14842 .59639 L
.15079 .59345 L
.15297 .58968 L
.15549 .58358 L
.15784 .57556 L
.16042 .56322 L
.16318 .54448 L
.16555 .52268 L
.16812 .49163 L
.1728 .41378 L
.18156 .22579 L
.18389 .18085 L
.1864 .13949 L
.18857 .11026 L
.19095 .08486 L
.19358 .06375 L
.19492 .05537 L
.19635 .0479 L
.19892 .03763 L
.20131 .03087 L
.20273 .02784 L
.20403 .02553 L
.20543 .0235 L
.20697 .0217 L
.20956 .01945 L
Mistroke
.21098 .01854 L
.21231 .01785 L
.2136 .01729 L
.21483 .01686 L
.21713 .01623 L
.21842 .01596 L
.21961 .01576 L
.22093 .01557 L
.22231 .01541 L
.22358 .01529 L
.22496 .01518 L
.2274 .01504 L
.22877 .01498 L
.23024 .01492 L
.23289 .01486 L
.23417 .01483 L
.23557 .01481 L
.2368 .01479 L
.2381 .01478 L
.23928 .01477 L
.24057 .01476 L
.24285 .01475 L
.24403 .01474 L
.24526 .01474 L
.24747 .01473 L
.24985 .01473 L
.2512 .01472 L
.25245 .01472 L
.25474 .01472 L
.25681 .01472 L
.25796 .01472 L
.25921 .01472 L
.26146 .01472 L
.26382 .01472 L
.26515 .01472 L
.26636 .01472 L
.26871 .01472 L
.27094 .01472 L
.27219 .01472 L
.27353 .01472 L
.27592 .01472 L
.27739 .01472 L
.27877 .01472 L
.28001 .01472 L
.28135 .01472 L
.28392 .01472 L
.28532 .01472 L
.28663 .01472 L
.28897 .01472 L
.29028 .01472 L
Mistroke
.29148 .01472 L
.29417 .01472 L
.29569 .01472 L
.29709 .01472 L
.29967 .01472 L
.30097 .01472 L
.3024 .01472 L
.30488 .01472 L
.30629 .01472 L
.30759 .01472 L
.30998 .01472 L
.31121 .01472 L
.31253 .01472 L
.31384 .01472 L
.31503 .01472 L
.31739 .01472 L
.31954 .01472 L
.32062 .01472 L
.3218 .01472 L
.32247 .01472 L
.3232 .01472 L
.32453 .01472 L
.32571 .01472 L
.32701 .01472 L
.32774 .01472 L
.32842 .01472 L
.32914 .01472 L
.32991 .01472 L
.33059 .01472 L
.33131 .01472 L
.3326 .01472 L
.3338 .01472 L
.33509 .01472 L
.33741 .01472 L
.34268 .01472 L
.34526 .01472 L
.34657 .01472 L
.348 .01472 L
.34923 .01472 L
.35054 .01472 L
.35178 .01472 L
.35291 .01472 L
.3536 .01472 L
.35433 .01472 L
.35564 .01472 L
.35644 .01472 L
.3572 .01472 L
.35861 .01472 L
.35987 .01472 L
.36051 .01472 L
Mistroke
.36121 .01472 L
.36196 .01472 L
.36267 .01472 L
.36332 .01472 L
.36401 .01472 L
.36661 .01472 L
.36798 .01472 L
.36943 .01472 L
.3707 .01472 L
.37137 .01472 L
.3721 .01472 L
.37337 .01472 L
.37456 .01472 L
.37573 .01472 L
.377 .01472 L
.37765 .01472 L
.37833 .01472 L
.37957 .01472 L
.38176 .01472 L
.383 .01472 L
.38416 .01472 L
.38542 .01472 L
.38612 .01472 L
.38676 .01472 L
.38743 .01472 L
.38817 .01472 L
.38951 .01472 L
.39184 .01472 L
.39309 .01472 L
.39443 .01472 L
.39518 .01472 L
.39587 .01472 L
.39653 .01472 L
.39722 .01472 L
.39796 .01472 L
.39864 .01472 L
.39939 .01472 L
.4002 .01472 L
.40155 .01472 L
.40228 .01472 L
.40297 .01472 L
.4042 .01472 L
.40484 .01472 L
.40554 .01472 L
.40624 .01472 L
.4069 .01472 L
.40814 .01472 L
.40884 .01472 L
.40949 .01472 L
.41025 .01472 L
Mistroke
.41097 .01472 L
.41227 .01472 L
.41345 .01472 L
.41474 .01472 L
.4161 .01472 L
.41724 .01472 L
.4185 .01472 L
.41964 .01472 L
.42071 .01472 L
.4257 .01472 L
.42813 .01472 L
.42936 .01472 L
.43071 .01472 L
.43141 .01472 L
.43217 .01472 L
.43288 .01472 L
.43354 .01472 L
.43481 .01472 L
.43546 .01472 L
.43616 .01472 L
.43746 .01472 L
.43864 .01472 L
.43929 .01472 L
.44 .01472 L
.44129 .01472 L
.44356 .01472 L
.44476 .01472 L
.44606 .01472 L
.44733 .01472 L
.44848 .01472 L
.44965 .01472 L
.45075 .01472 L
.45198 .01472 L
.45313 .01472 L
.45438 .01472 L
.45508 .01472 L
.45572 .01472 L
.45792 .01472 L
.45908 .01472 L
.4603 .01472 L
.46138 .01472 L
.46255 .01472 L
.46362 .01472 L
.46462 .01472 L
.46706 .01472 L
.46839 .01472 L
.46964 .01472 L
.47029 .01472 L
.47099 .01472 L
.47177 .01472 L
Mistroke
.47248 .01472 L
.47312 .01472 L
.47382 .01472 L
.4751 .01472 L
.47638 .01472 L
.47759 .01472 L
.47825 .01472 L
.47898 .01472 L
.48024 .01472 L
.48145 .01472 L
.48273 .01472 L
.48382 .01472 L
.48502 .01472 L
.48626 .01472 L
.48744 .01472 L
.48965 .01472 L
.49203 .01472 L
.49337 .01472 L
.49462 .01472 L
.49568 .01472 L
.49668 .01472 L
.49896 .01472 L
.50119 .01472 L
.50244 .01472 L
.50359 .01472 L
.50482 .01472 L
.50598 .01472 L
.50721 .01472 L
.50854 .01472 L
.51314 .01472 L
.51579 .01472 L
.51712 .01472 L
.51788 .01472 L
.51859 .01472 L
.51985 .01472 L
.52101 .01472 L
.52164 .01472 L
.52234 .01472 L
.52361 .01472 L
.5243 .01472 L
.52504 .01472 L
.52574 .01472 L
.52639 .01472 L
.52891 .01472 L
.53021 .01472 L
.53097 .01472 L
.53165 .01472 L
.53237 .01472 L
.53315 .01472 L
.53387 .01472 L
Mistroke
.53455 .01472 L
.53578 .01472 L
.53708 .01472 L
.53819 .01472 L
.53941 .01472 L
.54194 .01472 L
.54263 .01472 L
.54337 .01472 L
.54407 .01472 L
.5447 .01472 L
.54592 .01472 L
.54724 .01472 L
.54837 .01472 L
.54963 .01472 L
.55094 .01472 L
.55232 .01472 L
.55481 .01472 L
.55712 .01472 L
.55841 .01472 L
.55959 .01472 L
.56189 .01472 L
.56407 .01472 L
.56539 .01472 L
.56658 .01472 L
.56786 .01472 L
.56925 .01472 L
.57054 .01472 L
.57173 .01472 L
.57405 .01472 L
.57536 .01472 L
.57658 .01472 L
.57803 .01472 L
.57935 .01472 L
.58205 .01472 L
.58353 .01472 L
.58493 .01472 L
.58608 .01472 L
.58731 .01472 L
.58954 .01472 L
.5909 .01472 L
.5922 .01472 L
.59462 .01472 L
.59586 .01472 L
.59717 .01472 L
.59954 .01472 L
.60099 .01472 L
.60235 .01472 L
.6049 .01472 L
.60714 .01472 L
.60827 .01472 L
Mistroke
.60951 .01472 L
.61057 .01472 L
.61171 .01472 L
.61376 .01472 L
.61499 .01472 L
.61633 .01472 L
.6176 .01472 L
.61877 .01472 L
.61982 .01472 L
.62099 .01472 L
.62334 .01472 L
.62448 .01472 L
.62569 .01472 L
.62638 .01472 L
.62702 .01472 L
.62826 .01472 L
.63074 .01472 L
.63205 .01472 L
.63271 .01472 L
.63343 .01472 L
.63471 .01472 L
.63591 .01472 L
.63819 .01472 L
.6393 .01472 L
.64036 .01472 L
.64157 .01472 L
.64268 .01472 L
.64786 .01472 L
.64905 .01472 L
.65033 .01472 L
.65155 .01472 L
.65266 .01472 L
.65543 .01472 L
.65672 .01472 L
.65793 .01472 L
.65923 .01472 L
.65992 .01472 L
.66066 .01472 L
.66143 .01472 L
.66217 .01472 L
.66282 .01472 L
.66354 .01472 L
.66575 .01472 L
.66696 .01472 L
.66808 .01472 L
.66929 .01472 L
.66994 .01472 L
.67063 .01472 L
.67185 .01472 L
.67296 .01472 L
Mistroke
.67365 .01472 L
.67429 .01472 L
.67497 .01472 L
.67572 .01472 L
.67698 .01472 L
.67832 .01472 L
.67958 .01472 L
.68092 .01472 L
.68335 .01472 L
.68475 .01472 L
.68605 .01472 L
.68747 .01472 L
.68899 .01472 L
.69153 .01472 L
.69298 .01472 L
.69434 .01472 L
.69556 .01472 L
.69685 .01472 L
.69916 .01472 L
.70045 .01472 L
.70165 .01472 L
.70297 .01472 L
.70437 .01472 L
.70562 .01472 L
.70699 .01472 L
.70941 .01472 L
.71077 .01472 L
.71223 .01472 L
.71487 .01472 L
.71614 .01472 L
.71753 .01472 L
.71875 .01472 L
.72006 .01472 L
.72135 .01472 L
.72252 .01472 L
.7248 .01472 L
.72596 .01472 L
.72719 .01472 L
.72939 .01472 L
.73062 .01472 L
.73177 .01472 L
.7331 .01472 L
.73437 .01472 L
.73664 .01472 L
.73872 .01472 L
.74095 .01472 L
.74221 .01472 L
.74338 .01472 L
.74456 .01472 L
.7458 .01472 L
Mistroke
.74801 .01472 L
.74925 .01472 L
.7504 .01472 L
.75174 .01472 L
.75301 .01472 L
.75411 .01472 L
.7553 .01472 L
.75738 .01472 L
.75856 .01472 L
.75981 .01472 L
.76205 .01472 L
.76333 .01472 L
.7645 .01472 L
.76575 .01472 L
.76712 .01472 L
.76839 .01472 L
.76956 .01472 L
.77187 .01472 L
.77328 .01472 L
.77461 .01472 L
.77709 .01472 L
.77849 .01472 L
.77977 .01472 L
.78125 .01472 L
.78266 .01472 L
.78384 .01472 L
.78513 .01472 L
.78738 .01472 L
.78865 .01472 L
.79 .01472 L
.79117 .01472 L
.79243 .01472 L
.79359 .01472 L
.79466 .01472 L
.79676 .01472 L
.79793 .01472 L
.79921 .01472 L
.80153 .01472 L
.80293 .01472 L
.80425 .01472 L
.80545 .01472 L
.80672 .01472 L
.8081 .01472 L
.80938 .01472 L
.81075 .01472 L
.81225 .01472 L
.81355 .01472 L
.81474 .01472 L
.81611 .01472 L
.8174 .01472 L
Mistroke
.8186 .01472 L
.81971 .01472 L
.82092 .01472 L
.82221 .01472 L
.82335 .01472 L
.82459 .01472 L
.82589 .01472 L
.8271 .01472 L
.82821 .01472 L
.82926 .01472 L
.83047 .01472 L
.83158 .01472 L
.8328 .01472 L
.83409 .01472 L
.8352 .01472 L
.83642 .01472 L
.83773 .01472 L
.83913 .01472 L
.84046 .01472 L
.84167 .01472 L
.8428 .01472 L
.844 .01472 L
.84503 .01472 L
.84616 .01472 L
.84748 .01472 L
.84872 .01472 L
.84993 .01472 L
.85104 .01472 L
.85311 .01472 L
.85428 .01472 L
.85538 .01472 L
.85758 .01472 L
.85882 .01472 L
.85995 .01472 L
.86105 .01472 L
.86224 .01472 L
.86354 .01472 L
.86476 .01472 L
.86607 .01472 L
.86743 .01472 L
.8686 .01472 L
.86988 .01472 L
.87106 .01472 L
.87218 .01472 L
.87347 .01472 L
.87464 .01472 L
.87676 .01472 L
.87796 .01472 L
.87906 .01472 L
.88026 .01472 L
Mistroke
.88154 .01472 L
.88266 .01472 L
.88387 .01472 L
.88528 .01472 L
.88663 .01472 L
.88793 .01472 L
.88915 .01472 L
.89043 .01472 L
.89184 .01472 L
.89321 .01472 L
.89469 .01472 L
.896 .01472 L
.89737 .01472 L
.89854 .01472 L
.89983 .01472 L
.90114 .01472 L
.90235 .01472 L
.90366 .01472 L
.9044 .01472 L
.9051 .01472 L
.90636 .01472 L
.90751 .01472 L
.90875 .01472 L
.91008 .01472 L
.91118 .01472 L
.91236 .01472 L
.91366 .01472 L
.91486 .01472 L
.91609 .01472 L
.91724 .01472 L
.91828 .01472 L
.9194 .01472 L
.92071 .01472 L
.92193 .01472 L
.92327 .01472 L
.9247 .01472 L
.92543 .01472 L
.92621 .01472 L
.92695 .01472 L
.92764 .01472 L
.92893 .01472 L
.92958 .01472 L
.93031 .01472 L
.93152 .01472 L
.9328 .01472 L
.93347 .01472 L
.9342 .01472 L
.93548 .01472 L
.9367 .01472 L
.938 .01472 L
Mistroke
.93922 .01472 L
.94034 .01472 L
.94141 .01472 L
.94241 .01472 L
.9436 .01472 L
.94469 .01472 L
.94583 .01472 L
.94691 .01472 L
.94806 .01472 L
.94929 .01472 L
.95037 .01472 L
.95134 .01472 L
.95232 .01472 L
.95324 .01472 L
.95432 .01472 L
.95531 .01472 L
.95648 .01472 L
.95754 .01472 L
.95862 .01472 L
.95978 .01472 L
.96086 .01472 L
.96187 .01472 L
.96305 .01472 L
.96415 .01472 L
.96535 .01472 L
.96662 .01472 L
.96769 .01472 L
.96881 .01472 L
.97004 .01472 L
.97117 .01472 L
.97241 .01472 L
.97311 .01472 L
.97376 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.301471 0.51221 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.603319 0.147151 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01471 -28 -12.2813 ]
[-0.0125 .01471 0 12.2813 ]
[-0.0125 .16187 -28 -12.2813 ]
[-0.0125 .16187 0 12.2813 ]
[-0.0125 .30902 -28 -12.2813 ]
[-0.0125 .30902 0 12.2813 ]
[-0.0125 .45617 -28 -12.2813 ]
[-0.0125 .45617 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -52.5625 -24.5938 ]
[-0.01875 .30902 -28 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01471 m
.00625 .01471 L
s
gsave
-0.0125 .01471 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .16187 m
.00625 .16187 L
s
gsave
-0.0125 .16187 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .45617 m
.00625 .45617 L
s
gsave
-0.0125 .45617 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -125.875 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.03279 .60332 L
.0375 .60332 L
.03994 .60332 L
.0406 .60332 L
.04132 .60332 L
.04262 .60332 L
.04326 .60332 L
.04396 .60332 L
.04523 .60332 L
.04647 .60332 L
.04762 .60332 L
.05019 .60332 L
.05163 .60332 L
.05293 .60332 L
.05528 .60332 L
.05661 .60332 L
.05783 .60332 L
.06007 .60332 L
.0612 .60332 L
.06244 .60332 L
.0638 .60332 L
.06527 .60332 L
.06657 .60332 L
.06795 .60332 L
.06918 .60332 L
.07055 .60332 L
.07296 .60332 L
.07442 .60332 L
.07576 .60332 L
.0772 .60332 L
.07878 .60332 L
.08144 .60332 L
.08289 .60332 L
.08424 .60332 L
.08551 .60332 L
.08689 .60332 L
.0881 .60332 L
.08939 .60332 L
.09055 .60332 L
.09183 .60332 L
.09407 .60332 L
.09544 .60332 L
.09669 .60332 L
.09803 .60332 L
.0995 .60331 L
Mistroke
.10085 .60331 L
.10211 .60331 L
.10458 .60331 L
.10587 .60331 L
.10723 .60331 L
.10967 .6033 L
.11103 .60329 L
.1123 .60329 L
.11378 .60328 L
.11517 .60327 L
.11638 .60326 L
.11769 .60325 L
.11999 .60322 L
.12129 .6032 L
.12267 .60318 L
.12396 .60315 L
.12514 .60311 L
.12734 .60303 L
.12971 .6029 L
.1318 .60275 L
.134 .60253 L
.13642 .60218 L
.13866 .60172 L
.13996 .60137 L
.14113 .601 L
.14249 .60047 L
.14376 .59987 L
.14608 .59844 L
.14731 .59745 L
.14863 .59617 L
.15001 .59454 L
.15132 .59265 L
.15377 .58798 L
.15606 .58187 L
.15818 .57416 L
.16051 .5627 L
.16298 .54606 L
.16544 .52383 L
.16808 .49212 L
.17287 .41226 L
.17853 .29102 L
.1838 .18258 L
.18841 .11219 L
.191 .08438 L
.19335 .06533 L
.19593 .04996 L
.19739 .04333 L
.19873 .03828 L
.2012 .03115 L
.20244 .0284 L
Mistroke
.20381 .02589 L
.20522 .02378 L
.20655 .02214 L
.20906 .01982 L
.21046 .01885 L
.21176 .01812 L
.21328 .01742 L
.2147 .0169 L
.21595 .01653 L
.21729 .01619 L
.21964 .01575 L
.22098 .01556 L
.22238 .0154 L
.2249 .01518 L
.22613 .0151 L
.22745 .01503 L
.22862 .01498 L
.22987 .01494 L
.23222 .01487 L
.23439 .01483 L
.23559 .01481 L
.23688 .01479 L
.23922 .01477 L
.24058 .01476 L
.24201 .01475 L
.24334 .01474 L
.24456 .01474 L
.24675 .01473 L
.2491 .01473 L
.25127 .01472 L
.25332 .01472 L
.25448 .01472 L
.25571 .01472 L
.25791 .01472 L
.26029 .01472 L
.26163 .01472 L
.2629 .01472 L
.26415 .01472 L
.26548 .01472 L
.26788 .01472 L
.26935 .01472 L
.27073 .01472 L
.27197 .01472 L
.27331 .01472 L
.27451 .01472 L
.27582 .01472 L
.27648 .01472 L
.27719 .01472 L
.27847 .01472 L
.27974 .01472 L
Mistroke
.28094 .01472 L
.28202 .01472 L
.2832 .01472 L
.28435 .01472 L
.28542 .01472 L
.2866 .01472 L
.28788 .01472 L
.29284 .01472 L
.29749 .01472 L
.30174 .01472 L
.3065 .01472 L
.31158 .01472 L
.32072 .01472 L
.32631 .01472 L
.33158 .01472 L
.33628 .01472 L
.34144 .01472 L
.35119 .01472 L
.35652 .01472 L
.3615 .01472 L
.37042 .01472 L
.37997 .01473 L
.38525 .01473 L
.39014 .01474 L
.3954 .01474 L
.4012 .01475 L
.41096 .01476 L
.4163 .01477 L
.42132 .01478 L
.43115 .01482 L
.43609 .01484 L
.4415 .01486 L
.45108 .01493 L
.46 .01501 L
.46504 .01507 L
.47051 .01516 L
.47534 .01525 L
.48045 .01536 L
.49011 .01564 L
.49903 .016 L
.50846 .01654 L
.51376 .01694 L
.5186 .01737 L
.52799 .01845 L
.53691 .01986 L
.54651 .02192 L
.55674 .02493 L
.56639 .0287 L
.57514 .03302 L
.59441 .04569 L
Mistroke
.61524 .06266 L
.63482 .07797 L
.64519 .08466 L
.65629 .09044 L
.66699 .0947 L
.67674 .0976 L
.68654 .09976 L
.69582 .10125 L
.70549 .10238 L
.71576 .10323 L
.72452 .10374 L
.73418 .10417 L
.74363 .1045 L
.74878 .10468 L
.75356 .10489 L
.75877 .10518 L
.76152 .1054 L
.76445 .1057 L
.76714 .10605 L
.76968 .1065 L
.77196 .10701 L
.77443 .10772 L
.77679 .1086 L
.77933 .10983 L
.78173 .11134 L
.78391 .11309 L
.78647 .11573 L
.78926 .11949 L
.79189 .12413 L
.79433 .12958 L
.79918 .14449 L
.80194 .15582 L
.80454 .16848 L
.81539 .23876 L
.8243 .30108 L
.83383 .354 L
.83931 .37646 L
.84429 .39256 L
.84935 .40548 L
.85403 .41495 L
.85896 .42292 L
.86432 .42974 L
.87404 .43857 L
.87891 .44176 L
.88427 .44458 L
.88984 .44689 L
.89512 .44865 L
.89997 .44995 L
.90526 .45112 L
.91454 .45264 L
Mistroke
.91978 .45329 L
.92537 .45385 L
.93542 .45459 L
.94067 .45487 L
.94551 .45509 L
.95071 .45528 L
.95642 .45546 L
.96603 .45567 L
.97129 .45576 L
.97619 .45583 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.48779 0.301471 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.0147151 0.117721 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -14.0625 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .13244 -14.0625 -12.2813 ]
[-0.0125 .13244 0 12.2813 ]
[-0.0125 .25016 -14.0625 -12.2813 ]
[-0.0125 .25016 0 12.2813 ]
[-0.0125 .36788 -14.0625 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .4856 -14.0625 -12.2813 ]
[-0.0125 .4856 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -38.625 -24.5938 ]
[-0.01875 .30902 -14.0625 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03826 m
.00375 .03826 L
s
0 .0618 m
.00375 .0618 L
s
0 .08535 m
.00375 .08535 L
s
0 .10889 m
.00375 .10889 L
s
0 .15598 m
.00375 .15598 L
s
0 .17952 m
.00375 .17952 L
s
0 .20307 m
.00375 .20307 L
s
0 .22661 m
.00375 .22661 L
s
0 .2737 m
.00375 .2737 L
s
0 .29725 m
.00375 .29725 L
s
0 .32079 m
.00375 .32079 L
s
0 .34433 m
.00375 .34433 L
s
0 .39142 m
.00375 .39142 L
s
0 .41497 m
.00375 .41497 L
s
0 .43851 m
.00375 .43851 L
s
0 .46205 m
.00375 .46205 L
s
0 .50914 m
.00375 .50914 L
s
0 .53269 m
.00375 .53269 L
s
0 .55623 m
.00375 .55623 L
s
0 .57978 m
.00375 .57978 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.938 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03826 m
1 .03826 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .08535 m
1 .08535 L
s
.99625 .10889 m
1 .10889 L
s
.99625 .15598 m
1 .15598 L
s
.99625 .17952 m
1 .17952 L
s
.99625 .20307 m
1 .20307 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .2737 m
1 .2737 L
s
.99625 .29725 m
1 .29725 L
s
.99625 .32079 m
1 .32079 L
s
.99625 .34433 m
1 .34433 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .41497 m
1 .41497 L
s
.99625 .43851 m
1 .43851 L
s
.99625 .46205 m
1 .46205 L
s
.99625 .50914 m
1 .50914 L
s
.99625 .53269 m
1 .53269 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57978 m
1 .57978 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.03279 .01472 L
.0375 .01472 L
.03994 .01472 L
.0406 .01472 L
.04132 .01472 L
.04262 .01472 L
.04326 .01472 L
.04396 .01472 L
.04523 .01472 L
.04647 .01472 L
.04762 .01472 L
.05019 .01472 L
.05163 .01472 L
.05293 .01472 L
.05528 .01472 L
.05661 .01472 L
.05783 .01472 L
.06007 .01472 L
.0612 .01472 L
.06244 .01472 L
.0638 .01472 L
.06527 .01472 L
.06657 .01472 L
.06795 .01472 L
.06918 .01472 L
.07055 .01472 L
.07296 .01472 L
.07442 .01472 L
.07576 .01472 L
.0772 .01472 L
.07878 .01472 L
.08144 .01472 L
.08289 .01472 L
.08424 .01472 L
.08551 .01472 L
.08689 .01472 L
.0881 .01472 L
.08939 .01472 L
.09055 .01472 L
.09183 .01472 L
.09407 .01472 L
.09544 .01472 L
.09669 .01472 L
.09803 .01472 L
.0995 .01472 L
Mistroke
.10085 .01472 L
.10211 .01472 L
.10458 .01472 L
.10587 .01473 L
.10723 .01473 L
.10967 .01474 L
.11103 .01474 L
.1123 .01474 L
.11378 .01475 L
.11517 .01476 L
.11638 .01477 L
.11769 .01478 L
.11999 .01481 L
.12129 .01483 L
.12267 .01486 L
.12396 .01489 L
.12514 .01492 L
.12734 .015 L
.12971 .01513 L
.1318 .01528 L
.134 .01551 L
.13642 .01586 L
.13866 .01632 L
.13996 .01666 L
.14113 .01704 L
.14249 .01756 L
.14376 .01816 L
.14608 .0196 L
.14731 .02058 L
.14863 .02186 L
.15001 .0235 L
.15132 .02538 L
.15377 .03005 L
.15606 .03617 L
.15818 .04388 L
.16051 .05533 L
.16298 .07197 L
.16544 .09421 L
.16808 .12592 L
.17287 .20577 L
.17853 .32702 L
.1838 .43545 L
.18841 .50584 L
.191 .53365 L
.19335 .55271 L
.19593 .56807 L
.19739 .5747 L
.19873 .57975 L
.2012 .58688 L
.20244 .58964 L
Mistroke
.20381 .59215 L
.20522 .59426 L
.20655 .59589 L
.20906 .59822 L
.21046 .59918 L
.21176 .59992 L
.21328 .60061 L
.2147 .60113 L
.21595 .60151 L
.21729 .60184 L
.21964 .60228 L
.22098 .60247 L
.22238 .60263 L
.2249 .60285 L
.22613 .60293 L
.22745 .603 L
.22862 .60305 L
.22987 .6031 L
.23222 .60316 L
.23439 .60321 L
.23559 .60323 L
.23688 .60324 L
.23922 .60327 L
.24058 .60328 L
.24201 .60328 L
.24334 .60329 L
.24456 .6033 L
.24675 .6033 L
.2491 .60331 L
.25127 .60331 L
.25332 .60331 L
.25448 .60331 L
.25571 .60331 L
.25791 .60332 L
.25914 .60332 L
.26029 .60332 L
.26155 .60332 L
.2629 .60332 L
.26425 .60332 L
.26548 .60332 L
.26788 .60332 L
.26923 .60332 L
.27068 .60332 L
.27205 .60332 L
.27331 .60332 L
.2745 .60332 L
.27561 .60332 L
.27682 .60332 L
.27812 .60332 L
.27878 .60332 L
Mistroke
.27949 .60332 L
.28078 .60332 L
.28204 .60332 L
.2832 .60332 L
.28541 .60332 L
.28748 .60332 L
.2922 .60332 L
.29679 .60332 L
.30174 .60332 L
.31184 .60332 L
.31755 .60332 L
.32286 .60332 L
.33259 .60332 L
.33802 .60331 L
.34295 .60331 L
.34782 .60331 L
.35297 .60331 L
.36219 .60331 L
.36732 .60331 L
.37211 .6033 L
.37733 .6033 L
.38301 .60329 L
.38843 .60329 L
.39345 .60328 L
.39815 .60327 L
.40335 .60326 L
.41234 .60324 L
.4219 .60321 L
.42681 .60318 L
.43199 .60315 L
.44124 .60308 L
.4464 .60303 L
.4512 .60298 L
.45642 .6029 L
.46209 .6028 L
.46756 .60269 L
.47261 .60255 L
.47734 .6024 L
.48254 .60221 L
.49157 .60176 L
.50113 .6011 L
.50633 .60062 L
.51128 .60008 L
.52056 .59877 L
.53056 .59679 L
.53621 .59533 L
.54145 .59371 L
.55204 .58949 L
.56201 .58412 L
.57095 .57793 L
Mistroke
.58062 .56967 L
.62167 .52266 L
.63154 .51182 L
.64212 .50183 L
.65126 .49474 L
.66119 .48862 L
.67141 .48386 L
.68109 .48053 L
.6905 .47816 L
.6992 .47654 L
.70885 .47524 L
.7179 .47436 L
.72782 .47367 L
.73851 .4731 L
.74354 .47286 L
.74891 .47257 L
.75152 .4724 L
.75398 .47221 L
.75858 .47176 L
.7611 .47142 L
.76342 .47102 L
.76597 .47047 L
.76867 .4697 L
.77138 .46866 L
.77392 .46739 L
.7767 .46552 L
.77969 .46278 L
.78224 .45965 L
.78496 .45527 L
.78728 .45044 L
.78984 .44365 L
.79258 .43432 L
.79554 .42136 L
.8009 .38885 L
.806 .34642 L
.81138 .29267 L
.82101 .19583 L
.8259 .15563 L
.83053 .12515 L
.83586 .09819 L
.84071 .07979 L
.84529 .06652 L
.84952 .05694 L
.85416 .04868 L
.85907 .04186 L
.86399 .03654 L
.86849 .03268 L
.87333 .02934 L
.87861 .02646 L
.88348 .02433 L
Mistroke
.888 .02273 L
.89691 .02033 L
.90199 .01931 L
.90748 .01842 L
.91233 .01779 L
.91744 .01724 L
.92206 .01683 L
.92713 .01645 L
.93605 .01595 L
.94126 .01573 L
.94619 .01555 L
.95543 .01531 L
.96059 .0152 L
.96537 .01512 L
.97619 .01498 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{942.188, 582.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>^0002AR000`400?l00000o`00003oo`3ooooo
0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0ooooo`3ooona0?ooo`00
o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0ooooo`3ooona
0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0oooo
o`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?oo
ool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo
003o0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oo
ok40oooo003o0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3o
oooo0?oook40oooo003o0?ooool0ooooo`3ooona0?ooo`00o`3ooolD0?ooo`060;md000000000000
00000000B9`0gooo103oool00`3ookl0M01d0;ooo`3o0?ooojP0oooo00H0_g@00000000000000000
0018W03Oool40?ooo`030?oo_`1d07@0_ooo0=X0oooo003o0?oooaD0oooo00<0oono07@0M02oool0
1@3oool0103ooml0W4P00000M02ooooo0?ooojT0oooo00<0oono07@0M02oool01@3oool0103ooml0
W4P00000M02ooooJ0?ooo`00o`3ooolE0?ooo`030?oog`2LB7@0_ooo00D0oooo00@0_g@000000000
07@0_oooo`3ooonY0?ooo`030?oog`2LB7@0_ooo00D0oooo00@0_g@00000000007@0_ooofP3oool0
0?l0oooo5@3oool00`3ooml0W4Qd0;ooo`040?ooo`050=nLB0000000001804Q8M02oool0o`3ooonY
0?ooo`030?oog`2LB7@0_ooo00@0oooo00D0gia80000000004P0B4Qd0;ooo`3J0?ooo`00o`3ooolE
0?ooo`030?oog`2LB7@0_ooo00<0oooo00H0okmd0000000007@0_ooO09a8M02ooooo0?ooojT0oooo
00<0oooO09a8M02oool00`3oool01P3o_g@000000000M02ooml0W4Qd0;ooomX0oooo003o0?oooaD0
oooo00<0oooO09a8M02oool00P3oool01`3ogi`0B0000000B02Lgol0oooO09a8M02oool0o`3ooonY
0?ooo`030?oog`2LB7@0_ooo0080oooo00L0omnL04P0000004P0W=oo0?oog`2LB7@0_ooo0=X0oooo
003o0?oooaD0oooo00`0oooO09a8M02oool0oooo0?oo_`1d0000000007Boo`3oool0oooO09a8M02o
oooo0?ooojT0oooo00`0oooO09a8M02oool0oooo0?oo_`1d0000000007Boo`3oool0oooO09a8M02o
oooJ0?ooo`00o`3ooolE0?ooo`070?oog`2LB7@0_ooo0?oog`2LB000000004RLg`020?ooo`030?oo
g`2LB7@0_ooo0?l0ooooZ@3oool01`3ooml0W4Qd0;ooo`3ooml0W4P000000018W=l00P3oool00`3o
oml0W4Qd0;ooo`3J0?ooo`00o`3ooolE0?ooo`060?oog`2LB7@0_ooO09a80000000007Bo0`3oool0
0`3ooml0W4Qd0;ooo`3o0?ooojT0oooo00H0oooO09a8M02ooml0W4P000000000M;l30?ooo`030?oo
g`2LB7@0_ooo0=X0oooo003o0?oooaD0oooo00H0oooO09a8M01dM00000000018W03Oool30?ooo`03
0?oog`2LB7@0_ooo0?l0ooooZ@3oool01P3ooml0W4Qd07Ad0000000004RL0=ooo`<0oooo00<0oooO
09a8M02oool0fP3oool00?l0oooo5@3oool01@3ooml0W4P00000000007@0_ooo00@0oooo00<0oooO
09a8M02oool0o`3ooonY0?ooo`050?oog`2LB00000000000M02oool0103oool00`3ooml0W4Qd0;oo
o`3J0?ooo`00o`3ooolE0?ooo`040=nLB0000000001d0;ooo`D0oooo00<0oono07@0M02oool0o`3o
oonY0?ooo`040=nLB0000000001d0;ooo`D0oooo00<0oono07@0M02oool0fP3oool00?l0oooo4`3o
ool01@3OW4P000000000000004P0W=oo00@0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`3o0?oooj@0oooo00D0gia8000000000000001809cOo`040?ooo`030?oog`2LB00000000080
000000<004RL0=ooo`3oool0e`3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0ooooo`3o
oona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0
ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o
0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40
oooo003o0?ooool0ooooo`3ooona0?ooo`00J`3oool00`3ooml0W4P000000002000000030018W03O
ool0oooo00D0oooo00@0_g@0000000000000B9cO7`3oool00`3OW4P00000000000050000000407Bo
o`3oool0oooo0;md00<0000000<004RL0=ooo`3oool07P3oool00`3OW4P000000000000500000003
07Boo`3oool0oooo0080oooo00@0_g@0000000000000B9cO803oool00`3o_g@00000000000020000
0005001d_`3oool0oooo0?ooo`2oM0000`0000000`00B9`0gooo0?ooo`0P0?ooo`030?noM0000000
00000080000000<007Bo0?ooo`3oool00`3oool0102oM000000000000018W=lU0?ooo`060;md0000
0000000000000000B9`0gooo9@3oool0102oM000000000000018W=lZ0?ooo`060;md000000000000
00000000B9`0goooH03oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00@0
_g@0000000000000B9cO7`3oool00`3OW4P00000000000050000000407Boo`3oool0oooo0;md00<0
000000<004RL0=ooo`3oool07P3oool00`3OW4P00000000000050000000307Boo`3oool0oooo0080
oooo00@0_g@0000000000000B9cO8@3oool00`3o_g@000000000000200000005001d_`3oool0oooo
0?ooo`2oM0000`0000000`00B9`0gooo0?ooo`0O0?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool00`3oool0102oM000000000000018W=lU0?ooo`060;md00000000000000000000B9`0
gooo9@3oool0102oM000000000000018W=lZ0?ooo`060;md00000000000000000000B9`0gooo>`3o
ool006/0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`<0oooo00L0oooO09a80000
M;l0oooo0?oog`2LB00007Bo01l0oooo00<0gia8000000000000100000001@00M;l0oooo0?oog`2L
B000B9cO0080oooo00<0omnL04Q8W03Oool07`3oool00`3OW4P00000000000040000000:001d_`3o
ool0oooo0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_b40oooo00<0_g@00000M02oool00`3oool0
0`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo0280oooo00<0_g@00000M02oool0103oool0
1`3ooml0W4P0001d_`3oool0oooO09a80000M;l08`3oool00`3ooml0W4P004RLg`020?ooo`030?oO
W018B9`0gooo0280oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo02P0oooo00<0oooO09a8
0018W=l00P3oool00`3ogi`0B4RL0=ooo`1O0?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0
B02Lgol30?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0O0?ooo`030=nLB00000000000
00@0000000D007Bo0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo01l0oooo00<0gia8
000000000000100000002P00M;l0oooo0?ooo`3ooml0W4P0001d_`3oool0oooO09a80000M;lR0?oo
o`030;md000007@0_ooo00<0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0Q0?oo
o`030;md000007@0_ooo00@0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo02<0oooo00<0
oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0R0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0
W4P0001d_`0X0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0>P3oool00740oooo
00<0okmd0018W03Oool00P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo01l0oooo
00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?ooo`030?oOW018M;l0oooo01l0oooo
00<0gia804RLg`3oool00P3oool01`3ooml0W4Qd0;ooo`3oool0okmd0000B02Lgol00P3oool00`3o
gi`0B00007Boo`0P0?ooo`030;md000007@0_ooo00T0oooo00<0omnL04Qd_`3oool08@3oool00`2o
M000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0:03oool00`3o
gi`0B7Bo0?ooo`0Q0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0;@3oool00`3o
gi`0B7Bo0?ooo`1T0?ooo`030?noM000B9`0gooo0080oooo00<0okmd0000B02Lgol00P3oool00`3o
gi`0B00007Boo`0O0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01P3oool00`3o
gi`0B7Bo0?ooo`0O0?ooo`030=nLB018W=l0oooo0080oooo00L0oooO09a8M02oool0oooo0?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol08@3oool00`2oM000001d0;ooo`090?ooo`030?oOW018
M;l0oooo0200oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02P0oooo00<0omnL04Qd_`3oool08@3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02d0oooo00<0omnL04Qd_`3oool0>@3oool00740oooo00P0okmd0000B02Lgol0oooo0?oo
g`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0803oool00`3OW4P0B9cO0?ooo`0:0?ooo`03
0?oo_`1d04P0W=oo0200oooo00<0gia804RLg`3oool0103oool0103ooml0W4P00018W03Oool20?oo
o`030?oog`2LB00007Bo0200oooo00<0_g@00000M02oool02@3oool00`3ookl0M01809cOo`0Q0?oo
o`030;md000007@0_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0X
0?ooo`030?oo_`1d04P0W=oo0200oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d
_`0]0?ooo`030?oo_`1d04P0W=oo06@0oooo00P0okmd0000B02Lgol0oooo0?oog`2LB00004RL0=oo
o`80oooo00<0oooO09a80000M;l0803oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?oo_`1d04P0W=oo
0200oooo00<0gia804RLg`3oool0103oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB000
07Bo0240oooo00<0_g@00000M02oool02@3oool00`3ookl0M01809cOo`0P0?ooo`030;md000007@0
_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0X0?ooo`030?oo_`1d
04P0W=oo0200oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0]0?ooo`030?oo
_`1d04P0W=oo03T0oooo001a0?ooo`070;md000004P0W=oo0?ooo`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo0200oooo00<0gia807Boo`3oool02@3oool00`3ookl0M00007Boo`0Q0?ooo`03
0=nLB01d_ol0oooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0O0?ooo`03
0;md000007@0_ooo00T0oooo00<0oono07@0001d_ol08@3oool00`2oM000001d0;ooo`030?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool09`3oool00`3ookl0M00007Boo`0P0?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0;03oool00`3ookl0M00007Boo`1T0?ooo`07
0;md000004P0W=oo0?ooo`3ookl0M000001d_`040?ooo`030;md000007@0_ooo0200oooo00<0gia8
07Boo`3oool02@3oool00`3ookl0M00007Boo`0Q0?ooo`030=nLB01d_ol0oooo00<0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`0P0?ooo`030;md000007@0_ooo00T0oooo00<0oono
07@0001d_ol0803oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool09`3oool00`3ookl0M00007Boo`0P0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool0;03oool00`3ookl0M00007Boo`0i0?ooo`00GP3oool00`2oM0000000000000070000
000304RLg`3oool0oooo00D0oooo00P0_g@00000000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo
00<0_g@00000M02oool03`3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo
00<0oooO09a8B02Lgol02@3oool00`3o_g@0000007Boo`0@0?ooo`030;md00000000000000L00000
00<0B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`030?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool03P3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo
00<0_g@00000M02oool02@3oool00`3o_g@0000007Boo`0@0?ooo`030;md00000000000000L00000
00<0B9cO0?ooo`3oool0103oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool0503oool00`2oM0000000000000070000000304RLg`3oool0oooo00H0oooo
00<0okmd0000001d_ol0803oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo02`0oooo
00<0okmd0000001d_ol0D@3oool00`2oM0000000000000070000000304RLg`3oool0oooo00D0oooo
00P0_g@00000000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool03`3oool0
0`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol02@3oool0
0`3o_g@0000007Boo`0@0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool0
0`3ooml0W4Q809cOo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool03`3oool0
0`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0_g@00000M02oool02@3oool0
0`3o_g@0000007Boo`0?0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool0
0`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0503oool0
0`2oM0000000000000070000000304RLg`3oool0oooo00H0oooo00<0okmd0000001d_ol0803oool0
0`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo02`0oooo00<0okmd0000001d_ol0>@3oool0
06d0oooo00<0oono07@0000000000P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0
gia80000B02Lgol08@3oool00`3ogi`0B01d0;ooo`070?ooo`040?oOW0180000001d0;ooob80oooo
00<0omnL04P0M02oool00P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01l0oooo
00<0_g@00000M02oool0203oool0103ogi`0B0000000M02ooolQ0?ooo`030;md000007@0_ooo00<0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0V0?ooo`040?oOW0180000001d0;oo
ob00oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0[0?ooo`040?oOW0180000001d
0;ooof00oooo00<0oono07@0000000000P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo
00<0gia80000B02Lgol08@3oool00`3ogi`0B01d0;ooo`070?ooo`040?oOW0180000001d0;ooob80
oooo00<0omnL04P0M02oool00P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo0200
oooo00<0_g@00000M02oool0203oool0103ogi`0B0000000M02ooolP0?ooo`030;md000007@0_ooo
00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0V0?ooo`040?oOW0180000001d
0;ooob00oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0[0?ooo`040?oOW0180000
001d0;ooocT0oooo001_0?ooo`030?noM00004P0W=oo00<0oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`0R0?ooo`030;md0018W=l0oooo0080oooo00@0gmoO0?ooo`3oool0_g@00P00
00000`18W=l0oooo0?ooo`0R0?ooo`070;md0018W=l0oooo0?ooo`3ogi`0B00004RLg`040?ooo`03
0=nLB00004P0W=oo01l0oooo00<0_g@00000M02oool0103oool0103Ogml0oooo0?ooo`2oM0020000
000304RLg`3oool0oooo0200oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?oo
o`030=nLB00004P0W=oo0280oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0O
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol09`3oool0103Ogml0oooo0?ooo`2o
M0020000000304RLg`3oool0oooo0640oooo00<0okmd0000B02Lgol00`3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo0280oooo00<0_g@004RLg`3oool00P3oool0103Ogml0oooo0?oo
o`2oM0020000000304RLg`3oool0oooo0280oooo00L0_g@004RLg`3oool0oooo0?oOW0180000B9cO
00@0oooo00<0gia80000B02Lgol0803oool00`2oM000001d0;ooo`040?ooo`040=oOg`3oool0oooo
0;md0080000000<0B9cO0?ooo`3oool07`3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol08P3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3o
ool0oooo01l0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0W0?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool0>03oool00700oooo00<0omnL04Qd_`3oool00P3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo0280oooo00<0gia80000M02oool00P3o
ool00`3o_g@000000000000200000003001d_`3oool0oooo02<0oooo00L0gia80000M02oool0oooo
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool07`3oool00`2oM000001d0;ooo`040?ooo`03
0?noM000000000000080000000<007Bo0?ooo`3oool08@3oool00`2oM000001d0;ooo`030?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool08P3oool00`3o_g@000000000000200000003
001d_`3oool0oooo0200oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0W0?ooo`03
0?noM000000000000080000000<007Bo0?ooo`3oool0H`3oool00`3ogi`0B7Bo0?ooo`020?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool08P3oool00`3OW4P0001d0;ooo`020?ooo`03
0?noM000000000000080000000<007Bo0?ooo`3oool08`3oool01`3OW4P0001d0;ooo`3oool0oono
07@00000M;l0103oool00`2oM000001d0;ooo`0P0?ooo`030;md000007@0_ooo00@0oooo00<0okmd
0000000000000P0000000`00M;l0oooo0?ooo`0P0?ooo`030;md000007@0_ooo00<0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`0R0?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool0803oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02L0oooo00<0okmd
0000000000000P0000000`00M;l0oooo0?ooo`0i0?ooo`00L03oool00`3ooml0W4P004RLg`030?oo
o`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l08`3oool00`3o_g@0000007Boo`020?oo
o`050?oog`2LB00000000000M02oool09P3oool00`3o_g@0000007Boo`020?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l0803oool00`2oM000001d0;ooo`040?ooo`050?oog`2LB000
00000000M02oool0903oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0gooo0080oooo00<0
oooO09a80000M;l08`3oool01@3ooml0W4P00000000007@0_ooo02@0oooo00<0_g@00018W03Oool0
0P3oool00`3ooml0W4P0001d_`0X0?ooo`050?oog`2LB00000000000M02oool0IP3oool00`3ooml0
W4P004RLg`030?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l08`3oool00`3o_g@0
000007Boo`020?ooo`050?oog`2LB00000000000M02oool09P3oool00`3o_g@0000007Boo`020?oo
o`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l08@3oool00`2oM000001d0;ooo`040?oo
o`050?oog`2LB00000000000M02oool08`3oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l08`3oool01@3ooml0W4P00000000007@0_ooo02@0oooo00<0
_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0X0?ooo`050?oog`2LB00000000000M02oool0
?03oool006/0oooo00<0oooO09adW03Oool00P3oool00`3ooml0W4P0001d_`030?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol07@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md0000
0000M;oo00<0oooo00<0okmd001d_`3oool08@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md0000
0000M;oo0080oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0P0?ooo`030;md0000
07@0_ooo00D0oooo00<0okmd001d_`3oool09@3oool00`2oM000001d0;ooo`040?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol0903oool00`3o_g@007Bo0?ooo`0U0?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol0:@3oool00`3o_g@007Bo0?ooo`1R0?ooo`030?oog`2L
M9`0gooo0080oooo00<0oooO09a80000M;l00`3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo01d0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`030?ooo`030?noM000
M;l0oooo0240oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`020?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol08@3oool00`2oM000001d0;ooo`050?ooo`030?noM000
M;l0oooo02@0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02@0oooo00<0okmd001d_`3oool09@3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02T0oooo00<0okmd001d_`3oool0?@3oool006`0oooo00L0omnL04Q8W03Oool0oooo0=nL
B0000000M;oo00@0oooo00H0_g@00018W03Oool0oooo0;md0000M;lO0?ooo`080;md001d_ol0oooo
0?ooo`3OW4P000000018W03Oool30?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0
7@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0`3oool01P2oM00004RL0=ooo`3o
ool0_g@0001d_al0oooo00D0gia8000000000000001d0;ooo`050?ooo`030?oog`2LB00000000080
000000<0001d0;ooo`3oool07P3oool01@3OW4P000000000000007@0_ooo00D0oooo00H0_g@00018
W03Oool0oooo0;md0000M;lU0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool08@3o
ool01P2oM00004RL0=ooo`3oool0_g@0001d_bX0oooo00<0oooO09a8000000000P0000000`0007@0
_ooo0?ooo`1N0?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`040?ooo`060;md0000B9`0
gooo0?ooo`2oM00007Bo7`3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0`3oool0
0`3ooml0W4P000000002000000030000M02oool0oooo01d0oooo00P0_g@007Boo`3oool0oooo0=nL
B000000004RL0=ooo`<0oooo00H0_g@00018W03Oool0oooo0;md0000M;lP0?ooo`050=nLB0000000
00000000M02oool01@3oool00`3ooml0W4P000000002000000030000M02oool0oooo01d0oooo00D0
gia8000000000000001d0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo9@3oool00`3o
oml0W4P000000002000000030000M02oool0oooo0240oooo00H0_g@00018W03Oool0oooo0;md0000
M;lZ0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0>03oool006d0oooo00D0omnL
04P000000000000004RLg`060?ooo`040;md000000000000001d_b40oooo00D0_g@0000000000000
0000001d_`060?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool07@3oool01@2oM000
000000000000000007Bo00H0oooo00@0_g@000000000000007Bo8@3oool0103ookl0M0000000M02o
ool60?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool07P3oool0103ookl0M0000000
M02oool60?ooo`040;md000000000000001d_bL0oooo00<0okmd0000000000000P0000000`1d_ol0
oooo0?ooo`0Q0?ooo`040;md000000000000001d_b`0oooo00<0okmd0000000000000P0000000`1d
_ol0oooo0?ooo`1N0?ooo`050?oOW0180000000000000018W=l01P3oool0102oM000000000000000
M;lQ0?ooo`050;md00000000000000000000M;l01P3oool00`3o_g@00000000000020000000307Bo
o`3oool0oooo01d0oooo00D0_g@00000000000000000001d_`060?ooo`040;md000000000000001d
_b80oooo00@0oono07@0000007@0_ooo1P3oool00`3o_g@00000000000020000000307Boo`3oool0
oooo01d0oooo00@0oono07@0000007@0_ooo1P3oool0102oM000000000000000M;lW0?ooo`030?no
M000000000000080000000<0M;oo0?ooo`3oool08@3oool0102oM000000000000000M;l/0?ooo`03
0?noM000000000000080000000<0M;oo0?ooo`3oool0=`3oool00?l0ooooo`3ooooo0?oook40oooo
003o0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oo
ok40oooo003o0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3o
oooo0?oook40oooo003o0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool005P0
oooo00@0_g@0000000000000B9cOo`3ooona0?ooo`040;md00000000000004RLgol0ooooW`3oool0
05H0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00P0ooooo`00001/000003X0oooo00L0
oooO09a80000M;l0oooo0?oog`2LB00007Bo00T0ooooo`00001[000002X0oooo001F0?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0>03oool00`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo02P0oooo001E0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0g0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000
M;l0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0X0?ooo`00E@3oool00`3ookl0M000001d_`040?ooo`030;md
000007@0_ooo00H0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`030000003oool0oooo03L0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo0?l0oooo
I`3oool00`000000oooo0?ooo`0X0?ooo`00E@3oool00`3ogi`0B00004RLg`040?ooo`030;md0000
07@0_ooo00H0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`030000003oool0oooo03L0oooo00<0
omnL04P00018W=l0103oool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo0?l0ooooI`3o
ool00`000000oooo0?ooo`0X0?ooo`00E@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0
W=oo00H0oooo100000050?oooj<0o`00^`3oool4000003T0oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`070?ooo`<00000C@3ooooo0?l00180o`001P3oool3000002X0oooo001E0?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool00`000000oooo0?ooo`2Y0?oo
o``0o`00/P3oool00`000000oooo0?ooo`0g0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000
B02Lgol01`3oool00`000000oooo0?ooo`190?ooo`@0o`00o`3ooolJ0?ooo`030000003oool0oooo
02P0oooo001E0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`000000
oooo0?ooo`2e0?ooo`D0o`00[@3oool00`000000oooo0?ooo`0g0?ooo`030?oo_`1d000007Bo00@0
oooo00<0_g@00000M02oool01`3oool00`000000oooo0?ooo`180?ooo`80o`00o`3ooolM0?ooo`03
0000003oool0oooo02P0oooo001F0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0
1`3oool00`000000oooo0?ooo`2j0?ooo`@0o`00Z@3oool00`000000oooo0?ooo`0h0?ooo`030;md
0000B9`0gooo0080oooo00<0oooO09a80000M;l0203oool00`000000oooo0?ooo`170?ooo`80o`00
o`3ooolN0?ooo`030000003oool0oooo02P0oooo001F0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol01`3oool00`000000oooo0?ooo`2n0?ooo`@0o`00Y@3oool00`000000oooo0?oo
o`0h0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?oo
o`160?ooo`030?l0003oool0oooo0?l0oooo7P3oool00`000000oooo0?ooo`0X0?ooo`00E`3oool0
1P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<000000?ooo`3oool0`P3oool20?l00:<0oooo
00<000000?ooo`3oool0>@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00<000000?oo
o`3oool0AP3oool00`3o0000oooo0?ooo`3o0?oooah0oooo00<000000?ooo`3oool0:03oool005P0
oooo00@0_g@000000000000007Bo2@3oool00`000000oooo0?ooo`340?ooo`80o`00X@3oool00`00
0000oooo0?ooo`0j0?ooo`040;md000000000000001d_`X0oooo00<000000?ooo`3oool0A@3oool0
0`3o0000oooo0?ooo`3o0?oooal0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?oo
o`3oool0aP3oool20?l009l0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`150?oo
o`030?l0003oool0oooo0?l0oooo7`3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000
oooo0?ooo`380?ooo`030?l0003oool0oooo09`0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`150?ooo`030?l0003oool0oooo0?l0oooo7`3oool00`000000oooo0?ooo`0X0?ooo`00
I@3oool00`000000oooo0?ooo`390?ooo`80o`00W03oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo04D0oooo00<0o`000?ooo`3oool0o`3ooolO0?ooo`030000003oool0oooo02P0oooo
001U0?ooo`030000003oool0oooo0</0oooo00<0o`000?ooo`3oool0V@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo04@0oooo00<0o`000?ooo`3oool0o`3ooolP0?ooo`030000003o
ool0oooo02P0oooo001U0?ooo`<00000c03oool00`3o0000oooo0?ooo`2F0?ooo`<00000BP3oool2
000004D0oooo00<0o`000?ooo`3oool0o`3ooolO0?ooo`800000:P3oool006D0oooo00<000000?oo
o`3oool0c03oool00`3o0000oooo0?ooo`2H0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0A03oool00`3o0000oooo0?ooo`3o0?ooob00oooo00<000000?ooo`3oool0:03oool006D0
oooo00<000000?ooo`3oool0c@3oool00`3o0000oooo0?ooo`2G0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`3o0?ooob00oooo00<000000?ooo`3o
ool0:03oool006D0oooo00<000000?ooo`3oool0cP3oool00`3o0000oooo0?ooo`2F0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`3o0?ooob40oooo
00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0c`3oool00`3o0000oooo0?oo
o`2E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?oo
o`3o0?ooob40oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0d03oool0
0`3o0000oooo0?ooo`2D0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0@`3oool0
0`3o0000oooo0?ooo`3o0?ooob40oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?oo
o`3oool0d03oool00`3o0000oooo0?ooo`2D0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0@`3oool00`3o0000oooo0?ooo`3o0?ooob40oooo00<000000?ooo`3oool0:03oool006D0
oooo00<000000?ooo`3oool0d@3oool00`3o0000oooo0?ooo`2C0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`3o0?ooob40oooo00<000000?ooo`3o
ool0:03oool006D0oooo00<000000?ooo`3oool0dP3oool00`3o0000oooo0?ooo`2B0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`3o0?ooob40oooo
00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0d`3oool00`3o0000oooo0?oo
o`2A0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?oo
o`3o0?ooob40oooo00<000000?ooo`3oool0:03oool006D0oooo0`00003C0?ooo`030?l0003oool0
oooo08l0oooo0`00001:0?ooo`800000A03oool00`3o0000oooo0?ooo`3o0?ooob00oooo0P00000Z
0?ooo`00I@3oool00`000000oooo0?ooo`3D0?ooo`030?l0003oool0oooo0900oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0?l0oooo8P3oool00`00
0000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3E0?ooo`030?l0003oool0oooo08l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0?l0
oooo8P3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3F0?ooo`030?l0
003oool0oooo08h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`120?ooo`030?l0
003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?oo
o`3G0?ooo`030?l0003oool0oooo08d0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`120?ooo`030?l0003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool0
0`000000oooo0?ooo`3G0?ooo`030?l0003oool0oooo08d0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`0X
0?ooo`00I@3oool00`000000oooo0?ooo`3H0?ooo`030?l0003oool0oooo08`0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0?l0oooo8P3oool00`00
0000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3I0?ooo`030?l0003oool0oooo08/0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0?l0
oooo8P3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3J0?ooo`030?l0
003oool0oooo08X0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`120?ooo`030?l0
003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?oo
o`3J0?ooo`030?l0003oool0oooo08X0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`110?ooo`030?l0003oool0oooo0?l0oooo8`3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool0
0`000000oooo0?ooo`3K0?ooo`030?l0003oool0oooo08T0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0?l0oooo8`3oool00`000000oooo0?ooo`0X
0?ooo`00I@3oool300000=`0oooo00<0o`000?ooo`3oool0QP3oool3000004X0oooo0P0000120?oo
o`030?l0003oool0oooo0?l0oooo8P3oool2000002X0oooo001U0?ooo`030000003oool0oooo0=d0
oooo00<0o`000?ooo`3oool0Q`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0440
oooo00<0o`000?ooo`3oool0o`3ooolS0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000
003oool0oooo0=h0oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo0440oooo00<0o`000?ooo`3oool0o`3ooolS0?ooo`030000003oool0oooo02P0oooo
001U0?ooo`030000003oool0oooo0=l0oooo00<0o`000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0o`3ooolS0?ooo`030000003o
ool0oooo02P0oooo001U0?ooo`030000003oool0oooo0=l0oooo00<0o`000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0o`3ooolS
0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0>00oooo00<0o`000?oo
o`3oool0Q03oool00`000000oooo0?ooo`0[0?ooo`040;md00000000000004RLg`@0oooo00D0gia8
00000018W=l0oooo0=nLB0070000000307Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0@@3o
ool00`3o0000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool0:03oool006D0oooo00<00000
0?ooo`3oool0h@3oool00`3o0000oooo0?ooo`230?ooo`030000003oool0oooo02T0oooo00L0oooO
09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool00`3OW4P00000
0000000400000003001d_`3oool0oooo00H0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo
0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0hP3o
ool00`3o0000oooo0?ooo`220?ooo`030000003oool0oooo02T0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`080?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01`3o
ool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0?l0oooo8`3oool00`000000oooo0?oo
o`0X0?ooo`00I@3oool00`000000oooo0?ooo`3S0?ooo`030?l0003oool0oooo0840oooo00<00000
0?ooo`3oool0:03oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00T0oooo00<0
gia804RLg`3oool02`3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0?l0oooo903o
ool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3T0?ooo`030?l0003oool0
oooo0800oooo00<000000?ooo`3oool0:03oool00`3ookl0M000001d_`040?ooo`030;md000007@0
_ooo00T0oooo00<0gia807Boo`3oool02P3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0
oooo0?l0oooo903oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3U0?oo
o`030?l0003oool0oooo07l0oooo00<000000?ooo`3oool0:03oool00`3ogi`0B00004RLg`040?oo
o`030;md000007@0_ooo00T0oooo00<0oooO09a8B02Lgol02P3oool00`000000oooo0?ooo`100?oo
o`030?l0003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`0X0?ooo`00I@3oool300000>H0
oooo00<0o`000?ooo`3oool0O03oool3000002X0oooo00<0omnL04P00018W=l0103oool00`3OW4P0
001809cOo`0:0?ooo`030?oOW01807@0_ooo00T0oooo0`0000100?ooo`030?l0003oool0oooo0?l0
oooo8P3oool3000002X0oooo001U0?ooo`030000003oool0oooo0>L0oooo00<0o`000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0X0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
2`3oool00`2oM000B9cO0?ooo`080?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3oool0
o`3ooolT0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0>P0oooo00<0
o`000?ooo`3oool0O03oool00`000000oooo0?ooo`0X0?ooo`030?oo_`1d000007Bo00@0oooo00<0
_g@00000M02oool02`3oool00`3OW4P0001d0;ooo`080?ooo`030000003oool0oooo0400oooo00<0
o`000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0
oooo0>T0oooo0P3o001l0?ooo`030000003oool0oooo02T0oooo00<0_g@00018W03Oool00P3oool0
0`3ooml0W4P0001d_`0<0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0@03oool0
0`3o0000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?oo
o`3oool0j`3oool20?l007X0oooo00<000000?ooo`3oool0:@3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00H0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`080?oo
o`030000003oool0oooo0400oooo00<0o`000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo
02P0oooo00190?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l00P3oool01P2o
M000000000000000000004RL0=ooo`T0oooo00<000000?ooo`3oool0k@3oool20?l007P0oooo00<0
00000?ooo`3oool0:P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00P0_g@007Boo`3o
ool0oooo0=nLB000000004RL0=ooo`P0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?oo
o`3o0?ooob@0oooo00<000000?ooo`3oool0:03oool004L0oooo00L0oooO09a80000M;l0oooo0?oo
g`2LB00007Bo00<0oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8
W03Oool0203oool00`000000oooo0?ooo`3_0?ooo`80o`00MP3oool00`000000oooo0?ooo`0[0?oo
o`040;md000000000000001d_`X0oooo00D0_g@00000000000000000001d_`0:0?ooo`030000003o
ool0oooo0400oooo00<0o`000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo02P0oooo0017
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0303oool00`3ogi`0B7Bo0?ooo`07
0?ooo`030000003oool0oooo0?40oooo0`3o001c0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool0@03oool00`3o0000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool0:03oool0
04H0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0<0?ooo`030?oo_`1d04P0
W=oo00L0oooo00<000000?ooo`3oool0m03oool40?l006l0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`0X
0?ooo`00AP3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0oono07@0
001d_ol01`3oool00`000000oooo0?ooo`3h0?ooo`X0o`00I@3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo0400oooo00<0o`000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo
02P0oooo00160?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02`3oool00`3o_g@0
000007Boo`070?ooo`@00000o`3oool20?ooo`d0o`00E@3oool4000004X0oooo0P0000100?ooo`03
0?l0003oool0oooo0?l0oooo903oool2000002X0oooo00160?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol02P3oool0103ogi`0B0000000M02oool70?ooo`030000003oool0oooo0?l0
oooo403oool40?l005@0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0o0?ooo`03
0?l0003oool0oooo0?l0oooo9@3oool00`000000oooo0?ooo`0X0?ooo`00AP3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0
oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo503oool30?l00540oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0?l0oooo9@3oool00`000000
oooo0?ooo`0X0?ooo`00AP3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo
00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
5`3oool00`3o0000oooo0?ooo`1>0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
?`3oool00`3o0000oooo0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool0:03oool004L0oooo00<0
_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`050?oog`2LB00000000000M02oool0
2P3oool00`000000oooo0?ooo`3o0?oooaL0oooo00<0o`000?ooo`3oool0CP3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`030000
003oool0oooo02P0oooo00170?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203o
ool00`3o_g@007Bo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo5`3oool00`3o0000oooo0?oo
o`1>0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?oo
o`3o0?ooobD0oooo00<000000?ooo`3oool0:03oool004P0oooo00H0_g@00018W03Oool0oooo0;md
0000M;l90?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool01P3oool00`000000oooo
0?ooo`3o0?oooaP0oooo00<0o`000?ooo`3oool0C@3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo03l0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo02P0oooo
00190?ooo`040;md000000000000001d_`/0oooo00<0okmd0000000000000P0000000`1d_ol0oooo
0?ooo`050?ooo`030000003oool0oooo0?l0oooo6@3oool00`3o0000oooo0?ooo`1<0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`3o0?ooobD0oooo
00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030?l0003o
ool0oooo04`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0o0?ooo`030?l0003o
ool0oooo0?l0oooo9@3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o
0?oooaX0oooo00<0o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo03l0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo02P0oooo001U0?oo
o`030000003oool0oooo0?l0oooo6P3oool00`3o0000oooo0?ooo`1;0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`3o0?ooobD0oooo00<000000?oo
o`3oool0:03oool006D0oooo0`00003o0?oooaX0oooo00<0o`000?ooo`3oool0B@3oool3000004X0
oooo0P0000100?ooo`030?l0003oool0oooo0?l0oooo903oool2000002X0oooo001U0?ooo`030000
003oool0oooo0?l0oooo6`3oool00`3o0000oooo0?ooo`1:0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool0
:03oool006D0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030?l0003oool0oooo04X0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0?l0oooo9@3o
ool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<0o`00
0?ooo`3oool0BP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03l0oooo00<0o`00
0?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo
0?l0oooo6`3oool00`3o0000oooo0?ooo`1:0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0?P3oool00`3o0000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0:03oool006D0
oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030?l0003oool0oooo04T0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0?l0oooo9P3oool00`000000
oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<0o`000?ooo`3oool0
B@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0
o`3ooolV0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo703o
ool00`3o0000oooo0?ooo`190?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?P3o
ool00`3o0000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0:03oool006D0oooo00<00000
0?ooo`3oool0o`3ooolL0?ooo`030?l0003oool0oooo04T0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0?l0oooo9P3oool00`000000oooo0?ooo`0X
0?ooo`00I@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<0o`000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0o`3ooolV0?oo
o`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo7@3oool00`3o0000
oooo0?ooo`180?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?P3oool00`3o0000
oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0:03oool006D0oooo0`00003o0?oooad0oooo
00<0o`000?ooo`3oool0AP3oool3000004X0oooo0P00000o0?ooo`030?l0003oool0oooo0?l0oooo
9@3oool2000002X0oooo001U0?ooo`030000003oool0oooo0?l0oooo7@3oool00`3o0000oooo0?oo
o`180?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?oo
o`3o0?ooobH0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3ooolM
0?ooo`030?l0003oool0oooo04P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0n
0?ooo`030?l0003oool0oooo0?l0oooo9P3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`00
0000oooo0?ooo`3o0?oooad0oooo00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0o`3ooolV0?ooo`030000003oool0oooo
02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo7@3oool00`3o0000oooo0?ooo`180?ooo`03
0000003oool0oooo02/0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`060?oo
o`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`3o0?oo
obH0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`03
0?l0003oool0oooo04L0oooo00<000000?ooo`3oool0:@3oool01`3ooml0W4P0001d_`3oool0oooO
09a80000M;l00`3oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo00T0oooo00<00000
0?ooo`3oool0?P3oool00`3o0000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0:03oool0
06D0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`030?l0003oool0oooo04L0oooo00<000000?oo
o`3oool0:@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00/0oooo00<0okmd0000
001d_ol02@3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0?l0oooo9P3oool00`00
0000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o0?oooah0oooo00<0o`000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0X0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a8
0000M;l01P3oool00`3OW4P0000000000005000000030000B02Lgol0oooo00H0oooo00<000000?oo
o`3oool0?P3oool00`3o0000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0:03oool006D0
oooo00<000000?ooo`3oool0o`3ooolN0?ooo`030?l0003oool0oooo04L0oooo00<000000?ooo`3o
ool0:03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04Qd_`3o
ool00P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3o
ool0o`3ooolV0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo
7P3oool00`3o0000oooo0?ooo`170?ooo`030000003oool0oooo02P0oooo00<0omnL04P00018W=l0
103oool00`2oM000001d0;ooo`060?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Boo`090?oo
o`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0o`3ooolV0?ooo`030000003oool0oooo
02P0oooo000b0?ooo`030?noM01d_ol0oooo00H0oooo00<0_gAd0;ooo`3oool09`3oool300000?l0
oooo7P3oool00`3o0000oooo0?ooo`150?ooo`<000005P3oool00`3o_g@0M;oo0?ooo`060?ooo`03
0;mdM02oool0oooo00P0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`07
0?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`090?ooo`<00000?P3oool00`3o0000oooo0?ooo`3o
0?ooob@0oooo0`00000Z0?ooo`00<P3oool00`3o_g@0001d0;ooo`040?ooo`040?oog`2LB000001d
0;ooobP0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030?l0003oool0oooo04H0oooo00<00000
0?ooo`3oool0503oool00`3o_g@0001d0;ooo`040?ooo`040?oog`2LB000001d0;ooo`T0oooo00<0
omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`060?noM000M;l0oooo0?noM0000000
M;oo2@3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0?l0oooo9P3oool00`000000
oooo0?ooo`0X0?ooo`00<P3oool0103o_g@0000000000018W=l20?ooo`050?oo_`1d04P0W=oo0=nL
W02oool0:03oool00`000000oooo0?ooo`3o0?oooal0oooo00<0o`000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0D0?ooo`040?noM0000000000004RLg`80oooo00D0oono07@0B02Lgol0gibL0;oo
o`090?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0203oool01@2oM000M;oo0?no
M0000000M;oo00T0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`3o0?ooobH0oooo
00<000000?ooo`3oool0:03oool00380oooo00P0oknL09cOo`3OW4P000000000B01dM4P0001d0;oo
ob/0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030?l0003oool0oooo04H0oooo00<000000?oo
o`3oool0503oool0203o_i`0W=oo0=nLB0000000001807AdB00007@0_ooo3@3oool00`2oM00004RL
0=ooo`020?ooo`030?oog`2LB00007Bo00T0oooo00D0oono07@0M02o_g@0000007Boo`090?ooo`03
0000003oool0oooo03d0oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo02P0
oooo000e0?ooo`040?oo_`1d00000000001d_b`0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`03
0?l0003oool0oooo04H0oooo00<000000?ooo`3oool05`3oool0103ookl0M00000000000M;l>0?oo
o`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol02P3oool0103o_g@000000000001d_ol9
0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`030000003oool0
oooo02P0oooo000b0?ooo`0;0?noW02Lgol0okmd0000B02Lgol0gia80000000004P0W=oo0=nLW02o
ool0:03oool00`000000oooo0?ooo`3o0?oooal0oooo00<0o`000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0D0?ooo`0;0?noW02Lgol0okmd0000B02Lgol0gia80000000004P0W=oo0=nLW02oool0
2`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0oooO09a800000000M;oo2@3oool0
0`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0X
0?ooo`00<P3oool00`3o_g@00000001d_`030?ooo`050?oo_`1d000000000000M02oool0:03oool0
0`000000oooo0?ooo`3o0?oooal0oooo00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D
0?ooo`030?noM000000007Bo00<0oooo00D0oono07@000000000001d0;ooo`0<0?ooo`040;md0000
00000000001d_`d0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`0m0?ooo`030?l0
003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0X0?ooo`00<P3oool00`3o_g@0B9cO0?oo
o`050?ooo`030=nLB00007@0_ooo02P0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030?l0003o
ool0oooo04H0oooo00<000000?ooo`3oool0503oool00`3o_g@0B9cO0?ooo`050?ooo`030=nLB000
07@0_ooo02T0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3o0?ooobL0oooo00<0
00000?ooo`3oool0:03oool00380oooo00<0oknL09cOo`3oool01P3oool00`2oM7@0_ooo0?ooo`0W
0?ooo`030000003oool0oooo0?l0oooo7`3oool00`3o0000oooo0?ooo`160?ooo`030000003oool0
oooo01@0oooo00<0oknL09cOo`3oool01P3oool00`2oM7@0_ooo0?ooo`0X0?ooo`030000003oool0
oooo03d0oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo02P0oooo001U0?oo
o`030000003oool0oooo0?l0oooo7`3oool00`3o0000oooo0?ooo`160?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3o0?ooobL0oooo00<000000?oo
o`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`030?l0003oool0oooo04D0
oooo00<000000?ooo`3oool0703oool00`2oM000000004RLg`0Y0?ooo`030000003oool0oooo03d0
oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo02P0oooo000f0?ooo`030=nL
B01d_ol0oooo00@0oooo00<0omnL04Q8W03Oool09@3oool300000?l0oooo803oool00`3o0000oooo
0?ooo`130?ooo`<00000703oool01@3ogi`0B00007Boo`3OW4P0B9cO02T0oooo0P00000n0?ooo`03
0?l0003oool0oooo0?l0oooo9P3oool2000002X0oooo000e0?ooo`030?noM018W=l0oooo00D0oooo
00<0oooO09a8M02oool09@3oool00`000000oooo0?ooo`3o0?ooob00oooo00<0o`000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0I0?ooo`060=nLB000B9`0gooo0?ooo`3OW4P0B9cO:@3oool00`00
0000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0X0?oo
o`00=@3oool01P3OW4P0M;oo0?ooo`3ooml0W4P007Boo`<0oooo00<0gkno0=ooo`3oool0903oool0
0`000000oooo0?ooo`3o0?ooob00oooo00<0o`000?ooo`3oool0A@3oool00`000000oooo0?ooo`0H
0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0:03oool00`000000oooo0?ooo`0m
0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0X0?ooo`00=@3oool02P3O
W4P004RL0=ooo`2oM4P0W9ad0000M02oool0oooo0=nLB018W=lV0?ooo`030000003oool0oooo0?l0
oooo803oool00`3o0000oooo0?ooo`150?ooo`030000003oool0oooo01L0oooo00<0gia800000000
00001P0000000`0007@0_ooo0?ooo`0U0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3o
ool0o`3ooolW0?ooo`030000003oool0oooo02P0oooo000e0?ooo`060?oog`2LB000000007Boo`3o
ool0_g@00P0000000`18W=l0oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo803oool00`3o
0000oooo0?ooo`150?ooo`030000003oool0oooo01d0oooo00<0gia804RLg`3oool0:03oool00`00
0000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0X0?oo
o`00E`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3ooolP0?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0m0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0X0?ooo`00
F@3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo0?l0oooo803oool00`3o0000oooo
0?ooo`150?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo
0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0:03oool003<0oooo00<0okmd0000000000001000
00000`0007@0_ooo0?ooo`0L0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3o
oolP0?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`3o_g@000000000
0004000000030000M02oool0oooo02T0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?oo
o`3o0?ooobL0oooo00<000000?ooo`3oool0:03oool00340oooo00<0gia800000000000020000000
0`0004P0W=oo0?ooo`0J0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooolP
0?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool04`3oool00`3OW4P0000000000008
000000030000B02Lgol0oooo02L0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3o
0?ooobL0oooo00<000000?ooo`3oool0:03oool00300oooo00@0_g@0000000000000M;oo1`3oool0
102oM000000000000018W=lJ0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3o
oolQ0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool04P3oool0102oM00000000000
001d_ol70?ooo`040;md00000000000004RLgbL0oooo00<000000?ooo`3oool0?@3oool00`3o0000
oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0:03oool002l0oooo00<0_g@0001d_`3oool0
2`3oool00`3ooml0W4P004RLg`0I0?ooo`030;md000007@0_ooo00T0oooo1000003o0?ooob00oooo
00<0o`000?ooo`3oool0@@3oool4000001<0oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P0
04RLg`0V0?ooo`800000?P3oool00`3o0000oooo0?ooo`3o0?ooobH0oooo0P00000Z0?ooo`00;P3o
ool00`3o_g@0M;oo0?ooo`0>0?ooo`030=nLM02Lgol0oooo01L0oooo00<0_g@00000M02oool02@3o
ool00`000000oooo0?ooo`3o0?ooob40oooo00<0o`000?ooo`3oool0A03oool00`000000oooo0?oo
o`0@0?ooo`030?noM01d_ol0oooo00h0oooo00<0giad09cOo`3oool0903oool00`000000oooo0?oo
o`0m0?ooo`030?l0003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0X0?ooo`00;P3oool0
0`3o_i`0W=oo0?ooo`0X0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooolQ
0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool0403oool00`3o_i`0W=oo0?ooo`0e
0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`030000003oool0
oooo02P0oooo000^0?ooo`030?noM01d_ol0oooo00X0oooo00<0gibL0;ooo`3oool06`3oool00`2o
M000001d0;ooo`090?ooo`030000003oool0oooo0?l0oooo8@3oool00`3o0000oooo0?ooo`140?oo
o`030000003oool0oooo0100oooo00<0okmd07Boo`3oool02P3oool00`3OW9`0_ooo0?ooo`0X0?oo
o`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo
02P0oooo000^0?ooo`030?noM000B9`0gooo00X0oooo00<0_gAd0;ooo`3oool06`3oool00`2oM000
001d0;ooo`090?ooo`030000003oool0oooo0?l0oooo8@3oool00`3o0000oooo0?ooo`140?ooo`03
0000003oool0oooo0100oooo00<0okmd0018W03Oool02P3oool00`2oM7@0_ooo0?ooo`0X0?ooo`03
0000003oool0oooo03`0oooo00<0o`000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo02P0
oooo000^0?ooo`030?noM0000000000000X0000000<0001d0;ooo`3oool06`3oool00`2oM000001d
0;ooo`090?ooo`030000003oool0oooo0?l0oooo8@3oool00`3o0000oooo0?ooo`140?ooo`030000
003oool0oooo0100oooo00<0okmd0000000000002P0000000`0007@0_ooo0?ooo`0X0?ooo`030000
003oool0oooo03`0oooo00<0o`000?ooo`3oool0o`3ooolX0?ooo`030000003oool0oooo02P0oooo
000_0?ooo`040;md00000000001809cOo`P0oooo00<0_gAd0;ooo`3oool06@3oool01@3OW4P00000
0000000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`030?l0003oool0oooo04@0
oooo00<000000?ooo`3oool04@3oool0102oM00000000000B02Lgol80?ooo`030;mdM02oool0oooo
02P0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3o0?ooobP0oooo00<000000?oo
o`3oool0:03oool00300oooo00@0gia8000000000000M;oo1`3oool00`3OW9`0_ooo0?ooo`0J0?oo
o`040?oo_`1d0000001d0;ooo`T0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`030?l0003oool0
oooo04@0oooo00<000000?ooo`3oool04P3oool0103OW4P000000000001d_ol70?ooo`030=nLW02o
ool0oooo02P0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3o0?ooobP0oooo00<0
00000?ooo`3oool0:03oool00340oooo00@0okmd00000000000007Bo<03oool00`000000oooo0?oo
o`3o0?ooob40oooo00<0o`000?ooo`3oool0A03oool00`000000oooo0?ooo`0C0?ooo`040?noM000
00000000001d_c40oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3o0?ooobP0oooo
00<000000?ooo`3oool0:03oool00380oooo00D0omnL04P00000000004RL0=ooo`0^0?ooo`030000
003oool0oooo0?l0oooo8P3oool00`3o0000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo
00D0omnL04P00000000004RL0=ooo`0_0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3o
ool0o`3ooolX0?ooo`030000003oool0oooo02P0oooo000c0?ooo`050?oo_`1d000000000000B02L
gol0;@3oool00`000000oooo0?ooo`3o0?ooob80oooo00<0o`000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0E0?ooo`050?oo_`1d000000000000B02Lgol0;P3oool00`000000oooo0?ooo`0l0?oo
o`030?l0003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`0X0?ooo`00=03oool01@3ooml0
W4P0000000000000M;oo02`0oooo0`00003o0?ooob80oooo00<0o`000?ooo`3oool0@@3oool30000
01P0oooo00D0oooO09a800000000000007Boo`0]0?ooo`800000?@3oool00`3o0000oooo0?ooo`3o
0?ooobL0oooo0P00000Z0?ooo`00;P3oool00`3o_i`0W=oo0?ooo`050?ooo`040;md000000000000
001d_b/0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`030?l0003oool0oooo04<0oooo00<00000
0?ooo`3oool0403oool00`3o_i`0W=oo0?ooo`050?ooo`040;md000000000000001d_b`0oooo00<0
00000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0:03o
ool002h0oooo00<0okmd07Boo`3oool01P3oool01@3OW4P0000000000000B9`0gooo02T0oooo00<0
00000?ooo`3oool0o`3ooolR0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0403o
ool00`3o_g@0M;oo0?ooo`060?ooo`050=nLB000000000000018W03Oool0:P3oool00`000000oooo
0?ooo`0l0?ooo`030?l0003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`0X0?ooo`00;P3o
ool00`3o_g@000000000000:000000030000B02Lgol0oooo02L0oooo00<000000?ooo`3oool0o`3o
oolR0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0403oool00`3o_g@000000000
000:000000030000B02Lgol0oooo02P0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?oo
o`3o0?ooobP0oooo00<000000?ooo`3oool0:03oool002h0oooo00<0okmd07Boo`3oool0=03oool0
0`000000oooo0?ooo`3o0?ooob80oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`0@
0?ooo`030?noM01d_ol0oooo03D0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3o
0?ooobP0oooo00<000000?ooo`3oool0:03oool002h0oooo00<0oknL09cOo`3oool0=03oool00`00
0000oooo0?ooo`3o0?ooob80oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`0@0?oo
o`030?noW02Lgol0oooo01P0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`03
0?ooo`060?oog`2LB00000000000000007@0_ooo2@3oool00`000000oooo0?ooo`0l0?ooo`030?l0
003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?oo
o`3o0?ooob80oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`0Y0?ooo`070?oog`2L
B00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0oono07@00000
B9`0gooo0?ooo`3OW4P0001809cOo`P0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?oo
o`3o0?ooobP0oooo00<000000?ooo`3oool0:03oool002h0oooo00<0okmd07Boo`3oool03P3oool0
0`2oM4P0W=oo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooo8P3oool00`3o0000oooo0?ooo`13
0?ooo`030000003oool0oooo0100oooo00<0okmd07Boo`3oool03P3oool00`2oM4P0W=oo0?ooo`05
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000001d0;ooo`03
0?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3o
0?ooobP0oooo00<000000?ooo`3oool0:03oool002l0oooo00<0_g@0001d_`3oool02`3oool00`3o
oml0W4P007Boo`0U0?ooo`030000003oool0oooo0?l0oooo8P3oool00`3o0000oooo0?ooo`130?oo
o`030000003oool0oooo0140oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P007Boo`060?oo
o`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3ookl0M000001d_`04
0?ooo`030=nLB00007@0_ooo00L0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3o
0?ooobP0oooo00<000000?ooo`3oool0:03oool00300oooo00@0_g@0000000000000M;oo1`3oool0
102oM000000000000018W=lV0?ooo`030000003oool0oooo0?l0oooo8`3oool00`3o0000oooo0?oo
o`120?ooo`030000003oool0oooo0180oooo00@0_g@0000000000000M;oo1`3oool0102oM0000000
00000018W=l70?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0
B00004RLg`040?ooo`030;md000004P0W=oo00L0oooo00<000000?ooo`3oool0?03oool00`3o0000
oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0:03oool00340oooo00<0gia8000000000000
200000000`0004P0W=oo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo8`3oool00`3o0000oooo
0?ooo`120?ooo`030000003oool0oooo01<0oooo00<0gia8000000000000200000000`0004P0W=oo
0?ooo`070?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01@3oool00`3ogi`0B000
04RLg`030?ooo`040?oo_`1d0000001d0;ooo`L0oooo00<000000?ooo`3oool0?03oool00`3o0000
oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0:03oool003<0oooo00<0okmd000000000000
100000000`0007@0_ooo0?ooo`0X0?ooo`<00000o`3ooolS0?ooo`030?l0003oool0oooo0400oooo
0`00000G0?ooo`030?noM0000000000000@0000000<0001d0;ooo`3oool02@3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@0
00000018W=l0203oool3000003`0oooo00<0o`000?ooo`3oool0o`3ooolV0?ooo`<00000:P3oool0
06D0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`030?l0003oool0oooo0480oooo00<000000?oo
o`3oool0:03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00D0oooO09a8
000007@0_mnL04P000020000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0?03oool0
0`3o0000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?oo
o`3oool0o`3ooolS0?ooo`030?l0003oool0oooo0480oooo00<000000?ooo`3oool0:03oool00`3o
okl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd00000018W=l03@3oool00`00
0000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`0X0?oo
o`00I@3oool00`000000oooo0?ooo`3o0?ooob<0oooo00<0o`000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0Y0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3oool0103ooml0
W4P00000B02Lgol<0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0o`3ooolX0?oo
o`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo8`3oool00`3o0000
oooo0?ooo`120?ooo`030000003oool0oooo02T0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0
B00007Boo`080?ooo`040?oo_`1d0000001d0;ooo`/0oooo00<000000?ooo`3oool0?03oool00`3o
0000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3o
ool0o`3ooolS0?ooo`030?l0003oool0oooo0480oooo00<000000?ooo`3oool0:P3oool01P2oM000
04RL0=ooo`3oool0_g@0001d_`X0oooo00@0oooO09a80000000007Bo2P3oool00`000000oooo0?oo
o`0k0?ooo`030?l0003oool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool0
0`000000oooo0?ooo`3o0?ooob<0oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0[
0?ooo`040;md000000000000001d_`d0oooo00D0omnL04P00000000004RL0=ooo`070?ooo`030000
003oool0oooo03/0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo02P0oooo
001U0?ooo`030000003oool0oooo0?l0oooo8`3oool00`3o0000oooo0?ooo`120?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo00<0
00000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030?l0003oool0
oooo0440oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0
oooo0?l0oooo:@3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o0?oo
ob@0oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
03/0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo02P0oooo001U0?ooo`<0
0000o`3ooolT0?ooo`030?l0003oool0oooo03l0oooo0`00001:0?ooo`800000?03oool00`3o0000
oooo0?ooo`3o0?ooobP0oooo0P00000Z0?ooo`00I@3oool00`000000oooo0?ooo`3o0?ooob@0oooo
00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03/0oooo
00<0o`000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003o
ool0oooo0?l0oooo903oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool0:03o
ool006D0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030?l0003oool0oooo0440oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0?l0oooo:@3oool0
0`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0o`000?oo
o`3oool0@@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03/0oooo00<0o`000?oo
o`3oool0o`3ooolY0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0
oooo903oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0>`3oool00`3o0000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool0:03oool006D0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0?l0oooo:@3oool00`000000oooo
0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0o`000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0o`3o
oolY0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo903oool0
0`3o0000oooo0?ooo`110?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0>`3oool0
0`3o0000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?oo
o`3oool0o`3ooolU0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`0X0?oo
o`00I@3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3oool0@03oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`03
0000003oool0oooo02P0oooo001U0?ooo`<00000o`3ooolU0?ooo`030?l0003oool0oooo03h0oooo
0`00001:0?ooo`800000?03oool00`3o0000oooo0?ooo`3o0?ooobP0oooo0P00000Z0?ooo`00I@3o
ool00`000000oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0o`3ooolY0?ooo`030000003o
ool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo9@3oool00`3o0000oooo0?ooo`10
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o
0?ooobX0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3ooolU0?oo
o`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0j0?oo
o`030?l0003oool0oooo0?l0oooo:P3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000
oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo03X0oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`030000003oool0oooo02P0
oooo00180?ooo`030?noM000000000000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO
0080oooo00H0_g@000000000000000000018W03Oool90?ooo`030000003oool0oooo0?l0oooo9@3o
ool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0>P3o
ool00`3o0000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0:03oool004X0oooo00<0_g@0
0000M02oool0103oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL
0=ooo`080?ooo`030000003oool0oooo0?l0oooo9@3oool00`3o0000oooo0?ooo`100?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo
00<000000?ooo`3oool0:03oool004X0oooo00<0_g@00000M02oool03P3oool00`3ogi`0B7Bo0?oo
o`070?ooo`030000003oool0oooo0?l0oooo9@3oool00`3o0000oooo0?ooo`100?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo00<0
00000?ooo`3oool0:03oool004X0oooo00<0_g@00000M02oool03P3oool00`3ookl0M01809cOo`07
0?ooo`030000003oool0oooo0?l0oooo9@3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo00<00000
0?ooo`3oool0:03oool004X0oooo00<0_g@00000M02oool03P3oool00`3ookl0M00007Boo`070?oo
o`030000003oool0oooo0?l0oooo9@3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo00<000000?oo
o`3oool0:03oool004X0oooo00<0_g@00000M02oool03P3oool00`3o_g@0000007Boo`070?ooo`03
0000003oool0oooo0?l0oooo9@3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3o
ool0:03oool004X0oooo00<0_g@00000M02oool03@3oool0103ogi`0B0000000M02oool70?ooo`@0
0000o`3ooolT0?ooo`030?l0003oool0oooo03d0oooo1000001:0?ooo`800000>`3oool00`3o0000
oooo0?ooo`3o0?ooobT0oooo0P00000Z0?ooo`00BP3oool00`2oM000001d0;ooo`090?ooo`040=oO
g`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooobD0
oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03X0
oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`030000003oool0oooo02P0oooo001:0?ooo`030;md
000007@0_ooo00T0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030000
003oool0oooo0?l0oooo9P3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0
:03oool004X0oooo00<0_g@00000M02oool02@3oool01@3ooml0W4P00000000007@0_ooo00X0oooo
00<000000?ooo`3oool0o`3ooolV0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00`000000oooo
0?ooo`0X0?ooo`00BP3oool00`2oM000001d0;ooo`0:0?ooo`030?noM000M;l0oooo00/0oooo00<0
00000?ooo`3oool0o`3ooolV0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00`000000oooo0?oo
o`0X0?ooo`00B03oool01@3OW4P000000000000007@0_ooo00X0oooo00<0oooO09a8000000000P00
00000`0007@0_ooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo9P3oool00`3o0000oooo0?oo
o`0o0?ooo`030000003oool0oooo02/0oooo00@0_g@0000000000000B9cO103oool00`3OW4P00000
04RLg`030?ooo`060?oOW018000000000000000004P0W=oo2@3oool00`000000oooo0?ooo`0i0?oo
o`030?l0003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0X0?ooo`00B@3oool0103ookl0
M0000000M02oool;0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooobH0oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Y0?oo
o`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0
omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`P0oooo00<000000?ooo`3oool0>@3oool00`3o
0000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3o
ool0o`3ooolV0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0:@3oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0_g@00000M02oool00`3oool00`3OW4P0
04RL0=ooo`070?ooo`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`03
0000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo9P3oool00`3o0000oooo
0?ooo`0o0?ooo`030000003oool0oooo02P0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0
W4P0001d_`070?ooo`030;md000007@0_ooo00<0oooo00<0_g@00018W03Oool01`3oool00`000000
oooo0?ooo`0i0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0X0?ooo`00
I@3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0X0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@00018
09cOo`020?ooo`030=nLB000000007Bo00P0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo
0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0:03oool006D0oooo0`00003o0?ooobH0oooo00<0
o`000?ooo`3oool0?@3oool3000002X0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`070?ooo`070=nLB000M;l0oooo0;md00000000001d0;ooo`080?ooo`<00000>@3oool00`3o0000
oooo0?ooo`3o0?ooobT0oooo0`00000Z0?ooo`00I@3oool00`000000oooo0?ooo`3o0?ooobH0oooo
00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0X0?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol0203oool01@3o_g@0000000000000B9`0gooo00T0oooo00<000000?ooo`3o
ool0>@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0:03oool006D0oooo
00<000000?ooo`3oool0o`3ooolV0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0
:03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL04P000000000
000004RLg`0:0?ooo`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`03
0000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo9P3oool00`3o0000oooo
0?ooo`0o0?ooo`030000003oool0oooo02P0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`060?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`090?ooo`030000003oool0oooo
03T0oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`030000003oool0oooo02P0oooo001U0?ooo`03
0000003oool0oooo0?l0oooo9`3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo02T0
oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`030=nLB00004P0W=oo0080
oooo00<0oooO09a8001d_ol0203oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo0?l0
oooo:`3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o0?ooobL0oooo
00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Y0?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO00P0oooo
00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0
:03oool006D0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030?l0003oool0oooo03h0oooo00<0
00000?ooo`3oool0:P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL04P00018
W=l00P3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo03T0oooo00<0o`000?ooo`3o
ool0o`3oool[0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo
9`3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0oooo02/0oooo00@0_g@0000000000000
07Bo2P3oool01P3ookl0M000000000000000001809cOo`T0oooo00<000000?ooo`3oool0>@3oool0
0`3o0000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?oo
o`3oool0o`3ooolW0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0i0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0X0?oo
o`00I@3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<0o`000?ooo`3oool0?P3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`03
0000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo9`3oool00`3o0000oooo
0?ooo`0n0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo
0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0:03oool006D0oooo0`00003o0?ooobL0oooo00<0
o`000?ooo`3oool0?03oool3000004X0oooo0P00000j0?ooo`030?l0003oool0oooo0?l0oooo:P3o
ool2000002X0oooo001U0?ooo`030000003oool0oooo0?l0oooo:03oool00`3o0000oooo0?ooo`0m
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`3o
0?ooob/0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3ooolX0?oo
o`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0i0?oo
o`030?l0003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000
oooo0?ooo`3o0?ooobP0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo03T0oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`030000003oool0oooo02P0
oooo001U0?ooo`030000003oool0oooo0?l0oooo:03oool00`3o0000oooo0?ooo`0m0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo
00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030?l0003o
ool0oooo03d0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0i0?ooo`030?l0003o
ool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o
0?ooobP0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo03T0oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`030000003oool0oooo02P0oooo001U0?oo
o`030000003oool0oooo0?l0oooo:03oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo00<000000?oo
o`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030?l0003oool0oooo03`0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0?l0
oooo;03oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o0?ooobT0oooo
00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03P0oooo
00<0o`000?ooo`3oool0o`3oool/0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003o
ool0oooo0?l0oooo:@3oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool0>03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool0:03o
ool006D0oooo0`00003o0?ooobT0oooo00<0o`000?ooo`3oool0>P3oool3000004X0oooo0P00000i
0?ooo`030?l0003oool0oooo0?l0oooo:`3oool2000002X0oooo001U0?ooo`030000003oool0oooo
0?l0oooo:@3oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0>03oool00`3o0000oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool0:03oool006D0
oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0?l0oooo;03oool00`000000
oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<0o`000?ooo`3oool0
>`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool0
o`3oool]0?ooo`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo:P3o
ool00`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0=`3o
ool00`3o0000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0:03oool006D0oooo00<00000
0?ooo`3oool0o`3ooolZ0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0X
0?ooo`00I@3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<0o`000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool0o`3oool]0?oo
o`030000003oool0oooo02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo:`3oool00`3o0000
oooo0?ooo`0j0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0=`3oool00`3o0000
oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0
o`3oool[0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0g0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0X0?ooo`00I@3o
ool00`000000oooo0?ooo`3o0?ooob/0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool0o`3oool^0?ooo`030000003o
ool0oooo02P0oooo001U0?ooo`<00000o`3oool/0?ooo`030?l0003oool0oooo03L0oooo0`00001:
0?ooo`800000=`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo0P00000Z0?ooo`00I@3oool00`00
0000oooo0?ooo`3o0?ooob`0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo
02P0oooo001U0?ooo`030000003oool0oooo0?l0oooo;03oool00`3o0000oooo0?ooo`0i0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`3o0?ooobh0
oooo00<000000?ooo`3oool0:03oool006D0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030?l0
003oool0oooo03P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0e0?ooo`030?l0
003oool0oooo0?l0oooo;`3oool00`000000oooo0?ooo`0X0?ooo`00I@3oool00`000000oooo0?oo
o`3o0?ooobd0oooo00<0o`000?ooo`3oool0>03oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo03D0oooo00<0o`000?ooo`3oool0o`3oool_0?ooo`030000003oool0oooo02P0oooo001E
0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`3o
0?ooobh0oooo00<0o`000?ooo`3oool0=`3oool00`000000oooo0?ooo`0i0?ooo`030?noM0000000
00000080000000<007Bo0?ooo`3oool01`3oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0
oooo0?l0oooo<03oool00`000000oooo0?ooo`0X0?ooo`00EP3oool00`3OW4P00000000000040000
0003001d_`3oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool^0?ooo`030?l0003oool0oooo
03L0oooo00<000000?ooo`3oool0>`3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo
03@0oooo00<0o`000?ooo`3oool0o`3oool`0?ooo`030000003oool0oooo02P0oooo001G0?ooo`03
0=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01P3oool00`000000oooo0?ooo`3o0?ooobl0
oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`0k0?ooo`030;md000007@0_ooo00X0
oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`3o0?oooc40oooo00<000000?ooo`3o
ool0:03oool005P0oooo00<0gia804RLg`3oool02P3oool00`000000oooo0?ooo`3o0?ooobl0oooo
0P3o000g0?ooo`030000003oool0oooo03/0oooo00<0_g@00000M02oool02P3oool00`000000oooo
0?ooo`0b0?ooo`030?l0003oool0oooo0?l0oooo<P3oool00`000000oooo0?ooo`0X0?ooo`00F@3o
ool00`3OW4P0M;oo0?ooo`090?ooo`030000003oool0oooo0?l0oooo<@3oool00`3o0000oooo0?oo
o`0d0?ooo`030000003oool0oooo03/0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?oo
o`0a0?ooo`80o`00o`3ooold0?ooo`030000003oool0oooo02P0oooo001I0?ooo`030?oog`2LB4P0
W=oo00T0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`H0o`00<03oool00`000000oooo0?ooo`0k
0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0;@3oool50?l00?l0oooo=@3oool0
0`000000oooo0?ooo`0X0?ooo`00FP3oool00`3ogi`0B01d0;ooo`080?ooo`@00000o`3ooolg0?oo
obP0o`001@3oool4000003d0oooo00<0_g@00000M02oool02P3oool3000000D0oooo:@3o003o0?oo
ocL0oooo0`00000Z0?ooo`00F`3oool00`2oM000B9cO0?ooo`070?ooo`030000003oool0oooo0?l0
ooooJ03oool00`000000oooo0?ooo`0k0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3o
ool0o`3ooomW0?ooo`030000003oool0oooo02P0oooo001K0?ooo`030=nLB00007@0_ooo00L0oooo
00<000000?ooo`3oool0o`3ooomX0?ooo`030000003oool0oooo03/0oooo00<0_g@00000M02oool0
2P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0:03oool005/0oooo00<0
okmd0000001d_ol01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0k0?ooo`030;md000007@0_ooo00X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0:03oool005D0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000002oM00000000080000000T004RL0=ooo`3oool0oooo0000003oool0oono07@0M02o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0k0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00H0_g@000000000
000000000018W00000040?ooo`050?oo_`1d07@0_ooo0?ooo`0000002@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0X0?ooo`00EP3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo1`3ooooo000006`0
0000>`3oool01@3OW4P000000000000007@0_ooo00X0ooooo`00001[000002X0oooo001G0?ooo`05
0;md00000000000000000000M;l0]`3oool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000001d
0;ooond0oooo00@0oono07@0000007@0_ooo/@3oool00`3ooml0W4Qd0;ooo`050?ooo`040;md0000
0000001d0;ooon40oooo003o0?oooa@0oooo00<0oooO09a8M02oool0103oool01@3OW4P000000000
B018B7@0_ooo0?l0ooooX`3oool00`3ooml0W4Qd0;ooo`040?ooo`050=nLB0000000001804Q8M02o
ool0h@3oool00?l0oooo503oool00`3ooml0W4Qd0;ooo`030?ooo`060?noM0000000001d0;oog`2L
B7@0_oooo`3ooonS0?ooo`030?oog`2LB7@0_ooo00<0oooo00H0okmd0000000007@0_ooO09a8M02o
oooQ0?ooo`00o`3ooolD0?ooo`030?oog`2LB7@0_ooo0080oooo00L0omnL04P0000004P0W=oo0?oo
g`2LB7@0_ooo0?l0ooooX`3oool00`3ooml0W4Qd0;ooo`020?ooo`070?oOW0180000001809cOo`3o
oml0W4Qd0;ooo`3Q0?ooo`00o`3ooolD0?ooo`0<0?oog`2LB7@0_ooo0?ooo`3ookl0M0000000001d
_ol0oooo0?oog`2LB7@0_oooo`3ooonS0?ooo`0<0?oog`2LB7@0_ooo0?ooo`3ookl0M0000000001d
_ol0oooo0?oog`2LB7@0_oooh@3oool00?l0oooo503oool01`3ooml0W4Qd0;ooo`3ooml0W4P00000
0018W=l00P3oool00`3ooml0W4Qd0;ooo`3o0?oooj<0oooo00L0oooO09a8M02oool0oooO09a80000
0000B9cO0080oooo00<0oooO09a8M02oool0h@3oool00?l0oooo503oool01P3ooml0W4Qd0;oog`2L
B0000000001d_`<0oooo00<0oooO09a8M02oool0o`3ooonS0?ooo`060?oog`2LB7@0_ooO09a80000
000007Bo0`3oool00`3ooml0W4Qd0;ooo`3Q0?ooo`00o`3ooolD0?ooo`060?oog`2LB7@0M7@00000
0000B9`0gooo0`3oool00`3ooml0W4Qd0;ooo`3o0?oooj<0oooo00H0oooO09a8M01dM00000000018
W03Oool30?ooo`030?oog`2LB7@0_ooo0>40oooo003o0?oooa@0oooo00D0oooO09a800000000001d
0;ooo`040?ooo`030?oog`2LB7@0_ooo0?l0ooooX`3oool01@3ooml0W4P00000000007@0_ooo00@0
oooo00<0oooO09a8M02oool0h@3oool00?l0oooo503oool0103OW4P000000000M02oool50?ooo`03
0?oo_`1d07@0_ooo0?l0ooooX`3oool0103OW4P000000000M02oool50?ooo`030?oo_`1d07@0_ooo
0>40oooo003o0?oooa80oooo00D0gia8000000000000001809cOo`040?ooo`030?oog`2LB0000000
0080000000<004RL0=ooo`3oool0o`3ooonN0?ooo`050=nLB000000000000000B02Lgol0103oool0
0`3ooml0W4P000000002000000030018W03Oool0oooo0=h0oooo003o0?ooool0ooooo`3ooona0?oo
o`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0ooooo`3o
oona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0
ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o
0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40
oooo001Z0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool0102oM0000000
00000018W=lO0?ooo`030=nLB0000000000000D0000000@0M;oo0?ooo`3oool0_g@00`0000000`00
B9`0gooo0?ooo`0N0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool00P3oool0102o
M000000000000018W=lQ0?ooo`030?noM000000000000080000000D007Bo0?ooo`3oool0oooo0;md
0003000000030018W03Oool0oooo0200oooo00<0okmd0000000000000P0000000`00M;l0oooo0?oo
o`030?ooo`040;md00000000000004RLgb@0oooo00H0_g@000000000000000000018W03OoolU0?oo
o`040;md00000000000004RLgbX0oooo00H0_g@000000000000000000018W03OoomJ0?ooo`030?oo
g`2LB00000000080000000<004RL0=ooo`3oool01@3oool0102oM000000000000018W=lO0?ooo`03
0=nLB0000000000000D0000000@0M;oo0?ooo`3oool0_g@00`0000000`00B9`0gooo0?ooo`0M0?oo
o`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000018W=lQ
0?ooo`030?noM000000000000080000000D007Bo0?ooo`3oool0oooo0;md0003000000030018W03O
ool0oooo0200oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`030?ooo`040;md0000
0000000004RLgbD0oooo00H0_g@000000000000000000018W03OoolU0?ooo`040;md000000000000
04RLgbT0oooo00H0_g@000000000000000000018W03Ooom30?ooo`00JP3oool0203ogi`0B0000018
W03Oool0oooo0?oOW01804P0W=oo0`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l07`3o
ool00`3OW4P000000000000400000005001d_`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL
0=ooo`0O0?ooo`030=nLB0000000000000@0000000X007Bo0?ooo`3oool0oooO09a80000M;l0oooo
0?oog`2LB00007Bo8P3oool00`2oM000001d0;ooo`030?ooo`030?oog`2LB000B9cO0080oooo00<0
omnL04Q8W03Oool08P3oool00`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo0?ooo`3ooml0
W4P0001d_`0R0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool08P3oool01`3ooml0
W4P0001d_`3oool0oooO09a80000M;l0:03oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo05T0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`<0oooo00L0oooO09a80000
M;l0oooo0?oog`2LB00007Bo01l0oooo00<0gia8000000000000100000001@00M;l0oooo0?oog`2L
B000B9cO0080oooo00<0omnL04Q8W03Oool07P3oool00`3OW4P00000000000040000000:001d_`3o
ool0oooo0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_b80oooo00<0_g@00000M02oool00`3oool0
0`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo0280oooo00<0_g@00000M02oool0103oool0
1`3ooml0W4P0001d_`3oool0oooO09a80000M;l08`3oool00`3ooml0W4P004RLg`020?ooo`030?oO
W018B9`0gooo0280oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo02L0oooo00<0oooO09a8
0018W=l00P3oool00`3ogi`0B4RL0=ooo`120?ooo`00L03oool00`3o_g@004RL0=ooo`020?ooo`03
0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol07`3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?oog`2LB7@0_ooo00H0oooo00<0omnL04Qd_`3oool07`3oool00`3OW4P0B9cO0?ooo`020?ooo`07
0?oog`2LB7@0_ooo0?ooo`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo0240oooo00<0_g@0
0000M02oool02@3oool00`3ogi`0B7Bo0?ooo`0Q0?ooo`030;md000007@0_ooo00@0oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0W0?ooo`030?oOW018M;l0oooo0240oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0]0?ooo`030?oOW018M;l0oooo05h0oooo00<0okmd
0018W03Oool00P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo01l0oooo00<0gia8
04RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?ooo`030?oOW018M;l0oooo01h0oooo00<0gia8
04RLg`3oool00P3oool01`3ooml0W4Qd0;ooo`3oool0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`0Q0?ooo`030;md000007@0_ooo00T0oooo00<0omnL04Qd_`3oool08@3oool00`2oM000001d
0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0:03oool00`3ogi`0B7Bo
0?ooo`0Q0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0;03oool00`3ogi`0B7Bo
0?ooo`110?ooo`00L03oool0203o_g@0001809cOo`3oool0oooO09a80000B9`0gooo0P3oool00`3o
oml0W4P0001d_`0P0?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0B02Lgol0803oool00`3O
W4P0B9cO0?ooo`040?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l08@3oool0
0`2oM000001d0;ooo`090?ooo`030?oo_`1d04P0W=oo0240oooo00<0_g@00000M02oool00`3oool0
103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo02L0oooo00<0oono07@0B02Lgol0803o
ool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo02d0oooo00<0oono07@0B02Lgol0
GP3oool0203o_g@0001809cOo`3oool0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0P
0?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0B02Lgol07`3oool00`3OW4P0B9cO0?ooo`04
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l08@3oool00`2oM000001d0;oo
o`090?ooo`030?oo_`1d04P0W=oo0240oooo00<0_g@00000M02oool00`3oool0103ooml0W4P00018
W03Oool20?ooo`030?oog`2LB00007Bo02P0oooo00<0oono07@0B02Lgol0803oool0103ooml0W4P0
0018W03Oool20?ooo`030?oog`2LB00007Bo02`0oooo00<0oono07@0B02Lgol0@@3oool00700oooo
00L0_g@00000B02Lgol0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0803oool00`3O
W4P0M;oo0?ooo`090?ooo`030?oo_`1d0000M;oo0240oooo00<0gia807Boo`3oool00`3oool00`3o
okl0M000001d_`040?ooo`030;md000007@0_ooo0200oooo00<0_g@00000M02oool02@3oool00`3o
okl0M00007Boo`0Q0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2o
M000001d0;ooo`0V0?ooo`030?oo_`1d0000M;oo0200oooo00<0oono07@00000M;l0103oool00`2o
M000001d0;ooo`0/0?ooo`030?oo_`1d0000M;oo05h0oooo00L0_g@00000B02Lgol0oooo0?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool0803oool00`3OW4P0M;oo0?ooo`090?ooo`030?oo_`1d
0000M;oo0200oooo00<0gia807Boo`3oool00`3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo0200oooo00<0_g@00000M02oool02@3oool00`3ookl0M00007Boo`0Q0?ooo`030;md0000
07@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0W0?ooo`030?oo_`1d
0000M;oo0200oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0[0?ooo`030?oo_`1d
0000M;oo0440oooo001M0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool01@3oool0
202oM00000000000M02oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`0?0?ooo`03
0;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`090?ooo`03
0?noM0000000M;oo0100oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`03
0?oog`2LB4P0W=oo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0?0?ooo`03
0;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool00`2oM000001d0;ooo`090?ooo`03
0?noM0000000M;oo0100oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`03
0;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0C0?ooo`03
0;md00000000000000L0000000<0B9cO0?ooo`3oool01P3oool00`3o_g@0000007Boo`0P0?ooo`03
0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0;03oool00`3o_g@0000007Boo`1;0?ooo`03
0;md00000000000000L0000000<0B9cO0?ooo`3oool01@3oool0202oM00000000000M02oool0oooo
0?oOW0180000B9cO103oool00`2oM000001d0;ooo`0?0?ooo`030;md00000000000000L0000000<0
B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`090?ooo`030?noM0000000M;oo00l0oooo00<0
_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030?oog`2LB4P0W=oo00<0oooo00<0
omnL04P00018W=l0103oool00`2oM000001d0;ooo`0?0?ooo`030;md00000000000000L0000000<0
B9cO0?ooo`3oool0103oool00`2oM000001d0;ooo`090?ooo`030?noM0000000M;oo0100oooo00<0
_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo00<0oooo00<0
omnL04P00018W=l0103oool00`2oM000001d0;ooo`0D0?ooo`030;md00000000000000L0000000<0
B9cO0?ooo`3oool01P3oool00`3o_g@0000007Boo`0P0?ooo`030?oOW0180000B9cO00@0oooo00<0
_g@00000M02oool0:`3oool00`3o_g@0000007Boo`110?ooo`00K03oool00`3ookl0M00000000002
0000000604RLg`3oool0oooo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`0Q0?ooo`030?oO
W01807@0_ooo00L0oooo00@0omnL04P0000007@0_ooo8P3oool00`3ogi`0B01d0;ooo`020?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0803oool00`2oM000001d0;ooo`080?ooo`04
0?oOW0180000001d0;ooob40oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?oo
o`030=nLB00004P0W=oo02D0oooo00@0omnL04P0000007@0_ooo803oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo02/0oooo00@0omnL04P0000007@0_oooFP3oool00`3ookl0M0000000
00020000000604RLg`3oool0oooo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`0Q0?ooo`03
0?oOW01807@0_ooo00L0oooo00@0omnL04P0000007@0_ooo8@3oool00`3ogi`0B01d0;ooo`020?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0803oool00`2oM000001d0;ooo`080?oo
o`040?oOW0180000001d0;ooob40oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo02H0oooo00@0omnL04P0000007@0_ooo803oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo02X0oooo00@0omnL04P0000007@0_ooo@@3oool006h0oooo00<0
okmd0000B02Lgol00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo0280oooo00<0
_g@004RLg`3oool00P3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo0280oooo
00L0_g@004RLg`3oool0oooo0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0803oool00`2o
M000001d0;ooo`040?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0803oool0
0`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol08@3oool0
103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo01l0oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`0W0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0
F`3oool00`3o_g@0001809cOo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
8P3oool00`2oM000B9cO0?ooo`020?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3o
ool08@3oool01`2oM000B9cO0?ooo`3oool0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0P
0?ooo`030;md000007@0_ooo00@0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?oo
o`0P0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`0R0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool07`3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo02H0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0
oooo0?ooo`100?ooo`00K`3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool08P3oool00`3OW4P0001d0;ooo`020?ooo`030?noM0000000000000800000
00<007Bo0?ooo`3oool08`3oool01`3OW4P0001d0;ooo`3oool0oono07@00000M;l0103oool00`2o
M000001d0;ooo`0P0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`0Q0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2o
M000001d0;ooo`0Q0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0803oool00`3o
okl0M000001d_`040?ooo`030;md000007@0_ooo02L0oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`1M0?ooo`030?oOW018M;l0oooo0080oooo00<0oono07@00000M;l0103oool00`2o
M000001d0;ooo`0R0?ooo`030=nLB00007@0_ooo0080oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`0R0?ooo`070=nLB00007@0_ooo0?ooo`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo0200oooo00<0_g@00000M02oool0103oool00`3o_g@000000000000200000003001d_`3o
ool0oooo0240oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo0280oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0P0?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool09P3oool00`3o_g@000000000000200000003001d_`3o
ool0oooo0440oooo001_0?ooo`030?oog`2LB000B9cO00<0oooo00<0_g@00018W03Oool00P3oool0
0`3ooml0W4P0001d_`0S0?ooo`030?noM0000000M;oo0080oooo00D0oooO09a800000000001d0;oo
o`0V0?ooo`030?noM0000000M;oo0080oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d
_`0Q0?ooo`030;md000007@0_ooo00@0oooo00D0oooO09a800000000001d0;ooo`0T0?ooo`030;md
000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0R0?ooo`050?oo
g`2LB00000000000M02oool0903oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo02P0
oooo00D0oooO09a800000000001d0;ooo`1P0?ooo`030?oog`2LB000B9cO00<0oooo00<0_g@00018
W03Oool00P3oool00`3ooml0W4P0001d_`0S0?ooo`030?noM0000000M;oo0080oooo00D0oooO09a8
00000000001d0;ooo`0U0?ooo`030?noM0000000M;oo0080oooo00<0_g@00018W03Oool00P3oool0
0`3ooml0W4P0001d_`0Q0?ooo`030;md000007@0_ooo00@0oooo00D0oooO09a800000000001d0;oo
o`0T0?ooo`030;md000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d
_`0S0?ooo`050?oog`2LB00000000000M02oool0903oool00`2oM00004RL0=ooo`020?ooo`030?oo
g`2LB00007Bo02L0oooo00D0oooO09a800000000001d0;ooo`140?ooo`00JP3oool00`3ooml0W7BL
0=ooo`020?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`0M0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol00`3oool00`3o_g@007Bo
0?ooo`0Q0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol00P3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo0240oooo00<0_g@00000M02oool01@3oool00`3o_g@007Bo
0?ooo`0U0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`0S0?ooo`030?noM000M;l0oooo02D0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`0Y0?ooo`030?noM000M;l0oooo05`0oooo00<0oooO09adW03Oool00P3oool00`3ooml0W4P0
001d_`030?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol07@3oool00`3ogi`0W;oo
0?ooo`030?ooo`030;md00000000M;oo00<0oooo00<0okmd001d_`3oool0803oool00`3ogi`0W;oo
0?ooo`030?ooo`030;md00000000M;oo0080oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`0Q0?ooo`030;md000007@0_ooo00D0oooo00<0okmd001d_`3oool09@3oool00`2oM000001d
0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0903oool00`3o_g@007Bo
0?ooo`0U0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0:03oool00`3o_g@007Bo
0?ooo`150?ooo`00J`3oool01`3ogi`0B4RL0=ooo`3oool0gia80000001d_ol0103oool01P2oM000
04RL0=ooo`3oool0_g@0001d_al0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo`<0
oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0M0?ooo`080;md001d_ol0oooo0?oo
o`3OW4P000000018W03Oool30?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo803oool01@3OW4P0
00000000000007@0_ooo00D0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0N0?oo
o`050=nLB000000000000000M02oool01@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_b@0oooo
00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0Q0?ooo`060;md0000B9`0gooo0?ooo`2o
M00007Bo:P3oool00`3ooml0W4P000000002000000030000M02oool0oooo05P0oooo00L0omnL04Q8
W03Oool0oooo0=nLB0000000M;oo00@0oooo00H0_g@00018W03Oool0oooo0;md0000M;lO0?ooo`08
0;md001d_ol0oooo0?ooo`3OW4P000000018W03Oool30?ooo`030?oog`2LB00000000080000000<0
001d0;ooo`3oool0703oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0`3oool01P2o
M00004RL0=ooo`3oool0_g@0001d_b00oooo00D0gia8000000000000001d0;ooo`050?ooo`030?oo
g`2LB00000000080000000<0001d0;ooo`3oool07P3oool01@3OW4P000000000000007@0_ooo00D0
oooo00H0_g@00018W03Oool0oooo0;md0000M;lU0?ooo`030?oog`2LB00000000080000000<0001d
0;ooo`3oool08@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_bT0oooo00<0oooO09a800000000
0P0000000`0007@0_ooo0?ooo`100?ooo`00K03oool01@3ogi`0B000000000000000B9cO00H0oooo
00@0_g@000000000000007Bo8@3oool01@2oM000000000000000000007Bo00H0oooo00<0okmd0000
000000000P0000000`1d_ol0oooo0?ooo`0M0?ooo`050;md00000000000000000000M;l01P3oool0
102oM000000000000000M;lR0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00<0okmd000000000000
0P0000000`1d_ol0oooo0?ooo`0N0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00@0_g@000000000
000007Bo9P3oool00`3o_g@00000000000020000000307Boo`3oool0oooo0240oooo00@0_g@00000
0000000007Bo;03oool00`3o_g@00000000000020000000307Boo`3oool0oooo05P0oooo00D0omnL
04P000000000000004RLg`060?ooo`040;md000000000000001d_b40oooo00D0_g@0000000000000
0000001d_`060?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0703oool01@2oM000
000000000000000007Bo00H0oooo00@0_g@000000000000007Bo8P3oool0103ookl0M0000000M02o
ool60?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool07P3oool0103ookl0M0000000
M02oool60?ooo`040;md000000000000001d_bL0oooo00<0okmd0000000000000P0000000`1d_ol0
oooo0?ooo`0Q0?ooo`040;md000000000000001d_b/0oooo00<0okmd0000000000000P0000000`1d
_ol0oooo0?ooo`0o0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo
003o0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oo
ok40oooo003o0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3o
oooo0?oook40oooo003o0?ooool0ooooo`3ooona0?ooo`00F@3oool00`3o_g@0000007Boo`090?oo
ool00000J`00000f0?ooo`040;md00000000000004RLg`T0ooooo`00001[00000380oooo001I0?oo
o`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0380oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300oooo001I
0?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0380oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0`
0?ooo`00E03oool00`3OW4P0000000000005000000030000B02Lgol0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0<@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0<03oool005@0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`090?oo
o`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?ooo`0a0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool01P3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?oo
o`3oool0<03oool004L0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3oool0gia8
07Boo`80oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`3o0?ooofL0oooo00<00000
0?ooo`3oool0<@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo00<00000
0?ooo`3oool0o`3ooomW0?ooo`030000003oool0oooo0300oooo001E0?ooo`070?oo_`1d07@0_ooo
0?ooo`3o_g@0000007Boo`090?ooo`<00000B`3ooom[0?l00:h0oooo0`00000c0?ooo`030?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol01P3oool3000000H0oooo:`3o003o0?oooa`0oooo4`3o
00050?ooo`<00000<P3oool005H0oooo00H0okmd001d_`3oool0okmd0000001d_ol90?ooo`030000
003oool0oooo04T0oooo0P3o001[0?ooo`P0o`00Z03oool00`000000oooo0?ooo`0a0?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool00`000000oooo0?ooo`0`0?ooo`80o`00
o`3ooolB0?ooo`T0o`006P3oool00`000000oooo0?ooo`0`0?ooo`00E`3oool01@2oM000M;oo0?no
M0000000M;oo00T0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`1c0?ooo`H0o`00
XP3oool00`000000oooo0?ooo`0a0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
1P3oool00`000000oooo0?ooo`0b0?ooo`80o`00o`3oool=0?ooo`<0o`008`3oool00`000000oooo
0?ooo`0`0?ooo`00E`3oool01@3ookl0M01d0;noM0000000M;oo00T0oooo00<000000?ooo`3oool0
A`3oool00`3o0000oooo0?ooo`1j0?ooo`<0o`00W`3oool00`000000oooo0?ooo`0b0?ooo`030;md
0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`0c0?ooo`030?l0
003oool0oooo0?l0oooo1`3oool40?l002H0oooo00<000000?ooo`3oool0<03oool005P0oooo00@0
okmd000000000000M;oo2@3oool00`000000oooo0?ooo`170?ooo`030?l0003oool0oooo07d0oooo
0P3o002M0?ooo`030000003oool0oooo0380oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`070?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool0o`3oool50?ooo`030?l0
003oool0oooo02P0oooo00<000000?ooo`3oool0<03oool005P0oooo00@0oooO09a800000000M;oo
2@3oool00`000000oooo0?ooo`160?ooo`030?l0003oool0oooo0800oooo0P3o002K0?ooo`030000
003oool0oooo03<0oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`030000003oool0oooo
03D0oooo00<0o`000?ooo`3oool0o`3oool20?ooo`80o`00:`3oool00`000000oooo0?ooo`0`0?oo
o`00F@3oool00`3ogi`0B00007Boo`090?ooo`030000003oool0oooo04H0oooo00<0o`000?ooo`3o
ool0PP3oool30?l009P0oooo00<000000?ooo`3oool0=03oool0102oM000000000000000M;l90?oo
o`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool0o`3oool20?l002d0oooo00<000000?oo
o`3oool0<03oool006D0oooo00<000000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`260?ooo`80
o`00UP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3o
ool0o@3oool00`3o0000oooo0?ooo`0]0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000
003oool0oooo04D0oooo00<0o`000?ooo`3oool0R03oool00`3o0000oooo0?ooo`2C0?ooo`030000
003oool0oooo0440oooo0`00000f0?ooo`030?l0003oool0oooo0?`0oooo00<0o`000?ooo`3oool0
;@3oool200000380oooo001U0?ooo`030000003oool0oooo04@0oooo00<0o`000?ooo`3oool0RP3o
ool00`3o0000oooo0?ooo`2B0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=P3o
ool00`3o0000oooo0?ooo`3k0?ooo`030?l0003oool0oooo02l0oooo00<000000?ooo`3oool0<03o
ool006D0oooo0P0000150?ooo`030?l0003oool0oooo08/0oooo0P3o002A0?ooo`800000@`3oool0
0`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0?/0oooo00<0o`000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo
08d0oooo00<0o`000?ooo`3oool0S`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
03H0oooo00<0o`000?ooo`3oool0nP3oool00`3o0000oooo0?ooo`0`0?ooo`030000003oool0oooo
0300oooo001U0?ooo`030000003oool0oooo04@0oooo00<0o`000?ooo`3oool0SP3oool00`3o0000
oooo0?ooo`2>0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=P3oool00`3o0000
oooo0?ooo`3i0?ooo`030?l0003oool0oooo0340oooo00<000000?ooo`3oool0<03oool006D0oooo
00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`2?0?ooo`030?l0003oool0oooo08d0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo0?L0oooo
00<0o`000?ooo`3oool0<P3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?oo
o`140?ooo`030?l0003oool0oooo0900oooo0P3o002=0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`3g0?ooo`030?l0003oool0oooo0380oooo00<0
00000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`2B
0?ooo`030?l0003oool0oooo08X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0g
0?ooo`030?l0003oool0oooo0?H0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`0`
0?ooo`00I@3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo09@0oooo00<0o`000?oo
o`3oool0R@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03L0oooo00<0o`000?oo
o`3oool0mP3oool00`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo0300oooo001U0?ooo`03
0000003oool0oooo04<0oooo00<0o`000?ooo`3oool0U@3oool00`3o0000oooo0?ooo`280?ooo`03
0000003oool0oooo0440oooo0`00000g0?ooo`030?l0003oool0oooo0?D0oooo00<0o`000?ooo`3o
ool0<`3oool200000380oooo001U0?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool0
UP3oool00`3o0000oooo0?ooo`270?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
>03oool00`3o0000oooo0?ooo`3d0?ooo`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool0
<03oool006D0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`2G0?ooo`030?l0003o
ool0oooo08H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0h0?ooo`030?l0003o
ool0oooo0?@0oooo00<0o`000?ooo`3oool0=03oool00`000000oooo0?ooo`0`0?ooo`00I@3oool0
0`000000oooo0?ooo`130?ooo`030?l0003oool0oooo09P0oooo0P3o00260?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`3c0?ooo`030?l0003oool0
oooo03D0oooo00<000000?ooo`3oool0<03oool006D0oooo0P0000140?ooo`030?l0003oool0oooo
09X0oooo00<0o`000?ooo`3oool0PP3oool2000004<0oooo00<000000?ooo`3oool0>03oool00`3o
0000oooo0?ooo`3c0?ooo`030?l0003oool0oooo03D0oooo00<000000?ooo`3oool0<03oool006D0
oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`2L0?ooo`030?l0003oool0oooo0880
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0?80
oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo
0?ooo`120?ooo`030?l0003oool0oooo09d0oooo00<0o`000?ooo`3oool0P@3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool0lP3oool00`3o0000oooo
0?ooo`0f0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo0480oooo00<0
o`000?ooo`3oool0WP3oool20?l00840oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0h0?ooo`030?l0003oool0oooo0?80oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0`0?ooo`00I@3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0:00oooo0P3o001o
0?ooo`030000003oool0oooo0440oooo0`00000i0?ooo`030?l0003oool0oooo0?00oooo00<0o`00
0?ooo`3oool0=P3oool200000380oooo001U0?ooo`030000003oool0oooo0480oooo00<0o`000?oo
o`3oool0XP3oool20?l007d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0i0?oo
o`030?l0003oool0oooo0?00oooo00<0o`000?ooo`3oool0=`3oool00`000000oooo0?ooo`0`0?oo
o`00I@3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0:@0oooo0P3o001k0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`3`0?ooo`03
0?l0003oool0oooo03L0oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0
@P3oool00`3o0000oooo0?ooo`2V0?ooo`80o`00N@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo03T0oooo00<0o`000?ooo`3oool0l03oool00`3o0000oooo0?ooo`0g0?ooo`030000
003oool0oooo0300oooo001U0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3oool0Z03o
ool30?l007H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0i0?ooo`030?l0003o
ool0oooo0>l0oooo00<0o`000?ooo`3oool0>03oool00`000000oooo0?ooo`0`0?ooo`00I@3oool0
0`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0:`0oooo1`3o001_0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`3_0?ooo`030?l0003oool0
oooo03P0oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0@@3oool00`3o
0000oooo0?ooo`2c0?ooo`L0o`00J03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
03T0oooo00<0o`000?ooo`3oool0k`3oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo
0300oooo001U0?ooo`800000@P3oool00`3o0000oooo0?ooo`2j0?oooa80o`00E@3oool2000004<0
oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`3_0?ooo`030?l0003oool0oooo03P0
oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo
0?ooo`3<0?ooo`H0o`00D03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03T0oooo
00<0o`000?ooo`3oool0kP3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo0300oooo
001U0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0dP3oool00`3o0000oooo0?oo
o`1=0?ooo`030000003oool0oooo0440oooo0`00000i0?ooo`030?l0003oool0oooo0>h0oooo00<0
o`000?ooo`3oool0>03oool200000380oooo001U0?ooo`030000003oool0oooo0440oooo00<0o`00
0?ooo`3oool0d`3oool20?l004d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0j
0?ooo`030?l0003oool0oooo0>d0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0`
0?ooo`00I@3oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0=D0oooo00<0o`000?oo
o`3oool0BP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03X0oooo00<0o`000?oo
o`3oool0k@3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo0300oooo001U0?ooo`03
0000003oool0oooo0440oooo00<0o`000?ooo`3oool0e@3oool00`3o0000oooo0?ooo`1:0?ooo`03
0000003oool0oooo03<0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`060?ooo`03
0000003oool0oooo03X0oooo00<0o`000?ooo`3oool0k@3oool00`3o0000oooo0?ooo`0i0?ooo`03
0000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0
eP3oool00`3o0000oooo0?ooo`190?ooo`030000003oool0oooo03D0oooo00<0_g@00000M02oool0
2@3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0>`0oooo00<0o`000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`110?ooo`030?l0003o
ool0oooo0=L0oooo00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`0e0?ooo`030;md0000
07@0_ooo00T0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3/0?ooo`030?l0003o
ool0oooo03X0oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0@@3oool0
0`3o0000oooo0?ooo`3G0?ooo`030?l0003oool0oooo04P0oooo00<000000?ooo`3oool0=@3oool0
0`2oM000001d0;ooo`090?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0k03oool0
0`3o0000oooo0?ooo`0j0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo
0440oooo00<0o`000?ooo`3oool0f03oool00`3o0000oooo0?ooo`170?ooo`030000003oool0oooo
03D0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo
0>`0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool200000440
oooo00<0o`000?ooo`3oool0f@3oool00`3o0000oooo0?ooo`160?ooo`800000=`3oool00`2oM000
001d0;ooo`090?ooo`<00000>P3oool00`3o0000oooo0?ooo`3/0?ooo`030?l0003oool0oooo03P0
oooo0`00000b0?ooo`00I@3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0=X0oooo
00<0o`000?ooo`3oool0AP3oool00`000000oooo0?ooo`0e0?ooo`030;md000007@0_ooo00T0oooo
00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3/0?ooo`030?l0003oool0oooo03X0oooo
00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?oo
o`3J0?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3oool0=@3oool00`2oM000001d0;oo
o`090?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0k03oool00`3o0000oooo0?oo
o`0j0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo0400oooo00<0o`00
0?ooo`3oool0fP3oool00`3o0000oooo0?ooo`160?ooo`030000003oool0oooo03D0oooo00<0_g@0
0000M02oool02@3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0>`0oooo00<0o`00
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`100?oo
o`030?l0003oool0oooo0=/0oooo00<0o`000?ooo`3oool0A@3oool00`000000oooo0?ooo`0e0?oo
o`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3[0?oo
o`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool0<03oool005@0oooo00<0oooO09a80000
00000P0000000`00B9`0gooo0?ooo`090?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3o
ool0f`3oool00`3o0000oooo0?ooo`150?ooo`030000003oool0oooo03D0oooo00<0_g@00000M02o
ool02@3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0>/0oooo00<0o`000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0`0?ooo`00E03oool0203ogi`0B0000018W03Oool0oooo0?oO
W01804P0W=oo2@3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0=/0oooo00<0o`00
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0c0?ooo`050=nLB000000000000000M02oool02@3o
ool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0>X0oooo00<0o`000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0`0?ooo`00FP3oool00`3o_g@004RL0=ooo`080?ooo`030000003oool0
oooo0400oooo00<0o`000?ooo`3oool0f`3oool00`3o0000oooo0?ooo`150?ooo`030000003oool0
oooo03@0oooo00@0oono07@0000007@0_ooo2@3oool00`000000oooo0?ooo`0k0?ooo`030?l0003o
ool0oooo0>X0oooo00<0o`000?ooo`3oool0>`3oool00`000000oooo0?ooo`0`0?ooo`00FP3oool0
0`3o_g@0001809cOo`080?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3oool0g03oool0
0`3o0000oooo0?ooo`140?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0>`3oool0
0`3o0000oooo0?ooo`3Z0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool0<03oool0
05X0oooo00<0_g@00000B02Lgol0203oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo
0=`0oooo00<0o`000?ooo`3oool0A03oool00`000000oooo0?ooo`110?ooo`<00000>`3oool00`3o
0000oooo0?ooo`3Z0?ooo`030?l0003oool0oooo03X0oooo0P00000b0?ooo`00A`3oool00`2oM000
0000000000070000000304RLg`3oool0oooo00D0oooo00@0_g@00000000007@0_ooo203oool00`00
0000oooo0?ooo`100?ooo`030?l0003oool0oooo0=`0oooo00<0o`000?ooo`3oool0A03oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0jP3oool00`3o
0000oooo0?ooo`0k0?ooo`030000003oool0oooo0300oooo001F0?ooo`030?oo_`1d000000000080
000000<0B9cO0?ooo`3oool01`3oool300000400oooo00<0o`000?ooo`3oool0g03oool00`3o0000
oooo0?ooo`120?ooo`<00000@`3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0>X0
oooo00<0o`000?ooo`3oool0>`3oool00`000000oooo0?ooo`0`0?ooo`00F03oool00`3o_g@00018
09cOo`0:0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0gP3oool00`3o0000oooo
0?ooo`130?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo
0?ooo`3Z0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool0<03oool005T0oooo00<0
omnL04Qd_`3oool02@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0=h0oooo00<0
o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03/0oooo00<0
o`000?ooo`3oool0j@3oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0oooo0300oooo001I
0?ooo`030?oog`2LB000B9cO00T0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`3N
0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0k
0?ooo`030?l0003oool0oooo0>T0oooo00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`0`
0?ooo`00E03oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB00007Bo00T0oooo00<000000?oo
o`3oool0?`3oool00`3o0000oooo0?ooo`3N0?ooo`030?l0003oool0oooo04<0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0>T0oooo00<0o`000?oo
o`3oool0?03oool00`000000oooo0?ooo`0`0?ooo`00E@3oool01`3ogi`0B4RL0=ooo`3oool0gia8
0000001d_ol02@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0=h0oooo00<0o`00
0?ooo`3oool0@`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03/0oooo00<0o`00
0?ooo`3oool0j@3oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0oooo0300oooo001F0?oo
o`050?oOW0180000000000000018W=l02P3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0
oooo0=h0oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`110?ooo`<00000>`3oool0
0`3o0000oooo0?ooo`3Y0?ooo`030?l0003oool0oooo03/0oooo0P00000b0?ooo`00I@3oool00`00
0000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0=l0oooo00<0o`000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0j@3oool00`3o
0000oooo0?ooo`0l0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03l0
oooo00<0o`000?ooo`3oool0g`3oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`3Y0?ooo`030?l0003oool0oooo03`0
oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo
0?ooo`3O0?ooo`030?l0003oool0oooo0480oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0l0?ooo`030?l0003oool0oooo0>L0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0=l0oooo00<0
o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03`0oooo00<0
o`000?ooo`3oool0i`3oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo0300oooo001U
0?ooo`800000@03oool00`3o0000oooo0?ooo`3O0?ooo`030?l0003oool0oooo0440oooo0P000013
0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0i`3oool00`3o0000oooo0?ooo`0m
0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03l0oooo00<0o`000?oo
o`3oool0g`3oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0?03oool00`3o0000oooo0?ooo`3W0?ooo`030?l0003oool0oooo03d0oooo00<000000?oo
o`3oool0<03oool006D0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`3O0?ooo`03
0?l0003oool0oooo0480oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`03
0?l0003oool0oooo0>L0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`0`0?ooo`00
I@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0=l0oooo00<0o`000?ooo`3oool0
@P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0
i`3oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003o
ool0oooo03l0oooo00<0o`000?ooo`3oool0g`3oool00`3o0000oooo0?ooo`120?ooo`030000003o
ool0oooo0440oooo0`00000l0?ooo`030?l0003oool0oooo0>L0oooo00<0o`000?ooo`3oool0?03o
ool200000380oooo001U0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0h03oool0
0`3o0000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0?03oool0
0`3o0000oooo0?ooo`3W0?ooo`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool0<03oool0
06D0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`3Q0?ooo`030?l0003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo
0>H0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000
oooo0?ooo`0n0?ooo`030?l0003oool0oooo0>40oooo00<0o`000?ooo`3oool0@@3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0iP3oool00`3o0000
oooo0?ooo`0n0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03h0oooo
00<0o`000?ooo`3oool0h@3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3V0?ooo`030?l0003oool0oooo03h0oooo
00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?oo
o`3Q0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0l0?ooo`030?l0003oool0oooo0>H0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0`0?ooo`00I@3oool2000003l0oooo00<0o`000?ooo`3oool0h@3oool00`3o0000oooo0?ooo`10
0?ooo`800000@`3oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0>H0oooo00<0o`00
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0n0?oo
o`030?l0003oool0oooo0>40oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0iP3oool00`3o0000oooo0?ooo`0n0?oo
o`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3o
ool0h@3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo0`00000l0?ooo`03
0?l0003oool0oooo0>H0oooo00<0o`000?ooo`3oool0?@3oool200000380oooo001U0?ooo`030000
003oool0oooo03h0oooo00<0o`000?ooo`3oool0hP3oool00`3o0000oooo0?ooo`100?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3V0?ooo`030?l0
003oool0oooo03h0oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0?P3o
ool00`3o0000oooo0?ooo`3R0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0>H0oooo00<0o`000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0
oooo0>80oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`0a0?ooo`030=nLB0000000
000000D0000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0
oooo0>D0oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`00
0000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0>80oooo00<0o`000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0b0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool01@3oool00`00
0000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0>D0oooo00<0o`000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0>80
oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`030=nLB018W=l0oooo0080
oooo00<0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0>@0
oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo
0?ooo`0n0?ooo`030?l0003oool0oooo0>80oooo00<0o`000?ooo`3oool0@03oool00`000000oooo
0?ooo`0d0?ooo`030=nLB018W=l0oooo00X0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo
0?ooo`3T0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0<03oool006D0oooo00<0
00000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`3R0?ooo`030?l0003oool0oooo0400oooo00<0
00000?ooo`3oool0=@3oool00`3OW4P0M;oo0?ooo`090?ooo`030000003oool0oooo03d0oooo00<0
o`000?ooo`3oool0i03oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo0300oooo000c
0?ooo`030?noM01d_ol0oooo00H0oooo00<0_gAd0;ooo`3oool09P3oool00`000000oooo0?ooo`0n
0?ooo`030?l0003oool0oooo0><0oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0M
0?ooo`030?noM01d_ol0oooo00H0oooo00<0_gAd0;ooo`3oool0303oool00`3ooml0W4Q809cOo`09
0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0i03oool00`3o0000oooo0?ooo`0o
0?ooo`030000003oool0oooo0300oooo000c0?ooo`030?noM00007@0_ooo00@0oooo00@0oooO09a8
000007@0_ooo9`3oool2000003l0oooo00<0o`000?ooo`3oool0h`3oool00`3o0000oooo0?ooo`0n
0?ooo`8000007`3oool00`3o_g@0001d0;ooo`040?ooo`040?oog`2LB000001d0;ooo`h0oooo00<0
omnL04P0M02oool0203oool3000003d0oooo00<0o`000?ooo`3oool0i03oool00`3o0000oooo0?oo
o`0m0?ooo`<00000<P3oool003<0oooo00@0okmd000000000000B9cO0P3oool01@3ookl0M01809cO
o`3OW9`0_ooo02L0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`3S0?ooo`030?l0
003oool0oooo03l0oooo00<000000?ooo`3oool07@3oool0103o_g@0000000000018W=l20?ooo`05
0?oo_`1d04P0W=oo0=nLW02oool03`3oool00`2oM000B9cO0?ooo`070?ooo`030000003oool0oooo
03d0oooo00<0o`000?ooo`3oool0i03oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo
0300oooo000c0?ooo`080?noW02Lgol0gia80000000004P0M7A80000M02ooolZ0?ooo`030000003o
ool0oooo03h0oooo00<0o`000?ooo`3oool0h`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003o
ool0oooo01d0oooo00P0oknL09cOo`3OW4P000000000B01dM4P0001d0;oooa80oooo00<0gia80000
M02oool01`3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0><0oooo00<0o`000?oo
o`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=P3oool0103ookl0M00000000000M;l[0?oo
o`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0h`3oool00`3o0000oooo0?ooo`0o0?oo
o`030000003oool0oooo0200oooo00@0oono07@00000000007Bo4`3oool00`3o_g@0000007Boo`07
0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0h`3oool00`3o0000oooo0?ooo`10
0?ooo`030000003oool0oooo0300oooo000c0?ooo`0;0?noW02Lgol0okmd0000B02Lgol0gia80000
000004P0W=oo0=nLW02oool09`3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0><0
oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`0M0?ooo`0;0?noW02Lgol0okmd0000
B02Lgol0gia80000000004P0W=oo0=nLW02oool02@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md
00000000M;oo00L0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3S0?ooo`030?l0
003oool0oooo0400oooo00<000000?ooo`3oool0<03oool003<0oooo00<0okmd00000000M;l00`3o
ool01@3ookl0M0000000000007@0_ooo02L0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo
0?ooo`3U0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`3o_g@00000
001d_`030?ooo`050?oo_`1d000000000000M02oool02P3oool0202oM000M;oo0?ooo`3oool0gia8
00000000B9`0gooo1`3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0><0oooo00<0
o`000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00<`3oool00`3o_g@0B9cO0?ooo`05
0?ooo`030=nLB00007@0_ooo02L0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3U
0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00`3o_g@0B9cO0?ooo`05
0?ooo`030=nLB00007@0_ooo00/0oooo00D0_g@00000000000000000001d_`090?ooo`030000003o
ool0oooo03d0oooo00<0o`000?ooo`3oool0h`3oool00`3o0000oooo0?ooo`100?ooo`030000003o
ool0oooo0300oooo000c0?ooo`030?noW02Lgol0oooo00H0oooo00<0_gAd0;ooo`3oool09P3oool0
0`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0>D0oooo00<0o`000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`0M0?ooo`030?noW02Lgol0oooo00H0oooo00<0_gAd0;ooo`3oool0603oool0
0`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0><0oooo00<0o`000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo
0>D0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`110?ooo`<00000?@3oool00`3o
0000oooo0?ooo`3S0?ooo`030?l0003oool0oooo03l0oooo0P00000b0?ooo`00I@3oool00`000000
oooo0?ooo`0m0?ooo`030?l0003oool0oooo0>D0oooo00<0o`000?ooo`3oool0?P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0h`3oool00`3o0000
oooo0?ooo`100?ooo`030000003oool0oooo0300oooo001U0?ooo`800000?P3oool00`3o0000oooo
0?ooo`3V0?ooo`030?l0003oool0oooo03`0oooo0P0000130?ooo`030000003oool0oooo03d0oooo
00<0o`000?ooo`3oool0h`3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo0300oooo
001U0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0iP3oool00`3o0000oooo0?oo
o`0m0?ooo`030000003oool0oooo0240oooo00<0gia80018W03Oool0103oool00`3OW7@0B4Qd0;oo
o`0F0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0hP3oool00`3o0000oooo0?oo
o`110?ooo`030000003oool0oooo0300oooo000f0?ooo`030?oog`2LM9`0gooo00H0oooo00<0gibL
0;ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0>H0oooo00<0o`00
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0P0?ooo`030?noM000M;l0oooo00@0oooo00@0_g@0
04RLW01d07@0_ooo5P3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0>80oooo00<0
o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0`0?ooo`00=P3oool00`3o_g@0000000000006
000000030000M02oool0oooo02<0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3V
0?ooo`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool0803oool00`3OW4P0B9cO0?ooo`02
0?ooo`060?oog`2LB000M;oo0?oo_`1d07@0_ooo5P3oool00`000000oooo0?ooo`0m0?ooo`030?l0
003oool0oooo0>80oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?ooo`0`0?ooo`00?`3o
ool00`3OW9`0_ooo0?ooo`0S0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0iP3o
ool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo0200oooo00/0okmd0000B02Lgol0oooo
0?noM00004P0W=oo0?ooo`3ogi`0B01d0;ooo`0F0?ooo`030000003oool0oooo03d0oooo00<0o`00
0?ooo`3oool0hP3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo0300oooo001D0?oo
o`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?ooo`0m0?oo
o`030?l0003oool0oooo0>H0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`0Q0?oo
o`040=nLB00000000000001d_`80oooo00@0oooO09a80000B9`0gooo5P3oool00`000000oooo0?oo
o`0m0?ooo`030?l0003oool0oooo0>80oooo00<0o`000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0`0?ooo`00E@3oool00`3OW4P000000000000400000003001d_`3oool0oooo00H0oooo00<00000
0?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3W0?ooo`030?l0003oool0oooo03`0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0>80oooo00<0o`00
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0`0?ooo`00EP3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?oog`2LB7@0_ooo00L0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3W0?oo
o`030?l0003oool0oooo03`0oooo00<000000?ooo`3oool0@@3oool3000003d0oooo00<0o`000?oo
o`3oool0hP3oool00`3o0000oooo0?ooo`100?ooo`800000<P3oool003@0oooo00<0okmd00000000
0000100000000`0007@0_ooo0?ooo`0I0?ooo`030=nLB018W=l0oooo00/0oooo00<000000?ooo`3o
ool0?@3oool00`3o0000oooo0?ooo`3W0?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3o
ool07P3oool00`3o_g@0000000000004000000030000M02oool0oooo01T0oooo00<000000?ooo`3o
ool0?P3oool00`3o0000oooo0?ooo`3Q0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3o
ool0<03oool00380oooo00<0gia8000000000000200000000`0004P0W=oo0?ooo`0H0?ooo`030=nL
B01d_ol0oooo00X0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3W0?ooo`030?l0
003oool0oooo03`0oooo00<000000?ooo`3oool0703oool00`3OW4P0000000000008000000030000
B02Lgol0oooo01L0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`3Q0?ooo`030?l0
003oool0oooo0440oooo00<000000?ooo`3oool0<03oool00340oooo00@0_g@0000000000000M;oo
1`3oool0102oM000000000000018W=l70?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3o
ool0103oool00`3ooml0W4Q809cOo`0:0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3o
ool0i`3oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0oooo01/0oooo00@0_g@000000000
0000M;oo1`3oool0102oM000000000000018W=lG0?ooo`030000003oool0oooo03h0oooo00<0o`00
0?ooo`3oool0h03oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo0300oooo000`0?oo
o`030;md0000M;l0oooo00/0oooo00<0oooO09a80018W=l0603oool00`3ogi`0B01d0;ooo`090?oo
o`<00000?@3oool00`3o0000oooo0?ooo`3W0?ooo`030?l0003oool0oooo03X0oooo0`00000L0?oo
o`030;md0000M;l0oooo00/0oooo00<0oooO09a80018W=l05P3oool00`000000oooo0?ooo`0n0?oo
o`030?l0003oool0oooo0>00oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0`0?oo
o`00;`3oool00`3o_g@0M;oo0?ooo`0>0?ooo`030=nLM02Lgol0oooo01L0oooo00<0_g@004RLg`3o
ool0203oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0>P0oooo00<0o`000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0I0?ooo`030?noM01d_ol0oooo00h0oooo00<0giad09cOo`3o
ool0503oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0>00oooo00<0o`000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0`0?ooo`00;`3oool00`3o_i`0W=oo0?ooo`0X0?ooo`030=nL
B00007@0_ooo00P0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3X0?ooo`030?l0
003oool0oooo03/0oooo00<000000?ooo`3oool06@3oool00`3o_i`0W=oo0?ooo`0U0?ooo`030000
003oool0oooo03h0oooo00<0o`000?ooo`3oool0h03oool00`3o0000oooo0?ooo`120?ooo`030000
003oool0oooo0300oooo000_0?ooo`030?noM01d_ol0oooo00X0oooo00<0gibL0;ooo`3oool06`3o
ool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool0j03o
ool00`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo01T0oooo00<0okmd07Boo`3oool02P3o
ool00`3OW9`0_ooo0?ooo`0H0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0h03o
ool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo0300oooo000_0?ooo`030?noM000B9`0
gooo00X0oooo00<0_gAd0;ooo`3oool05@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000
M;oo00P0oooo00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3X0?ooo`030?l0003oool0
oooo03/0oooo00<000000?ooo`3oool06@3oool00`3o_g@004RL0=ooo`0:0?ooo`030;mdM02oool0
oooo01P0oooo0`00000n0?ooo`030?l0003oool0oooo0>00oooo00<0o`000?ooo`3oool0@@3oool2
00000380oooo000_0?ooo`030?noM0000000000000X0000000<0001d0;ooo`3oool05P3oool0202o
M000M;oo0?ooo`3oool0gia800000000B9`0gooo203oool00`000000oooo0?ooo`0l0?ooo`030?l0
003oool0oooo0>T0oooo00<0o`000?ooo`3oool0>`3oool00`000000oooo0?ooo`0I0?ooo`030?no
M0000000000000X0000000<0001d0;ooo`3oool0603oool00`000000oooo0?ooo`0n0?ooo`030?l0
003oool0oooo0>00oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0`0?ooo`00<03o
ool0102oM00000000000B02Lgol80?ooo`030;mdM02oool0oooo01L0oooo00D0_g@0000000000000
0000001d_`0:0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0j@3oool00`3o0000
oooo0?ooo`0k0?ooo`030000003oool0oooo01X0oooo00@0_g@00000000004P0W=oo203oool00`2o
M7@0_ooo0?ooo`0H0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0h03oool00`3o
0000oooo0?ooo`120?ooo`030000003oool0oooo0300oooo000a0?ooo`040=nLB0000000000007Bo
o`L0oooo00<0gibL0;ooo`3oool09P3oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo
0>X0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0K0?ooo`040=nLB00000000000
07Boo`L0oooo00<0gibL0;ooo`3oool0603oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0
oooo0>00oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool0103o
_g@0000000000000M;l_0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0jP3oool0
0`3o0000oooo0?ooo`0j0?ooo`030000003oool0oooo01`0oooo00@0okmd00000000000007Bo8@3o
ool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0>00oooo00<0o`000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0`0?ooo`00<`3oool01@3ogi`0B00000000000B9`0gooo02d0oooo00<0
00000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3Z0?ooo`030?l0003oool0oooo03X0oooo00<0
00000?ooo`3oool07@3oool01@3ogi`0B00000000000B9`0gooo01l0oooo00<000000?ooo`3oool0
?P3oool00`3o0000oooo0?ooo`3O0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0
<03oool003@0oooo00D0oono07@000000000001809cOo`0/0?ooo`030000003oool0oooo03`0oooo
00<0o`000?ooo`3oool0jP3oool00`3o0000oooo0?ooo`0j0?ooo`030000003oool0oooo01h0oooo
00D0oono07@000000000001809cOo`0N0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3o
ool0g`3oool00`3o0000oooo0?ooo`130?ooo`030000003oool0oooo0300oooo000e0?ooo`050?oo
g`2LB00000000000001d_ol0:`3oool2000003d0oooo00<0o`000?ooo`3oool0jP3oool00`3o0000
oooo0?ooo`0i0?ooo`8000008@3oool01@3ooml0W4P0000000000000M;oo01d0oooo00<000000?oo
o`3oool0?P3oool00`3o0000oooo0?ooo`3O0?ooo`030?l0003oool0oooo04<0oooo00<000000?oo
o`3oool0<03oool002l0oooo00<0oknL09cOo`3oool01@3oool0102oM000000000000000M;lZ0?oo
o`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0jP3oool00`3o0000oooo0?ooo`0j0?oo
o`030000003oool0oooo01T0oooo00<0oknL09cOo`3oool01@3oool0102oM000000000000000M;lL
0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0g`3oool00`3o0000oooo0?ooo`13
0?ooo`030000003oool0oooo0300oooo000_0?ooo`030?noM01d_ol0oooo00H0oooo00D0gia80000
0000000004RL0=ooo`0X0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0j`3oool0
0`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo01T0oooo00<0okmd07Boo`3oool01P3oool0
1@3OW4P0000000000000B9`0gooo01X0oooo0`00000n0?ooo`030?l0003oool0oooo0=l0oooo00<0
o`000?ooo`3oool0@P3oool200000380oooo000_0?ooo`030?noM0000000000000X0000000<00018
09cOo`3oool09P3oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0>/0oooo00<0o`00
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0I0?ooo`030?noM0000000000000X0000000<00018
09cOo`3oool0603oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo0=l0oooo00<0o`00
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0`0?ooo`00;`3oool00`3o_g@0M;oo0?ooo`0c0?oo
o`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0j`3oool00`3o0000oooo0?ooo`0i0?oo
o`030000003oool0oooo01T0oooo00<0okmd07Boo`3oool09@3oool00`000000oooo0?ooo`0n0?oo
o`030?l0003oool0oooo0=l0oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`0`0?oo
o`00;`3oool00`3o_i`0W=oo0?ooo`0c0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3o
ool0j`3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo01T0oooo00<0oknL09cOo`3o
ool05@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00P0oooo00<000000?ooo`3o
ool0?P3oool00`3o0000oooo0?ooo`3O0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3o
ool0<03oool002l0oooo00<0okmd07Boo`3oool03P3oool00`2oM4P0W=oo0?ooo`0R0?ooo`030000
003oool0oooo03`0oooo00<0o`000?ooo`3oool0j`3oool00`3o0000oooo0?ooo`0i0?ooo`030000
003oool0oooo01T0oooo00<0okmd07Boo`3oool03P3oool00`2oM4P0W=oo0?ooo`040?ooo`080?oO
W018000004RL0=ooo`3oool0omnL04P0B02Lgol80?ooo`030000003oool0oooo03l0oooo00<0o`00
0?ooo`3oool0gP3oool00`3o0000oooo0?ooo`130?ooo`030000003oool0oooo0300oooo000`0?oo
o`030;md0000M;l0oooo00/0oooo00<0oooO09a8001d_ol0903oool00`000000oooo0?ooo`0l0?oo
o`030?l0003oool0oooo0>/0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0J0?oo
o`030;md0000M;l0oooo00/0oooo00<0oooO09a8001d_ol0303oool00`3o_g@004RL0=ooo`070?oo
o`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0gP3oool00`3o0000oooo0?ooo`130?oo
o`030000003oool0oooo0300oooo000a0?ooo`040;md00000000000007Boo`L0oooo00@0_g@00000
00000000B9cO9@3oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0>`0oooo00<0o`00
0?ooo`3oool0>03oool00`000000oooo0?ooo`0K0?ooo`040;md00000000000007Boo`L0oooo00@0
_g@0000000000000B9cO3@3oool00`3o_g@0001809cOo`070?ooo`030000003oool0oooo03l0oooo
00<0o`000?ooo`3oool0gP3oool00`3o0000oooo0?ooo`130?ooo`030000003oool0oooo0300oooo
000b0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool09@3oool00`000000oooo0?oo
o`0l0?ooo`030?l0003oool0oooo0>`0oooo00<0o`000?ooo`3oool0>03oool00`000000oooo0?oo
o`0L0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool03@3oool00`2oM000001809cO
o`070?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0gP3oool00`3o0000oooo0?oo
o`130?ooo`030000003oool0oooo0300oooo000d0?ooo`030?noM0000000000000@0000000<0001d
0;ooo`3oool09`3oool2000003d0oooo00<0o`000?ooo`3oool0k03oool00`3o0000oooo0?ooo`0g
0?ooo`800000803oool00`3o_g@0000000000004000000030000M02oool0oooo00h0oooo00@0_g@0
0000000007@0_ooo1`3oool3000003l0oooo00<0o`000?ooo`3oool0gP3oool00`3o0000oooo0?oo
o`110?ooo`<00000<P3oool006D0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3/
0?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3oool0<`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo00H0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`3M
0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?oo
o`3oool0?03oool00`3o0000oooo0?ooo`3]0?ooo`030?l0003oool0oooo03L0oooo00<000000?oo
o`3oool0=@3oool00`3o_g@0001809cOo`090?ooo`030000003oool0oooo03l0oooo00<0o`000?oo
o`3oool0g@3oool00`3o0000oooo0?ooo`140?ooo`030000003oool0oooo0300oooo001U0?ooo`03
0000003oool0oooo03`0oooo00<0o`000?ooo`3oool0k@3oool00`3o0000oooo0?ooo`0g0?ooo`03
0000003oool0oooo03H0oooo00<0omnL04Qd_`3oool0203oool00`000000oooo0?ooo`0o0?ooo`03
0?l0003oool0oooo0=d0oooo00<0o`000?ooo`3oool0A03oool00`000000oooo0?ooo`0`0?ooo`00
I@3oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0>d0oooo00<0o`000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0f0?ooo`030?oog`2LB000B9cO00P0oooo00<000000?ooo`3oool0
?`3oool00`3o0000oooo0?ooo`3M0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool0
<03oool006D0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`3^0?ooo`030?l0003o
ool0oooo03H0oooo00<000000?ooo`3oool0<@3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2L
B00007Bo00P0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`3M0?ooo`030?l0003o
ool0oooo04@0oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0>`3oool0
0`3o0000oooo0?ooo`3_0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0<P3oool0
1`3ogi`0B4RL0=ooo`3oool0gia80000001d_ol0203oool00`000000oooo0?ooo`0o0?ooo`030?l0
003oool0oooo0=d0oooo00<0o`000?ooo`3oool0A03oool00`000000oooo0?ooo`0`0?ooo`00I@3o
ool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0>l0oooo00<0o`000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0c0?ooo`050?oOW0180000000000000018W=l02@3oool00`000000oooo
0?ooo`0o0?ooo`030?l0003oool0oooo0=d0oooo00<0o`000?ooo`3oool0A03oool00`000000oooo
0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0oooo0?00oooo00<0
o`000?ooo`3oool0=@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03l0oooo00<0
o`000?ooo`3oool0g@3oool00`3o0000oooo0?ooo`140?ooo`030000003oool0oooo0300oooo001U
0?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0l03oool00`3o0000oooo0?ooo`0e
0?ooo`030000003oool0oooo0440oooo0`00000o0?ooo`030?l0003oool0oooo0=d0oooo00<0o`00
0?ooo`3oool0@`3oool200000380oooo001U0?ooo`030000003oool0oooo03/0oooo00<0o`000?oo
o`3oool0l03oool00`3o0000oooo0?ooo`0e0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0?`3oool00`3o0000oooo0?ooo`3M0?ooo`030?l0003oool0oooo04@0oooo00<000000?oo
o`3oool0<03oool006D0oooo0P00000l0?ooo`030?l0003oool0oooo0?40oooo00<0o`000?ooo`3o
ool0<`3oool2000004<0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`3L0?ooo`03
0?l0003oool0oooo04D0oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0
>`3oool00`3o0000oooo0?ooo`3a0?ooo`030?l0003oool0oooo03@0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0=`0oooo00<0o`000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0k0?ooo`030?l0003o
ool0oooo0?80oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo03l0oooo00<0o`000?ooo`3oool0g03oool00`3o0000oooo0?ooo`150?ooo`030000003o
ool0oooo0300oooo001U0?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0lP3oool0
0`3o0000oooo0?ooo`0c0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0?`3oool0
0`3o0000oooo0?ooo`3L0?ooo`030?l0003oool0oooo04D0oooo00<000000?ooo`3oool0<03oool0
06D0oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`3b0?ooo`030?l0003oool0oooo
03<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo
0=`0oooo00<0o`000?ooo`3oool0A@3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000
oooo0?ooo`0k0?ooo`030?l0003oool0oooo0?<0oooo00<0o`000?ooo`3oool0<P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3oool0f`3oool00`3o0000
oooo0?ooo`150?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03/0oooo
00<0o`000?ooo`3oool0l`3oool00`3o0000oooo0?ooo`0b0?ooo`030000003oool0oooo0440oooo
0`0000100?ooo`030?l0003oool0oooo0=X0oooo00<0o`000?ooo`3oool0A@3oool200000380oooo
001U0?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0m03oool00`3o0000oooo0?oo
o`0a0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?oo
o`3J0?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3oool0<03oool006D0oooo00<00000
0?ooo`3oool0>`3oool00`3o0000oooo0?ooo`3d0?ooo`030?l0003oool0oooo0340oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0=X0oooo00<0o`00
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0k0?oo
o`030?l0003oool0oooo0?D0oooo00<0o`000?ooo`3oool0<03oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0400oooo00<0o`000?ooo`3oool0fP3oool00`3o0000oooo0?ooo`160?oo
o`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3o
ool0mP3oool00`3o0000oooo0?ooo`0_0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0@03oool00`3o0000oooo0?ooo`3J0?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3o
ool0<03oool006D0oooo0P00000l0?ooo`030?l0003oool0oooo0?H0oooo00<0o`000?ooo`3oool0
;P3oool2000004<0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?ooo`3I0?ooo`030?l0
003oool0oooo04L0oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0>`3o
ool00`3o0000oooo0?ooo`3g0?ooo`030?l0003oool0oooo02h0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0=T0oooo00<0o`000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0k0?ooo`030?l0003oool0
oooo0?P0oooo00<0o`000?ooo`3oool0;@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0400oooo00<0o`000?ooo`3oool0f@3oool00`3o0000oooo0?ooo`170?ooo`030000003oool0
oooo0300oooo001U0?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0n@3oool20?l0
02d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo
0=T0oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000
oooo0?ooo`0k0?ooo`030?l0003oool0oooo0?/0oooo00<0o`000?ooo`3oool0:P3oool00`000000
oooo0?ooo`110?ooo`<00000@03oool00`3o0000oooo0?ooo`3H0?ooo`030?l0003oool0oooo04L0
oooo0P00000b0?ooo`00EP3oool00`3o_g@000000000000200000003001d_`3oool0oooo00L0oooo
00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`3l0?ooo`030?l0003oool0oooo02T0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0=P0oooo
00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`0`0?ooo`00F03oool00`2oM000001d0;oo
o`0:0?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0o@3oool20?l002T0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0=P0oooo00<0
o`000?ooo`3oool0B03oool00`000000oooo0?ooo`0`0?ooo`00F03oool00`2oM000001d0;ooo`0:
0?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0o`3oool20?l002L0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo0=L0oooo00<0o`00
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0`0?ooo`00F03oool00`2oM000001d0;ooo`0:0?oo
o`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool0o`3oool20?ooo`L0o`00803oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0400oooo00<0o`000?ooo`3oool0e`3oool00`3o
0000oooo0?ooo`190?ooo`030000003oool0oooo0300oooo001H0?ooo`030;md000007@0_ooo00X0
oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o0?ooo`X0oooo1`3o000I0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?ooo`3F0?ooo`03
0?l0003oool0oooo04X0oooo00<000000?ooo`3oool0<03oool004L0oooo00<0_g@0000000000000
1`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo00X0oooo0`00000j0?ooo`030?l0
003oool0oooo0?l0oooo4@3ooolB0?l000D0oooo0`0000130?ooo`030000003oool0oooo0400oooo
00<0o`000?ooo`3oool0eP3oool00`3o0000oooo0?ooo`1:0?ooo`030000003oool0oooo0300oooo
001H0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?oo
o`3o0?ooobX0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030?l0003o
ool0oooo0=D0oooo00<0o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`0`0?ooo`00F03oool0
0`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0o`3ooolZ
0?ooo`030000003oool0oooo0440oooo0`0000100?ooo`030?l0003oool0oooo0=D0oooo00<0o`00
0?ooo`3oool0BP3oool200000380oooo001H0?ooo`030;md000007@0_ooo00X0oooo00<000000?oo
o`3oool0>P3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`100?ooo`030?l0003oool0oooo0=@0oooo00<0o`000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0`0?ooo`00F03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo03X0
oooo00<0o`000?ooo`3oool0o`3ooolZ0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0@03oool00`3o0000oooo0?ooo`3B0?ooo`80o`00C`3oool00`000000oooo0?ooo`0`0?ooo`00
F03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0
o`3ooolZ0?ooo`030000003oool0oooo03H0oooo00<0okmd0000001d_ol0203oool00`000000oooo
0?ooo`100?ooo`030?l0003oool0oooo0<l0oooo0`3o001A0?ooo`030000003oool0oooo0300oooo
001F0?ooo`050=nLB000000000000000M02oool02P3oool00`000000oooo0?ooo`0j0?ooo`030?l0
003oool0oooo0?l0oooo:P3oool00`000000oooo0?ooo`0f0?ooo`030?noM0000000M;oo00P0oooo
00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`330?ooo`/0o`00E03oool00`000000oooo
0?ooo`0`0?ooo`00E`3oool0103ookl0M0000000M02oool:0?ooo`030000003oool0oooo03X0oooo
00<0o`000?ooo`3oool0o`3ooolZ0?ooo`030000003oool0oooo03H0oooo00<0okmd0000001d_ol0
203oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0;P0oooo2`3o001O0?ooo`030000
003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0o`3o
oolZ0?ooo`030000003oool0oooo0340oooo00<0gia80000000000001@0000000`0004P0W=oo0?oo
o`050?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0/P3oool60?l006X0oooo00<0
00000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o
0?ooobX0oooo00<000000?ooo`3oool0<@3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?noM0000000
M;oo00P0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`2^0?ooo`@0o`00L03oool0
0`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo
0?l0oooo:P3oool00`000000oooo0?ooo`0b0?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@0000007Bo
o`080?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0[03oool20?l007@0oooo00<0
00000?ooo`3oool0<03oool006D0oooo0P00000k0?ooo`030?l0003oool0oooo0?l0oooo:@3oool2
000003@0oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo00P0oooo0`0000110?ooo`030?l0
003oool0oooo0:X0oooo0P3o001d0?ooo`<00000<P3oool006D0oooo00<000000?ooo`3oool0>P3o
ool00`3o0000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0<`3oool01P3o_g@007Bo0?oo
o`3o_g@0000007Boo`P0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`2X0?ooo`80
o`00N03oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0j0?ooo`030?l0
003oool0oooo0?l0oooo:P3oool00`000000oooo0?ooo`0d0?ooo`050;md001d_ol0okmd0000001d
_ol0203oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0:H0oooo0P3o001j0?ooo`03
0000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0
o`3ooolZ0?ooo`030000003oool0oooo03@0oooo00D0oono07@0M02o_g@0000007Boo`080?ooo`03
0000003oool0oooo0440oooo00<0o`000?ooo`3oool0Y@3oool00`3o0000oooo0?ooo`1j0?ooo`03
0000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03X0oooo00<0o`000?ooo`3oool0
o`3ooolZ0?ooo`030000003oool0oooo03D0oooo00@0okmd000000000000M;oo203oool00`000000
oooo0?ooo`110?ooo`030?l0003oool0oooo0:@0oooo00<0o`000?ooo`3oool0N`3oool00`000000
oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0?l0oooo
:P3oool00`000000oooo0?ooo`0e0?ooo`040?oog`2LB000000007Boo`P0oooo00<000000?ooo`3o
ool0@@3oool00`3o0000oooo0?ooo`2R0?ooo`80o`00OP3oool00`000000oooo0?ooo`0`0?ooo`00
I@3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0?l0oooo:P3oool00`000000oooo
0?ooo`0f0?ooo`030?oOW0180000M;oo00P0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo
0?ooo`2Q0?ooo`030?l0003oool0oooo07h0oooo00<000000?ooo`3oool0<03oool006D0oooo00<0
00000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0:00oooo00<0o`000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0
oooo0?l0oooo:`3oool00`000000oooo0?ooo`110?ooo`<00000@@3oool00`3o0000oooo0?ooo`2N
0?ooo`80o`00P@3oool200000380oooo001U0?ooo`030000003oool0oooo03T0oooo00<0o`000?oo
o`3oool0o`3oool[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`3o
0000oooo0?ooo`2M0?ooo`030?l0003oool0oooo0880oooo00<000000?ooo`3oool0<03oool006D0
oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo09`0oooo00<0o`000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool2000003X0oooo00<0o`000?ooo`3oool0
o`3ooolZ0?ooo`800000@`3oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo09/0oooo
00<0o`000?ooo`3oool0Q03oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?oo
o`0i0?ooo`030?l0003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0440oooo00<0o`000?ooo`3oool0V`3oool00`3o0000oooo0?ooo`240?ooo`030000003o
ool0oooo0300oooo001U0?ooo`030000003oool0oooo03T0oooo00<0o`000?ooo`3oool0o`3oool[
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`2I
0?ooo`030?l0003oool0oooo08D0oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?oo
o`3oool0>@3oool00`3o0000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`120?ooo`030?l0003oool0oooo09P0oooo00<0o`000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo0?l0
oooo:`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3o
ool0U`3oool00`3o0000oooo0?ooo`270?ooo`030000003oool0oooo0300oooo001U0?ooo`030000
003oool0oooo03T0oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`2F0?ooo`030?l0003oool0oooo08P0oooo
00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?oo
o`3o0?ooob/0oooo00<000000?ooo`3oool0@@3oool300000480oooo00<0o`000?ooo`3oool0U@3o
ool00`3o0000oooo0?ooo`280?ooo`800000<P3oool006D0oooo00<000000?ooo`3oool0>03oool0
0`3o0000oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`12
0?ooo`030?l0003oool0oooo09D0oooo00<0o`000?ooo`3oool0R@3oool00`000000oooo0?ooo`0`
0?ooo`00I@3oool00`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0?l0oooo;03oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3oool0U03oool00`3o
0000oooo0?ooo`2:0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03P0
oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0@P3oool00`3o0000oooo0?ooo`2C0?ooo`030?l0003oool0oooo08/0oooo00<000000?ooo`3o
ool0<03oool006D0oooo0P00000i0?ooo`030?l0003oool0oooo0?l0oooo:`3oool2000004<0oooo
00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`2A0?ooo`030?l0003oool0oooo08`0oooo
00<000000?ooo`3oool0<03oool006D0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?oo
o`3o0?ooob`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`130?ooo`030?l0003o
ool0oooo0900oooo00<0o`000?ooo`3oool0S@3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool0
0`000000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0?l0oooo;03oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool0S`3oool00`3o0000oooo0?ooo`2>
0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000003oool0oooo03P0oooo00<0o`000?oo
o`3oool0o`3oool/0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@`3oool00`3o
0000oooo0?ooo`2>0?ooo`030?l0003oool0oooo08l0oooo00<000000?ooo`3oool0<03oool006D0
oooo00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3o
ool0@@3oool3000004<0oooo00<0o`000?ooo`3oool0S@3oool00`3o0000oooo0?ooo`2?0?ooo`80
0000<P3oool006D0oooo00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo08d0oooo
00<0o`000?ooo`3oool0T03oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?oo
o`0g0?ooo`030?l0003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo04<0oooo00<0o`000?ooo`3oool0S03oool00`3o0000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0300oooo001U0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool0o`3oool]
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`2:
0?ooo`030?l0003oool0oooo0980oooo00<000000?ooo`3oool0<03oool006D0oooo00<000000?oo
o`3oool0=`3oool00`3o0000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`140?ooo`030?l0003oool0oooo08T0oooo00<0o`000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0?l0
oooo;P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04@0oooo00<0o`000?ooo`3o
ool0R03oool00`3o0000oooo0?ooo`2D0?ooo`030000003oool0oooo0300oooo001U0?ooo`030000
003oool0oooo03H0oooo00<0o`000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`270?ooo`030?l0003oool0oooo09D0oooo
00<000000?ooo`3oool0<03oool006D0oooo0P00000g0?ooo`030?l0003oool0oooo0?l0oooo;@3o
ool2000004<0oooo00<000000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`240?ooo`80o`00V03o
ool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0
oooo0?l0oooo;P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04D0oooo00<0o`00
0?ooo`3oool0P`3oool00`3o0000oooo0?ooo`2H0?ooo`030000003oool0oooo0300oooo001U0?oo
o`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool0o`3oool_0?ooo`030000003oool0oooo
0440oooo0`0000150?ooo`030?l0003oool0oooo0840oooo0P3o002J0?ooo`800000<P3oool006D0
oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`150?ooo`030?l0003oool0oooo0800oooo00<0o`000?ooo`3o
ool0V`3oool00`000000oooo0?ooo`0`0?ooo`00I@3oool00`000000oooo0?ooo`0d0?ooo`030?l0
003oool0oooo0?l0oooo<03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04H0oooo
00<0o`000?ooo`3oool0O@3oool20?l009h0oooo00<000000?ooo`3oool0<03oool005L0oooo00@0
_g@0000000000000B9cO2P3oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo0?l0oooo
<03oool00`000000oooo0?ooo`0b0?ooo`060;md00000000000000000000B9`0gooo2@3oool00`00
0000oooo0?ooo`160?ooo`030?l0003oool0oooo07`0oooo00<0o`000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`0`0?ooo`00E@3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l02@3oool0
0`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo0?l0oooo<03oool00`000000oooo0?ooo`0a
0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0203oool00`000000oooo0?ooo`17
0?ooo`030?l0003oool0oooo07T0oooo0P3o002Q0?ooo`030000003oool0oooo0300oooo001E0?oo
o`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?ooo`0c0?oo
o`80o`00o`3ooolb0?ooo`030000003oool0oooo03L0oooo00<0omnL04Qd_`3oool01`3oool00`00
0000oooo0?ooo`170?ooo`030?l0003oool0oooo07L0oooo0P3o002S0?ooo`030000003oool0oooo
0300oooo001D0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0203oool00`00
0000oooo0?ooo`0b0?ooo`80o`00o`3ooolc0?ooo`030000003oool0oooo03L0oooo00<0oono07@0
B02Lgol01`3oool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo0740oooo1@3o002U0?oo
o`030000003oool0oooo0300oooo001D0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02o
ool01`3oool00`000000oooo0?ooo`0`0?ooo`<0o`00o`3ooold0?ooo`030000003oool0oooo03L0
oooo00<0oono07@0001d_ol01`3oool00`000000oooo0?ooo`190?ooo`80o`00J@3oool80?l00:X0
oooo00<000000?ooo`3oool0<03oool005@0oooo00<0omnL04P00018W=l0103oool00`2oM000001d
0;ooo`070?ooo`<000001@3oool/0?l00?l0oooo=03oool3000003T0oooo00<0okmd0000001d_ol0
1`3oool3000004/0ooooJ@3o002`0?ooo`<00000<P3oool005@0oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo0?l0ooooI`3oool00`000000oooo0?oo
o`0f0?ooo`040?oOW0180000001d0;ooo`L0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo0300oooo001D0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3o
ool00`000000oooo0?ooo`3o0?ooofL0oooo00<000000?ooo`3oool0<P3oool0103Ogml0oooo0?oo
o`2oM0020000000304RLg`3oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`030000
003oool0oooo0300oooo001D0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0b0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0`0?ooo`00E@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0380oooo00D0oooO09a800000000001d0;ooo`0:0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`00E@3oool00`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo03<0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<03oool005H0oooo00H0_g@00018
W03Oool0oooo0;md0000M;l90?ooool00000J`00000e0?ooo`030?oog`2LB00000000080000000<0
001d0;ooo`3oool01P3ooooo000006/00000<P3oool005L0oooo00@0_g@000000000000007Boo`3o
oon[0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0o`3ooonR0?ooo`00o`3ooooo
0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0ooooo`3ooona0?ooo`00
o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0ooooo`3ooona
0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?ooool0oooo
o`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo003o0?oo
ool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oook40oooo
003o0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00?l0ooooo`3ooooo0?oo
ok40oooo003o0?ooool0ooooo`3ooona0?ooo`00o`3ooooo0?ooool0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 941.188}, {581.188, 0}} -> {-0.0509041, -0.0309082, \
0.00223315, 0.00223315}, {{22.75, 482.063}, {567.313, 283.438}} -> {-41.5675, \
-0.68505, 0.104636, 0.00940581}, {{459.063, 918.375}, {567.313, 283.438}} -> \
{-87.2215, -0.342525, 0.104636, 0.0047029}, {{22.75, 482.063}, {297.688, \
13.8125}} -> {-41.5086, -10.4422, 0.104636, 0.0188116}, {{459.063, 918.375}, \
{297.688, 13.8125}} -> {-86.4334, -8.05271, 0.104636, 0.0235145}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 3\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig3x1x2 = 
        ParametricPlot[{xx1[N], xx2[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] {{\(-5\), 1}, {\(-1\), 6}}, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {\*"\"\<\!\(x\_1\)\>\"", \
\*"\"\<\!\(x\_2\)\>\""}];\)\), "\[IndentingNewLine]", 
    \(\(fig3x3x4 = 
        ParametricPlot[{x3[N], xx4[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 2}}, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {\*"\"\<\!\(x\_3\)\>\"", \
\*"\"\<\!\(x\_4\)\>\""}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{fig3x1x2, fig3x3x4}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] \(-0.05\)];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig3_x1x2\>" <> "\<.m\>", 
        fig3x1x2];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig3_x3x4\>" <> "\<.m\>", fig3x3x4];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .31694 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0075462 0.47619 [
[ 0 0 0 0 ]
[ 1 .31694 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .31694 L
0 .31694 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0075462 0.51221 0.309394 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.833333 0.166667 0.0882906 0.0882906 [
[.16667 -0.0125 -14 -24.5625 ]
[.16667 -0.0125 14 0 ]
[.33333 -0.0125 -14 -24.5625 ]
[.33333 -0.0125 14 0 ]
[.5 -0.0125 -14 -24.5625 ]
[.5 -0.0125 14 0 ]
[.66667 -0.0125 -14 -24.5625 ]
[.66667 -0.0125 14 0 ]
[.83333 -0.0125 -7.03125 -24.5625 ]
[.83333 -0.0125 7.03125 0 ]
[1 -0.0125 -7.03125 -24.5625 ]
[1 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -10.8125 -49.125 ]
[.5 -0.0125 10.8125 -24.5625 ]
[-0.0125 .08829 -14.0625 -12.2813 ]
[-0.0125 .08829 0 12.2813 ]
[-0.0125 .17658 -14.0625 -12.2813 ]
[-0.0125 .17658 0 12.2813 ]
[-0.0125 .26487 -14.0625 -12.2813 ]
[-0.0125 .26487 0 12.2813 ]
[-0.0125 .35316 -14.0625 -12.2813 ]
[-0.0125 .35316 0 12.2813 ]
[-0.0125 .44145 -14.0625 -12.2813 ]
[-0.0125 .44145 0 12.2813 ]
[-0.0125 .52974 -14.0625 -12.2813 ]
[-0.0125 .52974 0 12.2813 ]
[-0.0125 .61803 -14.0625 -12.2813 ]
[-0.0125 .61803 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -38.625 -10.8125 ]
[-0.01875 .30902 -14.0625 10.8125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -71.8125 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
gsave
-0.0125 .08829 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .17658 m
.00625 .17658 L
s
gsave
-0.0125 .17658 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .26487 m
.00625 .26487 L
s
gsave
-0.0125 .26487 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .35316 m
.00625 .35316 L
s
gsave
-0.0125 .35316 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .44145 m
.00625 .44145 L
s
gsave
-0.0125 .44145 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .52974 m
.00625 .52974 L
s
gsave
-0.0125 .52974 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -98.1563 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.8125 16.2813 translate
90 rotate
-71.8125 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.03333 .61428 m
.03333 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.13333 .61428 m
.13333 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.23333 .61428 m
.23333 .61803 L
s
.26667 .61428 m
.26667 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.43333 .61428 m
.43333 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.53333 .61428 m
.53333 .61803 L
s
.56667 .61428 m
.56667 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.76667 .61428 m
.76667 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.93333 .61428 m
.93333 .61803 L
s
.96667 .61428 m
.96667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .08829 m
1 .08829 L
s
.99375 .17658 m
1 .17658 L
s
.99375 .26487 m
1 .26487 L
s
.99375 .35316 m
1 .35316 L
s
.99375 .44145 m
1 .44145 L
s
.99375 .52974 m
1 .52974 L
s
.125 Mabswid
.99625 .01766 m
1 .01766 L
s
.99625 .03532 m
1 .03532 L
s
.99625 .05297 m
1 .05297 L
s
.99625 .07063 m
1 .07063 L
s
.99625 .10595 m
1 .10595 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14126 m
1 .14126 L
s
.99625 .15892 m
1 .15892 L
s
.99625 .19424 m
1 .19424 L
s
.99625 .2119 m
1 .2119 L
s
.99625 .22956 m
1 .22956 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .28253 m
1 .28253 L
s
.99625 .30019 m
1 .30019 L
s
.99625 .31785 m
1 .31785 L
s
.99625 .3355 m
1 .3355 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .38848 m
1 .38848 L
s
.99625 .40614 m
1 .40614 L
s
.99625 .42379 m
1 .42379 L
s
.99625 .45911 m
1 .45911 L
s
.99625 .47677 m
1 .47677 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .51209 m
1 .51209 L
s
.99625 .5474 m
1 .5474 L
s
.99625 .56506 m
1 .56506 L
s
.99625 .58272 m
1 .58272 L
s
.99625 .60038 m
1 .60038 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.83333 .08829 m
.83333 .08829 L
.83332 .0883 L
.82919 .09103 L
.39103 .38118 L
.16741 .52925 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16667 .52974 L
.16669 .52972 L
.16675 .52966 L
.16703 .52936 L
.16823 .52809 L
.17372 .52232 L
.19208 .50341 L
.22588 .47027 L
.25485 .44369 L
.26536 .43451 L
.26815 .43209 L
.27389 .42525 L
.43509 .25162 L
.5674 .14666 L
.62795 .10935 L
.65858 .09258 L
.66498 .08918 L
.66628 .08849 L
.66629 .08849 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.48779 0.0075462 0.97619 0.309394 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.25 0.206011 0.206011 [
[.125 -0.0125 -21.5313 -24.5625 ]
[.125 -0.0125 21.5313 0 ]
[.25 -0.0125 -7.03125 -24.5625 ]
[.25 -0.0125 7.03125 0 ]
[.375 -0.0125 -14.5625 -24.5625 ]
[.375 -0.0125 14.5625 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.625 -0.0125 -14.5625 -24.5625 ]
[.625 -0.0125 14.5625 0 ]
[.75 -0.0125 -7.03125 -24.5625 ]
[.75 -0.0125 7.03125 0 ]
[.875 -0.0125 -14.5625 -24.5625 ]
[.875 -0.0125 14.5625 0 ]
[1 -0.0125 -7.03125 -24.5625 ]
[1 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -10.8125 -49.125 ]
[.5 -0.0125 10.8125 -24.5625 ]
[-0.0125 .10301 -43.0625 -12.2813 ]
[-0.0125 .10301 0 12.2813 ]
[-0.0125 .20601 -14.0625 -12.2813 ]
[-0.0125 .20601 0 12.2813 ]
[-0.0125 .30902 -29.125 -12.2813 ]
[-0.0125 .30902 0 12.2813 ]
[-0.0125 .41202 -14.0625 -12.2813 ]
[-0.0125 .41202 0 12.2813 ]
[-0.0125 .51503 -29.125 -12.2813 ]
[-0.0125 .51503 0 12.2813 ]
[-0.0125 .61803 -14.0625 -12.2813 ]
[-0.0125 .61803 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -10.8125 ]
[-0.01875 .30902 -43.0625 10.8125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -82.5313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -71.8125 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .20601 m
.00625 .20601 L
s
gsave
-0.0125 .20601 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .41202 m
.00625 .41202 L
s
gsave
-0.0125 .41202 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .51503 m
.00625 .51503 L
s
gsave
-0.0125 .51503 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127.156 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.8125 16.2813 translate
90 rotate
-71.8125 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.25 .41202 m
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41201 L
.25 .41201 L
.25 .412 L
.25 .412 L
.25 .41198 L
.25 .41197 L
.25 .41194 L
.25 .4119 L
.25 .41183 L
.25 .41174 L
.25 .41163 L
.25 .41145 L
.25 .41118 L
.25 .4108 L
.25 .41022 L
.25 .40945 L
Mistroke
.25 .40821 L
.25 .40626 L
.25 .40351 L
.25 .39981 L
.25 .39518 L
.25 .38861 L
.25 .36968 L
.25 .34398 L
.25 .30619 L
.25 .27217 L
.25 .25736 L
.25 .24399 L
.25 .234 L
.25 .22683 L
.25 .22364 L
.25 .22106 L
.25 .21845 L
.25 .21643 L
.25 .21325 L
.25 .21197 L
.25 .21087 L
.25 .20952 L
.25 .20893 L
.25 .20848 L
.25 .20813 L
.25 .2078 L
.25 .20732 L
.25 .20711 L
.25 .20692 L
.25 .20676 L
.25 .20663 L
.25 .20645 L
.25 .20638 L
.25 .20632 L
.25 .20623 L
.25 .20619 L
.25 .20616 L
.25 .20614 L
.25 .20611 L
.25 .2061 L
.25 .20608 L
.25 .20607 L
.25 .20606 L
.25 .20605 L
.25 .20604 L
.25 .20604 L
.25 .20603 L
.25 .20603 L
.25 .20602 L
.25 .20602 L
Mistroke
.25 .20602 L
.25 .20602 L
.25 .20602 L
.25 .20602 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
Mistroke
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25001 .20601 L
.25002 .20601 L
.25002 .20601 L
.25002 .20601 L
.25002 .20601 L
.25002 .20601 L
.25002 .20601 L
.25002 .20601 L
.25002 .20601 L
.25002 .20601 L
.25002 .20601 L
Mistroke
.25002 .20601 L
.25002 .20601 L
.25003 .20601 L
.25003 .20601 L
.25003 .20601 L
.25003 .20601 L
.25003 .20601 L
.25003 .20601 L
.25003 .20601 L
.25003 .20601 L
.25004 .20601 L
.25004 .20601 L
.25004 .20601 L
.25004 .20601 L
.25005 .20601 L
.25005 .20601 L
.25005 .20601 L
.25005 .20601 L
.25005 .20601 L
.25005 .20601 L
.25006 .20601 L
.25006 .20601 L
.25006 .20601 L
.25007 .20601 L
.25007 .20601 L
.25007 .20601 L
.25007 .20601 L
.25007 .20601 L
.25008 .20601 L
.25008 .20601 L
.25008 .20601 L
.25008 .20601 L
.25009 .20601 L
.25009 .20601 L
.2501 .20601 L
.2501 .20601 L
.25011 .20601 L
.25011 .20601 L
.25012 .20601 L
.25012 .20601 L
.25014 .20601 L
.25015 .20601 L
.25016 .20601 L
.25016 .20601 L
.25017 .20601 L
.25018 .20601 L
.25019 .20601 L
.25019 .20601 L
.2502 .20601 L
.25021 .20601 L
Mistroke
.25022 .20601 L
.25023 .20601 L
.25026 .20601 L
.25027 .20601 L
.25029 .20601 L
.25029 .20601 L
.2503 .20601 L
.25031 .20601 L
.25032 .20601 L
.25033 .20601 L
.25034 .20601 L
.25035 .20601 L
.25037 .20601 L
.25038 .20601 L
.2504 .20601 L
.25042 .20601 L
.25046 .20601 L
.25049 .20601 L
.25051 .20601 L
.25054 .20601 L
.25056 .20601 L
.25058 .20601 L
.25061 .20601 L
.25064 .20601 L
.25067 .20601 L
.2507 .20601 L
.25073 .20601 L
.25077 .20601 L
.25081 .20601 L
.25085 .20601 L
.25088 .20601 L
.25093 .20601 L
.25095 .20601 L
.25098 .20601 L
.25103 .20601 L
.25105 .20601 L
.25108 .20601 L
.25113 .20601 L
.25118 .20601 L
.25123 .20601 L
.25128 .20601 L
.25134 .20601 L
.25141 .20601 L
.25154 .20601 L
.25161 .20601 L
.25168 .20601 L
.25175 .20601 L
.25183 .20601 L
.25191 .20601 L
.25199 .20601 L
Mistroke
.25215 .20601 L
.25225 .20601 L
.25235 .20601 L
.25248 .20601 L
.2526 .20601 L
.25272 .20601 L
.25284 .20601 L
.25297 .20601 L
.25312 .20601 L
.25373 .20601 L
.25403 .20601 L
.25421 .20601 L
.25439 .20601 L
.2546 .20601 L
.2548 .20601 L
.255 .20601 L
.25523 .20601 L
.25535 .20601 L
.25549 .20601 L
.25564 .20601 L
.25578 .20601 L
.25604 .20601 L
.25633 .20601 L
.25666 .20601 L
.25698 .20601 L
.25715 .20601 L
.25733 .20601 L
.25754 .20601 L
.25773 .20601 L
.25809 .20601 L
.25828 .20601 L
.25849 .20601 L
.25888 .20601 L
.25927 .20601 L
.26004 .20601 L
.26048 .20601 L
.26096 .20601 L
.26144 .20601 L
.26189 .20601 L
.26237 .20601 L
.26282 .20601 L
.2634 .20601 L
.26406 .20601 L
.26466 .20601 L
.26532 .20601 L
.26653 .20601 L
.26725 .20601 L
.26795 .20601 L
.26862 .20601 L
.26937 .20601 L
Mistroke
.27006 .20601 L
.27081 .20601 L
.2715 .20601 L
.27228 .20601 L
.27372 .20601 L
.27462 .20601 L
.27547 .20601 L
.27641 .20601 L
.27747 .20601 L
.27932 .20601 L
.28037 .20601 L
.28136 .20601 L
.28251 .20601 L
.28376 .20601 L
.28606 .20601 L
.28739 .20601 L
.28865 .20601 L
.29015 .20601 L
.2916 .20601 L
.29287 .20601 L
.29427 .20601 L
.29677 .20601 L
.29821 .20601 L
.29976 .20601 L
.30123 .20601 L
.30259 .20601 L
.3054 .20601 L
.30688 .20601 L
.30846 .20601 L
.31112 .20601 L
.31265 .20601 L
.31404 .20601 L
.31664 .20601 L
.31807 .20601 L
.31941 .20601 L
.32179 .20601 L
.32433 .20601 L
.32574 .20601 L
.32702 .20601 L
.32829 .20601 L
.32948 .20601 L
.33232 .20601 L
.33368 .20601 L
.33488 .20601 L
.33613 .20601 L
.33729 .20601 L
.33977 .20601 L
.34095 .20601 L
.34159 .20601 L
.34218 .20601 L
Mistroke
.34281 .20601 L
.34349 .20601 L
.34466 .20601 L
.34669 .20601 L
.34765 .20601 L
.34852 .20601 L
.34929 .20601 L
.35009 .20601 L
.35087 .20601 L
.35171 .20601 L
.35259 .20601 L
.35336 .20601 L
.35418 .20601 L
.35504 .20601 L
.35576 .20601 L
.35642 .20601 L
.35779 .20601 L
.35912 .20601 L
.35946 .20601 L
.35981 .20601 L
.36043 .20601 L
.36078 .20601 L
.36108 .20601 L
.36144 .20601 L
.36176 .20601 L
.36232 .20601 L
.36262 .20601 L
.36289 .20601 L
.36338 .20601 L
.36388 .20601 L
.36434 .20601 L
.36474 .20601 L
.3652 .20601 L
.36542 .20601 L
.36566 .20601 L
.36606 .20601 L
.36642 .20601 L
.36712 .20601 L
.36774 .20601 L
.36825 .20601 L
.36877 .20601 L
.36929 .20601 L
.36954 .20601 L
.3698 .20601 L
.37023 .20601 L
.3706 .20601 L
.37096 .20601 L
.37133 .20601 L
.37165 .20601 L
.37181 .20601 L
Mistroke
.37197 .20601 L
.37223 .20601 L
.37247 .20601 L
.37267 .20601 L
.37285 .20601 L
.37304 .20601 L
.37321 .20601 L
.37338 .20601 L
.37354 .20601 L
.37362 .20601 L
.3737 .20601 L
.37377 .20601 L
.37384 .20601 L
.3739 .20601 L
.37396 .20601 L
.37402 .20601 L
.37408 .20601 L
.37418 .20601 L
.37423 .20601 L
.37429 .20601 L
.37435 .20601 L
.37441 .20601 L
.37446 .20601 L
.37452 .20601 L
.37458 .20601 L
.37464 .20601 L
.37471 .20601 L
.37478 .20601 L
.37485 .20601 L
.37492 .20601 L
.375 .20601 L
.37509 .20601 L
.37521 .20601 L
.37532 .20601 L
.37547 .20601 L
.37563 .20601 L
.3758 .20601 L
.37597 .20601 L
.37618 .20601 L
.37643 .20601 L
.37673 .20601 L
.37691 .20601 L
.37709 .20601 L
.37747 .20601 L
.37789 .20601 L
.37815 .20601 L
.37845 .20601 L
.37905 .20601 L
.37942 .20601 L
.3798 .20601 L
Mistroke
.38029 .20601 L
.38077 .20601 L
.38162 .20601 L
.38265 .20601 L
.38374 .20601 L
.3849 .20601 L
.38644 .20601 L
.38806 .20601 L
.39008 .20601 L
.39121 .20601 L
.39254 .20601 L
.39531 .20601 L
.39819 .20601 L
.39994 .20601 L
.40199 .20601 L
.40611 .20601 L
.41045 .20601 L
.41565 .20601 L
.42116 .20601 L
.42669 .20601 L
.43287 .20601 L
.44003 .20601 L
.44668 .20601 L
.45454 .20601 L
.46371 .20601 L
.4743 .20601 L
.485 .20601 L
.4953 .20601 L
.5062 .20601 L
.51664 .20601 L
.52847 .20601 L
.54132 .20601 L
.56329 .20601 L
.57581 .20601 L
.58745 .20601 L
.6003 .20601 L
.6136 .20601 L
.63613 .20601 L
.64883 .20601 L
.65995 .20601 L
.6784 .20601 L
.69323 .20601 L
.70456 .20601 L
.71469 .20601 L
.72316 .20601 L
.72875 .20601 L
.73353 .20601 L
.73681 .20601 L
.73967 .20601 L
.74225 .20601 L
Mistroke
.74411 .20601 L
.74649 .20601 L
.7473 .20601 L
.74797 .20601 L
.74878 .20601 L
.7491 .20601 L
.74934 .20601 L
.74962 .20601 L
.74972 .20601 L
.74979 .20601 L
.74988 .20601 L
.74991 .20601 L
.74994 .20601 L
.74995 .20601 L
.74997 .20601 L
.74998 .20601 L
.74998 .20601 L
.74998 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.74999 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
Mistroke
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{904.313, 286.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>800017R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;0?ooo`00
o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;
0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0oooo
o`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0oooo203oool01@3ogi`0B00000000000
0000M;oo0?l0oooo[03oool01@3OW4P000000000000004P0W=oo0<`0oooo003o0?ooo`T0oooo00<0
oono07@0B02Lgol0o`3ooon`0?ooo`030?oog`2LB4P0W=oo0</0oooo003o0?ooo`T0oooo00<0oono
07@0B02Lgol0o`3ooona0?ooo`030?noM000M;l0oooo0<X0oooo003l0?ooo`060;md00000000001d
0;ooo`3ookl0M0000P0000001`00B9`0gooo0?ooo`3oool0oono07@0B02Lgol0o`3ooonS0?ooo`06
0;md00000000001d0;ooo`3ookl0M0000P0000000`00B9`0gooo0?ooo`030?ooo`030=nLB000M;l0
oooo0<X0oooo003l0?ooo`030?oog`2LB4P0W=oo0080oooo00<0omnL04P00000M;l0103oool00`3o
okl0M01809cOo`3o0?oooj<0oooo00<0oooO09a8B02Lgol00P3oool00`3ogi`0B000001d_`050?oo
o`030?oOW0180000B9cO0</0oooo003m0?ooo`070?oo_`1dB9`0gooo0?oog`2LB00004RL0=ooo`04
0?ooo`030?oo_`1d04P0W=oo0?l0ooooY03oool01`3ookl0M4RL0=ooo`3ooml0W4P00018W03Oool0
0`3oool0103ooml0W4P000000000M;o<0?ooo`00oP3oool01@3ogi`0B7Bo0;md000004P0W=oo00D0
oooo00<0oono07@0B02Lgol0o`3ooonU0?ooo`050?oOW018M;l0_g@00000B02Lgol01P3oool00`3O
W4P007Bo0?ooo`3;0?ooo`00o`3oool00`3o_g@0000004RLg`060?ooo`030?oo_`1d04P0W=oo0?l0
ooooYP3oool00`3o_g@0000004RLg`040?ooo`060?oOg`3Oool0oooo0?ooo`2oM000M;oob`3oool0
0?h0oooo00@0oono07@0000007@0_ooo1@3oool0103o_g@000000000B02Lgooo0?ooojD0oooo00@0
oono07@0000007@0_ooo103oool01P3ookl0M7Bo0?ooo`3ookl0M00007Bool/0oooo003m0?ooo`06
0?oog`2LB000001809cO_`1dB9`0gooo1@3oool00`3ogi`0B01809cOo`3o0?oooj@0oooo00H0oooO
09a8000004P0W=no07A8W03Oool40?ooo`040?noM00000000000001d_l`0oooo003m0?ooo`070=nL
B0000000M;oo0?ooo`3ogi`0B4RL0=ooo`3o0?oooj/0oooo00L0gia80000001d_ol0oooo0?oOW018
B9`0gooo0=<0oooo003k0?ooo`0:0?oog`2LB00000000000000007@0_ooO09a800000000001d0;oo
ool0ooooZ03oool02P3ooml0W4P0000000000000001d0;oog`2LB00000000000M02ooooB0?ooo`00
o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;
0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0oooo
o`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?oo
ool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo
003o0?ooool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oo
oh/0oooo003o0?ooool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool009d0oooo00<0
okmd0000001d_ol0;`3oool00`3ooml0W4P000000002000000030018W03Oool0oooo0300oooo00<0
gia80000000000001@0000000`1d_ol0oooo0?ooo`0_0?ooo`030?noM000000000000080000000<0
07Bo0?ooo`3oool0:@3oool0102oM000000000000018W=lc0?ooo`030?noM0000000000000800000
00<007Bo0?ooo`3oool0Q@3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO0080
oooo00H0_g@000000000000000000018W03OoolG0?ooo`040;md00000000000004RLgah0oooo00@0
_g@0000000000000B9cO103oool00`3OW4P0000004RLg`020?ooo`060;md00000000000000000000
B9`0gooo7P3oool00`3o_g@000000000000200000003001d_`3oool0oooo01X0oooo00<0okmd0000
000000000P0000001`00M;l0oooo0?ooo`3oool0gia800000018W=l00P3oool01P2oM00000000000
0000000004RL0=oooa/0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`0G0?ooo`03
0=nLB0000000000000D0000000H0M;oo0?ooo`3oool0gia800000018W=l20?ooo`060;md00000000
000000000000B9`0gooo703oool00`3ooml0W4P000000002000000030018W03Oool0oooo02P0oooo
002M0?ooo`030?noM0000000M;oo02l0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cO
oc40oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`0a0?ooo`030;md000007@0_ooo
02X0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo03@0oooo00<0_g@00000M02oool0QP3o
ool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool01`3OW4P0000004RLg`3oool0oooO
09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0D0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0
001d_`0K0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`070=nLB0000000B9cO
0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo01l0oooo00<0_g@00000M02oool07`3o
ool00`2oM000001d0;ooo`040?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`03
0?oOW018B9`0gooo01/0oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`0H0?ooo`03
0=nLB0000000000000@0000000X007Bo0?ooo`3oool0gia800000018W=l0oooo0?oog`2LB000B9cO
0P3oool00`3ogi`0B4RL0=ooo`0K0?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0B02LgolX
0?ooo`00W@3oool00`3o_g@0000007Boo`0e0?ooo`030?noM000B9`0gooo0340oooo00<0gia804RL
g`3oool00P3oool00`3ooml0W4Qd0;ooo`0b0?ooo`030;md000007@0_ooo02X0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`0c0?ooo`030;md000007@0_ooo08H0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`0<0?ooo`030?oOW018M;l0oooo01<0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`0J0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol0303oool00`3ogi`0B7Bo0?ooo`0N0?ooo`030;md000007@0_ooo01l0oooo00<0_g@00000
M02oool03P3oool00`3ogi`0B7Bo0?ooo`0K0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8
M02oool06P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00/0oooo00<0omnL04Qd
_`3oool0803oool00`3o_g@004RL0=ooo`0W0?ooo`00V03oool00`3OW4P000000000000500000003
0000B02Lgol0oooo0380oooo00<0okmd0000B02Lgol0<P3oool00`3OW4P0B9cO0?ooo`0f0?ooo`03
0;md000007@0_ooo02T0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0c0?oo
o`030;md000007@0_ooo08D0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0<
0?ooo`030?oo_`1d04P0W=oo0180oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d
_`0I0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0303oool00`3ookl0M018
09cOo`0N0?ooo`030;md000007@0_ooo01l0oooo00<0_g@00000M02oool03P3oool00`3ookl0M018
09cOo`0L0?ooo`030=nLB018W=l0oooo01l0oooo00<0gia804RLg`3oool03`3oool00`3ookl0M018
09cOo`0P0?ooo`030?noM00004P0W=oo02L0oooo002H0?ooo`030?oOW018M;l0oooo0080oooo00<0
okmd0000001d_ol0=@3oool00`2oM000001809cOo`0c0?ooo`030=nLB01d_ol0oooo03D0oooo00<0
_g@00000M02oool0:@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo0380oooo00<0
_g@00000M02oool0Q@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0
oono07@0001d_ol04P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo01P0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`030?oo_`1d0000M;oo01h0oooo00<0
_g@00000M02oool07`3oool00`2oM000001d0;ooo`0>0?ooo`030?oo_`1d0000M;oo01d0oooo00<0
gia807Boo`3oool07`3oool00`3OW4P0M;oo0?ooo`0>0?ooo`030?oo_`1d0000M;oo0200oooo00<0
_g@00000B02Lgol09`3oool008/0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3o
ool0gia807Boo`80oooo00<0okmd0000001d_ol08P3oool00`2oM0000000000000070000000304RL
g`3oool0oooo00D0oooo00@0_g@00000000007@0_ooo8P3oool00`2oM00000000000000700000003
04RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol0903oool00`2oM00000000000000700000003
04RLg`3oool0oooo00@0oooo00<0_g@00000M02oool0:@3oool00`3ogi`0B00004RLg`040?ooo`03
0;md000007@0_ooo0380oooo00<0_g@00000M02oool0N03oool00`2oM00000000000000700000006
04RLg`3oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000
M;oo0180oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0H0?ooo`030?oOW0180000
B9cO00@0oooo00<0_g@00000M02oool02`3oool00`3o_g@0000007Boo`0N0?ooo`030;md000007@0
_ooo01l0oooo00<0_g@00000M02oool03P3oool00`3o_g@0000007Boo`0M0?ooo`030?oog`2LB4P0
W=oo01l0oooo00<0oooO09a8B02Lgol03P3oool00`3o_g@0000007Boo`0O0?ooo`040;md00000000
001d0;ooobL0oooo002I0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`0a0?ooo`030?oo
_`1d000000000080000000<0B9cO0?ooo`3oool0<`3oool00`3ogi`0B01d0;ooo`0d0?ooo`030;md
000007@0_ooo02T0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0b0?ooo`030;md
000007@0_ooo08D0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`040?oO
W0180000001d0;oooa80oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0H0?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02P3oool0103ogi`0B0000000M02ooolN0?oo
o`030;md000007@0_ooo01l0oooo00<0_g@00000M02oool03@3oool0103ogi`0B0000000M02ooolN
0?ooo`030?oOW01807@0_ooo01l0oooo00<0omnL04P0M02oool0303oool0103ogi`0B0000000M02o
oolL0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool09P3oool009X0oooo00H0okmd
001d_`3oool0okmd0000001d_olc0?ooo`030?noM00004P0W=oo03L0oooo00<0_g@004RLg`3oool0
<`3oool00`2oM000001d0;ooo`0Y0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
<P3oool00`2oM000001d0;ooo`250?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
1P3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo0140oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`0H0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol01P3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo01d0oooo00<0_g@00000
M02oool07`3oool00`2oM000001d0;ooo`090?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO
0?ooo`3oool07P3oool00`2oM000B9cO0?ooo`0O0?ooo`030;md0018W=l0oooo00L0oooo00@0gmoO
0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0M0?ooo`030?noM00004P0W=oo02T0oooo002K
0?ooo`050;md001d_ol0okmd0000001d_ol0=03oool00`3ogi`0B7Bo0?ooo`0f0?ooo`030=nLB000
07@0_ooo03<0oooo00<0_g@00000M02oool0:@3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo0380oooo00<0_g@00000M02oool0Q@3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo00H0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0B0?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool0603oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo00H0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0N0?ooo`030;md0000
07@0_ooo01l0oooo00<0_g@00000M02oool02@3oool00`3o_g@000000000000200000003001d_`3o
ool0oooo01l0oooo00<0gia80000M02oool07`3oool00`3OW4P0001d0;ooo`070?ooo`030?noM000
000000000080000000<007Bo0?ooo`3oool07`3oool00`3ogi`0B7Bo0?ooo`0X0?ooo`00V`3oool0
1@3ookl0M01d0;noM0000000M;oo03@0oooo00<0oooO09a80018W=l0=P3oool00`3o_g@0000007Bo
o`0c0?ooo`030;md000007@0_ooo02X0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d
_`0c0?ooo`030;md000007@0_ooo08H0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d
_`070?ooo`050?oog`2LB00000000000M02oool05P3oool00`2oM00004RL0=ooo`020?ooo`030?oo
g`2LB00007Bo01X0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`050?oo
g`2LB00000000000M02oool08@3oool00`2oM000001d0;ooo`0O0?ooo`030;md000007@0_ooo00T0
oooo00D0oooO09a800000000001d0;ooo`0R0?ooo`030?noM0000000M;oo01l0oooo00<0okmd0000
001d_ol01`3oool01@3ooml0W4P00000000007@0_ooo0280oooo00<0oooO09a80018W=l0:03oool0
09`0oooo00@0okmd000000000000M;oo;`3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB000
07Bo0300oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`0c0?ooo`030;md000007@0
_ooo02X0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0c0?ooo`030;md000007@0
_ooo08H0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`030?noM000M;l0
oooo01L0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0J0?ooo`030?noM00004P0
W=oo0080oooo00<0omnL04P0001d_ol0203oool00`3o_g@007Bo0?ooo`0R0?ooo`030;md000007@0
_ooo01l0oooo00<0_g@00000M02oool02P3oool00`3o_g@007Bo0?ooo`0M0?ooo`030?oOW02L_ol0
oooo00<0oooo00<0_g@00000001d_ol06@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000
M;oo00P0oooo00<0okmd001d_`3oool07P3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB000
07Bo02P0oooo002L0?ooo`040?oog`2LB000000007Booc00oooo00L0omnL04Q8W03Oool0oooo0=nL
B0000000M;oo0340oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=oooc40oooo00D0gia8
000000000000001d0;ooo`0[0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo<P3oool01@3OW4P0
00000000000007@0_ooo08L0oooo00H0_g@00018W03Oool0oooo0;md0000M;l90?ooo`030?oog`2L
B00000000080000000<0001d0;ooo`3oool04`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_a`0
oooo00H0_g@00018W03Oool0oooo0;md0000M;l90?ooo`030?oog`2LB00000000080000000<0001d
0;ooo`3oool06`3oool01@3OW4P000000000000007@0_ooo01d0oooo00D0gia8000000000000001d
0;ooo`0:0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool06@3oool0202oM000M;oo
0?ooo`3oool0gia800000000B9`0gooo6P3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0
gooo203oool00`3ooml0W4P000000002000000030000M02oool0oooo01X0oooo00L0omnL04Q8W03O
ool0oooo0=nLB0000000M;oo02P0oooo002M0?ooo`030?oOW0180000M;oo0340oooo00D0omnL04P0
00000000000004RLg`0c0?ooo`050;md00000000000000000000M;l0=03oool0103ookl0M0000000
M02oool/0?ooo`040;md000000000000001d_c@0oooo00@0oono07@0000007@0_oooR03oool0102o
M000000000000000M;l;0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool04`3oool0
102oM000000000000000M;lN0?ooo`040;md000000000000001d_`/0oooo00<0okmd000000000000
0P0000000`1d_ol0oooo0?ooo`0K0?ooo`040?oo_`1d0000001d0;oooah0oooo00@0oono07@00000
07@0_ooo2`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo01T0oooo00D0_g@00000
000000000000001d_`0M0?ooo`050;md00000000000000000000M;l02`3oool00`3o_g@000000000
00020000000307Boo`3oool0oooo01X0oooo00D0omnL04P000000000000004RLg`0Y0?ooo`00o`3o
oooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3ooon;0?oo
o`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0ooooo`3o
oon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0
ooooo`3ooon;0?ooo`00GP3ooooo000005000000HP3ooooo000005000000:P3oool005h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02P0oooo001N
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC03oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?oo
o`00GP3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000
003oool0oooo02P0oooo001N0?ooo`800000o`3ooom<0?ooo`800000HP3oool00`000000oooo0?oo
o`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`030000003oool0oooo0600oooo0P00003o0?oood/0oooo0`00000Z0?ooo`00GP3oool00`00
0000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oo
od`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0
oooo001N0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?oo
o`3o0?oood`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<0
00000?ooo`3oool0:03oool005h0oooo0P00003o0?oood`0oooo0P00001R0?ooo`030000003oool0
oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oo
od`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?oo
o`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo0600
oooo0P00003o0?oood/0oooo0`00000Z0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oood`0oooo
00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0
:03oool005h0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0
oooo0?l0ooooC03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooC03oool0
0`000000oooo0?ooo`0X0?ooo`00GP3oool200000?l0ooooC03oool200000680oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0
ooooC03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000
oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo0600oooo0P00003o0?oood/0oooo0`00
000Z0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`030000003oool0oooo02P0oooo001A0?ooo`040;md00000000000004RLg`T0oooo0P00003o0?oo
od`0oooo0P00001R0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?oo
o`00C`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0203oool00`000000oooo0?ooo`3o
0?oood`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<00000
0?ooo`3oool0:03oool004l0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?oo
o`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00CP3oool0103ooml0W4P00018W03Oool20?oo
o`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001>0?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`000000oooo0?ooo`3o0?oood`0
oooo00<000000?ooo`3oool0H03oool200000?l0ooooB`3oool3000002X0oooo001>0?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000M02oool01P3oool300000=`0oooo00<0o`000?ooo`3oool0
=03oool20?l003@0oooo0`0000150?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018
W=l00P3oool01P2oM000000000000000000004RL0=ooo`X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`030000003oool0oooo02P0oooo001>0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000
B02Lgol01P3oool00`000000oooo0?ooo`3K0?ooo`80o`00=@3oool00`3o0000oooo0?ooo`0f0?oo
o`030000003oool0oooo0440oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00L0
gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool02@3oool00`000000
oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool004h0oooo00<0omnL04P00018W=l0
103oool00`3OW4P0001809cOo`060?ooo`030000003oool0oooo0=T0oooo0P3o000e0?ooo`80o`00
>@3oool00`000000oooo0?ooo`110?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
303oool00`3ogi`0B7Bo0?ooo`080?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo
0?ooo`0X0?ooo`00CP3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0
00000?ooo`3oool0e`3oool20?l003H0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?oo
o`100?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0303oool00`3ookl0M018
09cOo`080?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00C`3o
ool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool0e@3o
ool20?l003H0oooo0P3o000l0?ooo`030000003oool0oooo0400oooo00<0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`0;0?ooo`030?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`030000003oool0oooo02P0oooo001?0?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol01`3oool00`000000oooo0?ooo`3D0?ooo`030?l0003oool0oooo03D0oooo00<0o`00
0?ooo`3oool0?03oool00`000000oooo0?ooo`0c0?ooo`030;md00000000000000L0000000H0B9cO
0?ooo`3oool0omnL04P00018W=l40?ooo`030;md000007@0_ooo00/0oooo00<0okmd0000001d_ol0
203oool300000?l0ooooBP3oool3000002X0oooo001@0?ooo`060;md0000B9`0gooo0?ooo`2oM000
07Bo203oool200000=<0oooo0P3o000f0?ooo`80o`00?P3oool200000480oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`0:0?ooo`040?oOW0180000001d0;ooo`P0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001A0?ooo`040;md000000000000001d
_`T0oooo00<000000?ooo`3oool0d03oool20?l003L0oooo00<0o`000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`100?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool0103O
gml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0<l0oooo00<0o`000?oo
o`3oool0=@3oool20?l00480oooo00<000000?ooo`3oool0@03oool00`3ookl0M000001d_`040?oo
o`030;md000007@0_ooo00H0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`080?oo
o`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000
oooo0?ooo`3=0?ooo`80o`00=`3oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo0440
oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?ooo`050?oog`2LB00000000000
M02oool02`3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0
oooo00<000000?ooo`3oool0b`3oool20?l003L0oooo0P3o00150?ooo`030000003oool0oooo0440
oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`030?noM000M;l0oooo00`0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000
003oool0oooo0<X0oooo00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`150?ooo`030000
003oool0oooo0480oooo00H0_g@00018W03Oool0oooo0;md0000M;l90?ooo`030?oog`2LB0000000
0080000000<0001d0;ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?oo
o`3oool0:03oool005h0oooo0P0000390?ooo`80o`00=`3oool20?l004L0oooo0P0000150?ooo`04
0;md000000000000001d_`/0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`060?oo
o`800000o`3ooom;0?ooo`<00000:P3oool005h0oooo00<000000?ooo`3oool0aP3oool20?l003P0
oooo00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0
ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`350?ooo`030?l0
003oool0oooo03H0oooo0P3o001;0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0<<0oooo0P3o
000h0?ooo`030?l0003oool0oooo04/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0`@3oool2
0?l003P0oooo0P3o001>0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0<00oooo00<0o`000?oo
o`3oool0=`3oool00`3o0000oooo0?ooo`1>0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`800000_`3oool20?l003P0
oooo0P3o001@0?ooo`800000HP3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3o
ool0:03oool005h0oooo00<000000?ooo`3oool0_03oool20?l003T0oooo00<0o`000?ooo`3oool0
D@3oool00`000000oooo0?ooo`1P0?ooo`800000o`3ooom;0?ooo`<00000:P3oool005h0oooo00<0
00000?ooo`3oool0^`3oool00`3o0000oooo0?ooo`0g0?ooo`80o`00E03oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool0
0`000000oooo0?ooo`2j0?ooo`030?l0003oool0oooo03L0oooo00<0o`000?ooo`3oool0E03oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X
0?ooo`00GP3oool00`000000oooo0?ooo`2h0?ooo`80o`00>03oool20?l005L0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0
oooo00<000000?ooo`3oool0]`3oool00`3o0000oooo0?ooo`0g0?ooo`030?l0003oool0oooo05L0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3o
ool0:03oool00500oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`060?ooo`800000
]`3oool00`3o0000oooo0?ooo`0f0?ooo`80o`00F@3oool200000680oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`030000003oool0oooo02P0oooo001B0?ooo`030;md000007@0_ooo00T0oooo00<0
00000?ooo`3oool0]03oool20?l003P0oooo00<0o`000?ooo`3oool0FP3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00DP3oool0
0`2oM000001d0;ooo`090?ooo`030000003oool0oooo0;<0oooo00<0o`000?ooo`3oool0=P3oool2
0?l005d0oooo00<000000?ooo`3oool0H03oool200000?l0ooooB`3oool3000002X0oooo001B0?oo
o`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0/P3oool00`3o0000oooo0?ooo`0f0?oo
o`030?l0003oool0oooo05d0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oo
od`0oooo00<000000?ooo`3oool0:03oool00580oooo00<0_g@00000M02oool02@3oool00`000000
oooo0?ooo`2a0?ooo`030?l0003oool0oooo03D0oooo0P3o001P0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001B0?ooo`030;md
000007@0_ooo00T0oooo00<000000?ooo`3oool0[`3oool20?l003L0oooo00<0o`000?ooo`3oool0
H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo
0?ooo`0X0?ooo`00DP3oool00`2oM000001d0;ooo`090?ooo`<00000[P3oool00`3o0000oooo0?oo
o`0e0?ooo`80o`00H@3oool300000680oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003o
ool0oooo02P0oooo001B0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0[@3oool0
0`3o0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo06<0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool00580oooo00<0_g@00000
M02oool02@3oool00`000000oooo0?ooo`2[0?ooo`80o`00=P3oool20?l006H0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool00580
oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`2Z0?ooo`030?l0003oool0oooo03D0
oooo00<0o`000?ooo`3oool0IP3oool00`000000oooo0?ooo`1P0?ooo`800000o`3ooom;0?ooo`<0
0000:P3oool00580oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`2Y0?ooo`030?l0
003oool0oooo03@0oooo0P3o001Y0?ooo`030000003oool0oooo0580oooo00@0_g@0000000000000
B9cO2P3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool00500oooo
00D0gia8000000000000001d0;ooo`090?ooo`030000003oool0oooo0:P0oooo00<0o`000?ooo`3o
ool0=03oool00`3o0000oooo0?ooo`1Y0?ooo`030000003oool0oooo0500oooo00L0oooO09a80000
M;l0oooo0?oog`2LB00007Bo00T0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0
oooo02P0oooo001A0?ooo`040?oo_`1d0000001d0;ooo`T0oooo0P00002W0?ooo`80o`00=@3oool2
0?l006/0oooo0P00001B0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool0
0`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?oo
o`3oool0Y@3oool00`3o0000oooo0?ooo`0d0?ooo`030?l0003oool0oooo06`0oooo00<000000?oo
o`3oool0C`3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00P0oooo00<00000
0?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo
0:@0oooo00<0o`000?ooo`3oool0<`3oool20?l006l0oooo00<000000?ooo`3oool0C`3oool00`3o
okl0M000001d_`040?ooo`030;md000007@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0:80oooo0P3o000e0?ooo`03
0?l0003oool0oooo06l0oooo00<000000?ooo`3oool0C`3oool00`3ogi`0B00004RLg`040?ooo`03
0;md000007@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0
oooo001N0?ooo`030000003oool0oooo0:40oooo00<0o`000?ooo`3oool0<`3oool20?l00780oooo
00<000000?ooo`3oool0C`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo
0`00001@0?ooojP0o`00D@3oool3000002X0oooo001N0?ooo`030000003oool0oooo0:00oooo00<0
o`000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`1b0?ooo`030000003oool0oooo04l0oooo00<0
omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo0500oooo00<0
o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool200000:00oooo00<0o`00
0?ooo`3oool0<P3oool20?l007@0oooo0P00001A0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool01`3oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<00000
0?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0W@3oool20?l003@0oooo00<0o`000?oo
o`3oool0M@3oool00`000000oooo0?ooo`1@0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a8
0000M;l0203oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<000000?oo
o`3oool0:03oool005h0oooo00<000000?ooo`3oool0W03oool00`3o0000oooo0?ooo`0b0?ooo`80
o`00N03oool00`000000oooo0?ooo`1@0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol0203oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<000000?ooo`3o
ool0:03oool005h0oooo00<000000?ooo`3oool0V`3oool00`3o0000oooo0?ooo`0b0?ooo`030?l0
003oool0oooo07P0oooo00<000000?ooo`3oool0D@3oool01P2oM00004RL0=ooo`3oool0_g@0001d
_`T0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo
02P0oooo001N0?ooo`030000003oool0oooo09T0oooo0P3o000c0?ooo`80o`00N`3oool00`000000
oooo0?ooo`1B0?ooo`040;md000000000000001d_`X0oooo00<000000?ooo`3oool0D03oool00`3o
0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo09P0
oooo00<0o`000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`1k0?ooo`030000003oool0oooo0600
oooo0P00001A0?ooo`030?l0003oool0oooo0?H0oooo0`00000Z0?ooo`00GP3oool2000009P0oooo
00<0o`000?ooo`3oool0<@3oool20?l007d0oooo0P00001R0?ooo`030000003oool0oooo0500oooo
00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?oo
o`2F0?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0OP3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?oo
o`0X0?ooo`00GP3oool00`000000oooo0?ooo`2D0?ooo`80o`00<P3oool20?l00840oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<00000
0?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0T`3oool00`3o0000oooo0?ooo`0`0?oo
o`80o`00P`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0500oooo00<0o`000?oo
o`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`2B0?ooo`03
0?l0003oool0oooo0300oooo00<0o`000?ooo`3oool0P`3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00
GP3oool00`000000oooo0?ooo`2@0?ooo`80o`00<@3oool20?l008H0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<000000?ooo`3oool0
:03oool004h0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`050?ooo`800000T03o
ool00`3o0000oooo0?ooo`0`0?ooo`030?l0003oool0oooo08D0oooo0P00001R0?ooo`800000D@3o
ool00`3o0000oooo0?ooo`3f0?ooo`<00000:P3oool004l0oooo00<0gia800000000000010000000
0`00M;l0oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00<0o`000?ooo`3oool0;`3oool2
0?l008T0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0
oooo0?P0oooo00<000000?ooo`3oool0:03oool00500oooo00<0gia804RLg`3oool00P3oool00`3o
oml0W4Qd0;ooo`060?ooo`030000003oool0oooo08d0oooo00<0o`000?ooo`3oool0;`3oool00`3o
0000oooo0?ooo`290?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0D03oool00`3o
0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001A0?ooo`030=nLB018W=l0oooo00X0
oooo00<000000?ooo`3oool0S03oool00`3o0000oooo0?ooo`0^0?ooo`80o`00S03oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000
oooo0?ooo`0X0?ooo`00DP3oool00`3OW4P0M;oo0?ooo`090?ooo`030000003oool0oooo08/0oooo
00<0o`000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`2<0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo
001B0?ooo`030?oog`2LB4P0W=oo00T0oooo0`00002:0?ooo`030?l0003oool0oooo02d0oooo0P3o
002=0?ooo`<00000HP3oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<0
00000?ooo`3oool0:03oool005<0oooo00<0omnL04P0M02oool0203oool00`000000oooo0?ooo`29
0?ooo`030?l0003oool0oooo02d0oooo00<0o`000?ooo`3oool0S`3oool00`000000oooo0?ooo`1P
0?ooo`800000D@3oool00`3o0000oooo0?ooo`3f0?ooo`<00000:P3oool005@0oooo00<0_g@004RL
g`3oool01`3oool00`000000oooo0?ooo`280?ooo`030?l0003oool0oooo02`0oooo0P3o002B0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?oo
o`030000003oool0oooo02P0oooo001D0?ooo`030=nLB00007@0_ooo00L0oooo00<000000?ooo`3o
ool0Q`3oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo0980oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<000000?ooo`3o
ool0:03oool005@0oooo00<0okmd0000001d_ol01`3oool00`000000oooo0?ooo`270?ooo`030?l0
003oool0oooo02X0oooo0P3o002E0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001>0?ooo`030?oOW02L
_ol0oooo00<0oooo00<0_g@00000001d_ol01`3oool00`000000oooo0?ooo`260?ooo`030?l0003o
ool0oooo02X0oooo00<0o`000?ooo`3oool0U@3oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00C`3oool0
202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo1`3oool2000008H0oooo00<0o`000?ooo`3o
ool0:@3oool20?l009L0oooo0P00001R0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3o
ool0n03oool00`000000oooo0?ooo`0X0?ooo`00>P3oool00`3o_g@0M;oo0?ooo`060?ooo`030;md
M02oool0oooo00X0oooo00D0_g@00000000000000000001d_`090?ooo`030000003oool0oooo08@0
oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`2H0?ooo`030000003oool0oooo01l0
oooo00<0okmd07Boo`3oool01P3oool00`2oM7@0_ooo0?ooo`0e0?ooo`030000003oool0oooo0500
oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00>P3oool00`3o_g@0001d
0;ooo`040?ooo`040?oog`2LB000001d0;oooaT0oooo00<000000?ooo`3oool0P`3oool00`3o0000
oooo0?ooo`0X0?ooo`80o`00V`3oool00`000000oooo0?ooo`0O0?ooo`030?noM00007@0_ooo00@0
oooo00@0oooO09a8000007@0_ooo=P3oool200000540oooo00<0o`000?ooo`3oool0mP3oool30000
02X0oooo000j0?ooo`040?noM0000000000004RLg`80oooo00D0oono07@0B02Lgol0gibL0;ooo`0I
0?ooo`030000003oool0oooo0880oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`2K
0?ooo`030000003oool0oooo01l0oooo00@0okmd000000000000B9cO0P3oool01@3ookl0M01809cO
o`3OW9`0_ooo03H0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000
003oool0oooo02P0oooo000j0?ooo`080?noW02Lgol0gia80000000004P0M7A80000M02ooolL0?oo
o`030000003oool0oooo0840oooo00<0o`000?ooo`3oool09`3oool20?l009h0oooo00<000000?oo
o`3oool07`3oool0203o_i`0W=oo0=nLB0000000001807AdB00007@0_ooo703oool0102oM0000000
00000018W=l40?ooo`030=nLB0000000B9cO0080oooo00H0_g@000000000000000000018W03Oool:
0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X
0?ooo`00?@3oool0103ookl0M00000000000M;lM0?ooo`030000003oool0oooo0800oooo00<0o`00
0?ooo`3oool09`3oool00`3o0000oooo0?ooo`2N0?ooo`030000003oool0oooo0280oooo00@0oono
07@00000000007Bo6`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool01`3OW4P0
000004RLg`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`090?ooo`030000003oool0
oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00>P3oool02`3o
_i`0W=oo0?noM00004P0W=oo0=nLB0000000001809cOo`3OW9`0_ooo01T0oooo0P0000200?ooo`03
0?l0003oool0oooo02H0oooo0P3o002P0?ooo`8000008@3oool02`3o_i`0W=oo0?noM00004P0W=oo
0=nLB0000000001809cOo`3OW9`0_ooo01L0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`0<0?ooo`030?oOW018M;l0oooo00P0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo
0?ooo`3h0?ooo`030000003oool0oooo02P0oooo000j0?ooo`030?noM000000007Bo00<0oooo00D0
oono07@000000000001d0;ooo`0I0?ooo`030000003oool0oooo07h0oooo00<0o`000?ooo`3oool0
9P3oool00`3o0000oooo0?ooo`2Q0?ooo`030000003oool0oooo01l0oooo00<0okmd00000000M;l0
0`3oool01@3ookl0M0000000000007@0_ooo01H0oooo00@0oooO09a80000B9`0gooo0P3oool00`3o
oml0W4P0001d_`0<0?ooo`030?oo_`1d04P0W=oo00P0oooo00<000000?ooo`3oool0D03oool00`3o
0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo000j0?ooo`030?noM018W=l0oooo00D0
oooo00<0gia80000M02oool06@3oool00`000000oooo0?ooo`1m0?ooo`030?l0003oool0oooo02D0
oooo0P3o002T0?ooo`030000003oool0oooo01l0oooo00<0okmd04RLg`3oool01@3oool00`3OW4P0
001d0;ooo`0F0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02`3oool00`3ookl0
M00007Boo`080?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000
oooo0?ooo`0X0?ooo`00>P3oool00`3o_i`0W=oo0?ooo`060?ooo`030;mdM02oool0oooo01P0oooo
00<000000?ooo`3oool0O03oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo0:@0oooo
00<000000?ooo`3oool07`3oool00`3o_i`0W=oo0?ooo`060?ooo`030;mdM02oool0oooo01D0oooo
00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000M;oo00P0oooo
0`00001@0?ooo`030?l0003oool0oooo0?H0oooo0`00000Z0?ooo`00GP3oool00`000000oooo0?oo
o`1k0?ooo`030?l0003oool0oooo02@0oooo0P3o002W0?ooo`030000003oool0oooo0400oooo00<0
omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`040?oOW0180000001d0;ooo`P0oooo
00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo
001N0?ooo`030000003oool0oooo07X0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?oo
o`2W0?ooo`030000003oool0oooo0400oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`060?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool01`3oool00`000000oooo
0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<000000?ooo`3oool0:03oool005h0oooo0P00
001k0?ooo`030?l0003oool0oooo0280oooo0P3o002Y0?ooo`800000:@3oool00`2oM000000004RL
g`0F0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@000000000
000200000003001d_`3oool0oooo00P0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?oo
o`3h0?ooo`030000003oool0oooo02P0oooo000n0?ooo`030=nLB000B9`0gooo00@0oooo00<0giad
04Q8M02oool05P3oool00`000000oooo0?ooo`1i0?ooo`030?l0003oool0oooo0280oooo00<0o`00
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`0U0?ooo`050?oOW0180000M;oo0=nLB018W=l05`3o
ool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00D0oooO09a800000000001d
0;ooo`0;0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo
0?ooo`0X0?ooo`00?@3oool00`3o_g@007Bo0?ooo`040?ooo`040;md0018W9`0M01d0;oooaH0oooo
00<000000?ooo`3oool0N03oool00`3o0000oooo0?ooo`0Q0?ooo`80o`00[@3oool00`000000oooo
0?ooo`0T0?ooo`060=nLB000B9`0gooo0?ooo`3OW4P0B9cO5`3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00P0oooo00<0okmd001d_`3oool0303oool00`000000oooo0?ooo`1@0?oo
o`030?l0003oool0oooo0?P0oooo00<000000?ooo`3oool0:03oool003d0oooo00<0gia804RLg`3o
ool00P3oool01P3ooml0W4P007Boo`3ookl0M01d0;oooaH0oooo00<000000?ooo`3oool0M`3oool0
0`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0:d0oooo00<000000?ooo`3oool08`3oool0
0`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo01L0oooo00H0_g@00018W03Oool0oooo0;md
0000M;l90?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool01`3oool00`000000oooo
0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<000000?ooo`3oool0:03oool003d0oooo00/0
okmd0000B02Lgol0oooo0?noM00004P0W=oo0?ooo`3ogi`0B01d0;ooo`0F0?ooo`030000003oool0
oooo07H0oooo00<0o`000?ooo`3oool0803oool20?l00;00oooo00<000000?ooo`3oool08P3oool0
0`3OW4P0000000000006000000030000M02oool0oooo01D0oooo00@0_g@000000000000007Bo2`3o
ool00`3o_g@00000000000020000000307Boo`3oool0oooo00H0oooo0P00001A0?ooo`030?l0003o
ool0oooo0?H0oooo0`00000Z0?ooo`00?P3oool0103OW4P0000000000000M;l20?ooo`040?oog`2L
B00004RL0=oooaH0oooo00<000000?ooo`3oool0M@3oool00`3o0000oooo0?ooo`0P0?ooo`030?l0
003oool0oooo0;00oooo00<000000?ooo`3oool0:03oool00`3OW4P0B9cO0?ooo`0e0?ooo`030000
003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00CP3o
ool00`3ooml0W4P000000002000000030018W03Oool0oooo00P0oooo0P00001e0?ooo`030?l0003o
ool0oooo01l0oooo0P3o002b0?ooo`800000HP3oool00`000000oooo0?ooo`1@0?ooo`030?l0003o
ool0oooo0?P0oooo00<000000?ooo`3oool0:03oool004h0oooo00P0omnL04P00000B9`0gooo0?oo
o`3ogi`0B01809cOo`P0oooo00<000000?ooo`3oool0L`3oool00`3o0000oooo0?ooo`0O0?ooo`03
0?l0003oool0oooo0;<0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1@0?ooo`03
0?l0003oool0oooo0?P0oooo00<000000?ooo`3oool0:03oool005@0oooo00<0okmd0018W03Oool0
1`3oool00`000000oooo0?ooo`1b0?ooo`030?l0003oool0oooo01h0oooo0P3o002f0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000
003oool0oooo02P0oooo001D0?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0L@3o
ool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0;H0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?P0oooo00<000000?ooo`3oool0:03o
ool005@0oooo00<0_g@00000B02Lgol01`3oool00`000000oooo0?ooo`1`0?ooo`030?l0003oool0
oooo01d0oooo0P3o002i0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0D03oool0
0`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001C0?ooo`040;md00000000001d
0;ooo`L0oooo00<000000?ooo`3oool0K`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0
oooo0;T0oooo00<000000?ooo`3oool0H03oool200000540oooo00<0o`000?ooo`3oool0mP3oool3
000002X0oooo001@0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool01P3oool30000
06h0oooo00<0o`000?ooo`3oool0703oool20?l00;X0oooo0`00001R0?ooo`030000003oool0oooo
0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00DP3oool00`3o_g@0
001809cOo`090?ooo`030000003oool0oooo06d0oooo00<0o`000?ooo`3oool0703oool00`3o0000
oooo0?ooo`2l0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0D03oool00`3o0000
oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001C0?ooo`030?oOW018M;l0oooo00P0oooo
00<000000?ooo`3oool0K03oool00`3o0000oooo0?ooo`0K0?ooo`80o`00_`3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo
0?ooo`0X0?ooo`00D`3oool00`3ooml0W4P004RLg`080?ooo`030000003oool0oooo06`0oooo00<0
o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`2o0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001>
0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l0203oool00`000000oooo0?ooo`1[
0?ooo`030?l0003oool0oooo01T0oooo0P3o00320?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001?0?oo
o`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`080?ooo`030000003oool0oooo06X0oooo00<0
o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`320?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001@
0?ooo`050?oOW0180000000000000018W=l02@3oool2000006X0oooo00<0o`000?ooo`3oool0603o
ool20?l00<@0oooo0P00001R0?ooo`800000D@3oool00`3o0000oooo0?ooo`3f0?ooo`<00000:P3o
ool005h0oooo00<000000?ooo`3oool0J03oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0
oooo0<D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0
oooo0?P0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0I`3oool00`3o
0000oooo0?ooo`0G0?ooo`80o`00b03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000
oooo0?ooo`1V0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool0b03oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000
oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`1U0?ooo`030?l0003oool0oooo01H0oooo
0P3o003;0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0D03oool00`3o0000oooo
0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo06@0oooo00<0
o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`3;0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001N
0?ooo`800000I03oool00`3o0000oooo0?ooo`0E0?ooo`80o`00c@3oool200000680oooo00<00000
0?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001N0?oo
o`030000003oool0oooo0680oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`3>0?oo
o`030000003oool0oooo0600oooo0P00001A0?ooo`030?l0003oool0oooo0?H0oooo0`00000Z0?oo
o`00GP3oool00`000000oooo0?ooo`1Q0?ooo`030?l0003oool0oooo01@0oooo0P3o003A0?ooo`03
0000003oool0oooo0540oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`03
0000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0X0?ooo`00
GP3oool00`000000oooo0?ooo`1P0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool0
d@3oool00`000000oooo0?ooo`1C0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0
D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003o
ool0oooo05l0oooo00<0o`000?ooo`3oool04`3oool20?l00=@0oooo00<000000?ooo`3oool0D`3o
ool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03o
ool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`1O0?ooo`030?l0003oool0
oooo0180oooo00<0o`000?ooo`3oool0e03oool00`000000oooo0?ooo`1C0?ooo`030;md000007@0
_ooo00X0oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`3h0?ooo`030000003oool0
oooo02P0oooo001N0?ooo`800000G`3oool00`3o0000oooo0?ooo`0A0?ooo`80o`00eP3oool20000
05D0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo
0?P0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0G@3oool00`3o0000
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0=L0oooo00<000000?ooo`3oool0D`3oool00`2oM000
001d0;ooo`0:0?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3oool0n03oool00`000000
oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`1L0?ooo`030?l0003oool0oooo0100oooo
0P3o003J0?ooo`030000003oool0oooo05<0oooo00<0_g@00000M02oool02P3oool300000500oooo
00<0o`000?ooo`3oool0mP3oool3000002X0oooo001N0?ooo`030000003oool0oooo05/0oooo00<0
o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`3J0?ooo`030000003oool0oooo05<0oooo00<0
_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03o
ool005h0oooo00<000000?ooo`3oool0FP3oool00`3o0000oooo0?ooo`0?0?ooo`80o`00g@3oool0
0`000000oooo0?ooo`1C0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo05T0oooo00<0o`000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`3M0?ooo`030000003oool0oooo05<0oooo00<0_g@00000
M02oool02P3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005<0
oooo00<0okmd0000001d_ol0203oool2000005T0oooo00<0o`000?ooo`3oool03P3oool20?l00=l0
oooo0P00001E0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`03
0000003oool0oooo02P0oooo001C0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0
E`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0>00oooo00<000000?ooo`3oool0
D@3oool01@3OW4P000000000000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`03
0000003oool0oooo02P0oooo001C0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0
E`3oool00`3o0000oooo0?ooo`0<0?ooo`80o`00h`3oool00`000000oooo0?ooo`1B0?ooo`040?oo
_`1d0000001d0;ooo`X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0
oooo001>0?ooo`030=nLB0000000000000D0000000<0001809cOo`3oool01@3oool00`000000oooo
0?ooo`1F0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0h`3oool00`000000oooo
0?ooo`1P0?ooo`800000o`3ooom;0?ooo`<00000:P3oool004h0oooo00<0omnL04Qd_`3oool00P3o
ool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo05D0oooo00<0o`000?ooo`3oool02`3o
ool20?l00>H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<0
00000?ooo`3oool0:03oool004l0oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo00P0oooo
0`00001C0?ooo`80o`003@3oool00`3o0000oooo0?ooo`3T0?ooo`<00000HP3oool00`000000oooo
0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool004l0oooo00L0oono07@0M02oool0oooo
0?noM0000000M;oo00P0oooo00<000000?ooo`3oool0DP3oool00`3o0000oooo0?ooo`0;0?ooo`80
o`00j@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000
oooo0?ooo`0X0?ooo`00D03oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`P0oooo00<000000?oo
o`3oool0D@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0>T0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool00540
oooo00D0_g@007Boo`3o_g@0000007Boo`080?ooo`030000003oool0oooo0500oooo00<0o`000?oo
o`3oool02P3oool20?l00>`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oo
od`0oooo00<000000?ooo`3oool0:03oool00540oooo00D0oono07@0M02o_g@0000007Boo`080?oo
o`030000003oool0oooo04l0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`3/0?oo
o`030000003oool0oooo0600oooo0P00003o0?oood/0oooo0`00000Z0?ooo`00DP3oool0103o_g@0
00000000001d_ol80?ooo`030000003oool0oooo04h0oooo00<0o`000?ooo`3oool02@3oool20?l0
0>l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?oo
o`3oool0:03oool00580oooo00@0oooO09a800000000M;oo203oool2000004d0oooo0P3o000;0?oo
o`030?l0003oool0oooo0>h0oooo0P00001R0?ooo`030000003oool0oooo0?l0ooooC03oool00`00
0000oooo0?ooo`0X0?ooo`00D`3oool00`3ogi`0B00007Boo`080?ooo`030000003oool0oooo04/0
oooo00<0o`000?ooo`3oool02@3oool20?l00?80oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0
BP3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0?80oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<0
00000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`080?ooo`80o`00m@3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool0
0`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0m@3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X
0?ooo`00GP3oool00`000000oooo0?ooo`170?ooo`030?l0003oool0oooo00L0oooo0P3o003h0?oo
o`030000003oool0oooo0600oooo0P00003o0?oood/0oooo0`00000Z0?ooo`00GP3oool2000004L0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`3g0?ooo`800000HP3oool00`000000
oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0
A@3oool00`3o0000oooo0?ooo`060?ooo`80o`00n`3oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?oo
o`140?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0n`3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool0
0`000000oooo0?ooo`130?ooo`030?l0003oool0oooo00D0oooo0P3o003n0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?oo
o`030000003oool0oooo0480oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3n0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo
02P0oooo001N0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool0103oool20?l00?l0
oooo0P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000
oooo0?ooo`0X0?ooo`00GP3oool200000440oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`3o0?ooo`40oooo0P00001R0?ooo`800000o`3ooom;0?ooo`<00000:P3oool005h0oooo00<0
00000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`030?ooo`80o`00o`3oool50?ooo`030000003o
ool0oooo0480oooo00<0okmd0000000000000P0000001`00M;l0oooo0?ooo`3oool0gia800000018
W=l00P3oool01P2oM000000000000000000004RL0=ooo`X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo03h0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0A03oool00`2o
M000001d0;ooo`040?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018
B9`0gooo00T0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N
0?ooo`030000003oool0oooo03d0oooo00<0o`000?ooo`3oool00P3oool20?l00?l0oooo203oool0
0`000000oooo0?ooo`140?ooo`030;md000007@0_ooo00h0oooo00<0omnL04Qd_`3oool0203oool0
0`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?oo
o`3oool0?03oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0oooo203oool00`00
0000oooo0?ooo`140?ooo`030;md000007@0_ooo00h0oooo00<0oono07@0B02Lgol0203oool00`00
0000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3o
ool0>`3oool0103o0000oooo0?ooo`3oool20?l00?l0oooo2`3oool00`000000oooo0?ooo`140?oo
o`030;md000007@0_ooo00h0oooo00<0oono07@0001d_ol0203oool00`000000oooo0?ooo`3o0?oo
od`0oooo00<000000?ooo`3oool0:03oool004l0oooo00H0_g@000000000000000000018W03Oool9
0?ooo`800000>`3oool01@3o0000oooo0?ooo`3oool0o`000?l0oooo303oool2000004H0oooo00<0
_g@00000M02oool03P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo0?l0ooooC03o
ool00`000000oooo0?ooo`0X0?ooo`00CP3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo00P0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`020?l00?l0oooo3P3oool0
0`000000oooo0?ooo`140?ooo`030;md000007@0_ooo00d0oooo00@0omnL04P0000007@0_ooo203o
ool300000?l0ooooBP3oool3000002X0oooo001D0?ooo`030?oOW018M;l0oooo00L0oooo00<00000
0?ooo`3oool0>03oool0103o0000oooo0?ooo`3o003o0?oooa00oooo00<000000?ooo`3oool0A03o
ool00`2oM000001d0;ooo`090?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0
1`3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005@0oooo00<0
oono07@0B02Lgol01`3oool00`000000oooo0?ooo`0g0?ooo`040?l0003oool0o`000?l00?l0oooo
4@3oool00`000000oooo0?ooo`140?ooo`030;md000007@0_ooo00T0oooo00<0okmd000000000000
0P0000000`00M;l0oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo
0?ooo`0X0?ooo`00E03oool00`3ookl0M00007Boo`070?ooo`030000003oool0oooo03H0oooo00<0
o`000?ooo`3o0000o`3ooolC0?ooo`030000003oool0oooo04@0oooo00<0_g@00000M02oool02@3o
ool01@3ooml0W4P00000000007@0_ooo00/0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000
003oool0oooo02P0oooo001D0?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool0=@3o
ool30?l00?l0oooo503oool00`000000oooo0?ooo`140?ooo`030;md000007@0_ooo00X0oooo00<0
okmd001d_`3oool0303oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03o
ool005<0oooo00@0omnL04P0000007@0_ooo1`3oool3000003D0oooo00<0o`000?ooo`3oool0o`3o
oolB0?ooo`<00000A03oool01@3OW4P000000000000007@0_ooo00X0oooo00<0oooO09a800000000
0P0000000`0007@0_ooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo
0?ooo`0X0?ooo`00C`3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00H0oooo
00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo04<0oooo00@0oono07@0000007@0
_ooo2`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001?0?ooo`030?noM0000000000000800000
00<007Bo0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0
H03oool200000?l0ooooB`3oool3000002X0oooo001?0?ooo`050?oog`2LB00000000000M02oool0
2P3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool00500oooo00<0okmd001d_`3oool02`3o
ool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`3o0?oood`0oooo00<000000?ooo`3oool0:03oool00500oooo00<0oooO09a8000000000P000000
0`0007@0_ooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00D@3oool00`3o
_g@00000000000020000000307Boo`3oool0oooo00D0oooo0P00003o0?oood`0oooo0P00001R0?oo
o`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000
oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0
oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo
001N0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`1P0?ooo`800000o`3o
oom;0?ooo`<00000:P3oool005h0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?oo
o`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
0?l0ooooC03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool200000?l0ooooC03oool200000680
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000
003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0oooo
C03oool00`000000oooo0?ooo`0X0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oood`0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03o
ool005h0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo
0?l0ooooC03oool00`000000oooo0?ooo`1P0?ooo`800000o`3ooom;0?ooo`<00000:P3oool005h0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`800000o`3ooom<0?ooo`800000
HP3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`030000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC03oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo0?ooo`0X
0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool005h0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooom<0?ooo`03
0000003oool0oooo02P0oooo001N0?ooo`030000003oool0oooo0?l0ooooC03oool00`000000oooo
0?ooo`1P0?ooo`800000o`3ooom;0?ooo`<00000:P3oool00500oooo00H0oooO09a8000000000000
0000M02oool80?ooo`800000o`3ooom<0?ooo`800000D@3oool00`3OW4P000000000000500000003
07Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo02P0
oooo001?0?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgol70?ooo`030000003oool0
oooo0?l0ooooC03oool00`000000oooo0?ooo`1@0?ooo`030=nLB0000000000000@0000000<007Bo
0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool0
04l0oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`060?ooo`030000003oool0oooo
0?l0ooooC03oool00`000000oooo0?ooo`1A0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8
M02oool01`3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3oool0:03oool004h0
oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`060?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0580
oooo00<0gia804RLg`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0:03oool004h0oooo00<0omnL04P00018W=l0103oool00`2oM0000018
09cOo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo05<0oooo00<0gia807Boo`3oool02P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02P0oooo001>0?ooo`030?oOW0180000B9cO00<0oooo00@0
oono07@0000007@0_ooo1P3ooooo000005000000E@3oool00`3ooml0W4Q809cOo`0:0?ooool00000
D000000Z0?ooo`00CP3oool02@3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`3o0?oo
ojd0oooo00<0omnL04P0M02oool0o`3ooon30?ooo`00CP3oool01@3ooml0W4P00000M02ogi`0B000
0080000000<0B9cO0?ooo`3oool0o`3ooon]0?ooo`030;md0018W=l0oooo0?l0ooooPP3oool004l0
oooo00<0okmd00000018W=l0o`3ooonc0?ooo`030=nLB00007@0_ooo0?l0ooooPP3oool004l0oooo
00@0oooO09a8000004P0W=ooo`3ooonb0?ooo`030?noM0000000M;oo0?l0ooooPP3oool00500oooo
00@0oono07@0000007@0_oooo`3ooon[0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d
_ol0o`3ooon20?ooo`00D@3oool0103ooml0W4P000000000M;oo0?oooj/0oooo00P0_g@007Boo`3o
ool0oooo0=nLB000000004RL0=ooool0ooooPP3oool005<0oooo00D0omnL04P00000000004RL0=oo
o`3o0?ooojT0oooo00D0_g@00000000000000000001d_`3o0?oooh@0oooo003o0?ooool0ooooo`3o
oon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o0?ooool0
ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0oooo003o
0?ooool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo0?oooh/0
oooo003o0?ooool0ooooo`3ooon;0?ooo`00o`3ooooo0?ooool0ooooR`3oool00?l0ooooo`3ooooo
0?oooh/0oooo0000\
\>"],
  ImageRangeCache->{{{0, 903.313}, {285.625, 0}} -> {-0.0524767, -0.0158504, \
0.00233026, 0.00233026}, {{22.5, 462.625}, {278.813, 6.75}} -> {-6.69616, \
-3.03799, 0.0179592, 0.0339017}, {{440.625, 880.75}, {278.813, 6.75}} -> \
{-7.31052, -1.87343, 0.0119728, 0.0145293}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 4\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    RowBox[{"(*", " ", 
      RowBox[{
        StyleBox["Red",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[" ",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox["=",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[" ",
          FontColor->RGBColor[1, 0, 0]], 
        RowBox[{
          RowBox[{
            StyleBox[\(\[CapitalOmega]\_m\),
              FontColor->RGBColor[1, 0, 0]], " ", "and", " ", 
            StyleBox["Blue",
              FontColor->RGBColor[0, 0, 1]]}], 
          StyleBox[" ",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["=",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[" ",
            FontColor->RGBColor[0, 0, 1]], 
          RowBox[{
            RowBox[{
              StyleBox[\(\[CapitalOmega]\_rad\),
                FontColor->RGBColor[0, 0, 1]], " ", "and", " ", 
              StyleBox["Green",
                FontColor->RGBColor[0, 1, 0]]}], 
            StyleBox[" ",
              FontColor->RGBColor[0, 1, 0]], 
            StyleBox["=",
              FontColor->RGBColor[0, 1, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[0, 1, 0]], 
            StyleBox[\(\[CapitalOmega]\_DE\),
              FontColor->RGBColor[0, 1, 0]]}]}]}], " ", "*)"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig4omega = 
        Plot[{1 - xx1[N] - xx2[N] - x3[N] - xx4[N], xx1[N] + xx2[N] + x3[N], 
            xx4[N]}, {N, nmin, 3}, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<N\>", "\<\[CapitalOmega]\>"}, 
          PlotRange \[Rule] {\(-0.05\), 1.1}, Axes \[Rule] False, 
          PlotStyle \[Rule] {Hue[0], Hue[ .3], 
              Hue[ .7]}];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig4_omega\>" <> "\<.m\>", 
        fig4omega];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.88961 0.02886 0.026871 0.537421 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.16811 -0.0125 -19.0313 -24.5625 ]
[.16811 -0.0125 19.0313 0 ]
[.31241 -0.0125 -19.0313 -24.5625 ]
[.31241 -0.0125 19.0313 0 ]
[.45671 -0.0125 -19.0313 -24.5625 ]
[.45671 -0.0125 19.0313 0 ]
[.60101 -0.0125 -19.0313 -24.5625 ]
[.60101 -0.0125 19.0313 0 ]
[.74531 -0.0125 -14 -24.5625 ]
[.74531 -0.0125 14 0 ]
[.88961 -0.0125 -7.03125 -24.5625 ]
[.88961 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .02687 -14.0625 -12.2813 ]
[-0.0125 .02687 0 12.2813 ]
[-0.0125 .13436 -29.125 -12.2813 ]
[-0.0125 .13436 0 12.2813 ]
[-0.0125 .24184 -29.125 -12.2813 ]
[-0.0125 .24184 0 12.2813 ]
[-0.0125 .34932 -29.125 -12.2813 ]
[-0.0125 .34932 0 12.2813 ]
[-0.0125 .45681 -29.125 -12.2813 ]
[-0.0125 .45681 0 12.2813 ]
[-0.0125 .56429 -14.0625 -12.2813 ]
[-0.0125 .56429 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -9.4375 ]
[-0.01875 .30902 -29.125 9.4375 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.16811 0 m
.16811 .00625 L
s
gsave
.16811 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.31241 0 m
.31241 .00625 L
s
gsave
.31241 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.45671 0 m
.45671 .00625 L
s
gsave
.45671 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.60101 0 m
.60101 .00625 L
s
gsave
.60101 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.74531 0 m
.74531 .00625 L
s
gsave
.74531 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.88961 0 m
.88961 .00625 L
s
gsave
.88961 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
.05267 0 m
.05267 .00375 L
s
.08153 0 m
.08153 .00375 L
s
.11039 0 m
.11039 .00375 L
s
.13925 0 m
.13925 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.22583 0 m
.22583 .00375 L
s
.25469 0 m
.25469 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.39899 0 m
.39899 .00375 L
s
.42785 0 m
.42785 .00375 L
s
.48557 0 m
.48557 .00375 L
s
.51443 0 m
.51443 .00375 L
s
.54329 0 m
.54329 .00375 L
s
.57215 0 m
.57215 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.68759 0 m
.68759 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.77417 0 m
.77417 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.83189 0 m
.83189 .00375 L
s
.86075 0 m
.86075 .00375 L
s
.91847 0 m
.91847 .00375 L
s
.94733 0 m
.94733 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02687 m
.00625 .02687 L
s
gsave
-0.0125 .02687 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13436 m
.00625 .13436 L
s
gsave
-0.0125 .13436 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24184 m
.00625 .24184 L
s
gsave
-0.0125 .24184 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .34932 m
.00625 .34932 L
s
gsave
-0.0125 .34932 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .45681 m
.00625 .45681 L
s
gsave
-0.0125 .45681 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .56429 m
.00625 .56429 L
s
gsave
-0.0125 .56429 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05374 m
.00375 .05374 L
s
0 .08061 m
.00375 .08061 L
s
0 .10748 m
.00375 .10748 L
s
0 .16123 m
.00375 .16123 L
s
0 .1881 m
.00375 .1881 L
s
0 .21497 m
.00375 .21497 L
s
0 .26871 m
.00375 .26871 L
s
0 .29558 m
.00375 .29558 L
s
0 .32245 m
.00375 .32245 L
s
0 .37619 m
.00375 .37619 L
s
0 .40307 m
.00375 .40307 L
s
0 .42994 m
.00375 .42994 L
s
0 .48368 m
.00375 .48368 L
s
0 .51055 m
.00375 .51055 L
s
0 .53742 m
.00375 .53742 L
s
0 .59116 m
.00375 .59116 L
s
0 .61803 m
.00375 .61803 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.844 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
70.4375 16.2813 translate
90 rotate
-70.4375 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\331) show
77.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.16811 .61178 m
.16811 .61803 L
s
.31241 .61178 m
.31241 .61803 L
s
.45671 .61178 m
.45671 .61803 L
s
.60101 .61178 m
.60101 .61803 L
s
.74531 .61178 m
.74531 .61803 L
s
.88961 .61178 m
.88961 .61803 L
s
.125 Mabswid
.05267 .61428 m
.05267 .61803 L
s
.08153 .61428 m
.08153 .61803 L
s
.11039 .61428 m
.11039 .61803 L
s
.13925 .61428 m
.13925 .61803 L
s
.19697 .61428 m
.19697 .61803 L
s
.22583 .61428 m
.22583 .61803 L
s
.25469 .61428 m
.25469 .61803 L
s
.28355 .61428 m
.28355 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.37013 .61428 m
.37013 .61803 L
s
.39899 .61428 m
.39899 .61803 L
s
.42785 .61428 m
.42785 .61803 L
s
.48557 .61428 m
.48557 .61803 L
s
.51443 .61428 m
.51443 .61803 L
s
.54329 .61428 m
.54329 .61803 L
s
.57215 .61428 m
.57215 .61803 L
s
.62987 .61428 m
.62987 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.68759 .61428 m
.68759 .61803 L
s
.71645 .61428 m
.71645 .61803 L
s
.77417 .61428 m
.77417 .61803 L
s
.80303 .61428 m
.80303 .61803 L
s
.83189 .61428 m
.83189 .61803 L
s
.86075 .61428 m
.86075 .61803 L
s
.91847 .61428 m
.91847 .61803 L
s
.94733 .61428 m
.94733 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02687 m
1 .02687 L
s
.99375 .13436 m
1 .13436 L
s
.99375 .24184 m
1 .24184 L
s
.99375 .34932 m
1 .34932 L
s
.99375 .45681 m
1 .45681 L
s
.99375 .56429 m
1 .56429 L
s
.125 Mabswid
.99625 .05374 m
1 .05374 L
s
.99625 .08061 m
1 .08061 L
s
.99625 .10748 m
1 .10748 L
s
.99625 .16123 m
1 .16123 L
s
.99625 .1881 m
1 .1881 L
s
.99625 .21497 m
1 .21497 L
s
.99625 .26871 m
1 .26871 L
s
.99625 .29558 m
1 .29558 L
s
.99625 .32245 m
1 .32245 L
s
.99625 .37619 m
1 .37619 L
s
.99625 .40307 m
1 .40307 L
s
.99625 .42994 m
1 .42994 L
s
.99625 .48368 m
1 .48368 L
s
.99625 .51055 m
1 .51055 L
s
.99625 .53742 m
1 .53742 L
s
.99625 .59116 m
1 .59116 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .02687 m
.03279 .02687 L
.04262 .02687 L
.05288 .02687 L
.06244 .02687 L
.06792 .02687 L
.0731 .02687 L
.0828 .02687 L
.09324 .02687 L
.09914 .02687 L
.10458 .02687 L
.11425 .02687 L
.12331 .02687 L
.13324 .02687 L
.13882 .02687 L
.14393 .02687 L
.15378 .02687 L
.16292 .02687 L
.16804 .02687 L
.17359 .02687 L
.17613 .02687 L
.17752 .02687 L
.17882 .02687 L
.18002 .02687 L
.18112 .02687 L
.18234 .02687 L
.18364 .02687 L
.18491 .02687 L
.18555 .02687 L
.18626 .02687 L
.18751 .02687 L
.18869 .02687 L
.19007 .02687 L
.19133 .02687 L
.19418 .02687 L
.19895 .02687 L
.20416 .02687 L
.20886 .02687 L
.21323 .02687 L
.21564 .02687 L
.21784 .02687 L
.22019 .02687 L
.22277 .02687 L
.22527 .02687 L
.22762 .02687 L
.23009 .02687 L
.23275 .02687 L
.23522 .02687 L
.23756 .02687 L
.23987 .02687 L
Mistroke
.24195 .02687 L
.24445 .02687 L
.24712 .02687 L
.24958 .02687 L
.2519 .02687 L
.25462 .02687 L
.25712 .02687 L
.25986 .02687 L
.26275 .02687 L
.26531 .02687 L
.26772 .02687 L
.2699 .02687 L
.27225 .02687 L
.27482 .02687 L
.27754 .02687 L
.27987 .02687 L
.28243 .02687 L
.28699 .02687 L
.28955 .02687 L
.29077 .02687 L
.2919 .02687 L
.2929 .02687 L
.29397 .02687 L
.29515 .02687 L
.29622 .02687 L
.29735 .02687 L
.29857 .02687 L
.29972 .02687 L
.30077 .02687 L
.30203 .02687 L
.30323 .02687 L
.3043 .02687 L
.30546 .02687 L
.30673 .02687 L
.30737 .02687 L
.30808 .02687 L
.30932 .02687 L
.31049 .02687 L
.3116 .02687 L
.31277 .02687 L
.31377 .02687 L
.31486 .02687 L
.31604 .02687 L
.3173 .02687 L
.31849 .02687 L
.31958 .02687 L
.32205 .02687 L
.3227 .02687 L
.3234 .02687 L
.32467 .02687 L
Mistroke
.32538 .02687 L
.32604 .02687 L
.32676 .02687 L
.32754 .02687 L
.32825 .02687 L
.3289 .02687 L
.3302 .02687 L
.33151 .02687 L
.33274 .02687 L
.33385 .02687 L
.33505 .02687 L
.33637 .02687 L
.33703 .02687 L
.33775 .02687 L
.33903 .02687 L
.34023 .02687 L
.34149 .02687 L
.34213 .02687 L
.34283 .02687 L
.34408 .02687 L
.34524 .02687 L
.34652 .02687 L
.34716 .02687 L
.34787 .02687 L
.34863 .02687 L
.34934 .02687 L
.34999 .02687 L
.35069 .02687 L
.35197 .02687 L
.3527 .02687 L
.35336 .02687 L
.35459 .02687 L
.35588 .02687 L
.35704 .02687 L
.35813 .02687 L
.35932 .02687 L
.3606 .02687 L
.37023 .02687 L
.37139 .02687 L
.37265 .02687 L
.37383 .02687 L
.37492 .02687 L
.3759 .02687 L
.37698 .02687 L
.37811 .02687 L
.37916 .02687 L
.3804 .02687 L
.38153 .02687 L
.38284 .02687 L
.38407 .02687 L
Mistroke
.38537 .02687 L
.38658 .02687 L
.3879 .02687 L
.38857 .02687 L
.3893 .02687 L
.38997 .02687 L
.39071 .02687 L
.3914 .02687 L
.39205 .02687 L
.39279 .02687 L
.39359 .02687 L
.39433 .02687 L
.395 .02687 L
.39633 .02687 L
.39707 .02687 L
.39776 .02687 L
.39902 .02687 L
.39965 .02687 L
.40035 .02687 L
.40099 .02687 L
.4017 .02687 L
.40297 .02687 L
.40422 .02687 L
.40537 .02687 L
.40792 .02687 L
.40928 .02687 L
.41004 .02687 L
.41075 .02687 L
.41193 .02687 L
.41317 .02687 L
.41426 .02687 L
.41545 .02687 L
.41804 .02687 L
.42046 .02687 L
.42173 .02687 L
.42237 .02687 L
.42308 .02687 L
.42433 .02687 L
.4255 .02687 L
.42621 .02687 L
.42688 .02687 L
.42814 .02687 L
.42884 .02687 L
.42949 .02687 L
.43021 .02687 L
.43097 .02687 L
.43226 .02687 L
.43299 .02687 L
.43366 .02687 L
.43489 .02687 L
Mistroke
.43618 .02687 L
.43735 .02687 L
.43846 .02687 L
.43974 .02687 L
.4409 .02687 L
.44197 .02687 L
.4431 .02687 L
.44434 .02687 L
.44549 .02687 L
.44647 .02687 L
.44752 .02687 L
.44868 .02687 L
.44977 .02687 L
.45105 .02687 L
.45224 .02687 L
.45348 .02687 L
.45414 .02687 L
.45484 .02687 L
.45609 .02687 L
.45728 .02687 L
.45834 .02687 L
.45949 .02687 L
.46072 .02687 L
.46185 .02687 L
.46315 .02687 L
.46439 .02687 L
.46553 .02687 L
.46658 .02687 L
.46774 .02687 L
.46897 .02687 L
.4702 .02687 L
.47089 .02687 L
.47152 .02687 L
.47277 .02687 L
.47392 .02687 L
.47519 .02687 L
.47587 .02687 L
.47659 .02687 L
.47734 .02687 L
.47806 .02687 L
.4787 .02687 L
.47939 .02687 L
.4807 .02687 L
.48192 .02687 L
.48261 .02687 L
.48326 .02687 L
.48402 .02687 L
.48471 .02687 L
.48538 .02687 L
.48611 .02687 L
Mistroke
.4874 .02687 L
.49034 .02687 L
.49165 .02687 L
.49234 .02687 L
.49307 .02687 L
.49371 .02687 L
.49441 .02687 L
.49564 .02687 L
.49684 .02687 L
.49813 .02687 L
.49934 .02687 L
.50045 .02687 L
.50164 .02687 L
.50293 .02687 L
.50414 .02687 L
.50526 .02687 L
.50644 .02687 L
.50768 .02687 L
.51036 .02687 L
.51145 .02687 L
.51248 .02687 L
.51367 .02687 L
.51475 .02687 L
.51594 .02687 L
.51723 .02687 L
.51843 .02687 L
.51954 .02687 L
.52073 .02687 L
.52202 .02687 L
.52323 .02687 L
.52434 .02687 L
.52564 .02687 L
.52637 .02687 L
.52705 .02687 L
.52829 .02687 L
.52894 .02687 L
.52962 .02687 L
.53035 .02687 L
.53102 .02687 L
.53234 .02687 L
.53351 .02687 L
.53479 .02687 L
.5355 .02687 L
.53617 .02687 L
.53694 .02687 L
.53764 .02687 L
.53892 .02687 L
.53964 .02687 L
.5403 .02687 L
.54154 .02687 L
Mistroke
.54273 .02687 L
.54379 .02687 L
.54495 .02687 L
.54621 .02687 L
.54691 .02687 L
.54755 .02687 L
.54879 .02687 L
.54996 .02687 L
.55106 .02687 L
.55222 .02687 L
.55321 .02687 L
.5543 .02687 L
.55548 .02687 L
.55673 .02687 L
.55792 .02687 L
.55901 .02687 L
.56028 .02687 L
.56093 .02687 L
.56164 .02687 L
.5629 .02687 L
.56408 .02687 L
.56475 .02687 L
.56546 .02687 L
.56673 .02687 L
.56744 .02687 L
.5681 .02687 L
.56882 .02687 L
.56959 .02687 L
.57089 .02687 L
.57162 .02687 L
.57229 .02687 L
.57353 .02687 L
.57485 .02687 L
.57602 .02687 L
.57712 .02687 L
.57833 .02687 L
.57963 .02687 L
.58031 .02687 L
.58096 .02687 L
.58217 .02687 L
.58347 .02687 L
.5842 .02687 L
.58487 .02687 L
.586 .02687 L
.58724 .02687 L
.58854 .02687 L
.58974 .02687 L
.59043 .02687 L
.59118 .02687 L
.59188 .02687 L
Mistroke
.59253 .02687 L
.59376 .02687 L
.59507 .02687 L
.59575 .02687 L
.59647 .02687 L
.59779 .02687 L
.59855 .02687 L
.59935 .02687 L
.60003 .02687 L
.60078 .02687 L
.60143 .02687 L
.60214 .02687 L
.60342 .02687 L
.60467 .02687 L
.60582 .02687 L
.60706 .02687 L
.60777 .02687 L
.60843 .02687 L
.60913 .02687 L
.60976 .02687 L
.6105 .02687 L
.6112 .02687 L
.6136 .02687 L
.61475 .02687 L
.61583 .02687 L
.61711 .02687 L
.61828 .02687 L
.61953 .02687 L
.62023 .02687 L
.62088 .02687 L
.62215 .02687 L
.62335 .02687 L
.62443 .02687 L
.6256 .02687 L
.62688 .02687 L
.62752 .02687 L
.62823 .02687 L
.63065 .02687 L
.63181 .02687 L
.63292 .02687 L
.63419 .02687 L
.63535 .02687 L
.63645 .02687 L
.63746 .02687 L
.63857 .02687 L
.63976 .02687 L
.64044 .02687 L
.64116 .02687 L
.64244 .02687 L
.64316 .02687 L
Mistroke
.64383 .02687 L
.64456 .02687 L
.64535 .02687 L
.64602 .02687 L
.64676 .02687 L
.64745 .02687 L
.6481 .02687 L
.64932 .02687 L
.65061 .02687 L
.65177 .02687 L
.65302 .02687 L
.6542 .02687 L
.65528 .02687 L
.65648 .02687 L
.6578 .02687 L
.65846 .02687 L
.65917 .02687 L
.66045 .02687 L
.66168 .02687 L
.66238 .02687 L
.66303 .02687 L
.66435 .02687 L
.66509 .02687 L
.66577 .02687 L
.66698 .02687 L
.66829 .02687 L
.66953 .02687 L
.67069 .02687 L
.67138 .02687 L
.67214 .02687 L
.67285 .02687 L
.67351 .02687 L
.67475 .02687 L
.67606 .02687 L
.67674 .02687 L
.67748 .02687 L
.67818 .02687 L
.67883 .02687 L
.67958 .02687 L
.68038 .02687 L
.68105 .02687 L
.68179 .02687 L
.68302 .02687 L
.68372 .02687 L
.68435 .02687 L
.68553 .02687 L
.68676 .02687 L
.68791 .02687 L
.68898 .02687 L
.69015 .02687 L
Mistroke
.6914 .02687 L
.69211 .02687 L
.69276 .02687 L
.69348 .02687 L
.69424 .02687 L
.69552 .02687 L
.69625 .02687 L
.69692 .02687 L
.69819 .02687 L
.69934 .02687 L
.69999 .02687 L
.70068 .02687 L
.70194 .02687 L
.70313 .02687 L
.70422 .02687 L
.70544 .02687 L
.70673 .02687 L
.70799 .02687 L
.70917 .02687 L
.71046 .02687 L
.71183 .02687 L
.71623 .02687 L
.71743 .02687 L
.71871 .02687 L
.7198 .02687 L
.721 .02687 L
.72239 .02687 L
.72317 .02687 L
.72388 .02687 L
.72454 .02687 L
.72527 .02687 L
.72658 .02687 L
.72727 .02687 L
.72791 .02687 L
.72865 .02687 L
.72932 .02687 L
.73054 .02687 L
.73186 .02687 L
.73306 .02687 L
.73437 .02687 L
.73503 .02687 L
.73573 .02687 L
.73701 .02687 L
.73828 .02687 L
.73949 .02687 L
.74057 .02687 L
.74175 .02687 L
.74288 .02687 L
.74408 .02687 L
.7454 .02687 L
Mistroke
.7466 .02687 L
.74773 .02687 L
.74877 .02687 L
.74992 .02687 L
.75115 .02687 L
.75181 .02687 L
.7525 .02687 L
.75325 .02687 L
.75395 .02687 L
.75521 .02687 L
.75592 .02687 L
.75659 .02687 L
.75774 .02687 L
.75896 .02687 L
.75966 .02687 L
.76029 .02687 L
.76153 .02687 L
.76221 .02687 L
.76293 .02687 L
.76425 .02687 L
.7649 .02687 L
.76559 .02687 L
.76683 .02687 L
.76802 .02687 L
.76913 .02687 L
.77035 .02687 L
.77166 .02687 L
.7724 .02687 L
.77308 .02687 L
.77373 .02687 L
.77441 .02687 L
.77561 .02687 L
.77692 .02687 L
.77765 .02687 L
.77832 .02687 L
.77909 .02687 L
.77982 .02687 L
.78112 .02687 L
.78186 .02687 L
.78254 .02687 L
.78383 .02687 L
.78447 .02687 L
.78518 .02687 L
.78644 .02687 L
.78761 .02687 L
.78833 .02687 L
.789 .02687 L
.79026 .02687 L
.79097 .02687 L
.79162 .02687 L
Mistroke
.79233 .02687 L
.7931 .02687 L
.79428 .02687 L
.79539 .02687 L
.79671 .02687 L
.79793 .02687 L
.79912 .02687 L
.80042 .02687 L
.80108 .02687 L
.80178 .02687 L
.80305 .02687 L
.82166 .02687 L
.82663 .02687 L
.82783 .02687 L
.82913 .02687 L
.82988 .02687 L
.83056 .02687 L
.8312 .02687 L
.83189 .02687 L
.83263 .02687 L
.83331 .02687 L
.83412 .02687 L
.83485 .02687 L
.83555 .02687 L
.8363 .02687 L
.83701 .02687 L
.83766 .02687 L
.8389 .02687 L
.83961 .02687 L
.84025 .02687 L
.84094 .02687 L
.84167 .02687 L
.84299 .02687 L
.84424 .02687 L
.84487 .02687 L
.84557 .02687 L
.84681 .02687 L
.84795 .02687 L
.8486 .02687 L
.84929 .02687 L
.84998 .02687 L
.85073 .02687 L
.85138 .02687 L
.85208 .02687 L
.85334 .02687 L
.85461 .02687 L
.85532 .02687 L
.85598 .02687 L
.85719 .02687 L
.85848 .02687 L
Mistroke
.85962 .02687 L
.8607 .02687 L
.86187 .02687 L
.86314 .02687 L
.86435 .02687 L
.86504 .02687 L
.86569 .02687 L
.867 .02687 L
.86773 .02687 L
.86841 .02687 L
.86954 .02687 L
.87078 .02687 L
.87208 .02687 L
.87329 .02687 L
.87398 .02687 L
.87472 .02687 L
.87543 .02687 L
.87608 .02687 L
.87732 .02687 L
.87863 .02687 L
.87994 .02687 L
.88066 .02687 L
.88134 .02687 L
.88215 .02687 L
.88289 .02687 L
.88358 .02687 L
.88434 .02687 L
.88561 .02687 L
.88625 .02687 L
.88695 .02687 L
.88771 .02687 L
.88842 .02687 L
.88907 .02687 L
.88977 .02687 L
.89043 .02687 L
.89114 .02687 L
.89245 .02687 L
.89371 .02687 L
.89489 .02687 L
.89602 .02687 L
.89709 .02687 L
.89836 .02687 L
.89952 .02687 L
.90068 .02687 L
.90189 .02687 L
.90311 .02687 L
.90381 .02687 L
.90445 .02687 L
.90568 .02687 L
.90637 .02687 L
Mistroke
.90701 .02687 L
.90819 .02687 L
.90943 .02687 L
.91055 .02687 L
.91159 .02687 L
.91273 .02687 L
.91396 .02687 L
.91527 .02687 L
.916 .02687 L
.91669 .02687 L
.91794 .02687 L
.91864 .02687 L
.91927 .02687 L
.92047 .02687 L
.92177 .02687 L
.923 .02687 L
.92412 .02687 L
.92534 .02687 L
.92664 .02687 L
.92787 .02687 L
.92899 .02687 L
.93031 .02687 L
.93105 .02687 L
.93174 .02687 L
.93299 .02687 L
.93363 .02687 L
.93433 .02687 L
.93501 .02687 L
.93573 .02687 L
.93701 .02687 L
.93772 .02687 L
.93838 .02687 L
.93911 .02687 L
.93989 .02687 L
.94056 .02687 L
.94129 .02687 L
.94198 .02687 L
.94262 .02687 L
.94382 .02687 L
.9451 .02687 L
.94609 .02687 L
.94718 .02687 L
.9482 .02687 L
.94915 .02687 L
.95 .02687 L
.95095 .02687 L
.95193 .02687 L
.95285 .02687 L
.95387 .02687 L
.95494 .02687 L
Mistroke
.95585 .02687 L
.95685 .02687 L
.95794 .02687 L
.95909 .02687 L
.96018 .02687 L
.96117 .02687 L
.96211 .02687 L
.9631 .02687 L
.96394 .02687 L
.96488 .02687 L
.96588 .02687 L
.96695 .02687 L
.96797 .02687 L
.96889 .02687 L
.96982 .02687 L
.97068 .02687 L
.97163 .02687 L
.97264 .02687 L
.9736 .02687 L
.9745 .02687 L
.97531 .02687 L
.97619 .02687 L
Mfstroke
.2 1 0 r
.02381 .02687 m
.02499 .02687 L
.02605 .02687 L
.02729 .02687 L
.02846 .02687 L
.03279 .02687 L
.0379 .02687 L
.04014 .02687 L
.04134 .02687 L
.04262 .02687 L
.04386 .02687 L
.045 .02687 L
.04616 .02687 L
.04723 .02687 L
.04843 .02687 L
.04974 .02687 L
.05212 .02687 L
.05347 .02687 L
.05474 .02687 L
.05712 .02687 L
.05968 .02687 L
.06112 .02687 L
.06244 .02687 L
.06488 .02687 L
.06622 .02687 L
.0675 .02687 L
.06996 .02687 L
.07221 .02687 L
.07351 .02687 L
.07488 .02687 L
.07735 .02687 L
.08 .02687 L
.08151 .02687 L
.08293 .02687 L
.08558 .02687 L
.08691 .02687 L
.08837 .02687 L
.09095 .02687 L
.09335 .02687 L
.09481 .02687 L
.0962 .02687 L
.09878 .02687 L
.10023 .02687 L
.10156 .02687 L
.10311 .02687 L
.10458 .02687 L
.10702 .02688 L
.10925 .02688 L
.11166 .02688 L
.11427 .02688 L
Mistroke
.11655 .02689 L
.11898 .02689 L
.12127 .0269 L
.12334 .02691 L
.12464 .02692 L
.12601 .02693 L
.12846 .02695 L
.12982 .02697 L
.13109 .02699 L
.13257 .02702 L
.13398 .02705 L
.13651 .02713 L
.13881 .02722 L
.14129 .02737 L
.14269 .02747 L
.14398 .02759 L
.14641 .02788 L
.14863 .02824 L
.15107 .02879 L
.15364 .0296 L
.15588 .03059 L
.15796 .03182 L
.16025 .03365 L
.16268 .03632 L
.16536 .04045 L
.16686 .0435 L
.16825 .04689 L
.1708 .05494 L
.17349 .06671 L
.17591 .08096 L
.17817 .0982 L
.18064 .12223 L
.1833 .1546 L
.19289 .31752 L
.19815 .4081 L
.20309 .47227 L
.20564 .49625 L
.2084 .51592 L
.20989 .52428 L
.21146 .53163 L
.21427 .54172 L
.21683 .54826 L
.21922 .55267 L
.22183 .55615 L
.2233 .55763 L
.22463 .55874 L
.22711 .56034 L
.22974 .56154 L
.23198 .56227 L
.23445 .56286 L
Mistroke
.23583 .56311 L
.2371 .5633 L
.23846 .56347 L
.23995 .56362 L
.24132 .56374 L
.24259 .56383 L
.2451 .56396 L
.24763 .56406 L
.25001 .56413 L
.25215 .56417 L
.25447 .5642 L
.25699 .56423 L
.25827 .56424 L
.25966 .56425 L
.26214 .56426 L
.26444 .56427 L
.26705 .56428 L
.26946 .56428 L
.2721 .56428 L
.27343 .56429 L
.2749 .56429 L
.27736 .56429 L
.27875 .56429 L
.28002 .56429 L
.28235 .56429 L
.28481 .56429 L
.28703 .56429 L
.28941 .56429 L
.29164 .56429 L
.29368 .56429 L
.29607 .56429 L
.29867 .56429 L
.30111 .56429 L
.30337 .56429 L
.30582 .56429 L
.30805 .56429 L
.30928 .56429 L
.31063 .56429 L
.31191 .56429 L
.31308 .56429 L
.31536 .56429 L
.31779 .56429 L
.32003 .56429 L
.32215 .56429 L
.32467 .56429 L
.32604 .56429 L
.32732 .56429 L
.32842 .56429 L
.32959 .56429 L
.33088 .56429 L
Mistroke
.33208 .56429 L
.33275 .56429 L
.33346 .56429 L
.33417 .56429 L
.33496 .56429 L
.33564 .56429 L
.33637 .56429 L
.33769 .56429 L
.33834 .56429 L
.33905 .56429 L
.34035 .56429 L
.34162 .56429 L
.34279 .56429 L
.34408 .56429 L
.34473 .56429 L
.34544 .56429 L
.34671 .56429 L
.34787 .56429 L
.34857 .56429 L
.34924 .56429 L
.34994 .56429 L
.35071 .56429 L
.35137 .56429 L
.35208 .56429 L
.35336 .56429 L
.35453 .56429 L
.35579 .56429 L
.35699 .56429 L
.35809 .56429 L
.3593 .56429 L
.35999 .56429 L
.36063 .56429 L
.36192 .56429 L
.36265 .56429 L
.36331 .56429 L
.3679 .56429 L
.36915 .56429 L
.37032 .56429 L
.37153 .56429 L
.37222 .56429 L
.37288 .56429 L
.37406 .56429 L
.37514 .56429 L
.37631 .56429 L
.37758 .56429 L
.37867 .56429 L
.37983 .56429 L
.38092 .56429 L
.38191 .56429 L
.38312 .56429 L
Mistroke
.38424 .56429 L
.38548 .56429 L
.3868 .56429 L
.38746 .56429 L
.38819 .56429 L
.3895 .56429 L
.39067 .56429 L
.39196 .56429 L
.39316 .56429 L
.39428 .56429 L
.39547 .56429 L
.39675 .56429 L
.39788 .56429 L
.39907 .56429 L
.40008 .56429 L
.40119 .56429 L
.40186 .56429 L
.4026 .56429 L
.40329 .56429 L
.40393 .56429 L
.40513 .56429 L
.40641 .56429 L
.4078 .56429 L
.40857 .56429 L
.40929 .56429 L
.40997 .56429 L
.4107 .56429 L
.41198 .56429 L
.41319 .56429 L
.41447 .56429 L
.41556 .56429 L
.41676 .56429 L
.41927 .56429 L
.4206 .56429 L
.42133 .56429 L
.42202 .56429 L
.42266 .56429 L
.42335 .56429 L
.42456 .56429 L
.42579 .56429 L
.42692 .56429 L
.42812 .56429 L
.42943 .56429 L
.43009 .56429 L
.4308 .56429 L
.43209 .56429 L
.43327 .56429 L
.43456 .56429 L
.43578 .56429 L
.43692 .56429 L
Mistroke
.43904 .56429 L
.44133 .56429 L
.44202 .56429 L
.44275 .56429 L
.44406 .56429 L
.44528 .56429 L
.44598 .56429 L
.44662 .56429 L
.44784 .56429 L
.44894 .56429 L
.45022 .56429 L
.45142 .56429 L
.45272 .56429 L
.45338 .56429 L
.4541 .56429 L
.45538 .56429 L
.45657 .56429 L
.45726 .56429 L
.45798 .56429 L
.45927 .56429 L
.45999 .56429 L
.46066 .56429 L
.46139 .56429 L
.46218 .56429 L
.46341 .56429 L
.46411 .56429 L
.46477 .56429 L
.46609 .56429 L
.46683 .56429 L
.46751 .56429 L
.46872 .56429 L
.47003 .56429 L
.47127 .56429 L
.47242 .56429 L
.47312 .56429 L
.47388 .56429 L
.47459 .56429 L
.47525 .56429 L
.47649 .56429 L
.4778 .56429 L
.47849 .56429 L
.47922 .56429 L
.48053 .56429 L
.48134 .56429 L
.4821 .56429 L
.48279 .56429 L
.48353 .56429 L
.48815 .56429 L
.48878 .56429 L
.48948 .56429 L
Mistroke
.49074 .56429 L
.49197 .56429 L
.49312 .56429 L
.49383 .56429 L
.4945 .56429 L
.49575 .56429 L
.49641 .56429 L
.49711 .56429 L
.49787 .56429 L
.49857 .56429 L
.50104 .56429 L
.50368 .56429 L
.50499 .56429 L
.50624 .56429 L
.50735 .56429 L
.50857 .56429 L
.51093 .56429 L
.51199 .56429 L
.51313 .56429 L
.51436 .56429 L
.51552 .56429 L
.51619 .56429 L
.51689 .56429 L
.51816 .56429 L
.51948 .56429 L
.52071 .56429 L
.52141 .56429 L
.52206 .56429 L
.5228 .56429 L
.5235 .56429 L
.53359 .56429 L
.53501 .56429 L
.53571 .56429 L
.53635 .56429 L
.53702 .56429 L
.53774 .56429 L
.53853 .56429 L
.53928 .56429 L
.54049 .56429 L
.54179 .56429 L
.54253 .56429 L
.54321 .56429 L
.54452 .56429 L
.54573 .56429 L
.54685 .56429 L
.54809 .56429 L
.54941 .56429 L
.55007 .56429 L
.55079 .56429 L
.5521 .56429 L
Mistroke
.55338 .56429 L
.55456 .56429 L
.55566 .56429 L
.55669 .56429 L
.55782 .56429 L
.55904 .56429 L
.56025 .56429 L
.56152 .56429 L
.5626 .56429 L
.56379 .56429 L
.56447 .56429 L
.5652 .56429 L
.56589 .56429 L
.56653 .56429 L
.56773 .56429 L
.56901 .56429 L
.56967 .56429 L
.57038 .56429 L
.57167 .56429 L
.57245 .56429 L
.57319 .56429 L
.57386 .56429 L
.57458 .56429 L
.57527 .56429 L
.57591 .56429 L
.57711 .56429 L
.5784 .56429 L
.57913 .56429 L
.57979 .56429 L
.58091 .56429 L
.58214 .56429 L
.58342 .56429 L
.58462 .56429 L
.58589 .56429 L
.58658 .56429 L
.58723 .56429 L
.58838 .56429 L
.58965 .56429 L
.59035 .56429 L
.59102 .56429 L
.59228 .56429 L
.59298 .56429 L
.59363 .56429 L
.59434 .56429 L
.59511 .56429 L
.59641 .56429 L
.59763 .56429 L
.59882 .56429 L
.59991 .56429 L
.6011 .56429 L
Mistroke
.6024 .56429 L
.60306 .56429 L
.60376 .56429 L
.60503 .56429 L
.60627 .56429 L
.60742 .56429 L
.60868 .56429 L
.60932 .56429 L
.61002 .56429 L
.61119 .56429 L
.61246 .56429 L
.61365 .56429 L
.61475 .56429 L
.61581 .56429 L
.61681 .56429 L
.6179 .56429 L
.61906 .56429 L
.62029 .56429 L
.62144 .56429 L
.62248 .56429 L
.62361 .56429 L
.62484 .56429 L
.62596 .56429 L
.62726 .56429 L
.62849 .56429 L
.63068 .56429 L
.63192 .56429 L
.63307 .56429 L
.63372 .56429 L
.63443 .56429 L
.63571 .56429 L
.63696 .56429 L
.63811 .56429 L
.63936 .56429 L
.64006 .56429 L
.64072 .56429 L
.64142 .56429 L
.64205 .56429 L
.64279 .56429 L
.64348 .56429 L
.64469 .56429 L
.64538 .56429 L
.64602 .56429 L
.64669 .56429 L
.64741 .56429 L
.64872 .56429 L
.64985 .56429 L
.65108 .56429 L
.65237 .56429 L
.65356 .56429 L
Mistroke
.65425 .56429 L
.65499 .56429 L
.6557 .56429 L
.65634 .56429 L
.65757 .56429 L
.65886 .56429 L
.65954 .56429 L
.66025 .56429 L
.66104 .56429 L
.66177 .56429 L
.66308 .56429 L
.66382 .56429 L
.66452 .56429 L
.66576 .56429 L
.6669 .56429 L
.66815 .56429 L
.66947 .56429 L
.67058 .56429 L
.67162 .56429 L
.67276 .56429 L
.67398 .56429 L
.67529 .56429 L
.67603 .56429 L
.67671 .56429 L
.67797 .56429 L
.6786 .56429 L
.6793 .56429 L
.6805 .56429 L
.68179 .56429 L
.68301 .56429 L
.68413 .56429 L
.68526 .56429 L
.68646 .56429 L
.6876 .56429 L
.68862 .56429 L
.68984 .56429 L
.69115 .56429 L
.69353 .56429 L
.6947 .56429 L
.69579 .56429 L
.69693 .56429 L
.69818 .56429 L
.69926 .56429 L
.70024 .56429 L
.70138 .56429 L
.70246 .56429 L
.70353 .56429 L
.70467 .56429 L
.70591 .56429 L
.70705 .56429 L
Mistroke
.7083 .56429 L
.709 .56429 L
.70966 .56429 L
.71085 .56429 L
.71212 .56429 L
.71281 .56429 L
.71344 .56429 L
.71488 .56429 L
.71613 .56429 L
.71683 .56429 L
.71749 .56429 L
.71864 .56429 L
.71987 .56429 L
.72117 .56429 L
.72238 .56429 L
.72352 .56429 L
.72474 .56429 L
.72544 .56429 L
.72609 .56429 L
.72732 .56429 L
.72849 .56429 L
.72957 .56429 L
.73076 .56429 L
.73201 .56429 L
.73305 .56429 L
.73418 .56429 L
.73524 .56429 L
.7362 .56429 L
.73733 .56429 L
.73857 .56429 L
.73973 .56429 L
.7408 .56429 L
.74318 .56429 L
.74545 .56429 L
.7467 .56429 L
.74741 .56429 L
.74807 .56429 L
.74923 .56429 L
.75046 .56429 L
.75163 .56429 L
.7529 .56429 L
.75402 .56429 L
.75521 .56429 L
.75628 .56429 L
.75745 .56429 L
.75852 .56429 L
.75951 .56429 L
.76079 .56429 L
.76152 .56429 L
.76218 .56429 L
Mistroke
.76341 .56429 L
.76472 .56429 L
.76588 .56429 L
.76697 .56429 L
.76817 .56429 L
.76946 .56429 L
.77087 .56429 L
.77217 .56429 L
.77283 .56429 L
.77354 .56429 L
.77432 .56429 L
.77503 .56429 L
.77629 .56429 L
.777 .56429 L
.77765 .56429 L
.77893 .56429 L
.78013 .56429 L
.7813 .56429 L
.78257 .56429 L
.78373 .56429 L
.7848 .56429 L
.78608 .56429 L
.78723 .56429 L
.78787 .56429 L
.78856 .56429 L
.78982 .56429 L
.79092 .56429 L
.79212 .56429 L
.79337 .56429 L
.79454 .56429 L
.79564 .56429 L
.79664 .56429 L
.79779 .56429 L
.79888 .56429 L
.80007 .56429 L
.80138 .56429 L
.80203 .56429 L
.80274 .56429 L
.80402 .56429 L
.80523 .56429 L
.8065 .56429 L
.80759 .56429 L
.80877 .56429 L
.8095 .56429 L
.81019 .56429 L
.81147 .56429 L
.81219 .56429 L
.81285 .56429 L
.81357 .56429 L
.81434 .56429 L
Mistroke
.81562 .56429 L
.81681 .56429 L
.81812 .56429 L
.81885 .56429 L
.81952 .56429 L
.82069 .56429 L
.8218 .56429 L
.82301 .56429 L
.82431 .56429 L
.82561 .56429 L
.82626 .56429 L
.82697 .56429 L
.82823 .56429 L
.82941 .56429 L
.8306 .56429 L
.83173 .56429 L
.83274 .56429 L
.83383 .56429 L
.83503 .56429 L
.8363 .56429 L
.83857 .56429 L
.83985 .56429 L
.84102 .56429 L
.84167 .56429 L
.84238 .56429 L
.84367 .56429 L
.84487 .56429 L
.84614 .56429 L
.84735 .56429 L
.84844 .56429 L
.84912 .56429 L
.84984 .56429 L
.85113 .56429 L
.85185 .56429 L
.85252 .56429 L
.85325 .56429 L
.85404 .56429 L
.85472 .56429 L
.85546 .56429 L
.85616 .56429 L
.8568 .56429 L
.85802 .56429 L
.85932 .56429 L
.86045 .56429 L
.8617 .56429 L
.863 .56429 L
.86421 .56429 L
.86534 .56429 L
.86637 .56429 L
.86756 .56429 L
Mistroke
.86869 .56429 L
.86991 .56429 L
.87121 .56429 L
.87232 .56429 L
.87353 .56429 L
.87484 .56429 L
.87558 .56429 L
.87625 .56429 L
.87755 .56429 L
.87879 .56429 L
.87994 .56429 L
.88099 .56429 L
.88219 .56429 L
.88333 .56429 L
.88438 .56429 L
.88535 .56429 L
.88641 .56429 L
.88754 .56429 L
.88866 .56429 L
.88973 .56429 L
.89096 .56429 L
.89208 .56429 L
.89332 .56429 L
.89402 .56429 L
.89466 .56429 L
.89583 .56429 L
.89707 .56429 L
.89821 .56429 L
.89946 .56429 L
.90076 .56429 L
.90197 .56429 L
.90311 .56429 L
.90415 .56429 L
.90534 .56429 L
.90647 .56429 L
.9077 .56429 L
.909 .56429 L
.9101 .56429 L
.91132 .56429 L
.91264 .56429 L
.91337 .56429 L
.91404 .56429 L
.91535 .56429 L
.91658 .56429 L
.91772 .56429 L
.91879 .56429 L
.9199 .56429 L
.92113 .56429 L
.92219 .56429 L
.92316 .56429 L
Mistroke
.92422 .56429 L
.92534 .56429 L
.92648 .56429 L
.9277 .56429 L
.92885 .56429 L
.92989 .56429 L
.93112 .56429 L
.93181 .56429 L
.93245 .56429 L
.93363 .56429 L
.93488 .56429 L
.93608 .56429 L
.9374 .56429 L
.93864 .56429 L
.9398 .56429 L
.94094 .56429 L
.94198 .56429 L
.94317 .56429 L
.9443 .56429 L
.94553 .56429 L
.94683 .56429 L
.94795 .56429 L
.94916 .56429 L
.95048 .56429 L
.95122 .56429 L
.95189 .56429 L
.95319 .56429 L
.95443 .56429 L
.95548 .56429 L
.95664 .56429 L
.95785 .56429 L
.95898 .56429 L
.96004 .56429 L
.96101 .56429 L
.96208 .56429 L
.9632 .56429 L
.96434 .56429 L
.96556 .56429 L
.96671 .56429 L
.96775 .56429 L
.96898 .56429 L
.96968 .56429 L
.97032 .56429 L
.97149 .56429 L
.97273 .56429 L
.97359 .56429 L
.97452 .56429 L
.97539 .56429 L
.97619 .56429 L
Mfstroke
.2 0 1 r
.02381 .56429 m
.02499 .56429 L
.02605 .56429 L
.02729 .56429 L
.02846 .56429 L
.03279 .56429 L
.0379 .56429 L
.04014 .56429 L
.04134 .56429 L
.04262 .56429 L
.04386 .56429 L
.045 .56429 L
.04616 .56429 L
.04723 .56429 L
.04843 .56429 L
.04974 .56429 L
.05212 .56429 L
.05347 .56429 L
.05474 .56429 L
.05712 .56429 L
.05968 .56429 L
.06112 .56429 L
.06244 .56429 L
.06488 .56429 L
.06622 .56429 L
.0675 .56429 L
.06996 .56429 L
.07221 .56429 L
.07351 .56429 L
.07488 .56429 L
.07735 .56429 L
.08 .56429 L
.08151 .56429 L
.08293 .56429 L
.08558 .56429 L
.08691 .56429 L
.08837 .56429 L
.09095 .56429 L
.09335 .56429 L
.09481 .56429 L
.0962 .56429 L
.09878 .56429 L
.10023 .56429 L
.10156 .56429 L
.10311 .56429 L
.10458 .56429 L
.10702 .56429 L
.10925 .56429 L
.11166 .56428 L
.11427 .56428 L
Mistroke
.11655 .56428 L
.11898 .56427 L
.12127 .56426 L
.12334 .56425 L
.12464 .56424 L
.12601 .56423 L
.12846 .56421 L
.12982 .56419 L
.13109 .56417 L
.13257 .56414 L
.13398 .56411 L
.13651 .56404 L
.13881 .56394 L
.14129 .5638 L
.14269 .56369 L
.14398 .56357 L
.14641 .56329 L
.14863 .56292 L
.15107 .56238 L
.15364 .56156 L
.15588 .56057 L
.15796 .55934 L
.16025 .55752 L
.16268 .55484 L
.16536 .55071 L
.16686 .54766 L
.16825 .54427 L
.1708 .53622 L
.17349 .52445 L
.17591 .5102 L
.17817 .49297 L
.18064 .46894 L
.1833 .43657 L
.19289 .27364 L
.19815 .18306 L
.20309 .11889 L
.20564 .09491 L
.2084 .07524 L
.20989 .06689 L
.21146 .05953 L
.21427 .04944 L
.21683 .0429 L
.21922 .03849 L
.22183 .03501 L
.2233 .03353 L
.22463 .03242 L
.22711 .03082 L
.22974 .02962 L
.23198 .02889 L
.23445 .02831 L
Mistroke
.23583 .02806 L
.2371 .02787 L
.23846 .02769 L
.23995 .02754 L
.24132 .02743 L
.24259 .02734 L
.2451 .0272 L
.24763 .0271 L
.25001 .02704 L
.25215 .02699 L
.25447 .02696 L
.25699 .02693 L
.25827 .02692 L
.25966 .02691 L
.26214 .0269 L
.26444 .02689 L
.26705 .02689 L
.26946 .02688 L
.2721 .02688 L
.27343 .02688 L
.2749 .02688 L
.27736 .02687 L
.27875 .02687 L
.28002 .02687 L
.28235 .02687 L
.28481 .02687 L
.28703 .02687 L
.28941 .02687 L
.29164 .02687 L
.29368 .02687 L
.29607 .02687 L
.29867 .02687 L
.30111 .02687 L
.30337 .02687 L
.30582 .02687 L
.30805 .02687 L
.30928 .02687 L
.31063 .02687 L
.31191 .02687 L
.31308 .02687 L
.31536 .02687 L
.31779 .02687 L
.32003 .02687 L
.32215 .02687 L
.32467 .02687 L
.32732 .02687 L
.32959 .02687 L
.33208 .02687 L
.33476 .02687 L
.33626 .02687 L
Mistroke
.33762 .02687 L
.34028 .02687 L
.34279 .02687 L
.34517 .02687 L
.34632 .02687 L
.3474 .02687 L
.34868 .02687 L
.34985 .02687 L
.35111 .02687 L
.35248 .02687 L
.35381 .02687 L
.35506 .02687 L
.35575 .02687 L
.3565 .02687 L
.35781 .02687 L
.35906 .02687 L
.36039 .02687 L
.36276 .02687 L
.36771 .02687 L
.3724 .02687 L
.37444 .02687 L
.37661 .02687 L
.37774 .02687 L
.37899 .02687 L
.38013 .02687 L
.3812 .02687 L
.38235 .02687 L
.38357 .02687 L
.38461 .02687 L
.38575 .02687 L
.38698 .02687 L
.3883 .02687 L
.38953 .02687 L
.39067 .02687 L
.39198 .02687 L
.39267 .02687 L
.3934 .02687 L
.39464 .02687 L
.39533 .02687 L
.39599 .02687 L
.39847 .02687 L
.40083 .02687 L
.40189 .02687 L
.40303 .02687 L
.40428 .02687 L
.40544 .02687 L
.40658 .02687 L
.40766 .02687 L
.40862 .02687 L
.40966 .02687 L
Mistroke
.41081 .02687 L
.41207 .02687 L
.41329 .02687 L
.41461 .02687 L
.41584 .02687 L
.41696 .02687 L
.41809 .02687 L
.41916 .02687 L
.42023 .02687 L
.42138 .02687 L
.42246 .02687 L
.42344 .02687 L
.42559 .02687 L
.42794 .02687 L
.42916 .02687 L
.43048 .02687 L
.43173 .02687 L
.43288 .02687 L
.43393 .02687 L
.43508 .02687 L
.43627 .02687 L
.4374 .02687 L
.43805 .02687 L
.43876 .02687 L
.43999 .02687 L
.44069 .02687 L
.44143 .02687 L
.44207 .02687 L
.44277 .02687 L
.44401 .02687 L
.44467 .02687 L
.44536 .02687 L
.44662 .02687 L
.44779 .02687 L
.44895 .02687 L
.45019 .02687 L
.45244 .02687 L
.45309 .02687 L
.45381 .02687 L
.4551 .02687 L
.45636 .02687 L
.45753 .02687 L
.46249 .02687 L
.46492 .02687 L
.46714 .02687 L
.46834 .02687 L
.46948 .02687 L
.47068 .02687 L
.47199 .02687 L
.47269 .02687 L
Mistroke
.47333 .02687 L
.47407 .02687 L
.47476 .02687 L
.47599 .02687 L
.47669 .02687 L
.47733 .02687 L
.47988 .02687 L
.48131 .02687 L
.48262 .02687 L
.48383 .02687 L
.48515 .02687 L
.4864 .02687 L
.48755 .02687 L
.48874 .02687 L
.49005 .02687 L
.49071 .02687 L
.49141 .02687 L
.4927 .02687 L
.49338 .02687 L
.49413 .02687 L
.49565 .02687 L
.49835 .02687 L
.49958 .02687 L
.50088 .02687 L
.50157 .02687 L
.50232 .02687 L
.50363 .02687 L
.50488 .02687 L
.50621 .02687 L
.50863 .02687 L
.50982 .02687 L
.51113 .02687 L
.51236 .02687 L
.51351 .02687 L
.51464 .02687 L
.51567 .02687 L
.51676 .02687 L
.51796 .02687 L
.51928 .02687 L
.52 .02687 L
.52067 .02687 L
.52187 .02687 L
.52315 .02687 L
.52388 .02687 L
.52466 .02687 L
.5254 .02687 L
.52609 .02687 L
.52738 .02687 L
.52804 .02687 L
.52876 .02687 L
Mistroke
.53128 .02687 L
.534 .02687 L
.53532 .02687 L
.53657 .02687 L
.53892 .02687 L
.54016 .02687 L
.5415 .02687 L
.54394 .02687 L
.54509 .02687 L
.54631 .02687 L
.54745 .02687 L
.54849 .02687 L
.5497 .02687 L
.55101 .02687 L
.55336 .02687 L
.5587 .02687 L
.56089 .02687 L
.562 .02687 L
.56322 .02687 L
.56454 .02687 L
.56577 .02687 L
.56691 .02687 L
.56814 .02687 L
.56922 .02687 L
.57041 .02687 L
.57165 .02687 L
.5728 .02687 L
.57488 .02687 L
.57602 .02687 L
.57708 .02687 L
.57833 .02687 L
.57899 .02687 L
.57971 .02687 L
.58097 .02687 L
.58213 .02687 L
.58278 .02687 L
.58347 .02687 L
.58423 .02687 L
.58493 .02687 L
.58565 .02687 L
.58633 .02687 L
.58759 .02687 L
.5888 .02687 L
.59008 .02687 L
.59117 .02687 L
.59237 .02687 L
.59365 .02687 L
.59503 .02687 L
.59633 .02687 L
.59752 .02687 L
Mistroke
.59992 .02687 L
.60252 .02687 L
.60481 .02687 L
.60725 .02687 L
.60942 .02687 L
.61146 .02687 L
.61369 .02687 L
.6161 .02687 L
.61851 .02687 L
.61983 .02687 L
.62107 .02687 L
.62349 .02687 L
.62569 .02687 L
.62696 .02687 L
.62831 .02687 L
.63072 .02687 L
.63206 .02687 L
.63331 .02687 L
.63468 .02687 L
.63617 .02687 L
.63758 .02687 L
.6389 .02687 L
.64026 .02687 L
.64149 .02687 L
.64384 .02687 L
.64513 .02687 L
.64634 .02687 L
.64768 .02687 L
.64908 .02687 L
.6516 .02687 L
.653 .02687 L
.65431 .02687 L
.65727 .02687 L
.65854 .02687 L
.65989 .02687 L
.6623 .02687 L
.66365 .02687 L
.6649 .02687 L
.66777 .02687 L
.66904 .02687 L
.67026 .02687 L
.67135 .02687 L
.67254 .02687 L
.67383 .02687 L
.67456 .02687 L
.67521 .02687 L
.67769 .02687 L
.67884 .02687 L
.67992 .02687 L
.68104 .02687 L
Mistroke
.68228 .02687 L
.68353 .02687 L
.68487 .02687 L
.6861 .02687 L
.68725 .02687 L
.68841 .02687 L
.68967 .02687 L
.69196 .02687 L
.69406 .02687 L
.6952 .02687 L
.69626 .02687 L
.69741 .02687 L
.69868 .02687 L
.69975 .02687 L
.70089 .02687 L
.70154 .02687 L
.70224 .02687 L
.70351 .02687 L
.70464 .02687 L
.70588 .02687 L
.70706 .02687 L
.70817 .02687 L
.70933 .02687 L
.71059 .02687 L
.71284 .02687 L
.71492 .02687 L
.7162 .02687 L
.71692 .02687 L
.71756 .02687 L
.71828 .02687 L
.71905 .02687 L
.71977 .02687 L
.72044 .02687 L
.72166 .02687 L
.72235 .02687 L
.72299 .02687 L
.72438 .02687 L
.72569 .02687 L
.72688 .02687 L
.72817 .02687 L
.72935 .02687 L
.73044 .02687 L
.73161 .02687 L
.7329 .02687 L
.73355 .02687 L
.73425 .02687 L
.73552 .02687 L
.73793 .02687 L
.73925 .02687 L
.74049 .02687 L
Mistroke
.74292 .02687 L
.74512 .02687 L
.74639 .02687 L
.74774 .02687 L
.75015 .02687 L
.75149 .02687 L
.75275 .02687 L
.75411 .02687 L
.7556 .02687 L
.75702 .02687 L
.75833 .02687 L
.76092 .02687 L
.76328 .02687 L
.76447 .02687 L
.76578 .02687 L
.76849 .02687 L
.77002 .02687 L
.77142 .02687 L
.77399 .02687 L
.77529 .02687 L
.77671 .02687 L
.77924 .02687 L
.78067 .02687 L
.78198 .02687 L
.7844 .02687 L
.78562 .02687 L
.78697 .02687 L
.78929 .02687 L
.79059 .02687 L
.79178 .02687 L
.7941 .02687 L
.79629 .02687 L
.79881 .02687 L
.80021 .02687 L
.80149 .02687 L
.80268 .02687 L
.80397 .02687 L
.80631 .02687 L
.80763 .02687 L
.80908 .02687 L
.81049 .02687 L
.812 .02687 L
.81342 .02687 L
.81471 .02687 L
.81601 .02687 L
.81723 .02687 L
.81952 .02687 L
.82074 .02687 L
.82204 .02687 L
.82334 .02687 L
Mistroke
.82471 .02687 L
.82589 .02687 L
.82715 .02687 L
.82943 .02687 L
.83154 .02687 L
.83283 .02687 L
.83405 .02687 L
.83633 .02687 L
.83753 .02687 L
.83885 .02687 L
.84013 .02687 L
.84152 .02687 L
.84281 .02687 L
.84399 .02687 L
.8463 .02687 L
.84767 .02687 L
.84895 .02687 L
.85046 .02687 L
.85184 .02687 L
.85438 .02687 L
.85578 .02687 L
.85709 .02687 L
.85826 .02687 L
.85951 .02687 L
.86177 .02687 L
.86315 .02687 L
.86445 .02687 L
.86689 .02687 L
.86814 .02687 L
.86947 .02687 L
.87184 .02687 L
.87317 .02687 L
.8744 .02687 L
.87575 .02687 L
.87722 .02687 L
.87846 .02687 L
.87961 .02687 L
.8808 .02687 L
.88187 .02687 L
.88393 .02687 L
.88506 .02687 L
.88613 .02687 L
.88729 .02687 L
.88853 .02687 L
.89073 .02687 L
.89196 .02687 L
.89311 .02687 L
.89437 .02687 L
.89571 .02687 L
.89695 .02687 L
Mistroke
.89831 .02687 L
.89955 .02687 L
.90071 .02687 L
.90208 .02687 L
.90333 .02687 L
.90471 .02687 L
.90615 .02687 L
.90734 .02687 L
.9086 .02687 L
.90969 .02687 L
.91088 .02687 L
.91227 .02687 L
.91359 .02687 L
.91487 .02687 L
.91605 .02687 L
.91712 .02687 L
.91827 .02687 L
.92034 .02687 L
.92161 .02687 L
.92281 .02687 L
.92506 .02687 L
.92621 .02687 L
.92743 .02687 L
.92963 .02687 L
.93097 .02687 L
.93224 .02687 L
.9346 .02687 L
.93577 .02687 L
.93702 .02687 L
.93927 .02687 L
.94064 .02687 L
.94195 .02687 L
.94438 .02687 L
.94563 .02687 L
.94696 .02687 L
.94933 .02687 L
.95065 .02687 L
.95189 .02687 L
.95325 .02687 L
.95471 .02687 L
.95695 .02687 L
.95823 .02687 L
.95941 .02687 L
.9618 .02687 L
.96314 .02687 L
.96435 .02687 L
.96654 .02687 L
.96777 .02687 L
.9689 .02687 L
.97099 .02687 L
Mistroke
.97204 .02687 L
.97319 .02687 L
.97619 .02687 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500.375, 309.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe
0?ooo`00o`3ooooe0?ooo`00o`3ooolB0?ooo`060;md00000000000000000000B9`0gooo103oool0
0`3ookl0M01d0;ooo`3F0?ooo`00o`3ooolC0?ooo`030?oo_`1d07@0_ooo00D0oooo00@0oooO09a8
000007@0_oooeP3oool00?l0oooo4`3oool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000001d
0;ooomH0oooo003o0?oooa<0oooo00<0oooO09a8M02oool0103oool01@3OW4P000000000B018B7@0
_ooo0=H0oooo003o0?oooa<0oooo00<0oooO09a8M02oool00`3oool01P3o_g@000000000M02ooml0
W4Qd0;ooomH0oooo003o0?oooa<0oooo00<0oooO09a8M02oool00P3oool01`3ogi`0B0000000B02L
gol0oooO09a8M02oool0eP3oool00?l0oooo4`3oool0303ooml0W4Qd0;ooo`3oool0oono07@00000
0000M;oo0?ooo`3ooml0W4Qd0;ooomH0oooo003o0?oooa<0oooo00L0oooO09a8M02oool0oooO09a8
00000000B9cO0080oooo00<0oooO09a8M02oool0eP3oool00?l0oooo4`3oool01P3ooml0W4Qd0;oo
g`2LB0000000001d_`<0oooo00<0oooO09a8M02oool0eP3oool00?l0oooo4`3oool01P3ooml0W4Qd
07Ad0000000004RL0=ooo`<0oooo00<0oooO09a8M02oool0eP3oool00?l0oooo4`3oool01@3ooml0
W4P00000000007@0_ooo00@0oooo00<0oooO09a8M02oool0eP3oool00?l0oooo4`3oool0103OW4P0
00000000M02oool50?ooo`030?oo_`1d07@0_ooo0=H0oooo003o0?oooa40oooo00D0gia800000000
0000001809cOo`040?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0d`3oool00?l0
oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0
oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0
oooom@3oool00540oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`040;md
00000000000004RLgbX0oooo00<0gia80000000000001@000000101d_ol0oooo0?ooo`2oM0030000
00030018W03Oool0oooo02X0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`020?oo
o`040;md00000000000004RLgb`0oooo00<0okmd0000000000000P0000001@00M;l0oooo0?ooo`3o
ool0_g@000<0000000<004RL0=ooo`3oool0:`3oool00`3o_g@000000000000200000003001d_`3o
ool0oooo00<0oooo00@0_g@0000000000000B9cO<@3oool01P2oM000000000000000000004RL0=oo
oc00oooo00@0_g@0000000000000B9cO>P3oool00540oooo00P0omnL04P00000B9`0gooo0?ooo`3o
gi`0B01809cOo`<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo02X0oooo00<0gia80000
00000000100000001@00M;l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0:`3oool0
0`3OW4P00000000000040000000:001d_`3oool0oooo0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d
_bd0oooo00<0_g@00000M02oool00`3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo
02d0oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0;`3o
ool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo02d0oooo00L0oooO09a80000M;l0oooo
0?oog`2LB00007Bo03T0oooo001G0?ooo`030?noM000B9`0gooo0080oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`0Z0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool0
1P3oool00`3ogi`0B7Bo0?ooo`0[0?ooo`030=nLB018W=l0oooo0080oooo00L0oooO09a8M02oool0
oooo0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0;03oool00`2oM000001d0;ooo`090?oo
o`030?oOW018M;l0oooo02`0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo03@0oooo00<0omnL04Qd_`3oool0;03oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo03P0oooo001G0?ooo`080?noM00004P0W=oo0?ooo`3ooml0W4P00018W03O
ool20?ooo`030?oog`2LB00007Bo02/0oooo00<0gia804RLg`3oool02P3oool00`3ookl0M01809cO
o`0/0?ooo`030=nLB018W=l0oooo00@0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0
001d_`0/0?ooo`030;md000007@0_ooo00T0oooo00<0oono07@0B02Lgol0;03oool00`2oM000001d
0;ooo`030?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0=03oool00`3ookl0
M01809cOo`0[0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0>03oool005L0
oooo00L0_g@00000B02Lgol0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0:`3oool0
0`3OW4P0M;oo0?ooo`090?ooo`030?oo_`1d0000M;oo02d0oooo00<0gia807Boo`3oool00`3oool0
0`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02/0oooo00<0_g@00000M02oool02@3oool0
0`3ookl0M00007Boo`0/0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`0c0?ooo`030?oo_`1d0000M;oo02/0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`0g0?ooo`00A03oool00`2oM0000000000000070000000304RLg`3oool0oooo
00D0oooo00P0_g@00000000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool0
6P3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol0
2@3oool00`3o_g@0000007Boo`0L0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool0
103oool00`3ooml0W4Q809cOo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0
6P3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0_g@00000M02oool0
2@3oool00`3o_g@0000007Boo`0K0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool0
103oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0
803oool00`2oM0000000000000070000000304RLg`3oool0oooo00H0oooo00<0okmd0000001d_ol0
:`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo03L0oooo001C0?ooo`030?oo_`1d
000000000080000000H0B9cO0?ooo`3oool0omnL04P00018W=l40?ooo`030=nLB00004P0W=oo02`0
oooo00<0omnL04P0M02oool01`3oool0103ogi`0B0000000M02oool^0?ooo`030?oOW01807@0_ooo
0080oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0[0?ooo`030;md000007@0_ooo
00P0oooo00@0omnL04P0000007@0_ooo;03oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol0<P3oool0103ogi`0B0000000M02oool[0?ooo`030?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol0=`3oool005D0oooo00<0okmd0000B02Lgol00`3oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02d0oooo00<0_g@004RLg`3oool00P3oool0
103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo02h0oooo00L0_g@004RLg`3oool0oooo
0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0:`3oool00`2oM000001d0;ooo`040?ooo`04
0=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0:`3oool00`2oM000001d0;ooo`030?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0;P3oool0103Ogml0oooo0?ooo`2oM002
0000000304RLg`3oool0oooo02X0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0g
0?ooo`00EP3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000
M02oool0;@3oool00`3OW4P0001d0;ooo`020?ooo`030?noM000000000000080000000<007Bo0?oo
o`3oool0;`3oool01`3OW4P0001d0;ooo`3oool0oono07@00000M;l0103oool00`2oM000001d0;oo
o`0[0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?oo
o`0/0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;oo
o`0^0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0:`3oool00`3ookl0M000001d
_`040?ooo`030;md000007@0_ooo03L0oooo001F0?ooo`030?oog`2LB000B9cO00<0oooo00<0_g@0
0018W03Oool00P3oool00`3ooml0W4P0001d_`0^0?ooo`030?noM0000000M;oo0080oooo00D0oooO
09a800000000001d0;ooo`0b0?ooo`030?noM0000000M;oo0080oooo00<0_g@00018W03Oool00P3o
ool00`3ooml0W4P0001d_`0/0?ooo`030;md000007@0_ooo00@0oooo00D0oooO09a800000000001d
0;ooo`0_0?ooo`030;md000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0
001d_`0_0?ooo`050?oog`2LB00000000000M02oool0;`3oool00`2oM00004RL0=ooo`020?ooo`03
0?oog`2LB00007Bo03P0oooo001A0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l0
0`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo02P0oooo00<0omnL09boo`3oool0
0`3oool00`2oM000000007Boo`030?ooo`030?noM000M;l0oooo02d0oooo00<0omnL09boo`3oool0
0`3oool00`2oM000000007Boo`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
;03oool00`2oM000001d0;ooo`050?ooo`030?noM000M;l0oooo0300oooo00<0_g@00000M02oool0
103oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo0300oooo00<0okmd001d_`3oool0
<03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo03P0oooo001B0?ooo`070?oOW018
B9`0gooo0?ooo`3OW4P0000007Boo`040?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo:P3oool0
202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0`3oool00`3ooml0W4P00000000200000003
0000M02oool0oooo02T0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo`<0oooo00H0
_g@00018W03Oool0oooo0;md0000M;l[0?ooo`050=nLB000000000000000M02oool01@3oool00`3o
oml0W4P000000002000000030000M02oool0oooo02T0oooo00D0gia8000000000000001d0;ooo`05
0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo<@3oool00`3ooml0W4P000000002000000030000
M02oool0oooo02`0oooo00H0_g@00018W03Oool0oooo0;md0000M;li0?ooo`00D`3oool01@3ogi`0
B000000000000000B9cO00H0oooo00@0_g@000000000000007Bo;03oool01@2oM000000000000000
000007Bo00H0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0Y0?ooo`050;md0000
0000000000000000M;l01P3oool0102oM000000000000000M;l]0?ooo`040?oo_`1d0000001d0;oo
o`H0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0Y0?ooo`040?oo_`1d0000001d
0;ooo`H0oooo00@0_g@000000000000007Bo<`3oool00`3o_g@00000000000020000000307Boo`3o
ool0oooo02`0oooo00@0_g@000000000000007Bo>P3oool00?l0oooom@3oool00?l0oooom@3oool0
0?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool0
0?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool004X0ooooo`00002M
000000h0oooo001:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0o`3ooonI0?ooo`030000
003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000oooo0?oo
o`0<0?ooo`00?03oool0102oM000000000000018W=l:0?ooo`030000003oool0oooo0?l0ooooV@3o
ool00`000000oooo0?ooo`0<0?ooo`00>P3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0
2@3oool00`000000oooo0?ooo`3o0?oooiT0oooo00<000000?ooo`3oool0303oool003X0oooo00<0
okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`030000003oool0oooo0?l0ooooV@3o
ool00`000000oooo0?ooo`0<0?ooo`00>@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2L
B00007Bo00P0oooo00<000000?ooo`3oool0o`3ooonI0?ooo`030000003oool0oooo00`0oooo000i
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01`3oool00`000000oooo0?ooo`3o
0?oooiT0oooo00<000000?ooo`3oool0303oool003T0oooo00<0omnL04P00018W=l0103oool00`2o
M000001d0;ooo`070?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000oooo0?ooo`0<0?oo
o`00>@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo100000060?ooocD0
<ol08@3o003o03<0oc@0<`3o1P3oool3000000h0oooo000i0?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol01`3oool00`000000oooo0?ooo`0l0?ooo`80<ol07@3oool203<0ool0oooo
?03oool00`000000oooo0?ooo`0<0?ooo`00>@3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo00L0oooo00<000000?ooo`3oool0?P3oool203?o01T0oooo0P0c0?oo0?oooch0oooo00<0
00000?ooo`3oool0303oool003X0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`08
0?ooo`030000003oool0oooo0400oooo00<0<ol00?ooo`3oool05P3oool00`0c0?l0oooo0?ooo`3o
0?ooocd0oooo00<000000?ooo`3oool0303oool003X0oooo00<0okmd0000B02Lgol00P3oool00`3o
gi`0B00007Boo`080?ooo`030000003oool0oooo0400oooo00<0<ol00?ooo`3oool0503oool203<0
ool0oooo@03oool00`000000oooo0?ooo`0<0?ooo`00>`3oool01P2oM00004RL0=ooo`3oool0_g@0
001d_`T0oooo00<000000?ooo`3oool0@@3oool00`0co`00oooo0?ooo`0B0?ooo`0303<0o`3oool0
oooo0?l0oooo@03oool00`000000oooo0?ooo`0<0?ooo`00?03oool0102oM000000000000000M;l:
0?ooo`030000003oool0oooo0480oooo00<0<ol00?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`3o
0?oood00oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0@P3oool00`0c
o`00oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo0?l0oooo@03oool00`000000oooo0?ooo`0<0?oo
o`00BP3oool00`000000oooo0?ooo`120?ooo`0303?o003oool0oooo0100oooo00<0<`3o0?ooo`3o
ool0o`3ooom10?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04<0oooo
00<0<ol00?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool0
303oool004X0oooo00<000000?ooo`3oool0@`3oool00`0co`00oooo0?ooo`0?0?ooo`0303<0o`3o
ool0oooo0?l0oooo@@3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool3000004@0oooo00<0<ol0
0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`3o0?oood40oooo0P00000>0?ooo`00BP3oool00`00
0000oooo0?ooo`140?ooo`0303?o003oool0oooo00d0oooo00<0<`3o0?ooo`3oool0o`3ooom20?oo
o`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04@0oooo00<0<ol00?ooo`3o
ool03@3oool00`0c0?l0oooo0?ooo`3o0?oood80oooo00<000000?ooo`3oool0303oool004X0oooo
00<000000?ooo`3oool0A@3oool00`0co`00oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo0?l0oooo
@P3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`150?ooo`0303?o003o
ool0oooo00`0oooo00<0<`3o0?ooo`3oool0o`3ooom20?ooo`030000003oool0oooo00`0oooo001:
0?ooo`030000003oool0oooo04D0oooo00<0<ol00?ooo`3oool0303oool00`0c0?l0oooo0?ooo`3o
0?oood80oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0A@3oool00`0c
o`00oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo0?l0oooo@P3oool00`000000oooo0?ooo`0<0?oo
o`00BP3oool00`000000oooo0?ooo`150?ooo`0303?o003oool0oooo00/0oooo00<0<`3o0?ooo`3o
ool0o`3ooom30?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04D0oooo
00<0<ol00?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool0
303oool004X0oooo00<000000?ooo`3oool0AP3oool00`0co`00oooo0?ooo`0:0?ooo`0303<0o`3o
ool0oooo0?l0oooo@`3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`16
0?ooo`0303?o003oool0oooo00X0oooo00<0<`3o0?ooo`3oool0o`3ooom30?ooo`030000003oool0
oooo00`0oooo001:0?ooo`<00000AP3oool00`0co`00oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo
0?l0oooo@P3oool2000000h0oooo001:0?ooo`030000003oool0oooo04H0oooo00<0<ol00?ooo`3o
ool02P3oool00`0c0?l0oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool0303oool004X0oooo
00<000000?ooo`3oool0AP3oool00`0co`00oooo0?ooo`090?ooo`0303<0o`3oool0oooo0?l0oooo
A03oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`160?ooo`0303?o003o
ool0oooo00T0oooo00<0<`3o0?ooo`3oool0o`3ooom40?ooo`030000003oool0oooo00`0oooo001:
0?ooo`030000003oool0oooo04L0oooo00<0<ol00?ooo`3oool0203oool00`0c0?l0oooo0?ooo`3o
0?oood@0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0A`3oool00`0c
o`00oooo0?ooo`080?ooo`0303<0o`3oool0oooo0?l0ooooA03oool00`000000oooo0?ooo`0<0?oo
o`00BP3oool00`000000oooo0?ooo`170?ooo`0303?o003oool0oooo00P0oooo00<0<`3o0?ooo`3o
ool0o`3ooom40?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04L0oooo
00<0<ol00?ooo`3oool0203oool00`0c0?l0oooo0?ooo`3o0?oood@0oooo00<000000?ooo`3oool0
303oool004X0oooo00<000000?ooo`3oool0A`3oool00`0co`00oooo0?ooo`080?ooo`0303<0o`3o
ool0oooo0?l0ooooA03oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`17
0?ooo`0303?o003oool0oooo00P0oooo00<0<`3o0?ooo`3oool0o`3ooom40?ooo`030000003oool0
oooo00`0oooo001:0?ooo`030000003oool0oooo04L0oooo00<0<ol00?ooo`3oool0203oool00`0c
0?l0oooo0?ooo`3o0?oood@0oooo00<000000?ooo`3oool0303oool004X0oooo0`0000170?ooo`03
03?o003oool0oooo00L0oooo00<0<`3o0?ooo`3oool0o`3ooom40?ooo`8000003P3oool004X0oooo
00<000000?ooo`3oool0A`3oool00`0co`00oooo0?ooo`070?ooo`0303<0o`3oool0oooo0?l0oooo
A@3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`180?ooo`0303?o003o
ool0oooo00H0oooo00<0<`3o0?ooo`3oool0o`3ooom50?ooo`030000003oool0oooo00`0oooo001:
0?ooo`030000003oool0oooo04P0oooo00<0<ol00?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`3o
0?ooodD0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0B03oool00`0c
o`00oooo0?ooo`060?ooo`0303<0o`3oool0oooo0?l0ooooA@3oool00`000000oooo0?ooo`0<0?oo
o`00;@3oool0102oM000000000000018W=l40?ooo`050=nLB0000000B9cO0?ooo`3OW4P01`000000
0`1d_ol0oooo0?ooo`060?ooo`030000003oool0oooo04P0oooo00<0<ol00?ooo`3oool01P3oool0
0`0c0?l0oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool0303oool002/0oooo00L0oooO09a8
0000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool00`3OW4P000000000
000400000003001d_`3oool0oooo00H0oooo00<000000?ooo`3oool0B03oool00`0co`00oooo0?oo
o`060?ooo`0303<0o`3oool0oooo0?l0ooooA@3oool00`000000oooo0?ooo`0<0?ooo`00:`3oool0
0`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00<0gia804RLg`3oool00P3oool0
0`3ooml0W4Qd0;ooo`070?ooo`030000003oool0oooo04P0oooo00<0<ol00?ooo`3oool01P3oool0
0`0c0?l0oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool0303oool002X0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3ooml0W4P0001d_`090?ooo`030=nLB018W=l0oooo00/0oooo00<00000
0?ooo`3oool0B03oool00`0co`00oooo0?ooo`060?ooo`0303<0o`3oool0oooo0?l0ooooA@3oool0
0`000000oooo0?ooo`0<0?ooo`00:P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
00T0oooo00<0gia807Boo`3oool02P3oool00`000000oooo0?ooo`180?ooo`0303?o003oool0oooo
00H0oooo00<0<`3o0?ooo`3oool0o`3ooom50?ooo`030000003oool0oooo00`0oooo000Z0?ooo`03
0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02@3oool00`3ooml0W4Q809cOo`0:0?ooo`03
0000003oool0oooo04P0oooo00<0<ol00?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`3o0?ooodD0
oooo00<000000?ooo`3oool0303oool002X0oooo00<0omnL04P00018W=l0103oool00`3OW4P00018
09cOo`0:0?ooo`030?oOW01807@0_ooo00T0oooo100000170?ooo`0303?o003oool0oooo00D0oooo
00<0<`3o0?ooo`3oool0o`3ooom40?ooo`<000003P3oool002X0oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`0;0?ooo`030;md0018W=l0oooo00P0oooo00<000000?ooo`3oool0B03o
ool00`0co`00oooo0?ooo`050?ooo`0303<0o`3oool0oooo0?l0ooooAP3oool00`000000oooo0?oo
o`0<0?ooo`00:P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0gia8
0000M02oool0203oool00`000000oooo0?ooo`190?ooo`0303?o003oool0oooo00@0oooo00<0<`3o
0?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo00`0oooo000[0?ooo`030;md0000B9`0gooo
0080oooo00<0oooO09a80000M;l0303oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo
04T0oooo00<0<ol00?ooo`3oool0103oool00`0c0?l0oooo0?ooo`3o0?ooodH0oooo00<000000?oo
o`3oool0303oool002/0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`060?ooo`03
0?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`000000oooo0?ooo`190?ooo`03
03?o003oool0oooo00@0oooo00<0<`3o0?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo00`0
oooo000/0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool0202oM000M;oo0?ooo`3oool0
gia800000000B9`0gooo203oool00`000000oooo0?ooo`190?ooo`0303?o003oool0oooo00@0oooo
00<0<`3o0?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo00`0oooo000]0?ooo`040;md0000
00000000001d_`X0oooo00D0_g@00000000000000000001d_`0:0?ooo`030000003oool0oooo04T0
oooo00<0<ol00?ooo`3oool0103oool00`0c0?l0oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3o
ool0303oool004X0oooo00<000000?ooo`3oool0B@3oool00`0co`00oooo0?ooo`040?ooo`0303<0
o`3oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?oo
o`190?ooo`0303?o003oool0oooo00@0oooo00<0<`3o0?ooo`3oool0o`3ooom60?ooo`030000003o
ool0oooo00`0oooo001:0?ooo`030000003oool0oooo04T0oooo00<0<ol00?ooo`3oool0103oool0
0`0c0?l0oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?oo
o`3oool0B@3oool00`0co`00oooo0?ooo`040?ooo`0303<0o`3oool0oooo0?l0ooooAP3oool00`00
0000oooo0?ooo`0<0?ooo`00BP3oool3000004T0oooo00<0<ol00?ooo`3oool0103oool00`0c0?l0
oooo0?ooo`3o0?ooodD0oooo0P00000>0?ooo`00BP3oool00`000000oooo0?ooo`190?ooo`0303?o
003oool0oooo00@0oooo00<0<`3o0?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo00`0oooo
001:0?ooo`030000003oool0oooo04T0oooo00<0<ol00?ooo`3oool0103oool00`0c0?l0oooo0?oo
o`3o0?ooodH0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0B@3oool0
0`0co`00oooo0?ooo`030?ooo`0303<0o`3oool0oooo0?l0ooooA`3oool00`000000oooo0?ooo`0<
0?ooo`00BP3oool00`000000oooo0?ooo`190?ooo`0303?o003oool0oooo00<0oooo00<0<`3o0?oo
o`3oool0o`3ooom70?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04T0
oooo00<0<ol00?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3o
ool0303oool004X0oooo00<000000?ooo`3oool0BP3oool00`0co`00oooo0?ooo`020?ooo`0303<0
o`3oool0oooo0?l0ooooA`3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?oo
o`1:0?ooo`0303?o003oool0oooo0080oooo00<0<`3o0?ooo`3oool0o`3ooom70?ooo`030000003o
ool0oooo00`0oooo001:0?ooo`030000003oool0oooo04X0oooo00<0<ol00?ooo`3oool00P3oool0
0`0c0?l0oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?oo
o`3oool0BP3oool00`0co`00oooo0?ooo`020?ooo`0303<0o`3oool0oooo0?l0ooooA`3oool00`00
0000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`1:0?ooo`0303?o003oool0oooo0080
oooo00<0<`3o0?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo00`0oooo001:0?ooo`<00000
BP3oool00`0co`00oooo0?ooo`020?ooo`0303<0o`3oool0oooo0?l0ooooAP3oool2000000h0oooo
001:0?ooo`030000003oool0oooo04X0oooo00<0<ol00?ooo`3oool00P3oool00`0c0?l0oooo0?oo
o`3o0?ooodL0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0BP3oool0
0`0co`00oooo0?ooo`020?ooo`0303<0o`3oool0oooo0?l0ooooA`3oool00`000000oooo0?ooo`0<
0?ooo`00BP3oool00`000000oooo0?ooo`1:0?ooo`0303?o003oool0oooo0080oooo00<0<`3o0?oo
o`3oool0o`3ooom70?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04X0
oooo00<0<ol00?ooo`3oool00P3oool00`0c0?l0oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3o
ool0303oool004X0oooo00<000000?ooo`3oool0BP3oool00`0co`00oooo0?ooo`020?ooo`0303<0
o`3oool0oooo0?l0ooooA`3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?oo
o`1:0?ooo`0303?o003oool0oooo0080oooo00<0<`3o0?ooo`3oool0o`3ooom70?ooo`030000003o
ool0oooo00`0oooo001:0?ooo`030000003oool0oooo04X0oooo00<0<ol00?ooo`3oool00P3oool0
0`0c0?l0oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?oo
o`3oool0BP3oool01@0co`00oooo0?ooo`3oool0<`3o0?l0ooooBP3oool00`000000oooo0?ooo`0<
0?ooo`00BP3oool00`000000oooo0?ooo`1:0?ooo`0503?o003oool0oooo0?ooo`0c0?l0o`3ooom:
0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04X0oooo00D0<ol00?oo
o`3oool0oooo03<0o`3o0?ooodX0oooo00<000000?ooo`3oool0303oool004X0oooo0`00001:0?oo
o`0503?o003oool0oooo0?ooo`0c0?l0o`3ooom90?ooo`8000003P3oool004X0oooo00<000000?oo
o`3oool0B`3oool0100co`00oooo0?ooo`0c0?oo0?ooodX0oooo00<000000?ooo`3oool0303oool0
04X0oooo00<000000?ooo`3oool0B`3oool0100co`00oooo0?ooo`0c0?oo0?ooodX0oooo00<00000
0?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0B`3oool0100co`00oooo0?ooo`0c0?oo
0?ooodX0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0B`3oool0100c
o`00oooo0?ooo`0c0?oo0?ooodX0oooo00<000000?ooo`3oool0303oool002d0oooo00@0_g@00000
00000000B9cO103oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo00T0oooo00<00000
0?ooo`3oool0B`3oool0100co`00oooo0?ooo`0c0?oo0?ooodX0oooo00<000000?ooo`3oool0303o
ool002/0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l0
1P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo04/0oooo00@0<ol00?ooo`3oool0
<`3oo`3ooom:0?ooo`030000003oool0oooo00`0oooo000[0?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol02`3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo04/0oooo
00@0<ol00?ooo`3oool0<`3oo`3ooom:0?ooo`030000003oool0oooo00`0oooo000Z0?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3OW4P000000000000500000003
0000B02Lgol0oooo00H0oooo00<000000?ooo`3oool0B`3oool0100co`00oooo0?ooo`0c0?oo0?oo
odX0oooo00<000000?ooo`3oool0303oool002X0oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`050?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol02@3oool00`000000
oooo0?ooo`1;0?ooo`0403?o003oool0oooo03<0ool0ooooBP3oool00`000000oooo0?ooo`0<0?oo
o`00:P3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo00L0gia807Boo`3o
ool0oooo0?noM0000000M;oo00T0oooo00<000000?ooo`3oool0B`3oool0100co`00oooo0?ooo`0c
0?oo0?ooodX0oooo00<000000?ooo`3oool0303oool002X0oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`090?ooo`@00000
BP3oool0100co`00oooo0?ooo`0c0?oo0?ooodP0oooo0`00000>0?ooo`00:P3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00H0okmd001d_`3oool0okmd0000001d_ol90?oo
o`030000003oool0oooo04/0oooo00@0<ol00?ooo`3oool0<`3oo`3ooom:0?ooo`030000003oool0
oooo00`0oooo000Z0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0203oool01@2o
M000M;oo0?noM0000000M;oo00T0oooo00<000000?ooo`3oool0B`3oool0100co`00oooo0?ooo`0c
0?oo0?ooodX0oooo00<000000?ooo`3oool0303oool002/0oooo00<0_g@00018W03Oool00P3oool0
0`3ooml0W4P0001d_`090?ooo`050?oo_`1d07@0_kmd0000001d_ol02@3oool00`000000oooo0?oo
o`1;0?ooo`0403?o003oool0oooo03<0ool0ooooBP3oool00`000000oooo0?ooo`0<0?ooo`00:`3o
ool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00X0oooo00@0okmd000000000000M;oo
2@3oool00`000000oooo0?ooo`1;0?ooo`0303?o003oool0<`3o0?l0ooooB`3oool00`000000oooo
0?ooo`0<0?ooo`00;03oool01P2oM00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0oooO09a80000
0000M;oo2@3oool00`000000oooo0?ooo`1;0?ooo`0303?o003oool0<`3o0?l0ooooB`3oool00`00
0000oooo0?ooo`0<0?ooo`00;@3oool0102oM000000000000000M;l=0?ooo`030?oOW0180000M;oo
00T0oooo00<000000?ooo`3oool0C03oool00`0co`00<`3o0?ooo`3o0?ooodX0oooo00<000000?oo
o`3oool0303oool004X0oooo00<000000?ooo`3oool0C03oool00`0co`00<`3o0?ooo`3o0?ooodX0
oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0C03oool00`0co`00<`3o
0?ooo`3o0?ooodX0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0C03o
ool00`0co`00<`3o0?ooo`3o0?ooodX0oooo00<000000?ooo`3oool0303oool004X0oooo00<00000
0?ooo`3oool0C03oool00`0co`00<`3o0?ooo`3o0?ooodX0oooo00<000000?ooo`3oool0303oool0
04X0oooo0`00001<0?ooo`0303?o000c0?l0oooo0?l0ooooB@3oool2000000h0oooo001:0?ooo`03
0000003oool0oooo04`0oooo00<0<ol003<0o`3oool0o`3ooom:0?ooo`030000003oool0oooo00`0
oooo001:0?ooo`030000003oool0oooo04`0oooo00<0<ol003<0o`3oool0o`3ooom:0?ooo`030000
003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04`0oooo00<0<ol003<0o`3oool0o`3o
oom:0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04`0oooo00<0<ol0
03<0o`3oool0o`3ooom:0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo
04`0oooo00<0<ol003<0o`3oool0o`3ooom:0?ooo`030000003oool0oooo00`0oooo001:0?ooo`03
0000003oool0oooo04`0oooo00<0<ol003<0o`3oool0o`3ooom:0?ooo`030000003oool0oooo00`0
oooo001:0?ooo`030000003oool0oooo04`0oooo00<0<ol003<0o`3oool0o`3ooom:0?ooo`030000
003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04`0oooo00<0<ol003<0o`3oool0o`3o
oom:0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04`0oooo00<0<ol0
03<0o`3oool0o`3ooom:0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo
04`0oooo00<0<ol003<0o`3oool0o`3ooom:0?ooo`030000003oool0oooo00`0oooo000E0?ooo`03
0?oo_`1d000000000080000000L004RL0=ooo`3ookl0M0000000000007@0_ooo02T0oooo0`00001<
0?ooo`0303<0o`3oool0oooo0?l0ooooB@3oool2000000h0oooo000D0?ooo`030?noM00000000000
00@0000000H0001809cOo`3ooml0W4P00000M02ooolY0?ooo`030000003oool0oooo04`0oooo00<0
<`3o03?o003oool0o`3ooom:0?ooo`030000003oool0oooo00`0oooo000C0?ooo`040?oOW0180000
04RL0=ooo`<0oooo00L0oono07@0000007@0_ooo0;md000007@0_ooo02T0oooo00<000000?ooo`3o
ool0C03oool00`0c0?l0<ol00?ooo`3o0?ooodX0oooo00<000000?ooo`3oool0303oool00180oooo
00<0oooO09a80018W=l01`3oool01@3OW4P0B9cO0;md000007@0_ooo02T0oooo00<000000?ooo`3o
ool0C03oool00`0c0?l0<ol00?ooo`3o0?ooodX0oooo00<000000?ooo`3oool0303oool00180oooo
00<0omnL04Qd_`3oool01`3oool01@3ookl0M0000000000007@0_ooo02T0oooo00<000000?ooo`3o
ool0C03oool00`0c0?l0<ol00?ooo`3o0?ooodX0oooo00<000000?ooo`3oool0303oool00180oooo
00<0okmd07Boo`3oool0=@3oool00`000000oooo0?ooo`1<0?ooo`0303<0o`0co`00oooo0?l0oooo
BP3oool00`000000oooo0?ooo`0<0?ooo`004P3oool00`3o_g@0M;oo0?ooo`0e0?ooo`030000003o
ool0oooo04`0oooo00<0<`3o03?o003oool0o`3ooom:0?ooo`030000003oool0oooo00`0oooo000B
0?ooo`030?noM01d_ol0oooo03D0oooo00<000000?ooo`3oool0C03oool00`0c0?l0<ol00?ooo`3o
0?ooodX0oooo00<000000?ooo`3oool0303oool00180oooo00<0omnL04Qd_`3oool01`3oool01@3o
okl0M0000000000007@0_ooo02T0oooo00<000000?ooo`3oool0C03oool00`0c0?l0<ol00?ooo`3o
0?ooodX0oooo00<000000?ooo`3oool0303oool00180oooo00<0oooO09a80018W=l01`3oool01@3O
W4P0B9cO0;md000007@0_ooo02T0oooo00<000000?ooo`3oool0C03oool00`0c0?l0<ol00?ooo`3o
0?ooodX0oooo00<000000?ooo`3oool0303oool001<0oooo00@0okmd00000000B9`0gooo0`3oool0
1`3ooml0W4P00000M02oool0_g@00000M02oool0:@3oool00`000000oooo0?ooo`1<0?ooo`0303<0
o`0co`00oooo0?l0ooooBP3oool00`000000oooo0?ooo`0<0?ooo`00503oool00`3OW4P000000000
0004000000060000B02Lgol0oooO09a8000007@0_ooo:@3oool3000004`0oooo00<0<`3o03?o003o
ool0o`3ooom90?ooo`8000003P3oool001D0oooo00<0omnL04P0000000000P0000001`00M;l0oooo
0?oo_`1d000000000000M02oool0:@3oool00`000000oooo0?ooo`1<0?ooo`0303<0o`0co`00oooo
0?l0ooooBP3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`1<0?ooo`03
03<0o`0co`00oooo0?l0ooooBP3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo
0?ooo`1<0?ooo`0303<0o`0co`00oooo0?l0ooooBP3oool00`000000oooo0?ooo`0<0?ooo`00BP3o
ool00`000000oooo0?ooo`1<0?ooo`0303<0o`0co`00oooo0?l0ooooBP3oool00`000000oooo0?oo
o`0<0?ooo`00;@3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00<0oooo00H0
oooO09a80000000000000000M02oool90?ooo`030000003oool0oooo04`0oooo00<0<`3o03?o003o
ool0o`3ooom:0?ooo`030000003oool0oooo00`0oooo000[0?ooo`070?oog`2LB00007Bo0?ooo`3o
oml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0oono07@00000B9`0gooo0?ooo`3O
W4P0001809cOo`P0oooo00<000000?ooo`3oool0B`3oool00`0c0?l0oooo03?o003o0?oood/0oooo
00<000000?ooo`3oool0303oool002/0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Bo
o`070?ooo`030;md000007@0_ooo00<0oooo00<0_g@0001d_`3oool01`3oool00`000000oooo0?oo
o`1;0?ooo`0303<0o`3oool0<ol00?l0ooooB`3oool00`000000oooo0?ooo`0<0?ooo`00:P3oool0
103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0oono07@00000M;l0103o
ool00`3OW4P0001d0;ooo`070?ooo`030000003oool0oooo04/0oooo00@0<`3o0?ooo`3oool0<ol0
o`3ooom:0?ooo`030000003oool0oooo00`0oooo000Z0?ooo`030?oo_`1d000007Bo00@0oooo00<0
_g@00000M02oool01@3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo00L0oooo00<0
00000?ooo`3oool0B`3oool0100c0?l0oooo0?ooo`0co`3o0?ooodX0oooo00<000000?ooo`3oool0
303oool002X0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW018
0000B9cO00<0oooo00@0oono07@0000007@0_ooo1`3oool00`000000oooo0?ooo`1;0?ooo`0403<0
o`3oool0oooo03?o0?l0ooooBP3oool00`000000oooo0?ooo`0<0?ooo`00:P3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@0
00000018W=l0203oool4000004X0oooo00@0<`3o0?ooo`3oool0<ol0o`3ooom80?ooo`<000003P3o
ool002X0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`050?oog`2LB000
001d0;oOW01800000P0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo04/0oooo00@0
<`3o0?ooo`3oool0<ol0o`3ooom:0?ooo`030000003oool0oooo00`0oooo000Z0?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@0000004RLg`0=0?ooo`030000003o
ool0oooo04/0oooo00@0<`3o0?ooo`3oool0<ol0o`3ooom:0?ooo`030000003oool0oooo00`0oooo
000[0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3oool0103ooml0W4P00000
B02Lgol<0?ooo`030000003oool0oooo04/0oooo00@0<`3o0?ooo`3oool0<ol0o`3ooom:0?ooo`03
0000003oool0oooo00`0oooo000[0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
203oool0103ookl0M0000000M02oool;0?ooo`030000003oool0oooo04/0oooo00@0<`3o0?ooo`3o
ool0<ol0o`3ooom:0?ooo`030000003oool0oooo00`0oooo000/0?ooo`060;md0000B9`0gooo0?oo
o`2oM00007Bo2P3oool0103ooml0W4P000000000M;l:0?ooo`030000003oool0oooo04/0oooo00@0
<`3o0?ooo`3oool0<ol0o`3ooom:0?ooo`030000003oool0oooo00`0oooo000]0?ooo`040;md0000
00000000001d_`d0oooo00D0omnL04P00000000004RL0=ooo`070?ooo`030000003oool0oooo04/0
oooo00@0<`3o0?ooo`3oool0<ol0o`3ooom:0?ooo`030000003oool0oooo00`0oooo001:0?ooo`03
0000003oool0oooo04/0oooo00@0<`3o0?ooo`3oool0<ol0o`3ooom:0?ooo`030000003oool0oooo
00`0oooo001:0?ooo`030000003oool0oooo04/0oooo00@0<`3o0?ooo`3oool0<ol0o`3ooom:0?oo
o`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04/0oooo00@0<`3o0?ooo`3o
ool0<ol0o`3ooom:0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04/0
oooo00@0<`3o0?ooo`3oool0<ol0o`3ooom:0?ooo`030000003oool0oooo00`0oooo001:0?ooo`<0
0000BP3oool01@0c0?l0oooo0?ooo`3oool0<ol00?l0ooooB@3oool2000000h0oooo001:0?ooo`03
0000003oool0oooo04X0oooo00D0<`3o0?ooo`3oool0oooo03?o003o0?ooodX0oooo00<000000?oo
o`3oool0303oool004X0oooo00<000000?ooo`3oool0BP3oool01@0c0?l0oooo0?ooo`3oool0<ol0
0?l0ooooBP3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`1:0?ooo`05
03<0o`3oool0oooo0?ooo`0co`00o`3ooom:0?ooo`030000003oool0oooo00`0oooo001:0?ooo`03
0000003oool0oooo04X0oooo00<0<`3o0?ooo`3oool00P3oool00`0co`00oooo0?ooo`3o0?ooodL0
oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0BP3oool00`0c0?l0oooo
0?ooo`020?ooo`0303?o003oool0oooo0?l0ooooA`3oool00`000000oooo0?ooo`0<0?ooo`00BP3o
ool00`000000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo0080oooo00<0<ol00?ooo`3oool0o`3o
oom70?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04X0oooo00<0<`3o
0?ooo`3oool00P3oool00`0co`00oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool0303oool0
04X0oooo00<000000?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`020?ooo`0303?o003oool0oooo
0?l0ooooA`3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`1:0?ooo`03
03<0o`3oool0oooo0080oooo00<0<ol00?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo00`0
oooo001:0?ooo`030000003oool0oooo04X0oooo00<0<`3o0?ooo`3oool00P3oool00`0co`00oooo
0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool0303oool004X0oooo0`00001:0?ooo`0303<0o`3o
ool0oooo0080oooo00<0<ol00?ooo`3oool0o`3ooom60?ooo`8000003P3oool004X0oooo00<00000
0?ooo`3oool0BP3oool00`0c0?l0oooo0?ooo`020?ooo`0303?o003oool0oooo0?l0ooooA`3oool0
0`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo
0080oooo00<0<ol00?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo00`0oooo001:0?ooo`03
0000003oool0oooo04X0oooo00<0<`3o0?ooo`3oool00P3oool00`0co`00oooo0?ooo`3o0?ooodL0
oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0BP3oool00`0c0?l0oooo
0?ooo`020?ooo`0303?o003oool0oooo0?l0ooooA`3oool00`000000oooo0?ooo`0<0?ooo`00BP3o
ool00`000000oooo0?ooo`1:0?ooo`0303<0o`3oool0oooo0080oooo00<0<ol00?ooo`3oool0o`3o
oom70?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04T0oooo00<0<`3o
0?ooo`3oool00`3oool00`0co`00oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool0303oool0
04X0oooo00<000000?ooo`3oool0B@3oool00`0c0?l0oooo0?ooo`030?ooo`0303?o003oool0oooo
0?l0ooooA`3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`190?ooo`03
03<0o`3oool0oooo00<0oooo00<0<ol00?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo00`0
oooo001:0?ooo`030000003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0103oool00`0co`00oooo
0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0B@3o
ool00`0c0?l0oooo0?ooo`040?ooo`0303?o003oool0oooo0?l0ooooAP3oool00`000000oooo0?oo
o`0<0?ooo`00BP3oool3000004T0oooo00<0<`3o0?ooo`3oool0103oool00`0co`00oooo0?ooo`3o
0?ooodD0oooo0P00000>0?ooo`00BP3oool00`000000oooo0?ooo`190?ooo`0303<0o`3oool0oooo
00@0oooo00<0<ol00?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo00`0oooo001:0?ooo`03
0000003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0103oool00`0co`00oooo0?ooo`3o0?ooodH0
oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0B@3oool00`0c0?l0oooo
0?ooo`040?ooo`0303?o003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0<0?ooo`00BP3o
ool00`000000oooo0?ooo`190?ooo`0303<0o`3oool0oooo00@0oooo00<0<ol00?ooo`3oool0o`3o
oom60?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04T0oooo00<0<`3o
0?ooo`3oool0103oool00`0co`00oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0303oool0
02d0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`030?ooo`060?oOW0180000
00000000000004P0W=oo2@3oool00`000000oooo0?ooo`190?ooo`0303<0o`3oool0oooo00@0oooo
00<0<ol00?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo00`0oooo000[0?ooo`070?oog`2L
B00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00P0omnL04P00000
B9`0gooo0?ooo`3ogi`0B00007Boo`P0oooo00<000000?ooo`3oool0B@3oool00`0c0?l0oooo0?oo
o`040?ooo`0303?o003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0<0?ooo`00:`3oool0
0`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0_g@00000M02oool00`3oool0
0`3OW4P004RL0=ooo`070?ooo`030000003oool0oooo04T0oooo00<0<`3o0?ooo`3oool0103oool0
0`0co`00oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0303oool002X0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3ooml0W4P0001d_`070?ooo`030;md000007@0_ooo00<0oooo00<0_g@0
0018W03Oool01`3oool00`000000oooo0?ooo`190?ooo`0303<0o`3oool0oooo00@0oooo00<0<ol0
0?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo00`0oooo000Z0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@0001809cOo`020?ooo`030=nLB000000007Bo
00P0oooo00<000000?ooo`3oool0B03oool00`0c0?l0oooo0?ooo`050?ooo`0303?o003oool0oooo
0?l0ooooAP3oool00`000000oooo0?ooo`0<0?ooo`00:P3oool00`3ogi`0B00004RLg`040?ooo`03
0;md000007@0_ooo00L0oooo00L0gia8001d_`3oool0_g@00000000007@0_ooo00P0oooo10000017
0?ooo`0303<0o`3oool0oooo00D0oooo00<0<ol00?ooo`3oool0o`3ooom40?ooo`<000003P3oool0
02X0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`080?ooo`050?noM00000000000
0018W03Oool02@3oool00`000000oooo0?ooo`180?ooo`0303<0o`3oool0oooo00H0oooo00<0<ol0
0?ooo`3oool0o`3ooom50?ooo`030000003oool0oooo00`0oooo000Z0?ooo`030?oOW0180000B9cO
00@0oooo00<0gia80000B02Lgol01`3oool01@3ogi`0B000000000000000B9cO00X0oooo00<00000
0?ooo`3oool0B03oool00`0c0?l0oooo0?ooo`060?ooo`0303?o003oool0oooo0?l0ooooA@3oool0
0`000000oooo0?ooo`0<0?ooo`00:P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
00H0oooo00L0omnL04P0000004P0W=oo0?ooo`3OW4P007Bo00T0oooo00<000000?ooo`3oool0B03o
ool00`0c0?l0oooo0?ooo`060?ooo`0303?o003oool0oooo0?l0ooooA@3oool00`000000oooo0?oo
o`0<0?ooo`00:`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<0gia8
0000B02Lgol00P3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo04P0oooo00<0<`3o
0?ooo`3oool01P3oool00`0co`00oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool0303oool0
02/0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030=nLB000B9`0gooo
0080oooo00<0oooO09a80018W=l0203oool00`000000oooo0?ooo`180?ooo`0303<0o`3oool0oooo
00H0oooo00<0<ol00?ooo`3oool0o`3ooom50?ooo`030000003oool0oooo00`0oooo000/0?ooo`06
0;md0000B9`0gooo0?ooo`2oM00007Bo203oool00`3ogi`0B00004RLg`020?ooo`030?noM00004P0
W=oo00P0oooo00<000000?ooo`3oool0B03oool00`0c0?l0oooo0?ooo`060?ooo`0303?o003oool0
oooo0?l0ooooA@3oool00`000000oooo0?ooo`0<0?ooo`00;@3oool0102oM000000000000000M;l:
0?ooo`060?oo_`1d000000000000000004P0W=oo2@3oool00`000000oooo0?ooo`180?ooo`0303<0
o`3oool0oooo00H0oooo00<0<ol00?ooo`3oool0o`3ooom50?ooo`030000003oool0oooo00`0oooo
001:0?ooo`030000003oool0oooo04P0oooo00<0<`3o0?ooo`3oool01P3oool00`0co`00oooo0?oo
o`3o0?ooodD0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0B03oool0
0`0c0?l0oooo0?ooo`060?ooo`0303?o003oool0oooo0?l0ooooA@3oool00`000000oooo0?ooo`0<
0?ooo`00BP3oool00`000000oooo0?ooo`170?ooo`0303<0o`3oool0oooo00L0oooo00<0<ol00?oo
o`3oool0o`3ooom50?ooo`030000003oool0oooo00`0oooo001:0?ooo`<00000A`3oool00`0c0?l0
oooo0?ooo`070?ooo`0303?o003oool0oooo0?l0ooooA03oool2000000h0oooo001:0?ooo`030000
003oool0oooo04L0oooo00<0<`3o0?ooo`3oool0203oool00`0co`00oooo0?ooo`3o0?oood@0oooo
00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0A`3oool00`0c0?l0oooo0?oo
o`080?ooo`0303?o003oool0oooo0?l0ooooA03oool00`000000oooo0?ooo`0<0?ooo`00BP3oool0
0`000000oooo0?ooo`170?ooo`0303<0o`3oool0oooo00P0oooo00<0<ol00?ooo`3oool0o`3ooom4
0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04L0oooo00<0<`3o0?oo
o`3oool0203oool00`0co`00oooo0?ooo`3o0?oood@0oooo00<000000?ooo`3oool0303oool004X0
oooo00<000000?ooo`3oool0A`3oool00`0c0?l0oooo0?ooo`080?ooo`0303?o003oool0oooo0?l0
ooooA03oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`170?ooo`0303<0
o`3oool0oooo00P0oooo00<0<ol00?ooo`3oool0o`3ooom40?ooo`030000003oool0oooo00`0oooo
001:0?ooo`030000003oool0oooo04L0oooo00<0<`3o0?ooo`3oool0203oool00`0co`00oooo0?oo
o`3o0?oood@0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0AP3oool0
0`0c0?l0oooo0?ooo`090?ooo`0303?o003oool0oooo0?l0ooooA03oool00`000000oooo0?ooo`0<
0?ooo`00BP3oool00`000000oooo0?ooo`160?ooo`0303<0o`3oool0oooo00T0oooo00<0<ol00?oo
o`3oool0o`3ooom40?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04H0
oooo00<0<`3o0?ooo`3oool02P3oool00`0co`00oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3o
ool0303oool004X0oooo0`0000160?ooo`0303<0o`3oool0oooo00X0oooo00<0<ol00?ooo`3oool0
o`3ooom20?ooo`8000003P3oool004X0oooo00<000000?ooo`3oool0AP3oool00`0c0?l0oooo0?oo
o`0:0?ooo`0303?o003oool0oooo0?l0oooo@`3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool0
0`000000oooo0?ooo`160?ooo`0303<0o`3oool0oooo00X0oooo00<0<ol00?ooo`3oool0o`3ooom3
0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04D0oooo00<0<`3o0?oo
o`3oool02`3oool00`0co`00oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool0303oool004X0
oooo00<000000?ooo`3oool0A@3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303?o003oool0oooo0?l0
oooo@`3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`150?ooo`0303<0
o`3oool0oooo00`0oooo00<0<ol00?ooo`3oool0o`3ooom20?ooo`030000003oool0oooo00`0oooo
001:0?ooo`030000003oool0oooo04D0oooo00<0<`3o0?ooo`3oool0303oool00`0co`00oooo0?oo
o`3o0?oood80oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0A@3oool0
0`0c0?l0oooo0?ooo`0<0?ooo`0303?o003oool0oooo0?l0oooo@P3oool00`000000oooo0?ooo`0<
0?ooo`00BP3oool00`000000oooo0?ooo`150?ooo`0303<0o`3oool0oooo00`0oooo00<0<ol00?oo
o`3oool0o`3ooom20?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04@0
oooo00<0<`3o0?ooo`3oool03@3oool00`0co`00oooo0?ooo`3o0?oood80oooo00<000000?ooo`3o
ool0303oool004X0oooo00<000000?ooo`3oool0A03oool00`0c0?l0oooo0?ooo`0=0?ooo`0303?o
003oool0oooo0?l0oooo@P3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool3000004@0oooo00<0
<`3o0?ooo`3oool03@3oool00`0co`00oooo0?ooo`3o0?oood40oooo0P00000>0?ooo`00BP3oool0
0`000000oooo0?ooo`130?ooo`0303<0o`3oool0oooo00l0oooo00<0<ol00?ooo`3oool0o`3ooom1
0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo04<0oooo00<0<`3o0?oo
o`3oool03`3oool00`0co`00oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool0303oool004X0
oooo00<000000?ooo`3oool0@P3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303?o003oool0oooo0?l0
oooo@@3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`120?ooo`0303<0
o`3oool0oooo0140oooo00<0<ol00?ooo`3oool0o`3ooom00?ooo`030000003oool0oooo00`0oooo
001:0?ooo`030000003oool0oooo0480oooo00<0<`3o0?ooo`3oool04@3oool00`0co`00oooo0?oo
o`3o0?oood00oooo00<000000?ooo`3oool0303oool003/0oooo00<0okmd0000000000000P000000
0`00M;l0oooo0?ooo`070?ooo`030000003oool0oooo0440oooo00<0<`3o0?ooo`3oool04P3oool0
0`0co`00oooo0?ooo`3o0?oood00oooo00<000000?ooo`3oool0303oool003d0oooo00<0_g@00000
M02oool02P3oool00`000000oooo0?ooo`100?ooo`0303<0o`3oool0oooo01@0oooo00<0<ol00?oo
o`3oool0o`3ooolo0?ooo`030000003oool0oooo00`0oooo000m0?ooo`030;md000007@0_ooo00X0
oooo00<000000?ooo`3oool0@03oool00`0c0?l0oooo0?ooo`0E0?ooo`80<ol0o`3ooolo0?ooo`03
0000003oool0oooo00`0oooo000m0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0
?P3oool203<0oaT0oooo0P0co`3o0?oooch0oooo00<000000?ooo`3oool0303oool003d0oooo00<0
_g@00000M02oool02P3oool00`000000oooo0?ooo`0l0?ooo`80<`3o7@3oool203?o0?l0oooo?03o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`2oM000001d0;ooo`0:0?ooo`@000001P3ooole
03<0ob40ooooo`0co`0d03?o00H0oooo0`00000>0?ooo`00?@3oool00`2oM000001d0;ooo`0:0?oo
o`030000003oool0oooo0?l0ooooV@3oool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`2oM000
001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000oooo0?ooo`0<0?ooo`00
?@3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000oooo
0?ooo`0<0?ooo`00?@3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooV@3o
ool00`000000oooo0?ooo`0<0?ooo`00?@3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0
oooo0?l0ooooV@3oool00`000000oooo0?ooo`0<0?ooo`00>`3oool01@3OW4P000000000000007@0
_ooo00X0oooo00<000000?ooo`3oool0o`3ooonI0?ooo`030000003oool0oooo00`0oooo000l0?oo
o`040?oo_`1d0000001d0;ooo`X0oooo00<000000?ooo`3oool0o`3ooonI0?ooo`030000003oool0
oooo00`0oooo001:0?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000oooo0?ooo`0<0?oo
o`00BP3oool00`000000oooo0?ooo`3o0?oooiT0oooo00<000000?ooo`3oool0303oool004X0oooo
00<000000?ooo`3oool0o`3ooonI0?ooo`030000003oool0oooo00`0oooo001:0?ooo`<00000o`3o
oonH0?ooo`8000003P3oool004X0oooo00<000000?ooo`3oool0o`3ooonI0?ooo`030000003oool0
oooo00`0oooo001:0?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000oooo0?ooo`0<0?oo
o`00BP3oool00`000000oooo0?ooo`3o0?oooiT0oooo00<000000?ooo`3oool0303oool004X0oooo
00<000000?ooo`3oool0o`3ooonI0?ooo`030000003oool0oooo00`0oooo001:0?ooo`030000003o
ool0oooo0?l0ooooV@3oool00`000000oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`3o
0?oooiT0oooo00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool0o`3ooonI0?oo
o`030000003oool0oooo00`0oooo001:0?ooo`030000003oool0oooo0?l0ooooV@3oool00`000000
oooo0?ooo`0<0?ooo`00BP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0303oool004X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00`0oooo001:0?ooool00000W@00000>0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499.375}, {308.25, 0}} -> {-37.1353, -0.295693, \
0.0843149, 0.00452779}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 5\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(Fsol = \(NDSolve[{\(F'\)[z]/F[z] \[Equal] x1z[z]/\((1 + z)\), 
              F[zmax] \[Equal] 1}, 
            F[z], {z, 0, zmax}]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(FNsol = \(NDSolve[{\(F'\)[N]/F[N] \[Equal] \(-xx1[N]\), 
              F[nmin] \[Equal] 1}, 
            F[N], {N, nmin, 6}]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(FN[N_] := F[N] /. FNsol // Evaluate\), "\[IndentingNewLine]", 
    \(Clear[x1n, FNacc]\), "\[IndentingNewLine]", 
    \(x1n[N_] := 
      0 /; \((\(-30\) \[LessEqual] N \[LessEqual] \(-24.2\))\)\), "\n", 
    \(x1n[N_] := \(-4\) /; \((\(-24.2\) < N \[LessEqual] \(-8\))\)\), "\n", 
    \(x1n[
        N_] := \(-3.386\) /; \((\(-8\) < 
            N \[LessEqual] \(- .3\))\)\), "\[IndentingNewLine]", 
    \(x1n[N_] := \(-1\) /; \((\(- .3\) < N \[LessEqual] nmax)\)\), "\n", 
    \(x2n[N_] := 
      0 /; \((\(-30\) \[LessEqual] N \[LessEqual] \(-24.4\))\)\), "\n", 
    \(x2n[N_] := 5 /; \((\(-24.4\) < N \[LessEqual] \(-8\))\)\), "\n", 
    \(x2n[N_] := 3.886 /; \((\(-8\) < N \[LessEqual] \(- .3\))\)\), "\n", 
    \(x2n[N_] := 
      0 /; \((\(- .3\) < N \[LessEqual] nmax)\)\), "\[IndentingNewLine]", 
    \(FNacc[N_] := 
      Exp[\(-NIntegrate[x1n[Nn], {Nn, nmin, N}, AccuracyGoal \[Rule] 6, 
            MaxRecursion \[Rule] 20]\)]\), "\[IndentingNewLine]", 
    \(RN[N_] := \(6 \((2  h[z]^2 - \((1 + z)\) h[z] \(h'\)[z])\) /. 
          z \[Rule] \((Exp[\(-N\)] - 1)\)\) /. {om \[Rule] om0, 
          or \[Rule] or0}\), "\n", 
    \(fN[N_] := \((\(-6\) xx2[N] 
            FN[N] \((h[z]^2 /. 
                z \[Rule] \((Exp[\(-N\)] - 1)\))\))\) /. {om \[Rule] om0, 
          or \[Rule] or0}\), "\n", 
    \(fNacc[
        N_] := \((\(-6\) x2n[N] 
            FNacc[N] \((h[z]^2 /. 
                z \[Rule] \((Exp[\(-N\)] - 1)\))\))\) /. {om \[Rule] om0, 
          or \[Rule] or0}\), "\[IndentingNewLine]", 
    \(fF[N_] := 
      9\ Exp[LogF0] \(om0\/\(xb1 + 3\)\) 
        Exp[\(-\((xb1 + 3)\)\) N]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(data1 = 
        Table[{N, 
            Log[FN[N]]}, {N, \(-22\), \(-14\),  .1}];\)\), "\
\[IndentingNewLine]", 
    \(f1 = FindFit[data1, LogF0 - xb1\ N, {LogF0, xb1}, N]\), "\n", 
    \(\(ppp1 = 
        Plot[\((LogF0 - xb1\ N)\) /. f1, {N, \(-22\), \(-14\)}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(pp2 = 
        ListPlot[data1, PlotStyle \[Rule] {PointSize[0.01]}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[ppp1, pp2, DisplayFunction \[Rule] $DisplayFunction, 
        Frame \[Rule] True, Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(tt1 = 
        Table[{\(fF[N] /. f1\) /. N \[Rule] nn, 
            fN[N] /. N \[Rule] 
                nn}, {nn, \(-22\), \(-14\),  .05}];\)\), "\n", 
    \(ft1 = FindFit[tt1, f0 + fbb, f0, fbb]\), "\n", 
    \(Print[\*"\"\<Log[-\!\(f\_0\)] = \>\"", 
      Log[\(-ft1[\([1, 2]\)]\)]]\)}], "Input"],

Cell[BoxData[
    \({LogF0 \[Rule] 96.72703439467705`, 
      xb1 \[Rule] \(-3.9999056064519345`\)}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.64286 0.119048 -0.145849 0.0183943 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.2619 -0.0125 -19.0313 -24.5625 ]
[.2619 -0.0125 19.0313 0 ]
[.5 -0.0125 -19.0313 -24.5625 ]
[.5 -0.0125 19.0313 0 ]
[.7381 -0.0125 -19.0313 -24.5625 ]
[.7381 -0.0125 19.0313 0 ]
[.97619 -0.0125 -19.0313 -24.5625 ]
[.97619 -0.0125 19.0313 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03809 -24.125 -12.2813 ]
[-0.0125 .03809 0 12.2813 ]
[-0.0125 .13006 -24.125 -12.2813 ]
[-0.0125 .13006 0 12.2813 ]
[-0.0125 .22204 -24.125 -12.2813 ]
[-0.0125 .22204 0 12.2813 ]
[-0.0125 .31401 -24.125 -12.2813 ]
[-0.0125 .31401 0 12.2813 ]
[-0.0125 .40598 -24.125 -12.2813 ]
[-0.0125 .40598 0 12.2813 ]
[-0.0125 .49795 -24.125 -12.2813 ]
[-0.0125 .49795 0 12.2813 ]
[-0.0125 .58992 -24.125 -12.2813 ]
[-0.0125 .58992 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03809 m
.00625 .03809 L
s
gsave
-0.0125 .03809 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .13006 m
.00625 .13006 L
s
gsave
-0.0125 .13006 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .22204 m
.00625 .22204 L
s
gsave
-0.0125 .22204 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .31401 m
.00625 .31401 L
s
gsave
-0.0125 .31401 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
0 .40598 m
.00625 .40598 L
s
gsave
-0.0125 .40598 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .49795 m
.00625 .49795 L
s
gsave
-0.0125 .49795 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
1.000 setlinewidth
grestore
0 .58992 m
.00625 .58992 L
s
gsave
-0.0125 .58992 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05649 m
.00375 .05649 L
s
0 .07488 m
.00375 .07488 L
s
0 .09328 m
.00375 .09328 L
s
0 .11167 m
.00375 .11167 L
s
0 .14846 m
.00375 .14846 L
s
0 .16685 m
.00375 .16685 L
s
0 .18525 m
.00375 .18525 L
s
0 .20364 m
.00375 .20364 L
s
0 .24043 m
.00375 .24043 L
s
0 .25882 m
.00375 .25882 L
s
0 .27722 m
.00375 .27722 L
s
0 .29561 m
.00375 .29561 L
s
0 .3324 m
.00375 .3324 L
s
0 .3508 m
.00375 .3508 L
s
0 .36919 m
.00375 .36919 L
s
0 .38758 m
.00375 .38758 L
s
0 .42437 m
.00375 .42437 L
s
0 .44277 m
.00375 .44277 L
s
0 .46116 m
.00375 .46116 L
s
0 .47956 m
.00375 .47956 L
s
0 .51634 m
.00375 .51634 L
s
0 .53474 m
.00375 .53474 L
s
0 .55313 m
.00375 .55313 L
s
0 .57153 m
.00375 .57153 L
s
0 .0197 m
.00375 .0197 L
s
0 .0013 m
.00375 .0013 L
s
0 .60832 m
.00375 .60832 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03809 m
1 .03809 L
s
.99375 .13006 m
1 .13006 L
s
.99375 .22204 m
1 .22204 L
s
.99375 .31401 m
1 .31401 L
s
.99375 .40598 m
1 .40598 L
s
.99375 .49795 m
1 .49795 L
s
.99375 .58992 m
1 .58992 L
s
.125 Mabswid
.99625 .05649 m
1 .05649 L
s
.99625 .07488 m
1 .07488 L
s
.99625 .09328 m
1 .09328 L
s
.99625 .11167 m
1 .11167 L
s
.99625 .14846 m
1 .14846 L
s
.99625 .16685 m
1 .16685 L
s
.99625 .18525 m
1 .18525 L
s
.99625 .20364 m
1 .20364 L
s
.99625 .24043 m
1 .24043 L
s
.99625 .25882 m
1 .25882 L
s
.99625 .27722 m
1 .27722 L
s
.99625 .29561 m
1 .29561 L
s
.99625 .3324 m
1 .3324 L
s
.99625 .3508 m
1 .3508 L
s
.99625 .36919 m
1 .36919 L
s
.99625 .38758 m
1 .38758 L
s
.99625 .42437 m
1 .42437 L
s
.99625 .44277 m
1 .44277 L
s
.99625 .46116 m
1 .46116 L
s
.99625 .47956 m
1 .47956 L
s
.99625 .51634 m
1 .51634 L
s
.99625 .53474 m
1 .53474 L
s
.99625 .55313 m
1 .55313 L
s
.99625 .57153 m
1 .57153 L
s
.99625 .0197 m
1 .0197 L
s
.99625 .0013 m
1 .0013 L
s
.99625 .60832 m
1 .60832 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
.01 w
.02381 .01472 Mdot
.03571 .02207 Mdot
.04762 .02943 Mdot
.05952 .03679 Mdot
.07143 .04414 Mdot
.08333 .0515 Mdot
.09524 .05886 Mdot
.10714 .06622 Mdot
.11905 .07357 Mdot
.13095 .08093 Mdot
.14286 .08829 Mdot
.15476 .09565 Mdot
.16667 .103 Mdot
.17857 .11036 Mdot
.19048 .11772 Mdot
.20238 .12508 Mdot
.21429 .13244 Mdot
.22619 .13979 Mdot
.2381 .14715 Mdot
.25 .15451 Mdot
.2619 .16187 Mdot
.27381 .16922 Mdot
.28571 .17658 Mdot
.29762 .18394 Mdot
.30952 .1913 Mdot
.32143 .19865 Mdot
.33333 .20601 Mdot
.34524 .21337 Mdot
.35714 .22073 Mdot
.36905 .22809 Mdot
.38095 .23544 Mdot
.39286 .2428 Mdot
.40476 .25016 Mdot
.41667 .25752 Mdot
.42857 .26487 Mdot
.44048 .27223 Mdot
.45238 .27959 Mdot
.46429 .28695 Mdot
.47619 .2943 Mdot
.4881 .30166 Mdot
.5 .30902 Mdot
.5119 .31638 Mdot
.52381 .32374 Mdot
.53571 .33109 Mdot
.54762 .33845 Mdot
.55952 .34581 Mdot
.57143 .35317 Mdot
.58333 .36052 Mdot
.59524 .36788 Mdot
.60714 .37524 Mdot
.61905 .3826 Mdot
.63095 .38995 Mdot
.64286 .39731 Mdot
.65476 .40467 Mdot
.66667 .41203 Mdot
.67857 .41938 Mdot
.69048 .42674 Mdot
.70238 .4341 Mdot
.71429 .44146 Mdot
.72619 .44881 Mdot
.7381 .45617 Mdot
.75 .46353 Mdot
.7619 .47089 Mdot
.77381 .47824 Mdot
.78571 .4856 Mdot
.79762 .49296 Mdot
.80952 .50032 Mdot
.82143 .50767 Mdot
.83333 .51503 Mdot
.84524 .52239 Mdot
.85714 .52974 Mdot
.86905 .5371 Mdot
.88095 .54446 Mdot
.89286 .55181 Mdot
.90476 .55917 Mdot
.91667 .56653 Mdot
.92857 .57388 Mdot
.94048 .58124 Mdot
.95238 .58859 Mdot
.96429 .59595 Mdot
.97619 .60331 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00903oool00`3OW4P00000000000050000000307Boo`3oool0gia800L0000000<0M;oo0?oo
o`3oool08P3oool00`3OW4P00000000000050000000307Boo`3oool0oooo0080oooo00@0_g@00000
00000000B9cO:@3oool00`3o_g@000000000000200000003001d_`3oool0oooo0080oooo00H0omnL
04P00000000000000000B02LgolW0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0
0P3oool01P3ooml0W4P0000000000000001d0;ooobL0oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`050?ooo`030?noM0000000M;oo00d0oooo000U0?ooo`030=nLB0000000000000@0
000000@007Bo0?ooo`3oool0gia81P0000000`00M;l0oooo0?ooo`0S0?ooo`030=nLB00000000000
00@0000000X007Bo0?ooo`3oool0oooO09a80000M;l0oooo0?oog`2LB00007Bo:P3oool00`2oM000
001d0;ooo`040?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0001d_olX0?ooo`030;md0000
07@0_ooo00@0oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOobP0oooo00<0_g@00000
M02oool0203oool00`3o_g@0000007Boo`0=0?ooo`009P3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?oog`2LB7@0_ooo0080oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0U0?ooo`03
0=nLB018W=l0oooo0080oooo00L0oooO09a8M02oool0oooo0?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol0:@3oool00`2oM000001d0;ooo`040?ooo`030;md000007@0_ooo00<0oooo00<0gia8
0018W03Oool09`3oool00`2oM000001d0;ooo`040?ooo`030;md000007@0_ooo00<0oooo00<0_g@0
001d_`3oool09`3oool00`2oM000001d0;ooo`080?ooo`030?noM0000000M;oo00d0oooo000W0?oo
o`030=nLB018W=l0oooo00L0oooo00<0gia804RLg`3oool0:P3oool00`3OW4P0B9cO0?ooo`040?oo
o`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0:@3oool00`2oM000001d0;ooo`04
0?ooo`030;md000007@0_ooo00<0oooo00<0_g@00018W03Oool09`3oool00`2oM000001d0;ooo`03
0?ooo`030?oo_`1d000007Bo00@0oooo00<0gia80000M02oool09`3oool00`2oM000001d0;ooo`03
0?ooo`030=nLB0000000000000D0000000<0001809cOo`3oool02P3oool002P0oooo00<0gia807Bo
o`3oool01`3oool00`3OW4P0M;oo0?ooo`0Z0?ooo`030=nLB01d_ol0oooo00<0oooo00<0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`0X0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000
B02Lgol00P3oool00`3OW4P00000001d_`0X0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P0
0018W=l0103oool00`2oM000001809cOo`0W0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04Qd
_`3oool00P3oool00`3o_g@0000007Boo`0=0?ooo`005`3oool00`2oM00000000000000700000003
04RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol01`3oool00`3ooml0W4Q809cOo`0I0?ooo`03
0;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`030?ooo`03
0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool05`3oool00`2oM00000000000000700000003
04RLg`3oool0oooo00@0oooo00<0_g@00000M02oool01@3oool01`3OW4P007Bo0?ooo`2oM0000000
0000M02oool05`3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0_g@0
0000M02oool00`3oool00`3ogi`0B00004RLg`030?ooo`040?oo_`1d0000001d0;oooaH0oooo00<0
_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo00@0oooo00L0
gia807Boo`3oool0oooo0?noM0000000M;oo00d0oooo000Y0?ooo`030?oOW01807@0_ooo00L0oooo
00<0omnL04P0M02oool0:P3oool00`3ogi`0B01d0;ooo`020?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol0:03oool00`2oM000001d0;ooo`060?ooo`050?noM000000000000018W03O
ool0:@3oool00`2oM000001d0;ooo`030?ooo`090?oo_`1d000000000018W03Oool0oooo0;md0000
0000B9cO02P0oooo00<0_g@00000M02oool0103oool01`3ookl0M01d0;ooo`3oool0okmd0000001d
_ol03@3oool002X0oooo00<0_g@004RLg`3oool01`3oool00`2oM000B9cO0?ooo`0Z0?ooo`070;md
0018W=l0oooo0?ooo`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02P0oooo00<0_g@00000
M02oool01@3oool01@3ogi`0B000000000000000B9cO02X0oooo00<0_g@00000M02oool00`3oool0
1@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool09`3oool00`2oM000001d0;oo
o`050?ooo`060?noM000M;l0oooo0?noM0000000M;oo3@3oool002X0oooo00<0gia80000M02oool0
1`3oool00`3OW4P0001d0;ooo`0Z0?ooo`070=nLB00007@0_ooo0?ooo`3ookl0M000001d_`040?oo
o`030;md000007@0_ooo02P0oooo00<0_g@00000M02oool0103oool01`3ogi`0B0000000B02Lgol0
oooo0=nLB000M;l0:@3oool00`2oM000001d0;ooo`040?ooo`030?noM0000000B9cO02d0oooo00<0
_g@00000M02oool01P3oool01@2oM000M;oo0?noM0000000M;oo00d0oooo000Z0?ooo`030?noM000
0000M;oo00L0oooo00<0okmd0000001d_ol0:P3oool00`3o_g@0000007Boo`020?ooo`030;md0000
B9`0gooo0080oooo00<0oooO09a80000M;l0:@3oool00`2oM000001d0;ooo`040?ooo`030=nLB000
04P0W=oo0080oooo00<0oooO09a8001d_ol0:03oool00`2oM000001d0;ooo`040?ooo`040?oog`2L
B000001809cOob`0oooo00<0_g@00000M02oool01P3oool01@3ookl0M01d0;noM0000000M;oo00d0
oooo000T0?ooo`030?oOW02L_ol0oooo00<0oooo00H0_g@00000001d_ol0oooo0?oOW02L_ol40?oo
o`030;md00000000M;oo02@0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`020?oo
o`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0:@3oool00`2oM000001d0;ooo`040?oo
o`030=nLB000B9`0gooo0080oooo00<0oooO09a80018W=l0:03oool00`2oM000001d0;ooo`050?oo
o`040?oo_`1d0000001d0;ooob/0oooo00<0_g@00000M02oool01`3oool0103o_g@000000000001d
_ol=0?ooo`009@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0P3oool0202oM000
M;oo0?ooo`3oool0gia800000000B9`0gooo9@3oool0202oM000M;oo0?ooo`3oool0gia800000000
B9`0gooo0`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_bP0oooo00D0gia8000000000000001d
0;ooo`040?ooo`030?oOW0180000B9cO0080oooo00<0okmd0000B02Lgol09P3oool01@3OW4P00000
0000000007@0_ooo00H0oooo00@0oooO09a80000000007Bo:03oool01@3OW4P000000000000007@0
_ooo00L0oooo00@0oooO09a800000000M;oo3@3oool002H0oooo00D0_g@00000000000000000001d
_`050?ooo`050;md00000000000000000000M;l0:03oool01@2oM000000000000000000007Bo00H0
oooo00@0_g@000000000000007Bo:P3oool0103ookl0M0000000M02oool50?ooo`060?oo_`1d0000
00000000000004P0W=oo:03oool0103ookl0M0000000M02oool80?ooo`050?oOW018000000000018
W03Oool09P3oool0103ookl0M0000000M02oool80?ooo`030?oOW0180000M;oo00d0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo000Q0?ooonX000005@3oool00240oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04`3oool00240oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`0C0?oo
o`002`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00<0oooo00@0_g@000000000
0000B9cO1`3oool00`000000oooo0?ooo`020?ooo`800000hP3oool00`000000oooo0?ooo`0C0?oo
o`003@3oool00`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`06
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`0000000000h03oool00`000000oooo0?oo
o`0C0?ooo`003@3oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol01@3oool2000000H0oooo0P00003N0?ooo`8000005@3oool000d0oooo00<0_g@00000
M02oool00`3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00D0oooo00<00000
0?ooo`3oool01@3oool010000000oooo00000000003M0?ooo`030000003oool0oooo01<0oooo000=
0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`04
0?ooo`030000003oool0oooo00P0oooo0P00003L0?ooo`030000003oool0oooo01<0oooo000=0?oo
o`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`040?oo
o`030000003oool0oooo00X0oooo0P00003J0?ooo`030000003oool0oooo01<0oooo000=0?ooo`03
0;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`040?ooo`<0
00002`3oool200000=P0oooo0P00000E0?ooo`003@3oool00`2oM000001d0;ooo`030?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol0103oool00`000000oooo0?ooo`0=0?ooo`800000
e`3oool00`000000oooo0?ooo`0C0?ooo`003@3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool0103oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0000000000=D0oooo00<000000?ooo`3oool04`3oool000d0oooo00<0_g@00000M02oool0103o
ool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00D0oooo00<000000?ooo`3oool0403o
ool200000=@0oooo00<000000?ooo`3oool04`3oool000d0oooo00<0_g@00000M02oool0103oool0
0`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00D0oooo0P00000A0?ooo`040000003oool0
000000000=40oooo0P00000E0?ooo`002`3oool01@3OW4P000000000000007@0_ooo00D0oooo00H0
_g@00018W03Oool0oooo0;md0000M;l60?ooo`030000003oool0oooo01<0oooo0`00003@0?ooo`03
0000003oool0oooo01<0oooo000<0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00@0_g@000000000
000007Bo1`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0<d0oooo00<000000?oo
o`3oool04`3oool00240oooo00<000000?ooo`3oool05P3oool300000<d0oooo00<000000?ooo`3o
ool04`3oool00240oooo0P00000J0?ooo`030000003oool0oooo0<T0oooo0P00000E0?ooo`008@3o
ool00`000000oooo0?ooo`0I0?ooo`<00000bP3oool00`000000oooo0?ooo`0C0?ooo`008@3oool0
0`000000oooo0?ooo`0K0?ooo`800000b@3oool00`000000oooo0?ooo`0C0?ooo`008@3oool00`00
0000oooo0?ooo`0M0?ooo`800000a`3oool00`000000oooo0?ooo`0C0?ooo`008@3oool00`000000
oooo0?ooo`0N0?ooo`800000aP3oool00`000000oooo0?ooo`0C0?ooo`008@3oool200000240oooo
0P0000330?ooo`8000005@3oool00240oooo00<000000?ooo`3oool08@3oool300000<80oooo00<0
00000?ooo`3oool04`3oool00240oooo00<000000?ooo`3oool0903oool200000<00oooo00<00000
0?ooo`3oool04`3oool000/0oooo00<0okmd0000000000000P0000001@00M;l0oooo0?ooo`3oool0
_g@000<0000000<004RL0=ooo`3oool01P3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0
000000000;h0oooo00<000000?ooo`3oool04`3oool000d0oooo00<0_g@00000M02oool00`3oool0
0`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00H0oooo0P00000W0?ooo`030000003oool0
00000;`0oooo0P00000E0?ooo`003@3oool00`2oM000001d0;ooo`090?ooo`030?oOW018M;l0oooo
00D0oooo00<000000?ooo`3oool0:@3oool200000;/0oooo00<000000?ooo`3oool04`3oool000d0
oooo00<0_g@00000M02oool02@3oool00`3ookl0M01809cOo`050?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`000000^P3oool00`000000oooo0?ooo`0C0?ooo`003@3oool00`2oM000001d
0;ooo`090?ooo`030?oo_`1d0000M;oo00D0oooo00<000000?ooo`3oool0;03oool200000;P0oooo
00<000000?ooo`3oool04`3oool000d0oooo00<0_g@00000M02oool02@3oool00`3o_g@0000007Bo
o`050?ooo`<00000;03oool010000000oooo00000000002e0?ooo`8000005@3oool000d0oooo00<0
_g@00000M02oool0203oool0103ogi`0B0000000M02oool50?ooo`030000003oool0oooo02l0oooo
0P00002e0?ooo`030000003oool0oooo01<0oooo000=0?ooo`030;md000007@0_ooo00@0oooo00@0
gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`040?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0C0?ooo`003@3oool00`2oM000001d0;oo
o`040?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01@3oool00`000000oooo0?oo
o`0a0?ooo`<00000/P3oool00`000000oooo0?ooo`0C0?ooo`003@3oool00`2oM000001d0;ooo`04
0?ooo`050?oog`2LB00000000000M02oool0203oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool04`3oool000d0oooo00<0_g@00000M02oool01@3oool0
0`3o_g@007Bo0?ooo`090?ooo`800000=@3oool300000:h0oooo0P00000E0?ooo`002`3oool01@3O
W4P000000000000007@0_ooo00D0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`04
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0C
0?ooo`00303oool0103ookl0M0000000M02oool60?ooo`030?noM000000000000080000000<0M;oo
0?ooo`3oool00`3oool00`000000oooo0?ooo`0g0?ooo`@00000Z`3oool00`000000oooo0?ooo`0C
0?ooo`008@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool04`3oool00240oooo0P00000l0?ooo`<00000Y`3oool2000001D0oooo000Q0?ooo`030000
003oool0oooo03d0oooo0P00002W0?ooo`030000003oool0oooo01<0oooo000Q0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0C0?ooo`008@3oool0
0`000000oooo0?ooo`0o0?ooo`@00000X`3oool00`000000oooo0?ooo`0C0?ooo`008@3oool20000
04<0oooo0P00002Q0?ooo`8000005@3oool00240oooo00<000000?ooo`3oool0A03oool200000:00
oooo00<000000?ooo`3oool04`3oool00240oooo00<000000?ooo`3oool0A@3oool2000009l0oooo
00<000000?ooo`3oool04`3oool000T0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?oo
o`020?ooo`040;md00000000000004RLg`L0oooo00<000000?ooo`3oool0A`3oool2000009d0oooo
00<000000?ooo`3oool04`3oool000X0oooo00<0gia8000000000000100000002P00M;l0oooo0?oo
o`3ooml0W4P0001d_`3oool0oooO09a80000M;l60?ooo`800000B@3oool3000009X0oooo0P00000E
0?ooo`002`3oool00`3OW4P0B9cO0?ooo`020?ooo`070?oog`2LB7@0_ooo0?ooo`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00D0oooo00<000000?ooo`3oool0BP3oool3000009T0oooo00<0
00000?ooo`3oool04`3oool000`0oooo00<0gia804RLg`3oool0103oool0103ooml0W4P00018W03O
ool20?ooo`030?oog`2LB00007Bo00D0oooo00<000000?ooo`3oool0BP3oool010000000oooo0?oo
o`00002H0?ooo`030000003oool0oooo01<0oooo000=0?ooo`030=nLB01d_ol0oooo00<0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`040?ooo`030000003oool0oooo04d0oooo0`00
002F0?ooo`030000003oool0oooo01<0oooo000=0?ooo`030?oog`2LB4P0W=oo00<0oooo00<0omnL
04P00018W=l0103oool00`2oM000001d0;ooo`040?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`0C0?ooo`003P3oool00`3ogi`0B01d0;ooo`020?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0103oool300000500oooo0`00002B0?oo
o`8000005@3oool000l0oooo00L0_g@004RLg`3oool0oooo0?oOW0180000B9cO00@0oooo00<0gia8
0000B02Lgol0103oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool04`3oool000l0oooo00L0gia80000M02oool0oooo0?oo_`1d000007Bo00@0oooo00<0
_g@00000M02oool0103oool00`000000oooo0?ooo`1C0?ooo`<00000T03oool00`000000oooo0?oo
o`0C0?ooo`003`3oool00`3o_g@0000007Boo`020?ooo`030;md0000B9`0gooo0080oooo00<0oooO
09a80000M;l01@3oool00`000000oooo0?ooo`1E0?ooo`800000S`3oool00`000000oooo0?ooo`0C
0?ooo`002@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo0080oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`050?ooo`800000F03oool2000008`0oooo0P00000E0?oo
o`002P3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0`3oool01P2oM00004RL0=oo
o`3oool0_g@0001d_`H0oooo00<000000?ooo`3oool0F03oool3000008/0oooo00<000000?ooo`3o
ool04`3oool000/0oooo00D0_g@00000000000000000001d_`060?ooo`040;md000000000000001d
_`L0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
01<0oooo000Q0?ooo`030000003oool0oooo05/0oooo0`0000280?ooo`030000003oool0oooo01<0
oooo000Q0?ooo`800000G`3oool2000008D0oooo0P00000E0?ooo`008@3oool00`000000oooo0?oo
o`1N0?ooo`040000003oool00000000008@0oooo00<000000?ooo`3oool04`3oool00240oooo00<0
00000?ooo`3oool0H@3oool2000008<0oooo00<000000?ooo`3oool04`3oool00240oooo00<00000
0?ooo`3oool0H`3oool200000840oooo00<000000?ooo`3oool04`3oool00240oooo0P00001T0?oo
o`040000003oool00000000007h0oooo0P00000E0?ooo`008@3oool00`000000oooo0?ooo`1V0?oo
o`<00000O@3oool00`000000oooo0?ooo`0C0?ooo`008@3oool00`000000oooo0?ooo`1V0?ooo`04
0000003oool0oooo000007`0oooo00<000000?ooo`3oool04`3oool000T0oooo00<0gia800000000
00001@000000101d_ol0oooo0?ooo`2oM003000000030018W03Oool0oooo00H0oooo00<000000?oo
o`3oool0J@3oool3000007X0oooo00<000000?ooo`3oool04`3oool000X0oooo00<0gia800000000
0000100000001@00M;l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool01P3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool04`3oool000/0
oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?ooo`030?oOW018M;l0oooo00D0
oooo0P00001]0?ooo`<00000MP3oool2000001D0oooo000<0?ooo`030=nLB018W=l0oooo00X0oooo
00<0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`1^0?ooo`800000MP3oool00`000000oooo
0?ooo`0C0?ooo`003@3oool00`3OW4P0M;oo0?ooo`090?ooo`030?oo_`1d0000M;oo00D0oooo00<0
00000?ooo`3oool0KP3oool010000000oooo00000000001d0?ooo`030000003oool0oooo01<0oooo
000=0?ooo`030?oog`2LB4P0W=oo00T0oooo00<0okmd0000001d_ol01@3oool00`000000oooo0?oo
o`1a0?ooo`800000L`3oool00`000000oooo0?ooo`0C0?ooo`003P3oool00`3ogi`0B01d0;ooo`07
0?ooo`040?oOW0180000001d0;ooo`D0oooo0`00001a0?ooo`040000003oool0000000000700oooo
0P00000E0?ooo`003`3oool00`2oM000B9cO0?ooo`020?ooo`040=oOg`3oool0oooo0;md00800000
00<0B9cO0?ooo`3oool0103oool00`000000oooo0?ooo`1d0?ooo`800000L03oool00`000000oooo
0?ooo`0C0?ooo`003`3oool00`3OW4P0001d0;ooo`020?ooo`030?noM000000000000080000000<0
07Bo0?ooo`3oool01@3oool00`000000oooo0?ooo`1f0?ooo`800000KP3oool00`000000oooo0?oo
o`0C0?ooo`003`3oool00`3o_g@0000007Boo`020?ooo`050?oog`2LB00000000000M02oool0203o
ool00`000000oooo0?ooo`1g0?ooo`800000K@3oool00`000000oooo0?ooo`0C0?ooo`002@3oool0
0`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00<0oooo00<0okmd001d_`3oool02@3oool2
000007X0oooo0P00001Z0?ooo`8000005@3oool000X0oooo00P0_g@007Boo`3oool0oooo0=nLB000
000004RL0=ooo`<0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`040?ooo`030000
003oool0oooo07T0oooo00@000000?ooo`0000000000J@3oool00`000000oooo0?ooo`0C0?ooo`00
2`3oool01@2oM000000000000000000007Bo00H0oooo00<0okmd0000000000000P0000000`1d_ol0
oooo0?ooo`030?ooo`030000003oool0oooo07`0oooo0P00001X0?ooo`030000003oool0oooo01<0
oooo000Q0?ooo`030000003oool0oooo07h0oooo0P00001V0?ooo`030000003oool0oooo01<0oooo
000Q0?ooo`030000003oool0oooo07l0oooo0`00001T0?ooo`030000003oool0oooo01<0oooo000Q
0?ooo`800000P`3oool200000640oooo0P00000E0?ooo`008@3oool00`000000oooo0?ooo`220?oo
o`040000003oool0000000000600oooo00<000000?ooo`3oool04`3oool00240oooo00<000000?oo
o`3oool0Q@3oool2000005l0oooo00<000000?ooo`3oool04`3oool00240oooo00<000000?ooo`3o
ool0Q`3oool2000005d0oooo00<000000?ooo`3oool04`3oool00240oooo0P0000280?ooo`030000
003oool0000005/0oooo0P00000E0?ooo`008@3oool00`000000oooo0?ooo`2:0?ooo`800000FP3o
ool00`000000oooo0?ooo`0C0?ooo`008@3oool00`000000oooo0?ooo`2:0?ooo`040000003oool0
0000000005P0oooo00<000000?ooo`3oool04`3oool000T0oooo00<0oooO09a8000000000P000000
0`00B9`0gooo0?ooo`050?ooo`040;md00000000000004RLg`L0oooo00<000000?ooo`3oool0S@3o
ool2000005L0oooo00<000000?ooo`3oool04`3oool000T0oooo00P0omnL04P00000B9`0gooo0?oo
o`3ogi`0B01809cOo`<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00H0oooo0P00002>
0?ooo`040000003oool00000000005@0oooo0P00000E0?ooo`003`3oool00`3o_g@004RL0=ooo`02
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01@3oool00`000000oooo0?ooo`2@
0?ooo`800000E03oool00`000000oooo0?ooo`0C0?ooo`003`3oool0203o_g@0001809cOo`3oool0
oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`050?ooo`030000003oool0oooo0980oooo
0P00001B0?ooo`030000003oool0oooo01<0oooo000?0?ooo`070;md000004P0W=oo0?ooo`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo00@0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0000001A0?ooo`030000003oool0oooo01<0oooo000>0?ooo`080;md00000000001d0;ooo`3o
ool0omnL04P00018W=l40?ooo`030;md000007@0_ooo00@0oooo0`00002E0?ooo`800000CP3oool2
000001D0oooo000;0?ooo`030?oo_`1d000000000080000000H0B9cO0?ooo`3oool0omnL04P00018
W=l40?ooo`030=nLB00004P0W=oo00@0oooo00<000000?ooo`3oool0U@3oool010000000oooo0000
0000001=0?ooo`030000003oool0oooo01<0oooo000=0?ooo`030?noM00004P0W=oo00<0oooo00<0
omnL04P00018W=l0103oool00`3OW4P0001809cOo`040?ooo`030000003oool0oooo09P0oooo0P00
001<0?ooo`030000003oool0oooo01<0oooo000>0?ooo`030?oOW018M;l0oooo0080oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`040?ooo`030000003oool0oooo09X0oooo0P00001:
0?ooo`030000003oool0oooo01<0oooo000>0?ooo`030?oog`2LB000B9cO00<0oooo00<0_g@00018
W03Oool00P3oool00`3ooml0W4P0001d_`050?ooo`030000003oool0oooo09/0oooo0`0000180?oo
o`030000003oool0oooo01<0oooo00090?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000
M;l00`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00D0oooo0P00002N0?ooo`<0
0000A@3oool2000001D0oooo000:0?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`040?oo
o`060;md0000B9`0gooo0?ooo`2oM00007Bo1P3oool00`000000oooo0?ooo`2M0?ooo`040000003o
ool0oooo000004D0oooo00<000000?ooo`3oool04`3oool000/0oooo00D0omnL04P0000000000000
04RLg`060?ooo`040;md000000000000001d_`L0oooo00<000000?ooo`3oool0X03oool3000004<0
oooo00<000000?ooo`3oool04`3oool00240oooo00<000000?ooo`3oool0X03oool010000000oooo
0?ooo`0000120?ooo`030000003oool0oooo01<0oooo000Q0?ooo`800000Y03oool3000003l0oooo
0P00000E0?ooo`008@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool04`3oool00240oooo00<000000?ooo`3oool0YP3oool3000003d0oooo00<00000
0?ooo`3oool04`3oool00240oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo01<0oooo000Q0?ooo`800000ZP3oool3000003T0oooo0P00000E0?ooo`00
8@3oool00`000000oooo0?ooo`2[0?ooo`800000>@3oool00`000000oooo0?ooo`0C0?ooo`008@3o
ool00`000000oooo0?ooo`2]0?ooo`800000=`3oool00`000000oooo0?ooo`0C0?ooo`002@3oool0
0`3ooml0W4P000000002000000030018W03Oool0oooo00<0oooo00H0_g@000000000000000000018
W03Oool70?ooo`030000003oool0oooo0:h0oooo0P00000f0?ooo`030000003oool0oooo01<0oooo
00090?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0B02Lgol20?ooo`030?oog`2LB000B9cO
0080oooo00<0omnL04Q8W03Oool01P3oool00`000000oooo0?ooo`2`0?ooo`800000=03oool00`00
0000oooo0?ooo`0C0?ooo`003`3oool00`3o_g@004RL0=ooo`070?ooo`030?oOW018M;l0oooo00D0
oooo0P00002b0?ooo`800000<P3oool2000001D0oooo000?0?ooo`030?noM00004P0W=oo00L0oooo
00<0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`2c0?ooo`800000<@3oool00`000000oooo
0?ooo`0C0?ooo`003`3oool00`2oM000001809cOo`070?ooo`030?oo_`1d0000M;oo00D0oooo00<0
00000?ooo`3oool0]03oool3000002l0oooo00<000000?ooo`3oool04`3oool000h0oooo00@0_g@0
0000000007@0_ooo1`3oool00`3o_g@0000007Boo`050?ooo`030000003oool0oooo0;H0oooo0P00
000^0?ooo`030000003oool0oooo01<0oooo000;0?ooo`030?oo_`1d000000000080000000<0B9cO
0?ooo`3oool01@3oool0103ogi`0B0000000M02oool50?ooo`<00000^03oool2000002/0oooo0P00
000E0?ooo`003@3oool00`3o_g@0001809cOo`040?ooo`040=oOg`3oool0oooo0;md0080000000<0
B9cO0?ooo`3oool0103oool00`000000oooo0?ooo`2i0?ooo`<00000:P3oool00`000000oooo0?oo
o`0C0?ooo`003P3oool00`3ogi`0B7Bo0?ooo`030?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool01@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool04`3oool000h0oooo00<0oooO09a80018W=l00`3oool01@3ooml0W4P00000000007@0
_ooo00P0oooo00<000000?ooo`3oool0_03oool4000002H0oooo00<000000?ooo`3oool04`3oool0
00T0oooo00<0oooO09adW03Oool00P3oool00`3ooml0W4P0001d_`040?ooo`030?noM000M;l0oooo
00T0oooo0P0000300?ooo`030000003oool0oooo02<0oooo0P00000E0?ooo`002P3oool01`3ogi`0
B4RL0=ooo`3oool0gia80000001d_ol0103oool00`3ooml0W4P000000002000000030000M02oool0
oooo00@0oooo00<000000?ooo`3oool0`03oool2000002@0oooo00<000000?ooo`3oool04`3oool0
00/0oooo00D0omnL04P000000000000004RLg`060?ooo`030?noM000000000000080000000<0M;oo
0?ooo`3oool00`3oool00`000000oooo0?ooo`310?ooo`8000008`3oool00`000000oooo0?ooo`0C
0?ooo`008@3oool00`000000oooo0?ooo`330?ooo`8000008@3oool00`000000oooo0?ooo`0C0?oo
o`008@3oool200000<D0oooo0P00000O0?ooo`8000005@3oool00240oooo00<000000?ooo`3oool0
aP3oool2000001h0oooo00<000000?ooo`3oool04`3oool00240oooo00<000000?ooo`3oool0a`3o
ool4000001/0oooo00<000000?ooo`3oool04`3oool00240oooo00<000000?ooo`3oool0bP3oool2
000001X0oooo00<000000?ooo`3oool04`3oool00240oooo00<000000?ooo`3oool0c03oool20000
01P0oooo00<000000?ooo`3oool04`3oool00240oooo0P00003>0?ooo`8000005P3oool2000001D0
oooo000Q0?ooo`030000003oool0oooo0<l0oooo0P00000E0?ooo`030000003oool0oooo01<0oooo
000>0?ooo`030?noM0000000M;oo00D0oooo00@0_g@0000000000000B9cO1`3oool00`000000oooo
0?ooo`3?0?ooo`040000003oool00000000001<0oooo00<000000?ooo`3oool04`3oool000h0oooo
00<0okmd0000001d_ol00`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l01P3oool00`00
0000oooo0?ooo`3B0?ooo`8000004P3oool00`000000oooo0?ooo`0C0?ooo`003P3oool00`3o_g@0
000007Boo`030?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01@3oool200000=D0
oooo0P00000?0?ooo`8000005@3oool000T0oooo00<0gia80000000000001@0000001P0004P0W=oo
0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01@3oool00`000000oooo0?ooo`3E0?oo
o`<000003P3oool00`000000oooo0?ooo`0C0?ooo`002@3oool00`3ogi`0B7Bo0?ooo`020?ooo`03
0?noM0000000M;oo0080oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`040?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`00
2P3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d_ol00P3oool00`3ogi`0B00004RLg`040?oo
o`030;md000007@0_ooo00@0oooo00<000000?ooo`3oool0f03oool3000000/0oooo00<000000?oo
o`3oool04`3oool000X0oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo0080oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`040?ooo`<00000fP3oool3000000P0oooo0P00000E
0?ooo`002`3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`80oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`040?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool00P00
00070?ooo`030000003oool0oooo01<0oooo000<0?ooo`050;md001d_ol0okmd0000001d_ol00P3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00@0oooo00<000000?ooo`3oool0g@3o
ool010000000oooo0000000000050?ooo`030000003oool0oooo01<0oooo000<0?ooo`050?oo_`1d
07@0_kmd0000001d_ol00`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00D0oooo
00<000000?ooo`3oool0h03oool2000000@0oooo00<000000?ooo`3oool04`3oool000d0oooo00@0
okmd000000000000M;oo0`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00D0oooo
0P00003Q0?ooo`030000003oool0oooo0080oooo0P00000E0?ooo`003@3oool0103ooml0W4P00000
001d_ol40?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo1P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?oo
o`003P3oool00`3ogi`0B00007Boo`050?ooo`040;md000000000000001d_`L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool04`3oool00240oooojP00000E0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-23.4279, 1.50716, \
0.0361213, 0.233777}}],

Cell[BoxData[
    \({f0 \[Rule] \(-3.061568868559652`*^39\)}\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("Log[-\!\(f\_0\)] = \
"\[InvisibleSpace]90.91974611348891`\),
      SequenceForm[ "Log[-\!\(f\_0\)] = ", 90.919746113488912],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(data2 = 
        Table[{N, 
            Log[FN[N]]}, {N, \(-8\), \(-1.75\),  .1}];\)\), "\
\[IndentingNewLine]", 
    \(f2 = FindFit[data2, LogF0 - xb1\ N, {LogF0, xb1}, N]\), "\n", 
    \(\(ppp1 = 
        Plot[\((LogF0 - xb1\ N)\) /. f2, {N, \(-8\), \(-1.75\)}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(pp2 = 
        ListPlot[data2, PlotStyle \[Rule] {PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[ppp1, pp2, DisplayFunction \[Rule] $DisplayFunction, 
        Frame \[Rule] True, Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(tt = 
        Table[{\(fF[N] /. f2\) /. N \[Rule] nn, 
            fN[N] /. N \[Rule] 
                nn}, {nn, \(-8\), \(-1.75\),  .05}];\)\), "\n", 
    \(ft2 = FindFit[tt, f0 + fbb, f0, fbb]\), "\n", 
    \(Print[\*"\"\<Log[-\!\(f\_0\)] = \>\"", 
      Log[\(-ft2[\([1, 2]\)]\)]]\)}], "Input"],

Cell[BoxData[
    \({LogF0 \[Rule] 92.16842340826722`, 
      xb1 \[Rule] \(-3.4495680882052198`\)}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.24286 0.152381 -1.72581 0.0270415 [
[.02381 -0.0125 -14 -24.5625 ]
[.02381 -0.0125 14 0 ]
[.17619 -0.0125 -14 -24.5625 ]
[.17619 -0.0125 14 0 ]
[.32857 -0.0125 -14 -24.5625 ]
[.32857 -0.0125 14 0 ]
[.48095 -0.0125 -14 -24.5625 ]
[.48095 -0.0125 14 0 ]
[.63333 -0.0125 -14 -24.5625 ]
[.63333 -0.0125 14 0 ]
[.78571 -0.0125 -14 -24.5625 ]
[.78571 -0.0125 14 0 ]
[.9381 -0.0125 -14 -24.5625 ]
[.9381 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03189 -24.125 -12.2813 ]
[-0.0125 .03189 0 12.2813 ]
[-0.0125 .16709 -24.125 -12.2813 ]
[-0.0125 .16709 0 12.2813 ]
[-0.0125 .3023 -24.125 -12.2813 ]
[-0.0125 .3023 0 12.2813 ]
[-0.0125 .43751 -24.125 -12.2813 ]
[-0.0125 .43751 0 12.2813 ]
[-0.0125 .57272 -24.125 -12.2813 ]
[-0.0125 .57272 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.17619 0 m
.17619 .00625 L
s
gsave
.17619 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.32857 0 m
.32857 .00625 L
s
gsave
.32857 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.48095 0 m
.48095 .00625 L
s
gsave
.48095 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.63333 0 m
.63333 .00625 L
s
gsave
.63333 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.9381 0 m
.9381 .00625 L
s
gsave
.9381 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.05429 0 m
.05429 .00375 L
s
.08476 0 m
.08476 .00375 L
s
.11524 0 m
.11524 .00375 L
s
.14571 0 m
.14571 .00375 L
s
.20667 0 m
.20667 .00375 L
s
.23714 0 m
.23714 .00375 L
s
.26762 0 m
.26762 .00375 L
s
.2981 0 m
.2981 .00375 L
s
.35905 0 m
.35905 .00375 L
s
.38952 0 m
.38952 .00375 L
s
.42 0 m
.42 .00375 L
s
.45048 0 m
.45048 .00375 L
s
.51143 0 m
.51143 .00375 L
s
.5419 0 m
.5419 .00375 L
s
.57238 0 m
.57238 .00375 L
s
.60286 0 m
.60286 .00375 L
s
.66381 0 m
.66381 .00375 L
s
.69429 0 m
.69429 .00375 L
s
.72476 0 m
.72476 .00375 L
s
.75524 0 m
.75524 .00375 L
s
.81619 0 m
.81619 .00375 L
s
.84667 0 m
.84667 .00375 L
s
.87714 0 m
.87714 .00375 L
s
.90762 0 m
.90762 .00375 L
s
.96857 0 m
.96857 .00375 L
s
.99905 0 m
.99905 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03189 m
.00625 .03189 L
s
gsave
-0.0125 .03189 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(65) show
1.000 setlinewidth
grestore
0 .16709 m
.00625 .16709 L
s
gsave
-0.0125 .16709 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
0 .3023 m
.00625 .3023 L
s
gsave
-0.0125 .3023 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
0 .43751 m
.00625 .43751 L
s
gsave
-0.0125 .43751 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .57272 m
.00625 .57272 L
s
gsave
-0.0125 .57272 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(85) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05893 m
.00375 .05893 L
s
0 .08597 m
.00375 .08597 L
s
0 .11301 m
.00375 .11301 L
s
0 .14005 m
.00375 .14005 L
s
0 .19414 m
.00375 .19414 L
s
0 .22118 m
.00375 .22118 L
s
0 .24822 m
.00375 .24822 L
s
0 .27526 m
.00375 .27526 L
s
0 .32934 m
.00375 .32934 L
s
0 .35639 m
.00375 .35639 L
s
0 .38343 m
.00375 .38343 L
s
0 .41047 m
.00375 .41047 L
s
0 .46455 m
.00375 .46455 L
s
0 .49159 m
.00375 .49159 L
s
0 .51863 m
.00375 .51863 L
s
0 .54568 m
.00375 .54568 L
s
0 .00485 m
.00375 .00485 L
s
0 .59976 m
.00375 .59976 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17619 .61178 m
.17619 .61803 L
s
.32857 .61178 m
.32857 .61803 L
s
.48095 .61178 m
.48095 .61803 L
s
.63333 .61178 m
.63333 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.9381 .61178 m
.9381 .61803 L
s
.125 Mabswid
.05429 .61428 m
.05429 .61803 L
s
.08476 .61428 m
.08476 .61803 L
s
.11524 .61428 m
.11524 .61803 L
s
.14571 .61428 m
.14571 .61803 L
s
.20667 .61428 m
.20667 .61803 L
s
.23714 .61428 m
.23714 .61803 L
s
.26762 .61428 m
.26762 .61803 L
s
.2981 .61428 m
.2981 .61803 L
s
.35905 .61428 m
.35905 .61803 L
s
.38952 .61428 m
.38952 .61803 L
s
.42 .61428 m
.42 .61803 L
s
.45048 .61428 m
.45048 .61803 L
s
.51143 .61428 m
.51143 .61803 L
s
.5419 .61428 m
.5419 .61803 L
s
.57238 .61428 m
.57238 .61803 L
s
.60286 .61428 m
.60286 .61803 L
s
.66381 .61428 m
.66381 .61803 L
s
.69429 .61428 m
.69429 .61803 L
s
.72476 .61428 m
.72476 .61803 L
s
.75524 .61428 m
.75524 .61803 L
s
.81619 .61428 m
.81619 .61803 L
s
.84667 .61428 m
.84667 .61803 L
s
.87714 .61428 m
.87714 .61803 L
s
.90762 .61428 m
.90762 .61803 L
s
.96857 .61428 m
.96857 .61803 L
s
.99905 .61428 m
.99905 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03189 m
1 .03189 L
s
.99375 .16709 m
1 .16709 L
s
.99375 .3023 m
1 .3023 L
s
.99375 .43751 m
1 .43751 L
s
.99375 .57272 m
1 .57272 L
s
.125 Mabswid
.99625 .05893 m
1 .05893 L
s
.99625 .08597 m
1 .08597 L
s
.99625 .11301 m
1 .11301 L
s
.99625 .14005 m
1 .14005 L
s
.99625 .19414 m
1 .19414 L
s
.99625 .22118 m
1 .22118 L
s
.99625 .24822 m
1 .24822 L
s
.99625 .27526 m
1 .27526 L
s
.99625 .32934 m
1 .32934 L
s
.99625 .35639 m
1 .35639 L
s
.99625 .38343 m
1 .38343 L
s
.99625 .41047 m
1 .41047 L
s
.99625 .46455 m
1 .46455 L
s
.99625 .49159 m
1 .49159 L
s
.99625 .51863 m
1 .51863 L
s
.99625 .54568 m
1 .54568 L
s
.99625 .00485 m
1 .00485 L
s
.99625 .59976 m
1 .59976 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02031 m
.06244 .04396 L
.10458 .06975 L
.14415 .09398 L
.18221 .11728 L
.22272 .14207 L
.26171 .16594 L
.30316 .19131 L
.34309 .21576 L
.3815 .23927 L
.42237 .26429 L
.46172 .28838 L
.49955 .31154 L
.53984 .3362 L
.57861 .35994 L
.61984 .38517 L
.65954 .40948 L
.69774 .43286 L
.73838 .45774 L
.77751 .4817 L
.81909 .50715 L
.85916 .53168 L
.89771 .55528 L
.93871 .58038 L
.97619 .60332 L
s
.02 w
.02381 .01472 Mdot
.03905 .02478 Mdot
.05429 .03479 Mdot
.06952 .04477 Mdot
.08476 .05471 Mdot
.1 .06461 Mdot
.11524 .07447 Mdot
.13048 .08428 Mdot
.14571 .09406 Mdot
.16095 .10381 Mdot
.17619 .11351 Mdot
.19143 .12318 Mdot
.20667 .13282 Mdot
.2219 .14242 Mdot
.23714 .15199 Mdot
.25238 .16154 Mdot
.26762 .17105 Mdot
.28286 .18054 Mdot
.2981 .19 Mdot
.31333 .19944 Mdot
.32857 .20885 Mdot
.34381 .21825 Mdot
.35905 .22762 Mdot
.37429 .23698 Mdot
.38952 .24632 Mdot
.40476 .25565 Mdot
.42 .26496 Mdot
.43524 .27425 Mdot
.45048 .28354 Mdot
.46571 .29281 Mdot
.48095 .30208 Mdot
.49619 .31133 Mdot
.51143 .32058 Mdot
.52667 .32981 Mdot
.5419 .33904 Mdot
.55714 .34827 Mdot
.57238 .35748 Mdot
.58762 .36669 Mdot
.60286 .3759 Mdot
.6181 .3851 Mdot
.63333 .3943 Mdot
.64857 .40349 Mdot
.66381 .41268 Mdot
.67905 .42187 Mdot
.69429 .43105 Mdot
.70952 .44024 Mdot
.72476 .44942 Mdot
.74 .45859 Mdot
.75524 .46777 Mdot
.77048 .47694 Mdot
.78571 .48611 Mdot
.80095 .49528 Mdot
.81619 .50445 Mdot
.83143 .51361 Mdot
.84667 .52278 Mdot
.8619 .53194 Mdot
.87714 .5411 Mdot
.89238 .55026 Mdot
.90762 .55941 Mdot
.92286 .56856 Mdot
.9381 .57771 Mdot
.95333 .58685 Mdot
.96857 .59599 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;`3oool01P3ogi`0B000000000000000001809cOoal0oooo00<0omnL04P0M02oool0803o
ool01P3ooml0W4P0000000000000001d0;oooah0oooo00H0_g@000000000000000000018W03OoolR
0?ooo`030?noM0000000M;oo01d0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0L
0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool03P3oool002h0oooo00P0omnL04P0
0000B9`0gooo0?ooo`3ogi`0B00007Booal0oooo00<0_g@007Boo`3oool07P3oool0203ookl0M000
0018W03Oool0oooo0=nLB00004P0W=oo703oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo0240oooo00<0okmd0000001d_ol07@3oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0
W=oo7@3oool00`3OW4P000000000000400000003001d_`3oool0oooo00h0oooo000^0?ooo`030;md
000007@0_ooo00<0oooo00<0gia80018W03Oool07P3oool00`3o_g@007Bo0?ooo`0N0?ooo`030;md
000007@0_ooo00<0oooo00<0_g@0001d_`3oool08@3oool00`3ogi`0B7Bo0?ooo`0P0?ooo`030?no
M0000000M;oo02<0oooo00<0okmd0018W03Oool07@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oo
g`2LB7@0_ooo00l0oooo000^0?ooo`030;md000007@0_ooo00<0oooo00<0_g@00018W03Oool07P3o
ool00`3ookl0M01d0;ooo`0M0?ooo`030?oo_`1d000007Bo00@0oooo00<0gia80000M02oool08@3o
ool00`3ookl0M01809cOo`0K0?ooo`030=nLB0000000000000D0000000<0001809cOo`3oool0803o
ool00`3o_g@0001809cOo`0N0?ooo`030=nLB018W=l0oooo01<0oooo000^0?ooo`030?noM00004P0
W=oo0080oooo00<0gia800000000M;l0803oool00`2oM000M;oo0?ooo`0L0?ooo`030?oOW0180000
B9cO00@0oooo00<0_g@00000B02Lgol08@3oool00`3ookl0M00007Boo`0K0?ooo`030?oOW018M;l0
oooo0080oooo00<0okmd0000001d_ol08`3oool00`2oM000001809cOo`0O0?ooo`030=nLB01d_ol0
oooo0180oooo000P0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool00P3oool01`3O
W4P007Bo0?ooo`2oM00000000000M02oool03P3oool00`2oM0000000000000070000000304RLg`3o
ool0oooo00D0oooo00<0okmd001d_`3oool03`3oool00`2oM0000000000000070000000604RLg`3o
ool0oooo0?oOW0180000B9cO0`3oool0103ookl0M0000000M02oool>0?ooo`030;md000000000000
00L0000000<0B9cO0?ooo`3oool01P3oool00`3o_g@0000007Boo`0>0?ooo`030;md000000000000
00L0000000H0B9cO0?ooo`3oool0oooo0=nLB01d_ol20?ooo`030?noM0000000M;oo0100oooo00<0
_g@00000000000001`0000000`18W=l0oooo0?ooo`050?ooo`040;md00000000001d0;ooo`h0oooo
00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030?oog`2LB4P0W=oo0180oooo
000`0?ooo`050?noM000000000000018W03Oool08@3oool00`3ookl0M01d0;ooo`0L0?ooo`090?oo
_`1d000000000018W03Oool0oooo0;md00000000B9cO0240oooo00@0omnL04P0000007@0_ooo703o
ool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol07`3oool00`3ookl0M0000000000200000003
04RLg`3oool0oooo01l0oooo00<0omnL04P0M02oool04@3oool002l0oooo00D0omnL04P000000000
000004RLg`0S0?ooo`030;md001d_ol0oooo01/0oooo00D0oooO09a8000007@0_mnL04P000020000
000304RLg`3oool0oooo01`0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0L
0?ooo`060?noM000M;l0oooo0?noM0000000M;oo8@3oool00`3o_g@0001809cOo`0S0?ooo`030;md
0018W=l0oooo0100oooo000^0?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`0R0?ooo`03
0?noM000M;l0oooo01`0oooo00<0okmd00000018W=l08P3oool00`3o_g@000000000000200000003
001d_`3oool0oooo01h0oooo00D0_g@007Boo`3o_g@0000007Boo`0R0?ooo`030?oOW018M;l0oooo
0280oooo00<0gia80000M02oool0403oool002h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0
W4P007Boo`0K0?ooo`030?oO_`2ogol0oooo00<0oooo00<0oono07@0M02oool0703oool0103ooml0
W4P00000B02LgolQ0?ooo`050?oog`2LB00000000000M02oool08@3oool01@3ookl0M01d0;noM000
0000M;oo0280oooo00<0oooO09a80018W=l08P3oool00`3o_g@0000007Boo`0@0?ooo`00;P3oool0
0`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO01/0oooo00<0oooO09a8M02oool0103oool0
0`2oM000M;oo0?ooo`0L0?ooo`040?oo_`1d0000001d0;ooob40oooo00<0okmd001d_`3oool08`3o
ool0103o_g@000000000001d_olM0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l0
703oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo0100oooo000^0?ooo`030?oOW018
0000B9cO0080oooo00<0okmd0000B02Lgol0703oool00`3OW4P000000000000400000003001d_`3o
ool0oooo01`0oooo00@0oooO09a80000000007Bo803oool00`3ooml0W4P000000002000000030000
M02oool0oooo01h0oooo00@0oooO09a800000000M;oo7P3oool01`3ogi`0B4RL0=ooo`3oool0gia8
0000001d_ol07@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo403oool002l0oooo
00H0oono07@00000000000000000B02LgolM0?ooo`030?oOW0180000000000@0000000<0001809cO
o`3oool07P3oool01@3ogi`0B00000000000B9`0gooo01h0oooo00<0okmd0000000000000P000000
0`1d_ol0oooo0?ooo`0N0?ooo`030?oOW0180000M;oo01l0oooo00D0omnL04P000000000000004RL
g`0O0?ooo`050;md00000000000000000000M;l04P3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool002D0ooool000000;0?ooo`009@3oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`8000002`3oool000h0oooo00H0oooO09a8000000000000
0000M02oool30?ooo`060;md00000000000000000000B9`0gooo203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool000d0oooo00`0oono07@0
0000B9`0gooo0?ooo`3OW4P0001809cOo`3oool0oooO09a80018W=l20?ooo`030?oOW018B9`0gooo
00L0oooo00<000000?ooo`3oool00P3oool200000>P0oooo00<000000?ooo`3oool02@3oool000d0
oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo0?ooo`060?ooo`030?oOW018M;l0oooo00H0
oooo00@000000?ooo`3oool0oooo1000003W0?ooo`030000003oool0oooo00T0oooo000<0?ooo`03
0?oo_`1d000007Bo00@0oooo00<0gia80000M02oool01P3oool00`3ookl0M01809cOo`060?ooo`04
0000003oool0oooo0?ooo`H00000i@3oool00`000000oooo0?ooo`090?ooo`00303oool00`3ogi`0
B00004RLg`040?ooo`030;md000004P0W=oo00H0oooo00<0oono07@0001d_ol01P3oool00`000000
oooo0?ooo`020?ooo`H00000i03oool00`000000oooo0?ooo`090?ooo`00303oool00`3ogi`0B000
04RLg`030?ooo`040?oo_`1d0000001d0;ooo`H0oooo00<0okmd0000001d_ol01P3oool00`000000
oooo0?ooo`040?ooo`@0000000<0oooo000000000000h@3oool00`000000oooo0?ooo`090?ooo`00
303oool02@3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`060?ooo`040?oOW0180000
001d0;ooo`H0oooo0P0000060?ooo`L00000g`3oool2000000/0oooo000<0?ooo`050?oog`2LB000
001d0;oOW01800000P0000001@18W=l0oooo0?ooo`3oool0gmoO0080oooo00@0_g@0000000000000
B9cO1`3oool00`000000oooo0?ooo`080?ooo`@00000h03oool00`000000oooo0?ooo`090?ooo`00
3@3oool00`3o_g@0000004RLg`070?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`<0000000<0oooo000000000000g@3oool00`000000oooo
0?ooo`090?ooo`003@3oool0103ooml0W4P00000B02Lgol60?ooo`050?oog`2LB00000000000M02o
ool02@3oool00`000000oooo0?ooo`0<0?ooo`@00000g03oool00`000000oooo0?ooo`090?ooo`00
3P3oool0103ookl0M0000000M02oool60?ooo`030?noM000M;l0oooo00X0oooo00<000000?ooo`3o
ool0303oool600000=X0oooo00<000000?ooo`3oool02@3oool000l0oooo00@0oooO09a800000000
07Bo1@3oool00`3ooml0W4P000000002000000030000M02oool0oooo00D0oooo00<000000?ooo`3o
ool03@3oool600000=T0oooo00<000000?ooo`3oool02@3oool00140oooo00D0omnL04P000000000
04RL0=ooo`030?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0103oool200000100
oooo100000000`3oool000000000003E0?ooo`8000002`3oool002D0oooo00<000000?ooo`3oool0
403oool700000=D0oooo00<000000?ooo`3oool02@3oool002D0oooo00<000000?ooo`3oool04`3o
ool400000=D0oooo00<000000?ooo`3oool02@3oool002D0oooo00<000000?ooo`3oool0503oool3
000000030?ooo`00000000000=80oooo00<000000?ooo`3oool02@3oool002D0oooo00<000000?oo
o`3oool05`3oool400000=40oooo00<000000?ooo`3oool02@3oool002D0oooo00<000000?ooo`3o
ool05`3oool600000<l0oooo00<000000?ooo`3oool02@3oool002D0oooo00<000000?ooo`3oool0
603oool600000<h0oooo00<000000?ooo`3oool02@3oool002D0oooo0P00000K0?ooo`@00000c@3o
ool2000000/0oooo000U0?ooo`030000003oool0oooo01/0oooo1P00003;0?ooo`030000003oool0
oooo00T0oooo000U0?ooo`030000003oool0oooo01h0oooo1000003:0?ooo`030000003oool0oooo
00T0oooo000U0?ooo`030000003oool0oooo01h0oooo1P0000380?ooo`030000003oool0oooo00T0
oooo000U0?ooo`030000003oool0oooo01l0oooo1P0000370?ooo`030000003oool0oooo00T0oooo
000U0?ooo`030000003oool0oooo0240oooo1`0000340?ooo`030000003oool0oooo00T0oooo000U
0?ooo`8000008`3oool2000000030?ooo`000000000000800000`P3oool2000000/0oooo000U0?oo
o`030000003oool0oooo02D0oooo100000000`3oool00000000000300?ooo`030000003oool0oooo
00T0oooo000U0?ooo`030000003oool0oooo02H0oooo0P0000000`3oool000000000000200000;l0
oooo00<000000?ooo`3oool02@3oool002D0oooo00<000000?ooo`3oool0:@3oool400000;l0oooo
00<000000?ooo`3oool02@3oool002D0oooo00<000000?ooo`3oool0:P3oool2000000030?ooo`00
000000000;d0oooo00<000000?ooo`3oool02@3oool002D0oooo00<000000?ooo`3oool0;03oool4
00000;`0oooo00<000000?ooo`3oool02@3oool002D0oooo00<000000?ooo`3oool0;03oool70000
0;T0oooo00<000000?ooo`3oool02@3oool000l0oooo00<0omnL04P0M02oool01`3oool0102oM000
000000000018W=l80?ooo`800000;P3oool2000000030?ooo`000000000000800000]`3oool20000
00/0oooo000@0?ooo`030;md001d_ol0oooo00@0oooo00L0oooO09a80000M;l0oooo0?oog`2LB000
07Bo00L0oooo00<000000?ooo`3oool0<03oool700000;D0oooo00<000000?ooo`3oool02@3oool0
0100oooo00<0okmd001d_`3oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo
00H0oooo00<000000?ooo`3oool0<@3oool2000000030?ooo`000000000000800000]03oool00`00
0000oooo0?ooo`090?ooo`00403oool00`3ookl0M01d0;ooo`030?ooo`040?oog`2LB00004RL0=oo
o`80oooo00<0oooO09a80000M;l01P3oool00`000000oooo0?ooo`0d0?ooo`@00000]03oool00`00
0000oooo0?ooo`090?ooo`004@3oool00`2oM000M;oo0?ooo`020?ooo`030?oo_`1d000007Bo00@0
oooo00<0_g@00000M02oool01@3oool00`000000oooo0?ooo`0e0?ooo`80000000<0oooo00000000
0000/P3oool00`000000oooo0?ooo`090?ooo`004@3oool00`3o_g@007Bo0?ooo`020?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000M02oool01@3oool00`000000oooo0?ooo`0g0?ooo`@00000
/@3oool00`000000oooo0?ooo`090?ooo`004@3oool00`3ookl0M01d0;ooo`020?ooo`030?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol01@3oool2000003P0oooo1`00002]0?ooo`8000002`3o
ool00180oooo00L0_g@007Boo`3oool0oooo0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
1@3oool00`000000oooo0?ooo`0h0?ooo`80000000<0oooo0000000000000P00002]0?ooo`030000
003oool0oooo00T0oooo000B0?ooo`070?noM000M;l0oooo0?ooo`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo00D0oooo00<000000?ooo`3oool0>`3oool700000:X0oooo00<000000?ooo`3o
ool02@3oool000`0oooo00<0omno0;oOo`3oool00`3oool00`3ookl0M01d0;ooo`020?ooo`030;md
0000B9`0gooo0080oooo00<0oooO09a80000M;l01P3oool00`000000oooo0?ooo`0l0?ooo`800000
00<0oooo0000000000000P00002Y0?ooo`030000003oool0oooo00T0oooo000<0?ooo`030?oog`2L
B7@0_ooo00@0oooo00L0_g@007Boo`3oool0oooo0?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol01P3oool00`000000oooo0?ooo`0o0?ooo`H00000Y`3oool00`000000oooo0?ooo`090?ooo`00
3@3oool00`3OW4P00000000000040000000:001d_`3oool0oooo0?ooo`2oM00004RL0=ooo`3oool0
_g@0001d_`L0oooo00<000000?ooo`3oool0@03oool600000:H0oooo00<000000?ooo`3oool02@3o
ool000d0oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`020?ooo`040;md00000000
0000001d_`P0oooo00<000000?ooo`3oool0@P3oool400000:H0oooo00<000000?ooo`3oool02@3o
ool002D0oooo0P0000140?ooo`80000000@0oooo0000000000000000XP3oool2000000/0oooo000U
0?ooo`030000003oool0oooo04H0oooo1000002R0?ooo`030000003oool0oooo00T0oooo000U0?oo
o`030000003oool0oooo04H0oooo1`00002O0?ooo`030000003oool0oooo00T0oooo000U0?ooo`03
0000003oool0oooo04L0oooo0P0000000`3oool0000000000002000009h0oooo00<000000?ooo`3o
ool02@3oool002D0oooo00<000000?ooo`3oool0BP3oool6000009`0oooo00<000000?ooo`3oool0
2@3oool002D0oooo00<000000?ooo`3oool0B`3oool6000009/0oooo00<000000?ooo`3oool02@3o
ool002D0oooo0P00001>0?ooo`L00000U`3oool2000000/0oooo000U0?ooo`030000003oool0oooo
04h0oooo0P0000000`3oool0000000000002000009L0oooo00<000000?ooo`3oool02@3oool002D0
oooo00<000000?ooo`3oool0D@3oool5000009H0oooo00<000000?ooo`3oool02@3oool002D0oooo
00<000000?ooo`3oool0DP3oool200000080oooo0P00002D0?ooo`030000003oool0oooo00T0oooo
000U0?ooo`030000003oool0oooo05D0oooo1000002C0?ooo`030000003oool0oooo00T0oooo000U
0?ooo`030000003oool0oooo05D0oooo1P00002A0?ooo`030000003oool0oooo00T0oooo000U0?oo
o`030000003oool0oooo05H0oooo1`00002?0?ooo`030000003oool0oooo00T0oooo000U0?ooo`80
0000F@3oool4000000030?ooo`000000000008`0oooo0P00000;0?ooo`009@3oool00`000000oooo
0?ooo`1I0?ooo`80000000<0oooo0000000000000P00002<0?ooo`030000003oool0oooo00T0oooo
000U0?ooo`030000003oool0oooo05`0oooo1P00002:0?ooo`030000003oool0oooo00T0oooo000U
0?ooo`030000003oool0oooo05d0oooo1P0000290?ooo`030000003oool0oooo00T0oooo000U0?oo
o`030000003oool0oooo05l0oooo1P0000270?ooo`030000003oool0oooo00T0oooo000U0?ooo`03
0000003oool0oooo0600oooo0P0000020?ooo`800000QP3oool00`000000oooo0?ooo`090?ooo`00
9@3oool2000006@0oooo1@0000230?ooo`8000002`3oool000l0oooo00<0omnL04P0M02oool01@3o
ool01P2oM000000000000000000004RL0=ooo`P0oooo00<000000?ooo`3oool0H`3oool400000003
0?ooo`00000000000880oooo00<000000?ooo`3oool02@3oool00100oooo00<0_g@007Boo`3oool0
0`3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00L0oooo00<000000?ooo`3oool0
I03oool2000000030?ooo`000000000000800000P@3oool00`000000oooo0?ooo`090?ooo`00403o
ool00`3o_g@007Bo0?ooo`090?ooo`030?oOW018M;l0oooo00H0oooo00<000000?ooo`3oool0I`3o
ool6000007l0oooo00<000000?ooo`3oool02@3oool00100oooo00<0oono07@0M02oool02@3oool0
0`3ookl0M01809cOo`060?ooo`030000003oool0oooo06P0oooo1P00001n0?ooo`030000003oool0
oooo00T0oooo000A0?ooo`030;md001d_ol0oooo00P0oooo00<0oono07@0001d_ol01P3oool00`00
0000oooo0?ooo`1Z0?ooo`L00000N`3oool00`000000oooo0?ooo`090?ooo`004@3oool00`3o_g@0
07Bo0?ooo`080?ooo`030?noM0000000M;oo00H0oooo0P00001/0?ooo`80000000<0oooo00000000
00000P00001i0?ooo`8000002`3oool00140oooo00<0oono07@0M02oool01`3oool0103ogi`0B000
0000M02oool60?ooo`030000003oool0oooo06h0oooo1000001j0?ooo`030000003oool0oooo00T0
oooo000B0?ooo`030;md001d_ol0oooo0080oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0
oooo0?ooo`050?ooo`030000003oool0oooo06l0oooo0P000000103oool0000000000000001g0?oo
o`030000003oool0oooo00T0oooo000B0?ooo`030?noM000M;l0oooo0080oooo00<0okmd00000000
00000P0000000`00M;l0oooo0?ooo`060?ooo`030000003oool0oooo0780oooo1000001f0?ooo`03
0000003oool0oooo00T0oooo000<0?ooo`030?oO_`2ogol0oooo00<0oooo00<0oono07@0M02oool0
0P3oool01@3ooml0W4P00000000007@0_ooo00T0oooo00<000000?ooo`3oool0LP3oool6000007@0
oooo00<000000?ooo`3oool02@3oool000`0oooo00<0oooO09a8M02oool0103oool00`2oM000M;oo
0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<000000?ooo`3oool0L`3oool6000007<0oooo
00<000000?ooo`3oool02@3oool000d0oooo00<0gia8000000000000100000001P00M;l0oooo0?oo
o`3oool0oooO09a800<0000000<0001d0;ooo`3oool01@3oool00`000000oooo0?ooo`1e0?ooo`L0
0000L03oool00`000000oooo0?ooo`090?ooo`003@3oool00`3ogi`0B00000000004000000030000
B02Lgol0oooo0080oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`040?ooo`800000
M`3oool2000000030?ooo`000000000000800000KP3oool2000000/0oooo000U0?ooo`030000003o
ool0oooo07T0oooo1`00001/0?ooo`030000003oool0oooo00T0oooo000U0?ooo`030000003oool0
oooo07X0oooo0P0000000`3oool0000000000002000006/0oooo00<000000?ooo`3oool02@3oool0
02D0oooo00<000000?ooo`3oool0O@3oool6000006T0oooo00<000000?ooo`3oool02@3oool002D0
oooo00<000000?ooo`3oool0OP3oool6000006P0oooo00<000000?ooo`3oool02@3oool002D0oooo
00<000000?ooo`3oool0P03oool5000006L0oooo00<000000?ooo`3oool02@3oool002D0oooo0P00
00220?ooo`8000000P3oool2000006@0oooo0P00000;0?ooo`009@3oool00`000000oooo0?ooo`24
0?ooo`@00000I03oool00`000000oooo0?ooo`090?ooo`009@3oool00`000000oooo0?ooo`240?oo
o`L00000H@3oool00`000000oooo0?ooo`090?ooo`009@3oool00`000000oooo0?ooo`250?ooo`80
000000<0oooo0000000000000P00001P0?ooo`030000003oool0oooo00T0oooo000U0?ooo`030000
003oool0oooo08P0oooo1P00001N0?ooo`030000003oool0oooo00T0oooo000U0?ooo`030000003o
ool0oooo08T0oooo1P00001M0?ooo`030000003oool0oooo00T0oooo000U0?ooo`030000003oool0
oooo08/0oooo1`00001J0?ooo`030000003oool0oooo00T0oooo000U0?ooo`800000S@3oool20000
00030?ooo`000000000000800000F03oool2000000/0oooo000U0?ooo`030000003oool0oooo08l0
oooo1`00001F0?ooo`030000003oool0oooo00T0oooo000U0?ooo`030000003oool0oooo0900oooo
0P0000000`3oool0000000000002000005D0oooo00<000000?ooo`3oool02@3oool002D0oooo00<0
00000?ooo`3oool0T`3oool4000005D0oooo00<000000?ooo`3oool02@3oool002D0oooo00<00000
0?ooo`3oool0U03oool2000000030?ooo`000000000005<0oooo00<000000?ooo`3oool02@3oool0
02D0oooo00<000000?ooo`3oool0UP3oool500000540oooo00<000000?ooo`3oool02@3oool002D0
oooo0P00002G0?ooo`@0000000<0oooo000000000000CP3oool2000000/0oooo000>0?ooo`060?oO
W018000000000000000004P0W=oo1@3oool0102oM000000000000018W=l80?ooo`030000003oool0
oooo09L0oooo0P0000000`3oool0000000000002000004h0oooo00<000000?ooo`3oool02@3oool0
00d0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`80oooo00L0oooO09a80000M;l0
oooo0?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool0VP3oool6000004`0oooo00<000000?oo
o`3oool02@3oool000d0oooo00<0_g@00000M02oool00`3oool01`3OW4P004RL0=ooo`3oool0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`060?ooo`030000003oool0oooo09/0oooo1P00001;
0?ooo`030000003oool0oooo00T0oooo000=0?ooo`030;md000007@0_ooo00<0oooo00L0_g@00018
W03Oool0oooO09a80000B9`0gooo0080oooo00<0oooO09a80000M;l01P3oool00`000000oooo0?oo
o`2M0?ooo`L00000B03oool00`000000oooo0?ooo`090?ooo`003@3oool00`3o_g@0001809cOo`02
0?ooo`070=nLB000000007Bo0?ooo`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo
00<000000?ooo`3oool0WP3oool2000000030?ooo`000000000000800000A`3oool00`000000oooo
0?ooo`090?ooo`003P3oool02`3OW4P007Bo0?ooo`2oM00000000000M02oool0oooo0?oOW0180000
B9cO00@0oooo00<0_g@00000M02oool01@3oool00`000000oooo0?ooo`2Q0?ooo`@0000000<0oooo
000000000000A03oool00`000000oooo0?ooo`090?ooo`003`3oool01@3o_g@0000000000000B9`0
gooo0080oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`800000X`3oool2
000000030?ooo`000000000000800000@P3oool2000000/0oooo000>0?ooo`050?oOW01800000000
00000018W=l00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00D0oooo00<00000
0?ooo`3oool0Y@3oool4000004<0oooo00<000000?ooo`3oool02@3oool000d0oooo00L0omnL04P0
000004P0W=oo0?ooo`3OW4P007Bo0080oooo00<0oono07@00000M;l0103oool00`2oM000001d0;oo
o`050?ooo`030000003oool0oooo0:H0oooo0P0000000`3oool00000000000110?ooo`030000003o
ool0oooo00T0oooo000=0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8001d_ol00P3oool0
0`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00H0oooo00<000000?ooo`3oool0Z03oool4
00000400oooo00<000000?ooo`3oool02@3oool000d0oooo00<0gia80018W03Oool00P3oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01P3oool00`00
0000oooo0?ooo`2X0?ooo`L00000?@3oool00`000000oooo0?ooo`090?ooo`003@3oool00`3ogi`0
B00004RLg`020?ooo`030?noM00004P0W=oo00<0oooo00H0_g@00018W03Oool0oooo0;md0000M;l7
0?ooo`030000003oool0oooo0:T0oooo0P0000000`3oool0000000000002000003`0oooo00<00000
0?ooo`3oool02@3oool000h0oooo00H0oono07@00000000000000000B02Lgol50?ooo`040;md0000
00000000001d_`P0oooo0P00002]0?ooo`L00000>03oool2000000/0oooo000U0?ooo`030000003o
ool0oooo0:d0oooo0P0000000`3oool0000000000002000003P0oooo00<000000?ooo`3oool02@3o
ool002D0oooo00<000000?ooo`3oool0/03oool6000003H0oooo00<000000?ooo`3oool02@3oool0
02D0oooo00<000000?ooo`3oool0/@3oool6000003D0oooo00<000000?ooo`3oool02@3oool002D0
oooo00<000000?ooo`3oool0/`3oool700000380oooo00<000000?ooo`3oool02@3oool002D0oooo
00<000000?ooo`3oool0]03oool2000000030?ooo`000000000000800000<@3oool00`000000oooo
0?ooo`090?ooo`009@3oool00`000000oooo0?ooo`2g0?ooo`@00000<@3oool00`000000oooo0?oo
o`090?ooo`009@3oool200000;T0oooo0P000000103oool0000000000000000]0?ooo`8000002`3o
ool002D0oooo00<000000?ooo`3oool0^`3oool4000002d0oooo00<000000?ooo`3oool02@3oool0
02D0oooo00<000000?ooo`3oool0^`3oool6000002/0oooo00<000000?ooo`3oool02@3oool002D0
oooo00<000000?ooo`3oool0_03oool6000002X0oooo00<000000?ooo`3oool02@3oool002D0oooo
00<000000?ooo`3oool0_P3oool4000000030?ooo`000000000002L0oooo00<000000?ooo`3oool0
2@3oool002D0oooo00<000000?ooo`3oool0_`3oool2000000030?ooo`0000000000008000009P3o
ool00`000000oooo0?ooo`090?ooo`009@3oool200000<<0oooo100000000`3oool000000000000R
0?ooo`8000002`3oool002D0oooo00<000000?ooo`3oool0``3oool2000000030?ooo`0000000000
008000008P3oool00`000000oooo0?ooo`090?ooo`009@3oool00`000000oooo0?ooo`360?ooo`H0
0000803oool00`000000oooo0?ooo`090?ooo`009@3oool00`000000oooo0?ooo`370?ooo`H00000
7`3oool00`000000oooo0?ooo`090?ooo`009@3oool00`000000oooo0?ooo`390?ooo`@000007`3o
ool00`000000oooo0?ooo`090?ooo`009@3oool00`000000oooo0?ooo`3:0?ooo`80000000@0oooo
0000000000000000703oool00`000000oooo0?ooo`090?ooo`009@3oool00`000000oooo0?ooo`3=
0?ooo`@000006`3oool00`000000oooo0?ooo`090?ooo`003P3oool01P3ogi`0B000000000000000
001809cOo`<0oooo00H0_g@000000000000000000018W03Oool80?ooo`800000cP3oool7000001L0
oooo0P00000;0?ooo`003@3oool0303ogi`0B0000018W03Oool0oooo0?oOW0180000M;oo0?ooo`3o
oml0W4P004RLg`80oooo00<0omnL04Q8W03Oool01`3oool00`000000oooo0?ooo`3>0?ooo`800000
00<0oooo0000000000000P00000G0?ooo`030000003oool0oooo00T0oooo000=0?ooo`030;md0000
07@0_ooo00<0oooo00<0gia80018W03Oool01P3oool00`3ogi`0B7Bo0?ooo`060?ooo`030000003o
ool0oooo0=40oooo1P00000E0?ooo`030000003oool0oooo00T0oooo000=0?ooo`030;md000007@0
_ooo00<0oooo00<0_g@00018W03Oool01P3oool00`3ookl0M01809cOo`060?ooo`030000003oool0
oooo0=80oooo1P00000D0?ooo`030000003oool0oooo00T0oooo000=0?ooo`030?noM00004P0W=oo
0080oooo00<0gia800000000M;l01`3oool00`3ookl0M00007Boo`060?ooo`030000003oool0oooo
0=@0oooo1`00000A0?ooo`030000003oool0oooo00T0oooo000>0?ooo`070=nLB000M;l0oooo0;md
00000000001d0;ooo`070?ooo`030?noM0000000M;oo00H0oooo00<000000?ooo`3oool0e@3oool2
000000030?ooo`000000000000800000403oool00`000000oooo0?ooo`090?ooo`003`3oool01@3o
_g@0000000000000B9`0gooo00L0oooo00@0omnL04P0000007@0_ooo1P3oool200000=T0oooo1P00
000=0?ooo`8000002`3oool000h0oooo00D0omnL04P000000000000004RLg`040?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`3I0?ooo`H00000
3@3oool00`000000oooo0?ooo`090?ooo`003@3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000
M;l00`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00H0oooo00<000000?ooo`3o
ool0f`3oool4000000030?ooo`000000000000X0oooo00<000000?ooo`3oool02@3oool000d0oooo
00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Boo`020?ooo`050?oog`2LB00000000000M02o
ool02@3oool00`000000oooo0?ooo`3L0?ooo`80000000<0oooo0000000000000P0000090?ooo`03
0000003oool0oooo00T0oooo000=0?ooo`030=nLB000B9`0gooo0080oooo00<0oooO09a80018W=l0
0`3oool00`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo0=l0oooo100000090?ooo`030000
003oool0oooo00T0oooo000=0?ooo`030?oOW0180000B9cO0080oooo00<0okmd0000B02Lgol00`3o
ool00`3ooml0W4P000000002000000030000M02oool0oooo00D0oooo00<000000?ooo`3oool0h03o
ool3000000030?ooo`000000000000H0oooo00<000000?ooo`3oool02@3oool000h0oooo00H0oono
07@00000000000000000B02Lgol50?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0
103oool00`000000oooo0?ooo`3S0?ooo`@000001@3oool00`000000oooo0?ooo`090?ooo`009@3o
ool200000>@0oooo100000040?ooo`8000002`3oool002D0oooo00<000000?ooo`3oool0i03oool3
000000D0oooo00<000000?ooo`3oool02@3oool002D0oooo00<000000?ooo`3oool0k03oool00`00
0000oooo0?ooo`090?ooo`009@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`009@3oooo`000000/0oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.17893, 59.564, 0.0274141, \
0.154481}}],

Cell[BoxData[
    \({f0 \[Rule] \(-2.203650714195628`*^39\)}\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("Log[-\!\(f\_0\)] = \
"\[InvisibleSpace]90.59093402736681`\),
      SequenceForm[ "Log[-\!\(f\_0\)] = ", 90.590934027366814],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(data3 = 
        Table[{N, Log[FN[N]]}, {N, 3.5, 
            6,  .1}];\)\), "\[IndentingNewLine]", 
    \(f3 = FindFit[data3, LogF0 - xb1\ N, {LogF0, xb1}, N]\), "\n", 
    \(\(ppp1 = 
        Plot[\((LogF0 - xb1\ N)\) /. f3, {N, 3.5, 6}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(pp2 = 
        ListPlot[data3, PlotStyle \[Rule] {PointSize[0.02]}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[ppp1, pp2, DisplayFunction \[Rule] $DisplayFunction, 
        Frame \[Rule] True, Axes \[Rule] False];\)\), "\[IndentingNewLine]", 
    \(\(tt2 = 
        Table[{\(fF[N] /. f3\) /. N \[Rule] nn, fN[N] /. N \[Rule] nn}, {nn, 
            3.5, 6,  .1}];\)\), "\n", 
    \(ft3 = FindFit[tt2, f0 + fbb, f0, fbb]\), "\n", 
    \(Print[\*"\"\<Log[-\!\(f\_0\)] = \>\"", 
      Log[\(-ft3[\([1, 2]\)]\)]]\)}], "Input"],

Cell[BoxData[
    \({LogF0 \[Rule] 92.61987189068594`, 
      xb1 \[Rule] \(-1.0094827749111897`\)}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.30952 0.380952 -22.3582 0.232695 [
[.02381 -0.0125 -14.5625 -24.5625 ]
[.02381 -0.0125 14.5625 0 ]
[.21429 -0.0125 -7.03125 -24.5625 ]
[.21429 -0.0125 7.03125 0 ]
[.40476 -0.0125 -14.5625 -24.5625 ]
[.40476 -0.0125 14.5625 0 ]
[.59524 -0.0125 -7.03125 -24.5625 ]
[.59524 -0.0125 7.03125 0 ]
[.78571 -0.0125 -14.5625 -24.5625 ]
[.78571 -0.0125 14.5625 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0968 -39.1875 -12.2813 ]
[-0.0125 .0968 0 12.2813 ]
[-0.0125 .21314 -24.125 -12.2813 ]
[-0.0125 .21314 0 12.2813 ]
[-0.0125 .32949 -39.1875 -12.2813 ]
[-0.0125 .32949 0 12.2813 ]
[-0.0125 .44584 -24.125 -12.2813 ]
[-0.0125 .44584 0 12.2813 ]
[-0.0125 .56219 -39.1875 -12.2813 ]
[-0.0125 .56219 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0968 m
.00625 .0968 L
s
gsave
-0.0125 .0968 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(96.5) show
1.000 setlinewidth
grestore
0 .21314 m
.00625 .21314 L
s
gsave
-0.0125 .21314 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(97) show
1.000 setlinewidth
grestore
0 .32949 m
.00625 .32949 L
s
gsave
-0.0125 .32949 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(97.5) show
1.000 setlinewidth
grestore
0 .44584 m
.00625 .44584 L
s
gsave
-0.0125 .44584 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(98) show
1.000 setlinewidth
grestore
0 .56219 m
.00625 .56219 L
s
gsave
-0.0125 .56219 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(98.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12007 m
.00375 .12007 L
s
0 .14334 m
.00375 .14334 L
s
0 .1666 m
.00375 .1666 L
s
0 .18987 m
.00375 .18987 L
s
0 .23641 m
.00375 .23641 L
s
0 .25968 m
.00375 .25968 L
s
0 .28295 m
.00375 .28295 L
s
0 .30622 m
.00375 .30622 L
s
0 .35276 m
.00375 .35276 L
s
0 .37603 m
.00375 .37603 L
s
0 .3993 m
.00375 .3993 L
s
0 .42257 m
.00375 .42257 L
s
0 .46911 m
.00375 .46911 L
s
0 .49238 m
.00375 .49238 L
s
0 .51565 m
.00375 .51565 L
s
0 .53892 m
.00375 .53892 L
s
0 .07353 m
.00375 .07353 L
s
0 .05026 m
.00375 .05026 L
s
0 .02699 m
.00375 .02699 L
s
0 .00372 m
.00375 .00372 L
s
0 .58546 m
.00375 .58546 L
s
0 .60872 m
.00375 .60872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0968 m
1 .0968 L
s
.99375 .21314 m
1 .21314 L
s
.99375 .32949 m
1 .32949 L
s
.99375 .44584 m
1 .44584 L
s
.99375 .56219 m
1 .56219 L
s
.125 Mabswid
.99625 .12007 m
1 .12007 L
s
.99625 .14334 m
1 .14334 L
s
.99625 .1666 m
1 .1666 L
s
.99625 .18987 m
1 .18987 L
s
.99625 .23641 m
1 .23641 L
s
.99625 .25968 m
1 .25968 L
s
.99625 .28295 m
1 .28295 L
s
.99625 .30622 m
1 .30622 L
s
.99625 .35276 m
1 .35276 L
s
.99625 .37603 m
1 .37603 L
s
.99625 .3993 m
1 .3993 L
s
.99625 .42257 m
1 .42257 L
s
.99625 .46911 m
1 .46911 L
s
.99625 .49238 m
1 .49238 L
s
.99625 .51565 m
1 .51565 L
s
.99625 .53892 m
1 .53892 L
s
.99625 .07353 m
1 .07353 L
s
.99625 .05026 m
1 .05026 L
s
.99625 .02699 m
1 .02699 L
s
.99625 .00372 m
1 .00372 L
s
.99625 .58546 m
1 .58546 L
s
.99625 .60872 m
1 .60872 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01607 m
.06244 .03989 L
.10458 .06587 L
.14415 .09027 L
.18221 .11374 L
.22272 .13872 L
.26171 .16276 L
.30316 .18831 L
.34309 .21294 L
.3815 .23662 L
.42237 .26182 L
.46172 .28609 L
.49955 .30942 L
.53984 .33426 L
.57861 .35817 L
.61984 .38358 L
.65954 .40807 L
.69774 .43162 L
.73838 .45668 L
.77751 .48081 L
.81909 .50645 L
.85916 .53116 L
.89771 .55493 L
.93871 .58021 L
.97619 .60332 L
s
.02 w
.02381 .01472 Mdot
.0619 .03861 Mdot
.1 .06245 Mdot
.1381 .08624 Mdot
.17619 .10997 Mdot
.21429 .13366 Mdot
.25238 .15731 Mdot
.29048 .18092 Mdot
.32857 .2045 Mdot
.36667 .22804 Mdot
.40476 .25157 Mdot
.44286 .27506 Mdot
.48095 .29854 Mdot
.51905 .32199 Mdot
.55714 .34543 Mdot
.59524 .36885 Mdot
.63333 .39226 Mdot
.67143 .41566 Mdot
.70952 .43904 Mdot
.74762 .46241 Mdot
.78571 .48577 Mdot
.82381 .50912 Mdot
.8619 .53247 Mdot
.9 .55581 Mdot
.9381 .57914 Mdot
.97619 .60246 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00903oool00`3ooml0W4P000000002000000030018W03Oool0oooo00<0oooo00<0gia80000
0018W=l00P3oool01P2oM000000000000000000004RL0=ooob@0oooo00<0okmd0000001d_ol0903o
ool00`3o_g@0000007Boo`030?ooo`030=nLB0000000B9cO0080oooo00H0_g@00000000000000000
0018W03OoolP0?ooo`060;md00000000000000000000B9`0gooo8@3oool01P2oM000000000000000
000004RL0=ooo`@0oooo00<0gia800000018W=l00P3oool01P2oM000000000000000000004RL0=oo
ob80oooo00H0oooO09a80000000000000000M02oool60?ooo`00903oool0203ogi`0B0000018W03O
ool0oooo0?oOW01804P0W=oo0`3oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool0
0`3ogi`0B4RL0=ooo`0S0?ooo`030?noM0000000M;oo02@0oooo00<0okmd0000001d_ol00`3oool0
1`3OW4P0000004RLg`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0N0?ooo`030?oo
g`2LB000B9cO0080oooo00<0omnL04Q8W03Oool07`3oool00`3ooml0W4P004RLg`020?ooo`030?oO
W018B9`0gooo00<0oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8
W03Oool0803oool0203ookl0M0000018W03Oool0oooo0=nLB00004P0W=oo1@3oool002X0oooo00<0
okmd0018W03Oool0303oool00`3ogi`0B7Bo0?ooo`0R0?ooo`030?noM0000000M;oo02@0oooo00<0
okmd0000001d_ol03@3oool00`3ogi`0B7Bo0?ooo`0S0?ooo`030?oOW018M;l0oooo02@0oooo00<0
omnL04Qd_`3oool0303oool00`3ogi`0B7Bo0?ooo`0O0?ooo`030;md000007@0_ooo00<0oooo00<0
_g@0001d_`3oool0103oool002X0oooo00<0okmd0000B02Lgol0303oool00`3ookl0M01809cOo`0M
0?ooo`030=nLB0000000000000D0000000<0001809cOo`3oool0703oool00`3OW4P0000000000005
000000030000B02Lgol0oooo00X0oooo00<0oono07@0B02Lgol08`3oool00`3ookl0M01809cOo`0T
0?ooo`030?oo_`1d04P0W=oo00`0oooo00<0oono07@0B02Lgol07P3oool00`3ookl0M000001d_`04
0?ooo`030=nLB00007@0_ooo00@0oooo000Z0?ooo`030;md000004P0W=oo00`0oooo00<0oono07@0
001d_ol07@3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo01l0oooo00<0omnL04Qd
_`3oool00P3oool00`3o_g@0000007Boo`0=0?ooo`030?oo_`1d0000M;oo02<0oooo00<0oono07@0
001d_ol0903oool00`3ookl0M00007Boo`0<0?ooo`030?oo_`1d0000M;oo01h0oooo00<0omnL04P0
0018W=l0103oool00`2oM000001809cOo`040?ooo`00:@3oool0102oM00000000000M02oool<0?oo
o`030?noM0000000M;oo01h0oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo0200oooo00L0
gia807Boo`3oool0oooo0?noM0000000M;oo00d0oooo00<0okmd0000001d_ol08`3oool00`3o_g@0
000007Boo`0T0?ooo`030?noM0000000M;oo00`0oooo00<0okmd0000001d_ol07P3oool00`3ogi`0
B00004RLg`030?ooo`040?oo_`1d0000001d0;ooo`@0oooo000V0?ooo`030?oo_`1d000000000080
000000<0B9cO0?ooo`3oool02P3oool0103ogi`0B0000000M02ooolN0?ooo`070?oo_`1d07@0_ooo
0?ooo`3o_g@0000007Boo`0P0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`0<0?ooo`04
0?oOW0180000001d0;ooob80oooo00@0omnL04P0000007@0_ooo8`3oool0103ogi`0B0000000M02o
ool;0?ooo`040?oOW0180000001d0;oooah0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@0
00000018W=l01@3oool002P0oooo00<0okmd0000B02Lgol02@3oool0103Ogml0oooo0?ooo`2oM002
0000000304RLg`3oool0oooo01h0oooo00H0okmd001d_`3oool0okmd0000001d_olQ0?ooo`060?no
M000M;l0oooo0?noM0000000M;oo203oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0
oooo01d0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0N0?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool01P3oool0103Ogml0oooo0?ooo`2oM00200000003
04RLg`3oool0oooo01d0oooo00D0oooO09a8000007@0_mnL04P000020000000304RLg`3oool0oooo
00@0oooo000Y0?ooo`030?oOW018M;l0oooo00P0oooo00<0okmd0000000000000P0000000`00M;l0
oooo0?ooo`0P0?ooo`050;md001d_ol0okmd0000001d_ol08P3oool01@2oM000M;oo0?noM0000000
M;oo00P0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0N0?ooo`030?noM0000000
00000080000000<007Bo0?ooo`3oool07`3oool00`3o_g@000000000000200000003001d_`3oool0
oooo00L0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0O0?ooo`030?noM0000000
B9cO00X0oooo000Y0?ooo`030?oog`2LB000B9cO00P0oooo00D0oooO09a800000000001d0;ooo`0S
0?ooo`050?oo_`1d07@0_kmd0000001d_ol08P3oool01@3ookl0M01d0;noM0000000M;oo00P0oooo
00D0oooO09a800000000001d0;ooo`0Q0?ooo`050?oog`2LB00000000000M02oool08P3oool01@3o
oml0W4P00000000007@0_ooo00X0oooo00D0oooO09a800000000001d0;ooo`0R0?ooo`040?oog`2L
B000001809cOo`T0oooo000T0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l02@3o
ool00`3o_g@007Bo0?ooo`0U0?ooo`040?noM0000000000007Boob<0oooo00@0okmd000000000000
M;oo2@3oool00`3o_g@007Bo0?ooo`0S0?ooo`030?noM000M;l0oooo02@0oooo00<0okmd001d_`3o
ool0303oool00`3o_g@007Bo0?ooo`0T0?ooo`040?oo_`1d0000001d0;ooo`P0oooo000U0?ooo`07
0?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`090?ooo`030?oog`2LB00000000080000000<0001d
0;ooo`3oool0803oool0103ooml0W4P00000001d_olS0?ooo`040?oog`2LB000000007Boo`T0oooo
00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0N0?ooo`030?oog`2LB000000000800000
00<0001d0;ooo`3oool07`3oool00`3ooml0W4P000000002000000030000M02oool0oooo00L0oooo
00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0P0?ooo`040?oog`2LB0000000001d_`L0
oooo000V0?ooo`050?oOW0180000000000000018W=l02`3oool00`3o_g@000000000000200000003
07Boo`3oool0oooo0200oooo00<0omnL04P0001d_ol0903oool00`3ogi`0B00007Boo`0:0?ooo`03
0?noM000000000000080000000<0M;oo0?ooo`3oool07P3oool00`3o_g@000000000000200000003
07Boo`3oool0oooo01l0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`070?ooo`03
0?noM000000000000080000000<0M;oo0?ooo`3oool08@3oool01@3ogi`0B00000000000B9`0gooo
00@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000[0?oooo8000000`3oool0
02/0oooo0P0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo0P000003
0?ooo`00:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo000[0?ooo`03
0000003oool0oooo0080oooo0P00003Z0?ooo`030000003oool0oooo0040oooo000[0?ooo`040000
003oool0oooo0?ooo`@00000j@3oool00`000000oooo0?ooo`010?ooo`00:`3oool010000000oooo
0?ooo`3oool400000>T0oooo00<000000?ooo`3oool00@3oool002/0oooo00<000000?ooo`3oool0
0P3oool2000000030?ooo`00000000000>L0oooo00<000000?ooo`3oool00@3oool002/0oooo0P00
00080?ooo`030000003oool0oooo0><0oooo0P0000030?ooo`00:`3oool00`000000oooo0?ooo`08
0?ooo`80000000<0oooo000000000000h@3oool00`000000oooo0?ooo`010?ooo`00:`3oool00`00
0000oooo0?ooo`0:0?ooo`@00000h03oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000
oooo0?ooo`0:0?ooo`@00000h03oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000oooo
0?ooo`0;0?ooo`@00000g`3oool00`000000oooo0?ooo`010?ooo`00:`3oool200000100oooo0P00
003L0?ooo`8000000`3oool002/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3J
0?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo0180oooo1000003H0?oo
o`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo01<0oooo1000003G0?ooo`03
0000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo01<0oooo1000003G0?ooo`030000
003oool0oooo0040oooo000[0?ooo`030000003oool0oooo01@0oooo0P0000000`3oool000000000
003E0?ooo`030000003oool0oooo0040oooo00020?ooo`050?oog`2LB00000000000B02Lgol01`3o
ool01P3ooml0W4P0000000000000001d0;ooo`<0oooo00<0gia800000018W=l00P3oool01P2oM000
000000000000000004RL0=ooo`T0oooo0P00000J0?ooo`030000003oool0oooo0=40oooo0P000003
0?ooo`001@3oool0103OW4P000000018W03Oool40?ooo`080?oo_`1d000004RL0=ooo`3oool0gia8
0000B02Lgol20?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo00P0oooo00<000000?ooo`3oool06P3oool200000=80oooo00<000000?ooo`3oool00@3oool0
00H0oooo00@0oono07@0000007@0_ooo0`3oool00`2oM000001d0;ooo`030?ooo`030;md0000M;l0
oooo00/0oooo00<0omnL04Qd_`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`<00000c`3oool0
0`000000oooo0?ooo`010?ooo`001`3oool0203ookl0M0000018W03Oool0oooo0?oo_`1d000007Bo
103oool00`3OW4P0001d0;ooo`0;0?ooo`030?oo_`1d04P0W=oo00L0oooo00<000000?ooo`3oool0
703oool400000<h0oooo00<000000?ooo`3oool00@3oool000P0oooo00L0gia80000001d_ol0oooo
0?oOW0180000B9cO00@0oooo00<0_g@00000B02Lgol02`3oool00`3ookl0M00007Boo`070?ooo`03
0000003oool0oooo01`0oooo1000003>0?ooo`030000003oool0oooo0040oooo00040?ooo`030=nL
B0000000000000<0000000D004RL0=ooo`3ogi`0B00004RLg`030?ooo`040?oo_`1d0000001d0;oo
o`/0oooo00<0okmd0000001d_ol01`3oool00`000000oooo0?ooo`0M0?ooo`80000000<0oooo0000
00000000c03oool00`000000oooo0?ooo`010?ooo`000`3oool00`2oM0000000001d_`020?ooo`0=
0?oo_`1d0000001d0;ooo`3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`0;0?ooo`04
0?oOW0180000001d0;ooo`L0oooo0P00000S0?ooo`800000b@3oool2000000<0oooo00020?ooo`04
0?oo_`1d000004RL0=ooo`<0oooo00P0_g@00000B02Lgol0oooO09a8000007@0_mnL04P000800000
00<0B9cO0?ooo`3oool01P3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00H0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo0040
oooo00020?ooo`030?oOW0180000B9cO00@0oooo00L0gia80000B02Lgol0oooo0?noM0000000B9cO
00`0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030000003oool0oooo
02D0oooo0`0000360?ooo`030000003oool0oooo0040oooo00020?ooo`030?oOW0180000B9cO00@0
oooo00P0_g@00000M02oool0oooo0?oog`2LB000001809cOo`/0oooo00D0oooO09a800000000001d
0;ooo`0:0?ooo`030000003oool0oooo02D0oooo100000350?ooo`030000003oool0oooo0040oooo
00020?ooo`030?oog`2LB00007Bo00<0oooo00<0oono07@00018W=l00`3oool0103ookl0M0000000
M02oool;0?ooo`030?noM000M;l0oooo00/0oooo00<000000?ooo`3oool09@3oool500000<@0oooo
00<000000?ooo`3oool00@3oool000<0oooo00P0omnL04P0001d_ol0oooo0?oog`2LB00004RL0=oo
o`@0oooo00@0oooO09a80000000007Bo2P3oool00`3ooml0W4P000000002000000030000M02oool0
oooo00H0oooo0P00000W0?ooo`8000000P3oool200000<40oooo0P0000030?ooo`00103oool01P3o
okl0M00000000000000004RL0=ooo`L0oooo00D0omnL04P00000000004RL0=ooo`080?ooo`030?no
M000000000000080000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0;l0oooo00<000000?ooo`3oool00@3oool002/0oooo00<000000?ooo`3oool0;@3o
ool2000000030?ooo`00000000000;`0oooo00<000000?ooo`3oool00@3oool002/0oooo00<00000
0?ooo`3oool0;`3oool400000;/0oooo00<000000?ooo`3oool00@3oool002/0oooo00<000000?oo
o`3oool0;`3oool400000;/0oooo00<000000?ooo`3oool00@3oool002/0oooo00<000000?ooo`3o
ool0<03oool300000;/0oooo00<000000?ooo`3oool00@3oool002/0oooo0P00000d0?ooo`800000
^03oool2000000<0oooo000[0?ooo`030000003oool0oooo03D0oooo0P00002g0?ooo`030000003o
ool0oooo0040oooo000[0?ooo`030000003oool0oooo03L0oooo1000002c0?ooo`030000003oool0
oooo0040oooo000[0?ooo`030000003oool0oooo03P0oooo1000002b0?ooo`030000003oool0oooo
0040oooo000[0?ooo`030000003oool0oooo03P0oooo1@00002a0?ooo`030000003oool0oooo0040
oooo000[0?ooo`800000>P3oool200000080oooo0P00002^0?ooo`8000000`3oool002/0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0040oooo000[
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`01
0?ooo`00:`3oool00`000000oooo0?ooo`110?ooo`<00000ZP3oool00`000000oooo0?ooo`010?oo
o`00:`3oool00`000000oooo0?ooo`110?ooo`@00000Z@3oool00`000000oooo0?ooo`010?ooo`00
:`3oool00`000000oooo0?ooo`110?ooo`D00000Z03oool00`000000oooo0?ooo`010?ooo`004P3o
ool01@3ooml0W4P00000000004P0W=oo00P0oooo00<0omnL04P0M02oool02@3oool2000004<0oooo
0P0000020?ooo`030000003oool0oooo0:@0oooo0P0000030?ooo`005@3oool0103OW4P000000018
W03Oool70?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0A`3oool200000:D0oooo
00<000000?ooo`3oool00@3oool001H0oooo00@0oono07@0000007@0_ooo1P3oool00`3o_g@007Bo
0?ooo`080?ooo`030000003oool0oooo04T0oooo1000002Q0?ooo`030000003oool0oooo0040oooo
000G0?ooo`040?oo_`1d000004RL0=ooo`D0oooo00<0oono07@0M02oool0203oool00`000000oooo
0?ooo`1:0?ooo`@00000X03oool00`000000oooo0?ooo`010?ooo`00603oool00`3OW4P0000007Bo
o`060?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool0BP3oool400000:00oooo00<0
00000?ooo`3oool00@3oool001@0oooo00<0gia80000000000000`0000000`00B9`0gooo0?ooo`04
0?ooo`030?noM000M;l0oooo00L0oooo00<000000?ooo`3oool0B`3oool2000000030?ooo`000000
000009h0oooo00<000000?ooo`3oool00@3oool001<0oooo00<0_g@000000000M;l00P3oool0103o
okl0M0000000M02oool50?ooo`030?oo_`1d07@0_ooo00L0oooo0P00001A0?ooo`030000003oool0
oooo09X0oooo0P0000030?ooo`004P3oool0103ookl0M0000018W03Oool30?ooo`030;md000004P0
W=oo00H0oooo00<0_g@007Boo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`800000V`3oool0
0`000000oooo0?ooo`010?ooo`004P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
00H0oooo00<0okmd001d_`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`<00000V03oool00`00
0000oooo0?ooo`010?ooo`004P3oool00`3ogi`0B00004RLg`040?ooo`050;md000007@0_ooo0?oO
_`2ogol0103oool00`3ookl0M01d0;ooo`060?ooo`030000003oool0oooo05<0oooo1000002G0?oo
o`030000003oool0oooo0040oooo000B0?ooo`030?oog`2LB00007Bo00<0oooo00L0oono07@00018
W=l0oooo0?oog`2LB7@0_ooo00@0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`1C
0?ooo`H00000U@3oool00`000000oooo0?ooo`010?ooo`004`3oool0203ogi`0B00007Boo`3oool0
oooO09a80000B9`0gooo0P3oool00`3OW4P000000000000400000003001d_`3oool0oooo00@0oooo
0P00001E0?ooo`8000000`3oool00`000000oooo0?ooo`2A0?ooo`8000000`3oool001@0oooo00H0
oono07@00000000000000018W03Oool30?ooo`030?oOW0180000000000@0000000<0001809cOo`3o
ool0103oool00`000000oooo0?ooo`1J0?ooo`800000TP3oool00`000000oooo0?ooo`010?ooo`00
:`3oool00`000000oooo0?ooo`1L0?ooo`800000T03oool00`000000oooo0?ooo`010?ooo`00:`3o
ool00`000000oooo0?ooo`1N0?ooo`800000SP3oool00`000000oooo0?ooo`010?ooo`00:`3oool0
0`000000oooo0?ooo`1M0?ooo`@00000S@3oool00`000000oooo0?ooo`010?ooo`00:`3oool00`00
0000oooo0?ooo`1M0?ooo`H00000R`3oool00`000000oooo0?ooo`010?ooo`00:`3oool2000005l0
oooo0P0000030?ooo`030000003oool0oooo08L0oooo0P0000030?ooo`00:`3oool00`000000oooo
0?ooo`1T0?ooo`800000R03oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000oooo0?oo
o`1V0?ooo`<00000Q@3oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000oooo0?ooo`1V
0?ooo`@00000Q03oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000oooo0?ooo`1V0?oo
o`@00000Q03oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000oooo0?ooo`1W0?ooo`80
000000<0oooo000000000000PP3oool00`000000oooo0?ooo`010?ooo`00:`3oool2000006d0oooo
00<000000?ooo`3oool0OP3oool2000000<0oooo000[0?ooo`030000003oool0oooo06d0oooo0P00
001o0?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo06l0oooo0`00001l
0?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo06l0oooo1000001k0?oo
o`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo06l0oooo1000001k0?ooo`03
0000003oool0oooo0040oooo00020?ooo`050?oog`2LB00000000000B02Lgol0203oool00`3ogi`0
B01d0;ooo`050?ooo`030=nLB0000000B9cO0080oooo00H0_g@000000000000000000018W03Oool9
0?ooo`800000L@3oool2000000030?ooo`000000000007P0oooo0P0000030?ooo`001@3oool0103O
W4P000000018W03Oool70?ooo`030;md001d_ol0oooo00@0oooo00L0gia800000018W=l0oooo0?oo
g`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0203oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo07H0oooo00<000000?ooo`3oool00@3oool000H0oooo00@0oono07@0000007@0_ooo
1P3oool00`3o_g@007Bo0?ooo`0>0?ooo`030?oOW018M;l0oooo00L0oooo00<000000?ooo`3oool0
MP3oool2000007H0oooo00<000000?ooo`3oool00@3oool000L0oooo00@0oono07@00000B9`0gooo
1@3oool00`3ookl0M01d0;ooo`0>0?ooo`030?oo_`1d04P0W=oo00L0oooo00<000000?ooo`3oool0
N03oool3000007<0oooo00<000000?ooo`3oool00@3oool000P0oooo00<0gia80000001d_ol01P3o
ool00`2oM000M;oo0?ooo`0=0?ooo`030?oo_`1d0000M;oo00L0oooo00<000000?ooo`3oool0N03o
ool400000780oooo00<000000?ooo`3oool00@3oool000@0oooo00<0gia80000000000000`000000
0`00B9`0gooo0?ooo`040?ooo`030?noM000M;l0oooo00d0oooo00<0okmd0000001d_ol01`3oool0
0`000000oooo0?ooo`1h0?ooo`D00000L@3oool00`000000oooo0?ooo`010?ooo`000`3oool00`2o
M0000000001d_`020?ooo`040?oo_`1d0000001d0;ooo`D0oooo00<0oono07@0M02oool0303oool0
103ogi`0B0000000M02oool70?ooo`800000NP3oool200000080oooo0P00001^0?ooo`8000000`3o
ool00080oooo00@0oono07@00000B9`0gooo0`3oool00`2oM000001809cOo`060?ooo`030;md001d
_ol0oooo00L0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`060?ooo`030000
003oool0oooo07l0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`010?ooo`000P3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00<0okmd001d_`3oool01`3o
ool00`3o_g@000000000000200000003001d_`3oool0oooo00L0oooo00<000000?ooo`3oool0P03o
ool4000006X0oooo00<000000?ooo`3oool00@3oool00080oooo00<0omnL04P00018W=l0103oool0
1@2oM000001d0;ooo`3ogkl0_moo00@0oooo00<0oono07@0M02oool01`3oool01@3ooml0W4P00000
000007@0_ooo00X0oooo00<000000?ooo`3oool0P@3oool4000006T0oooo00<000000?ooo`3oool0
0@3oool00080oooo00<0oooO09a80000M;l00`3oool01`3ookl0M00004RLg`3oool0oooO09a8M02o
ool0103oool00`2oM000M;oo0?ooo`070?ooo`030?noM000M;l0oooo00/0oooo00<000000?ooo`3o
ool0P@3oool4000006T0oooo00<000000?ooo`3oool00@3oool000<0oooo00P0omnL04P0001d_ol0
oooo0?oog`2LB00004RL0=ooo`80oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`06
0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool01P3oool2000008<0oooo0P000000
0`3oool000000?ooo`1V0?ooo`8000000`3oool000@0oooo00H0oono07@00000000000000018W03O
ool30?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool01`3oool00`3o_g@000000000
00020000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0QP3oool2000006H0oooo00<0
00000?ooo`3oool00@3oool002/0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo08T0oooo0P0000000`3o
ool000000000001P0?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo08/0
oooo1000001O0?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo08/0oooo
1000001O0?ooo`030000003oool0oooo0040oooo000[0?ooo`800000S@3oool4000005d0oooo0P00
00030?ooo`00:`3oool00`000000oooo0?ooo`2@0?ooo`800000G03oool00`000000oooo0?ooo`01
0?ooo`00:`3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool00@3oool002/0oooo00<000000?ooo`3oool0T`3oool4000005L0oooo00<000000?ooo`3o
ool00@3oool002/0oooo00<000000?ooo`3oool0U03oool4000005H0oooo00<000000?ooo`3oool0
0@3oool002/0oooo00<000000?ooo`3oool0U03oool4000005H0oooo00<000000?ooo`3oool00@3o
ool002/0oooo0P00002F0?ooo`80000000<0oooo000000000000D`3oool2000000<0oooo000[0?oo
o`030000003oool0oooo09X0oooo0P00001B0?ooo`030000003oool0oooo0040oooo000[0?ooo`03
0000003oool0oooo09`0oooo00@000000?ooo`0000000000CP3oool00`000000oooo0?ooo`010?oo
o`00:`3oool00`000000oooo0?ooo`2M0?ooo`@00000C@3oool00`000000oooo0?ooo`010?ooo`00
:`3oool00`000000oooo0?ooo`2M0?ooo`@00000C@3oool00`000000oooo0?ooo`010?ooo`004P3o
ool01@3ooml0W4P00000000004P0W=oo00L0oooo00H0omnL04P00000000000000000B02Lgol70?oo
o`800000W`3oool2000000030?ooo`000000000004X0oooo0P0000030?ooo`005@3oool0103OW4P0
00000018W03Oool40?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0001d_ol60?ooo`030000
003oool0oooo0:<0oooo0P0000190?ooo`030000003oool0oooo0040oooo000F0?ooo`040?oo_`1d
0000001d0;ooo`<0oooo00<0_g@00000M02oool00`3oool00`3OW4P004RL0=ooo`050?ooo`030000
003oool0oooo0:D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`010?ooo`005`3o
ool0103ookl0M0000018W03Oool20?ooo`030;md000007@0_ooo00<0oooo00<0_g@00018W03Oool0
1@3oool00`000000oooo0?ooo`2V0?ooo`<00000A@3oool00`000000oooo0?ooo`010?ooo`00603o
ool00`3OW4P0000007Boo`020?ooo`030?noM00004P0W=oo0080oooo00<0gia800000000M;l01P3o
ool00`000000oooo0?ooo`2V0?ooo`@00000A03oool00`000000oooo0?ooo`010?ooo`00503oool0
0`3OW4P00000000000030000000;0018W03Oool0oooo0?ooo`3OW4P007Bo0?ooo`2oM00000000000
M02oool01P3oool00`000000oooo0?ooo`2V0?ooo`@00000A03oool00`000000oooo0?ooo`010?oo
o`004`3oool00`2oM0000000001d_`020?ooo`040?oo_`1d0000001d0;ooo`<0oooo00D0okmd0000
0000000004RL0=ooo`070?ooo`800000Z03oool2000000030?ooo`00000000000440oooo0P000003
0?ooo`004P3oool0103ookl0M0000018W03Oool30?ooo`030;md000004P0W=oo0080oooo00D0omnL
04P000000000000004RLg`080?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`010?ooo`004P3oool00`3ogi`0B00004RLg`040?ooo`0;0=nLB00004P0
W=oo0?ooo`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l01`3oool00`000000oooo0?ooo`2]0?oo
o`800000?`3oool00`000000oooo0?ooo`010?ooo`004P3oool00`3ogi`0B00004RLg`040?ooo`07
0;md000007@0_ooo0?ooo`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo00H0oooo00<00000
0?ooo`3oool0[`3oool3000003`0oooo00<000000?ooo`3oool00@3oool00180oooo00<0oooO09a8
0000M;l00`3oool00`3ookl0M00004RLg`020?ooo`030=nLB000B9`0gooo0080oooo00<0oooO09a8
0018W=l01P3oool00`000000oooo0?ooo`2_0?ooo`@00000>`3oool00`000000oooo0?ooo`010?oo
o`004`3oool0203ogi`0B00007Boo`3oool0oooO09a80000B9`0gooo0P3oool00`3ogi`0B00004RL
g`020?ooo`030?noM00004P0W=oo00H0oooo00<000000?ooo`3oool0[`3oool5000003X0oooo00<0
00000?ooo`3oool00@3oool001@0oooo00H0oono07@00000000000000018W03Oool40?ooo`060?oo
_`1d000000000000000004P0W=oo1`3oool200000;40oooo0P0000020?ooo`800000=`3oool20000
00<0oooo000[0?ooo`030000003oool0oooo0;H0oooo0P00000f0?ooo`030000003oool0oooo0040
oooo000[0?ooo`030000003oool0oooo0;P0oooo1000000b0?ooo`030000003oool0oooo0040oooo
000[0?ooo`030000003oool0oooo0;T0oooo1000000a0?ooo`030000003oool0oooo0040oooo000[
0?ooo`030000003oool0oooo0;T0oooo1000000a0?ooo`030000003oool0oooo0040oooo000[0?oo
o`800000^`3oool2000000030?ooo`000000oooo02h0oooo0P0000030?ooo`00:`3oool00`000000
oooo0?ooo`2n0?ooo`800000;P3oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000oooo
0?ooo`300?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00@3oool002/0oooo00<0
00000?ooo`3oool0`@3oool4000002T0oooo00<000000?ooo`3oool00@3oool002/0oooo00<00000
0?ooo`3oool0`P3oool4000002P0oooo00<000000?ooo`3oool00@3oool002/0oooo00<000000?oo
o`3oool0`P3oool4000002P0oooo00<000000?ooo`3oool00@3oool002/0oooo0P0000340?ooo`80
000000<0oooo0000003oool09@3oool2000000<0oooo000[0?ooo`030000003oool0oooo0<L0oooo
0P00000U0?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo0<T0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000oooo0?ooo`3:
0?ooo`@00000803oool00`000000oooo0?ooo`010?ooo`00:`3oool00`000000oooo0?ooo`3;0?oo
o`@000007`3oool00`000000oooo0?ooo`010?ooo`000P3oool01@3ooml0W4P00000000004P0W=oo
00L0oooo00H0omnL04P00000000000000000B02Lgol30?ooo`030=nLB0000000B9cO0080oooo00H0
_g@000000000000000000018W03Oool90?ooo`800000c03oool4000001h0oooo0P0000030?ooo`00
1@3oool0103OW4P000000018W03Oool40?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0001d
_ol20?ooo`070=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00P0
oooo00<000000?ooo`3oool0c03oool2000000030?ooo`000000000001d0oooo00<000000?ooo`3o
ool00@3oool000H0oooo00@0oono07@0000007@0_ooo0`3oool00`2oM000001d0;ooo`030?ooo`03
0=nLB000B9`0gooo00/0oooo00<0omnL04Qd_`3oool01`3oool00`000000oooo0?ooo`3A0?ooo`80
00006`3oool00`000000oooo0?ooo`010?ooo`001`3oool0103ookl0M0000018W03Oool20?ooo`03
0;md000007@0_ooo00<0oooo00<0_g@00018W03Oool02`3oool00`3ookl0M01809cOo`070?ooo`03
0000003oool0oooo0=<0oooo1000000G0?ooo`030000003oool0oooo0040oooo00080?ooo`030=nL
B0000000M;oo0080oooo00<0okmd0000B02Lgol00P3oool00`3OW4P00000001d_`0<0?ooo`030?oo
_`1d0000M;oo00L0oooo00<000000?ooo`3oool0e03oool4000001H0oooo00<000000?ooo`3oool0
0@3oool000@0oooo00<0gia80000000000000`0000002`00B9`0gooo0?ooo`3oool0gia8001d_`3o
ool0_g@00000000007@0_ooo00`0oooo00<0okmd0000001d_ol01`3oool00`000000oooo0?ooo`3D
0?ooo`D000005@3oool00`000000oooo0?ooo`010?ooo`000`3oool00`2oM0000000001d_`020?oo
o`040?oo_`1d0000001d0;ooo`<0oooo00D0okmd00000000000004RL0=ooo`0<0?ooo`040?oOW018
0000001d0;ooo`L0oooo0P00003F0?ooo`8000000P3oool00`000000oooo0?ooo`0A0?ooo`800000
0`3oool00080oooo00@0oono07@00000B9`0gooo0`3oool00`2oM000001809cOo`020?ooo`050?oO
W0180000000000000018W=l02@3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo
00H0oooo00<000000?ooo`3oool0fP3oool200000180oooo00<000000?ooo`3oool00@3oool00080
oooo00<0omnL04P00018W=l0103oool02`3OW4P0001809cOo`3oool0omnL04P0000004P0W=oo0?oo
o`3OW4P007Bo00P0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030000
003oool0oooo0=`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`010?ooo`000P3o
ool00`3ogi`0B00004RLg`040?ooo`070;md000007@0_ooo0?ooo`3OW4P0001809cOo`020?ooo`03
0?oog`2LB000M;oo00L0oooo00D0oooO09a800000000001d0;ooo`0:0?ooo`030000003oool0oooo
0=d0oooo0`00000>0?ooo`030000003oool0oooo0040oooo00020?ooo`030?oog`2LB00007Bo00<0
oooo00<0oono07@00018W=l00P3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO00P0
oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`3M0?ooo`@000003@3oool00`000000
oooo0?ooo`010?ooo`000`3oool0203ogi`0B00007Boo`3oool0oooO09a80000B9`0gooo0P3oool0
0`3ogi`0B00004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0oooO09a8000000000P000000
0`0007@0_ooo0?ooo`060?ooo`030000003oool0oooo0=d0oooo1@00000<0?ooo`030000003oool0
oooo0040oooo00040?ooo`060?oo_`1d0000000000000000B9`0gooo103oool01P3ookl0M0000000
00000000001809cOo`X0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`050?ooo`80
0000g`3oool200000080oooo0P0000090?ooo`8000000`3oool002/0oooo00<000000?ooo`3oool0
i03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003o
ool0oooo0>D0oooo0P0000070?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0
oooo0>L0oooo0`0000040?ooo`030000003oool0oooo0040oooo000[0?ooo`030000003oool0oooo
0>L0oooo100000030?ooo`030000003oool0oooo0040oooo000[0?ooo`800000j03oool400000080
oooo0P0000030?ooo`00:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0:P3oool2000000@0oooo00<000000?ooo`3oool00@3oool002/0oooolP00
00030?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {2.96894, 95.5932, 0.0108624, \
0.0177832}}],

Cell[BoxData[
    \({f0 \[Rule] \(-6.832481059503098`*^40\)}\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("Log[-\!\(f\_0\)] = \
"\[InvisibleSpace]94.02509158645998`\),
      SequenceForm[ "Log[-\!\(f\_0\)] = ", 94.025091586459979],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    RowBox[{"(*", " ", 
      RowBox[{
        StyleBox["Numeric",
          FontColor->RGBColor[1, 0, 0]], " ", "-", " ", 
        StyleBox["Analytic",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[" ",
        FontColor->RGBColor[0, 0, 1]], "*)"}]], "Input"],

Cell[BoxData[{
    \(\(Fpr = 
        Plot[\((\(LogF0 - xb1\ N /. f1\) /. 
              N \[Rule] nn)\), {nn, \(-22\), \(-14\)}, PlotRange \[Rule] All, 
          Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.01], 
              Hue[0.3]}];\)\), "\[IndentingNewLine]", 
    \(\(Fpr1 = 
        Plot[\((\(LogF0 - xb1\ N /. f2\) /. 
              N \[Rule] nn)\), {nn, \(-8\), \(-1.75\)}, 
          PlotRange \[Rule] All, Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.01], Hue[0.3]}];\)\), "\n", 
    \(\(Fpr2 = 
        Plot[\((\(LogF0 - xb1\ N /. f3\) /. N \[Rule] nn)\), {nn, 3.5, 6}, 
          PlotRange \[Rule] All, Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.01], Hue[0.3]}];\)\), "\n", 
    \(\(Fpr = Show[Fpr, Fpr1, Fpr2];\)\), "\[IndentingNewLine]", 
    \(\(FFplot = 
        Plot[{Log[FN[N]], Log[FNacc[N]]}, {N, nmin, nmax}, 
          Frame \[Rule] True, FrameLabel \[Rule] {"\<N\>", "\<Log(F(z))\>"}, 
          PlotRange \[Rule] All, Axes \[Rule] False, 
          PlotStyle \[Rule] {Hue[0], Hue[ .7]}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig5logF = 
        Show[Fpr, FFplot, DisplayFunction \[Rule] $DisplayFunction, 
          FrameLabel \[Rule] {"\<N\>", "\<Log(F(N))\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig5_logF\>" <> "\<.m\>", fig5logF];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.0147151 0.00596497 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -14.0625 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .13401 -24.125 -12.2813 ]
[-0.0125 .13401 0 12.2813 ]
[-0.0125 .25331 -24.125 -12.2813 ]
[-0.0125 .25331 0 12.2813 ]
[-0.0125 .37261 -24.125 -12.2813 ]
[-0.0125 .37261 0 12.2813 ]
[-0.0125 .49191 -24.125 -12.2813 ]
[-0.0125 .49191 0 12.2813 ]
[-0.0125 .61121 -34.1875 -12.2813 ]
[-0.0125 .61121 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -58.75 -44 ]
[-0.01875 .30902 -34.1875 44 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13401 m
.00625 .13401 L
s
gsave
-0.0125 .13401 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .25331 m
.00625 .25331 L
s
gsave
-0.0125 .25331 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .37261 m
.00625 .37261 L
s
gsave
-0.0125 .37261 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .49191 m
.00625 .49191 L
s
gsave
-0.0125 .49191 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .61121 m
.00625 .61121 L
s
gsave
-0.0125 .61121 -95.1875 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04454 m
.00375 .04454 L
s
0 .07436 m
.00375 .07436 L
s
0 .10419 m
.00375 .10419 L
s
0 .16384 m
.00375 .16384 L
s
0 .19366 m
.00375 .19366 L
s
0 .22349 m
.00375 .22349 L
s
0 .28314 m
.00375 .28314 L
s
0 .31296 m
.00375 .31296 L
s
0 .34279 m
.00375 .34279 L
s
0 .40244 m
.00375 .40244 L
s
0 .43226 m
.00375 .43226 L
s
0 .46209 m
.00375 .46209 L
s
0 .52174 m
.00375 .52174 L
s
0 .55156 m
.00375 .55156 L
s
0 .58139 m
.00375 .58139 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -151.469 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 16.2813 translate
90 rotate
-105 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.375 23.000 moveto
(H) show
101.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.000 23.000 moveto
(H) show
119.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
134.125 23.000 moveto
(L) show
140.563 23.000 moveto
(L) show
147.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13401 m
1 .13401 L
s
.99375 .25331 m
1 .25331 L
s
.99375 .37261 m
1 .37261 L
s
.99375 .49191 m
1 .49191 L
s
.99375 .61121 m
1 .61121 L
s
.125 Mabswid
.99625 .04454 m
1 .04454 L
s
.99625 .07436 m
1 .07436 L
s
.99625 .10419 m
1 .10419 L
s
.99625 .16384 m
1 .16384 L
s
.99625 .19366 m
1 .19366 L
s
.99625 .22349 m
1 .22349 L
s
.99625 .28314 m
1 .28314 L
s
.99625 .31296 m
1 .31296 L
s
.99625 .34279 m
1 .34279 L
s
.99625 .40244 m
1 .40244 L
s
.99625 .43226 m
1 .43226 L
s
.99625 .46209 m
1 .46209 L
s
.99625 .52174 m
1 .52174 L
s
.99625 .55156 m
1 .55156 L
s
.99625 .58139 m
1 .58139 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.2 1 0 r
.01 w
.23545 .06678 m
.24404 .07453 L
.2534 .08297 L
.26219 .0909 L
.27065 .09853 L
.27965 .10665 L
.28832 .11446 L
.29753 .12277 L
.3064 .13077 L
.31494 .13847 L
.32402 .14666 L
.33276 .15455 L
.34117 .16213 L
.35012 .17021 L
.35874 .17798 L
.3679 .18624 L
.37672 .1942 L
.38521 .20185 L
.39424 .21 L
.40294 .21784 L
.41218 .22617 L
.42108 .2342 L
.42965 .24193 L
.43876 .25015 L
.44709 .25766 L
s
.60582 .39988 m
.61253 .4051 L
.61984 .41079 L
.62671 .41613 L
.63332 .42127 L
.64035 .42674 L
.64712 .43201 L
.65432 .43761 L
.66125 .443 L
.66792 .44818 L
.67501 .4537 L
.68185 .45902 L
.68841 .46413 L
.69541 .46957 L
.70214 .4748 L
.7093 .48037 L
.71619 .48573 L
.72282 .49089 L
.72988 .49638 L
.73667 .50166 L
.74389 .50727 L
.75085 .51268 L
.75754 .51789 L
.76466 .52343 L
.77116 .52849 L
s
.91005 .58827 m
.91274 .58888 L
.91566 .58954 L
.91841 .59017 L
.92105 .59077 L
.92387 .59141 L
.92657 .59203 L
.92945 .59268 L
.93222 .59331 L
.93489 .59392 L
.93773 .59456 L
.94046 .59519 L
.94309 .59578 L
.94589 .59642 L
.94858 .59703 L
.95144 .59769 L
.9542 .59831 L
.95685 .59892 L
.95968 .59956 L
.96239 .60018 L
.96528 .60084 L
.96806 .60147 L
.97074 .60208 L
.97359 .60273 L
.97619 .60332 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03279 .01472 L
.03388 .01472 L
.03506 .01472 L
.03635 .01472 L
.03756 .01472 L
.04018 .01472 L
.04146 .01472 L
.04262 .01472 L
.04385 .01472 L
.04516 .01472 L
.04649 .01472 L
.04793 .01472 L
.04928 .01472 L
.05052 .01472 L
.05171 .01472 L
.05297 .01472 L
.0541 .01472 L
.05531 .01472 L
.05749 .01472 L
.05882 .01472 L
.06008 .01472 L
.06244 .01472 L
.06486 .01472 L
.06624 .01472 L
.06753 .01472 L
.07013 .01472 L
.07146 .01472 L
.07293 .01472 L
.0742 .01472 L
.07539 .01472 L
.07799 .01472 L
.08023 .01472 L
.08263 .01472 L
.0841 .01472 L
.08547 .01472 L
.08696 .01472 L
.08854 .01472 L
.0912 .01472 L
.09271 .01472 L
.09413 .01472 L
.09548 .01472 L
.09676 .01472 L
.09917 .01472 L
Mistroke
.10051 .01472 L
.10176 .01472 L
.10313 .01472 L
.10458 .01472 L
.10585 .01472 L
.10723 .01472 L
.10967 .01472 L
.11105 .01472 L
.11252 .01472 L
.11517 .01472 L
.11646 .01472 L
.11786 .01472 L
.11909 .01472 L
.12039 .01472 L
.12157 .01472 L
.12286 .01472 L
.12514 .01472 L
.12632 .01472 L
.12756 .01472 L
.12977 .01472 L
.13215 .01472 L
.1335 .01472 L
.13475 .01472 L
.13704 .01473 L
.13911 .01473 L
.1415 .01474 L
.14376 .01475 L
.14616 .01477 L
.14841 .01479 L
.14969 .0148 L
.15087 .01482 L
.15224 .01484 L
.15351 .01487 L
.15604 .01494 L
.15738 .01498 L
.1588 .01505 L
.16118 .01519 L
.16382 .0154 L
.1662 .01568 L
.16839 .01602 L
.1708 .01651 L
.17334 .01719 L
.17761 .0188 L
.18228 .02125 L
.19254 .02868 L
.20187 .03665 L
.22281 .05539 L
.26276 .09141 L
.30119 .12608 L
.34208 .16295 L
Mistroke
.38145 .19846 L
.4193 .2326 L
.45961 .26894 L
.4984 .30389 L
.53965 .3409 L
.57938 .37601 L
.61759 .40845 L
.65826 .4411 L
.6974 .47145 L
.73901 .50333 L
.77909 .53389 L
.79749 .54751 L
.80792 .55459 L
.81766 .5603 L
.83762 .56901 L
.85869 .57556 L
.89762 .58532 L
.939 .59487 L
.97619 .6033 L
Mfstroke
.2 0 1 r
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06453 .01472 L
.06529 .01472 L
.06657 .01472 L
.06729 .01472 L
.06797 .01472 L
.06924 .01472 L
.0704 .01472 L
.07103 .01472 L
.07173 .01472 L
.073 .01472 L
Mistroke
.07376 .01472 L
.07448 .01472 L
.07513 .01472 L
.07583 .01472 L
.0766 .01472 L
.0774 .01472 L
.07809 .01472 L
.07885 .01472 L
.07956 .01472 L
.0802 .01472 L
.08095 .01472 L
.08166 .01472 L
.08291 .01472 L
.08362 .01472 L
.08427 .01472 L
.08544 .01472 L
.08669 .01472 L
.08787 .01472 L
.08896 .01472 L
.09016 .01472 L
.09148 .01472 L
.09214 .01472 L
.09285 .01472 L
.09413 .01472 L
.09483 .01472 L
.09548 .01472 L
.09619 .01472 L
.09695 .01472 L
.09821 .01472 L
.09893 .01472 L
.09961 .01472 L
.10086 .01472 L
.10201 .01472 L
.10333 .01472 L
.10458 .01472 L
.10572 .01472 L
.10694 .01472 L
.1081 .01472 L
.10916 .01472 L
.11033 .01472 L
.11162 .01472 L
.11227 .01472 L
.11297 .01472 L
.11422 .01472 L
.11491 .01472 L
.11554 .01472 L
.11624 .01472 L
.11698 .01472 L
.11822 .01472 L
.11892 .01472 L
Mistroke
.11958 .01472 L
.12081 .01472 L
.12194 .01472 L
.12323 .01472 L
.12446 .01472 L
.12562 .01472 L
.12668 .01472 L
.12789 .01472 L
.12903 .01472 L
.13009 .01472 L
.13107 .01472 L
.13214 .01472 L
.13327 .01472 L
.13441 .01472 L
.13564 .01472 L
.1368 .01472 L
.13785 .01472 L
.13909 .01472 L
.13979 .01472 L
.14043 .01472 L
.14162 .01472 L
.14288 .01472 L
.14402 .01472 L
.14526 .01472 L
.14656 .01472 L
.14777 .01472 L
.14891 .01472 L
.14994 .01472 L
.15113 .01472 L
.15226 .01472 L
.15348 .01472 L
.15478 .01472 L
.15589 .01472 L
.15711 .01472 L
.15842 .01472 L
.15915 .01472 L
.15982 .01472 L
.16113 .01472 L
.16236 .01472 L
.16352 .01472 L
.16456 .01472 L
.16577 .01472 L
.1669 .01472 L
.16796 .01472 L
.16893 .01472 L
.16999 .01472 L
.17111 .01472 L
.17225 .01472 L
.17347 .01472 L
.17462 .01472 L
Mistroke
.17566 .01472 L
.17689 .01472 L
.17758 .01472 L
.17823 .01472 L
.1794 .01666 L
.18065 .01778 L
.21847 .05189 L
.25875 .08822 L
.29751 .12317 L
.33872 .16034 L
.37841 .19615 L
.41659 .23059 L
.45723 .26723 L
.49634 .30251 L
.53791 .34 L
.57797 .37613 L
.61651 .4094 L
.6575 .44067 L
.69697 .47084 L
.73493 .49982 L
.77534 .53067 L
.79397 .5449 L
.8038 .55239 L
.80619 .55422 L
.80876 .55618 L
.80948 .55672 L
.81024 .55731 L
.81088 .5578 L
.81159 .55723 L
.81225 .55738 L
.81296 .55754 L
.81424 .55783 L
.82527 .56031 L
.83547 .56262 L
.85559 .56715 L
.89707 .57651 L
.93704 .58552 L
.9755 .59419 L
.97619 .59434 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{542.75, 335.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008N0001Cb000`400?l00000o`00003oo`3ooooo
0?ooob00oooo003o0?ooool0oooo803oool00?l0ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo
003o0?ooool0oooo803oool00?l0ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo003o0?ooobX0
oooo00H0_g@000000000000000000018W03Oool40?ooo`030?oo_`1d07@0_ooo0>P0oooo003o0?oo
ob/0oooo00<0oono07@0M02oool01@3oool0103ooml0W4P00000M02ooooX0?ooo`00o`3oool[0?oo
o`030?oog`2LB7@0_ooo00D0oooo00@0_g@00000000007@0_oooj03oool00?l0oooo:`3oool00`3o
oml0W4Qd0;ooo`040?ooo`050=nLB0000000001804Q8M02oool0j03oool00?l0oooo:`3oool00`3o
oml0W4Qd0;ooo`030?ooo`060?noM0000000001d0;oog`2LB7@0_oooj03oool00?l0oooo:`3oool0
0`3ooml0W4Qd0;ooo`020?ooo`070?oOW0180000001809cOo`3ooml0W4Qd0;ooo`3X0?ooo`00o`3o
ool[0?ooo`0<0?oog`2LB7@0_ooo0?ooo`3ookl0M0000000001d_ol0oooo0?oog`2LB7@0_oooj03o
ool00?l0oooo:`3oool01`3ooml0W4Qd0;ooo`3ooml0W4P000000018W=l00P3oool00`3ooml0W4Qd
0;ooo`3X0?ooo`00o`3oool[0?ooo`060?oog`2LB7@0_ooO09a80000000007Bo0`3oool00`3ooml0
W4Qd0;ooo`3X0?ooo`00o`3oool[0?ooo`060?oog`2LB7@0M7@000000000B9`0gooo0`3oool00`3o
oml0W4Qd0;ooo`3X0?ooo`00o`3oool[0?ooo`050?oog`2LB00000000000M02oool0103oool00`3o
oml0W4Qd0;ooo`3X0?ooo`00o`3oool[0?ooo`040=nLB0000000001d0;ooo`D0oooo00<0oono07@0
M02oool0j03oool00?l0oooo:@3oool01@3OW4P000000000000004P0W=oo00@0oooo00<0oooO09a8
000000000P0000000`00B9`0gooo0?ooo`3U0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo
803oool00?l0ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803oool00?l0
ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803oool00?l0ooooo`3ooolP
0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803oool005`0oooo00<0oooO09a800000000
0P0000000`00B9`0gooo0?ooo`050?ooo`040;md00000000000004RLgbT0oooo00<0gia800000000
00001@000000101d_ol0oooo0?ooo`2oM003000000030018W03Oool0oooo02P0oooo00<0gia80000
000000001@0000000`1d_ol0oooo0?ooo`020?ooo`040;md00000000000004RLgb/0oooo00<0okmd
0000000000000P0000001@00M;l0oooo0?ooo`3oool0_g@000<0000000<004RL0=ooo`3oool0:P3o
ool00`3o_g@000000000000200000003001d_`3oool0oooo00<0oooo00@0_g@0000000000000B9cO
;`3oool01P2oM000000000000000000004RL0=ooobl0oooo00@0_g@0000000000000B9cO=03oool0
1P2oM000000000000000000004RL0=ooobL0oooo001L0?ooo`080?oOW018000004RL0=ooo`3oool0
omnL04P0B02Lgol30?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0Y0?ooo`030=nLB000
0000000000@0000000D007Bo0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo02T0oooo
00<0gia8000000000000100000002P00M;l0oooo0?ooo`3ooml0W4P0001d_`3oool0oooO09a80000
M;l/0?ooo`030;md000007@0_ooo00<0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=oo
o`0/0?ooo`030;md000007@0_ooo00@0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo02d0
oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0/0?ooo`070?oog`2LB00007Bo0?oo
o`3ooml0W4P0001d_`0b0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool09P3oool0
0680oooo00<0okmd0018W03Oool00P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo
02T0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?ooo`030?oOW018M;l0oooo
02T0oooo00<0gia804RLg`3oool00P3oool01`3ooml0W4Qd0;ooo`3oool0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`0[0?ooo`030;md000007@0_ooo00T0oooo00<0omnL04Qd_`3oool0:`3o
ool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0<P3o
ool00`3ogi`0B7Bo0?ooo`0[0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0=`3o
ool00`3ogi`0B7Bo0?ooo`0U0?ooo`00HP3oool0203o_g@0001809cOo`3oool0oooO09a80000B9`0
gooo0P3oool00`3ooml0W4P0001d_`0Z0?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0B02L
gol0:P3oool00`3OW4P0B9cO0?ooo`040?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a8
0000M;l0:`3oool00`2oM000001d0;ooo`090?ooo`030?oo_`1d04P0W=oo02/0oooo00<0_g@00000
M02oool00`3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo0380oooo00<0oono
07@0B02Lgol0:P3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo03L0oooo00<0
oono07@0B02Lgol09@3oool00680oooo00L0_g@00000B02Lgol0oooo0?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool0:P3oool00`3OW4P0M;oo0?ooo`090?ooo`030?oo_`1d0000M;oo02/0oooo
00<0gia807Boo`3oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02X0oooo
00<0_g@00000M02oool02@3oool00`3ookl0M00007Boo`0[0?ooo`030;md000007@0_ooo00<0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0a0?ooo`030?oo_`1d0000M;oo02X0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0f0?ooo`030?oo_`1d0000M;oo02D0oooo
001?0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool01@3oool0202oM00000000000
M02oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`0I0?ooo`030;md000000000000
00L0000000<0B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`090?ooo`030?noM0000000M;oo
01X0oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030?oog`2LB4P0W=oo
00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0I0?ooo`030;md000000000000
00L0000000<0B9cO0?ooo`3oool0103oool00`2oM000001d0;ooo`090?ooo`030?noM0000000M;oo
01X0oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo
00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0N0?ooo`030;md000000000000
00L0000000<0B9cO0?ooo`3oool01P3oool00`3o_g@0000007Boo`0Z0?ooo`030?oOW0180000B9cO
00@0oooo00<0_g@00000M02oool0=P3oool00`3o_g@0000007Boo`0U0?ooo`00GP3oool00`3ookl0
M000000000020000000604RLg`3oool0oooo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`0[
0?ooo`030?oOW01807@0_ooo00L0oooo00@0omnL04P0000007@0_ooo;03oool00`3ogi`0B01d0;oo
o`020?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0:P3oool00`2oM000001d0;oo
o`080?ooo`040?oOW0180000001d0;ooob/0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo0300oooo00@0omnL04P0000007@0_ooo:P3oool00`3ogi`0
B00004RLg`040?ooo`030=nLB00004P0W=oo03D0oooo00@0omnL04P0000007@0_ooo9@3oool00600
oooo00<0okmd0000B02Lgol00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02`0
oooo00<0_g@004RLg`3oool00P3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo
02`0oooo00L0_g@004RLg`3oool0oooo0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0:P3o
ool00`2oM000001d0;ooo`040?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0
:P3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
;03oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo02T0oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`0a0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?oo
o`3oool0903oool00640oooo00<0omnL04Qd_`3oool00P3oool00`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo02`0oooo00<0gia80000M02oool00P3oool00`3o_g@000000000000200000003
001d_`3oool0oooo02d0oooo00L0gia80000M02oool0oooo0?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool0:P3oool00`2oM000001d0;ooo`040?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool0:`3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool0;03oool00`3o_g@000000000000200000003001d_`3oool0oooo02X0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`0a0?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool09@3oool00640oooo00<0oooO09a80018W=l00`3oool00`2oM00004RL0=ooo`020?oo
o`030?oog`2LB00007Bo02d0oooo00<0okmd0000001d_ol00P3oool01@3ooml0W4P00000000007@0
_ooo0300oooo00<0okmd0000001d_ol00P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo02/0oooo00<0_g@00000M02oool0103oool01@3ooml0W4P00000000007@0_ooo02h0oooo00<0
_g@00000M02oool0103oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo02d0oooo00D0
oooO09a800000000001d0;ooo`0^0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0
<P3oool01@3ooml0W4P00000000007@0_ooo02P0oooo001L0?ooo`030?oog`2LM9`0gooo0080oooo
00<0oooO09a80000M;l00`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo02L0oooo
00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`030?ooo`030?noM000M;l0oooo02/0oooo
00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`020?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol0:`3oool00`2oM000001d0;ooo`050?ooo`030?noM000M;l0oooo02l0oooo
00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo02h0oooo
00<0okmd001d_`3oool0;`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo03<0oooo
00<0okmd001d_`3oool0:@3oool005d0oooo00L0omnL04Q8W03Oool0oooo0=nLB0000000M;oo00@0
oooo00H0_g@00018W03Oool0oooo0;md0000M;lY0?ooo`080;md001d_ol0oooo0?ooo`3OW4P00000
0018W03Oool30?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool09`3oool0202oM000
M;oo0?ooo`3oool0gia800000000B9`0gooo0`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_bX0
oooo00D0gia8000000000000001d0;ooo`050?ooo`030?oog`2LB00000000080000000<0001d0;oo
o`3oool0:03oool01@3OW4P000000000000007@0_ooo00D0oooo00H0_g@00018W03Oool0oooo0;md
0000M;l_0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0:`3oool01P2oM00004RL
0=ooo`3oool0_g@0001d_c@0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0T0?oo
o`00GP3oool01@3ogi`0B000000000000000B9cO00H0oooo00@0_g@000000000000007Bo:`3oool0
1@2oM000000000000000000007Bo00H0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?oo
o`0W0?ooo`050;md00000000000000000000M;l01P3oool0102oM000000000000000M;l/0?ooo`04
0?oo_`1d0000001d0;ooo`H0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0X0?oo
o`040?oo_`1d0000001d0;ooo`H0oooo00@0_g@000000000000007Bo<@3oool00`3o_g@000000000
00020000000307Boo`3oool0oooo02/0oooo00@0_g@000000000000007Bo=P3oool00`3o_g@00000
000000020000000307Boo`3oool0oooo02<0oooo003o0?ooool0oooo803oool00?l0ooooo`3ooolP
0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803oool00?l0ooooo`3ooolP0?ooo`00o`3o
oooo0?ooob00oooo003o0?ooool0oooo803oool00?l0ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00
oooo003o0?ooool0oooo803oool00?l0ooooo`3ooolP0?ooo`00AP3oool0102oM000000000000018
W=l;0?ooool00000^000000B0?ooo`00A03oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
403oool004@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0100oooo00130?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02@3o
ool00`000000oooo0?ooo`3o0?oook@0oooo00<000000?ooo`3oool0403oool004<0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`080?ooo`030000003oool0oooo0?l0oooo]03oool0
0`000000oooo0?ooo`0@0?ooo`00@`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo
00P0oooo00<000000?ooo`3oool0o`3ooond0?ooo`030000003oool0oooo0100oooo00130?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0203oool4000000H0ooooA@0c0?oo0?ooofD0
oooo1000000B0?ooo`00@`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo
00<000000?ooo`3oool0AP3oool40?l000030?ooo`0c0?l0<`3o0?l0ooooI`3oool00`000000oooo
0?ooo`0@0?ooo`00@`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00<0
00000?ooo`3oool0BP3oool20?l000030?ooo`0c0?l0oooo0?l0ooooI@3oool00`000000oooo0?oo
o`0@0?ooo`00A03oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0oooo00<00000
0?ooo`3oool0C03oool20?l0000303<0o`3oool0oooo0?l0ooooH`3oool00`000000oooo0?ooo`0@
0?ooo`00A03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00T0oooo00<000000?oo
o`3oool0CP3oool00`3o0000<`3o0?ooo`3o0?ooof<0oooo00<000000?ooo`3oool0403oool004D0
oooo00H0_g@00018W03Oool0oooo0;md0000M;l:0?ooo`030000003oool0oooo04l0oooo00<0o`00
03<0o`0c0?l0o`3ooomR0?ooo`030000003oool0oooo0100oooo00160?ooo`040;md000000000000
001d_`/0oooo00<000000?ooo`3oool0D@3oool00`3o0000<`3o0?ooo`3o0?ooof00oooo00<00000
0?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0DP3oool00`3o0000<`3o0?ooo`3o0?oo
oel0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0D`3oool00`3o0000
<`3o0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0
E03oool00`3o0000<`3o0?ooo`3o0?oooed0oooo00<000000?ooo`3oool0403oool005D0oooo00<0
00000?ooo`3oool0E@3oool00`3o0000<`3o0?ooo`3o0?oooe`0oooo00<000000?ooo`3oool0403o
ool005D0oooo00<000000?ooo`3oool0EP3oool00`3o0000<`3o0?ooo`3o0?oooe/0oooo00<00000
0?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0E`3oool00`3o0000<`3o03<0o`3o0?oo
oeX0oooo00<000000?ooo`3oool0403oool005D0oooo0`00001H0?ooo`030?l0003oool0<`3o0?l0
ooooE`3oool300000180oooo001E0?ooo`030000003oool0oooo05T0oooo0P3o00000`0c0?l0oooo
0?ooo`3o0?oooeH0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0F`3o
ool00`3o0000<`3o0?ooo`3o0?oooeH0oooo00<000000?ooo`3oool0403oool005D0oooo00<00000
0?ooo`3oool0G03oool00`3o0000<`3o0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0403oool0
05D0oooo00<000000?ooo`3oool0G@3oool00`3o0000<`3o0?ooo`3o0?oooe@0oooo00<000000?oo
o`3oool0403oool005D0oooo00<000000?ooo`3oool0GP3oool00`3o0000<`3o0?ooo`3o0?oooe<0
oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0G`3oool00`3o0000<`3o
0?ooo`3o0?oooe80oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0H03o
ool00`3o0000<`3o0?ooo`3o0?oooe40oooo00<000000?ooo`3oool0403oool005D0oooo00<00000
0?ooo`3oool0H@3oool0103o0000<`3o0?ooo`0co`3o0?ooodl0oooo00<000000?ooo`3oool0403o
ool005D0oooo00<000000?ooo`3oool0HP3oool00`3o0000<`3o03?o000203?o0?l0ooooC@3oool0
0`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`1R0?ooo`80<ol000@0<`3o03?o
000co`00<ol0o`3ooom<0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo
0680oooo0`0co`0203<0o`80<ol0o`3ooom;0?ooo`030000003oool0oooo0100oooo001E0?ooo`03
0000003oool0oooo06@0oooo0P0co`00103o0000<`3o03?o000co`3o0?ooodX0oooo00<000000?oo
o`3oool0403oool005D0oooo0`00001U0?ooo`80<ol000@0o`0003<0o`0co`00<ol0o`3ooom70?oo
o`<000004P3oool005D0oooo00<000000?ooo`3oool0IP3oool203?o00040?l0000c0?l0<ol003?o
0?l0ooooB03oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`1W0?ooo`80
<ol000@0o`0003<0o`0co`00<ol0o`3ooom70?ooo`030000003oool0oooo0100oooo001E0?ooo`03
0000003oool0oooo06P0oooo0P0co`000`3o0000<`3o03?o000203?o0?l0ooooA@3oool00`000000
oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`1Y0?ooo`80<ol000<0o`0003<0o`0co`00
0P0co`3o0?oood@0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0JP3o
ool303?o000403<0o`0co`00<ol003?o0?l0oooo@`3oool00`000000oooo0?ooo`0@0?ooo`00E@3o
ool00`000000oooo0?ooo`1/0?ooo`80<ol000@0<`3o03?o000co`00<ol0o`3ooom20?ooo`030000
003oool0oooo0100oooo001E0?ooo`030000003oool0oooo06d0oooo0P0co`00100c0?l0<ol003?o
000co`3o0?oood40oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0KP3o
ool203?o000403<0o`0co`00<ol003?o0?l0oooo@03oool00`000000oooo0?ooo`0@0?ooo`00E@3o
ool00`000000oooo0?ooo`1_0?ooo`80<ol000@0<`3o03?o000co`00<ol0o`3ooolo0?ooo`030000
003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0700oooo0P0co`00100c0?l0<ol003?o
000co`3o0?oooch0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0L@3o
ool203?o000403<0o`0co`00<ol003?o0?l0oooo?@3oool00`000000oooo0?ooo`0@0?ooo`00E@3o
ool00`000000oooo0?ooo`1b0?ooo`80<ol000@0<`3o0?l0000co`00<ol0o`3oooll0?ooo`030000
003oool0oooo0100oooo001E0?ooo`<00000L`3oool203?o000403<0o`3o0000<ol003?o0?l0oooo
>@3oool300000180oooo001E0?ooo`030000003oool0oooo07@0oooo0P0co`0203<0o`80<ol0o`3o
oolj0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo07D0oooo0`0co`00
0`0c0?l0<ol003?o003o0?ooocT0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?oo
o`3oool0MP3oool303?o000303<0o`0co`00<ol00?l0oooo>03oool00`000000oooo0?ooo`0@0?oo
o`00E@3oool00`000000oooo0?ooo`1g0?ooo`<0<ol000@0<`3o03?o000co`00<ol0o`3ooolf0?oo
o`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo07P0oooo0`0co`00100c0?l0
<ol003?o000co`3o0?ooocD0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3o
ool0N@3oool303?o000403<0o`3o0000<ol003?o0?l0oooo=03oool00`000000oooo0?ooo`0@0?oo
o`00E@3oool00`000000oooo0?ooo`1k0?ooo`80<ol000@0<`3o0?l0000co`00<ol0o`3ooolc0?oo
o`030000003oool0oooo0100oooo000i0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3o
ool00P3oool0102oM000000000000018W=l;0?ooo`030000003oool0oooo07`0oooo0P0co`00100c
0?l0o`0003?o000co`3o0?oooc80oooo00<000000?ooo`3oool0403oool003X0oooo00<0gia80000
00000000100000002P00M;l0oooo0?ooo`3ooml0W4P0001d_`3oool0oooO09a80000M;l:0?ooo`03
0000003oool0oooo07d0oooo0P0co`00100c0?l0o`0003?o000co`3o0?oooc40oooo00<000000?oo
o`3oool0403oool003/0oooo00<0gia804RLg`3oool00P3oool01`3ooml0W4Qd0;ooo`3oool0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`090?ooo`030000003oool0oooo07h0oooo0P0co`00
100c0?l0o`0003?o000co`3o0?oooc00oooo00<000000?ooo`3oool0403oool003`0oooo00<0gia8
04RLg`3oool0103oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00T0oooo00<0
00000?ooo`3oool0O`3oool203?o000303<0o`3o0000<ol00080<ol0o`3oool^0?ooo`030000003o
ool0oooo0100oooo000m0?ooo`030=nLB01d_ol0oooo00<0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`080?ooo`030000003oool0oooo0800oooo0P0co`000`0c0?l0o`0003?o0002
03?o0?l0oooo;@3oool00`000000oooo0?ooo`0@0?ooo`00?@3oool00`3ooml0W4Q809cOo`030?oo
o`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0203oool400000800oooo0P0co`0203<0
o`<0<ol0o`3ooolY0?ooo`@000004P3oool003h0oooo00<0omnL04P0M02oool00P3oool00`3ogi`0
B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo00<000000?ooo`3oool0P`3oool203?o0004
03<0o`3o0000<ol003?o0?l0oooo:`3oool00`000000oooo0?ooo`0@0?ooo`00?`3oool01`2oM000
B9cO0?ooo`3oool0omnL04P00018W=l0103oool00`3OW4P0001809cOo`080?ooo`030000003oool0
oooo08@0oooo0P0co`00100c0?l0o`0003?o000co`3o0?ooobX0oooo00<000000?ooo`3oool0403o
ool003l0oooo00L0gia80000M02oool0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
203oool00`000000oooo0?ooo`250?ooo`80<ol000@0<`3o0?l0000co`00<ol0o`3ooolY0?ooo`03
0000003oool0oooo0100oooo000o0?ooo`030?noM0000000M;oo0080oooo00<0_g@00018W03Oool0
0P3oool00`3ooml0W4P0001d_`090?ooo`030000003oool0oooo08H0oooo0P0co`00100c0?l0o`00
03?o000co`3o0?ooobP0oooo00<000000?ooo`3oool0403oool003T0oooo00<0omnL09boo`3oool0
0`3oool00`2oM000000007Boo`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
2@3oool00`000000oooo0?ooo`270?ooo`80<ol000<0<`3o0?l0000co`000P0co`3o0?ooobH0oooo
00<000000?ooo`3oool0403oool003X0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=oo
o`<0oooo00H0_g@00018W03Oool0oooo0;md0000M;l:0?ooo`030000003oool0oooo08P0oooo0P0c
o`000`0c0?l0o`0003?o000203?o0?l0oooo9@3oool00`000000oooo0?ooo`0@0?ooo`00>`3oool0
1@2oM000000000000000000007Bo00H0oooo00@0_g@000000000000007Bo2`3oool00`000000oooo
0?ooo`290?ooo`80<ol000<0<`3o0?l0000co`000P0co`3o0?ooob@0oooo00<000000?ooo`3oool0
403oool005D0oooo00<000000?ooo`3oool0R`3oool00`0co`00<`3o03<0o`0303?o0?l0oooo8`3o
ool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`2<0?ooo`80<ol000@0<`3o
0?l0000co`00<ol0o`3ooolR0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0
oooo08d0oooo0P0co`00100c0?l0o`0003?o000co`3o0?ooob40oooo00<000000?ooo`3oool0403o
ool005D0oooo00<000000?ooo`3oool0SP3oool203?o000403<0o`3o0000<ol003?o0?l0oooo803o
ool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`2?0?ooo`80<ol000@0<`3o
0?l0000co`00<ol0o`3ooolO0?ooo`030000003oool0oooo0100oooo001E0?ooo`<00000T03oool2
03?o000403<0o`3o0000<ol003?o0?l0oooo703oool300000180oooo001E0?ooo`030000003oool0
oooo0940oooo0P0co`00100c0?l0o`0003?o000co`3o0?oooad0oooo00<000000?ooo`3oool0403o
ool005D0oooo00<000000?ooo`3oool0TP3oool203?o000403<0o`3o0000<ol003?o0?l0oooo703o
ool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`2C0?ooo`80<ol00P0c0?l2
03?o0?l0oooo6`3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`2D0?oo
o`<0<ol000<0<`3o03?o000co`00o`3ooolJ0?ooo`030000003oool0oooo0100oooo001E0?ooo`03
0000003oool0oooo09D0oooo0`0co`000`0c0?l0<ol003?o003o0?oooaT0oooo00<000000?ooo`3o
ool0403oool005D0oooo00<000000?ooo`3oool0UP3oool303?o000403<0o`0co`00<ol003?o0?l0
oooo5`3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`2G0?ooo`<0<ol0
00@0<`3o03?o000co`00<ol0o`3ooolF0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000
003oool0oooo09P0oooo0`0co`00100c0?l0o`0003?o000co`3o0?oooaD0oooo00<000000?ooo`3o
ool0403oool005D0oooo00<000000?ooo`3oool0VP3oool203?o000403<0o`3o0000<ol003?o0?l0
oooo503oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`2K0?ooo`80<ol0
00@0<`3o0?l0000co`00<ol0o`3ooolC0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000
003oool0oooo09`0oooo0P0co`0203<0o`80<ol0o`3ooolB0?ooo`030000003oool0oooo0100oooo
001E0?ooo`030000003oool0oooo09d0oooo0`0co`000`0c0?l0<ol003?o003o0?oooa40oooo00<0
00000?ooo`3oool0403oool005D0oooo0`00002N0?ooo`<0<ol000@0<`3o03?o000co`00<ol0o`3o
ool=0?ooo`<000004P3oool005D0oooo00<000000?ooo`3oool0W`3oool303?o000403<0o`0co`00
<ol003?o0?l0oooo3P3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`2P
0?ooo`<0<ol000@0<`3o03?o000co`00<ol0o`3oool=0?ooo`030000003oool0oooo0100oooo001E
0?ooo`030000003oool0oooo0:80oooo0P0co`00100c0?l0<ol003?o000co`3o0?ooo``0oooo00<0
00000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0X`3oool203?o000403<0o`0co`00
<ol003?o0?l0oooo2`3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`2T
0?ooo`80<ol000@0<`3o03?o000co`00<ol0o`3oool:0?ooo`030000003oool0oooo0100oooo001E
0?ooo`030000003oool0oooo0:D0oooo0P0co`00100c0?l0<ol003?o000co`3o0?ooo`T0oooo00<0
00000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0YP3oool203?o000403<0o`3o0000
<ol003?o0?l0oooo203oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`2W
0?ooo`80<ol000@0<`3o0?l0000co`00<ol0o`3oool70?ooo`030000003oool0oooo0100oooo001E
0?ooo`030000003oool0oooo0:P0oooo0P0co`00100c0?l0o`0003?o000co`3o0?ooo`H0oooo00<0
00000?ooo`3oool0403oool001L0oooo00<0oknL09cOo`3oool02P3oool00`3OW9`0_ooo0?ooo`0^
0?ooo`030000003oool0oooo0:T0oooo0P0co`0203<0o`80<ol0o`3oool50?ooo`030000003oool0
oooo0100oooo000G0?ooo`030?noM01d_ol0oooo00X0oooo00<0_gAd0;ooo`3oool0;P3oool00`00
0000oooo0?ooo`2Z0?ooo`<0<ol000<0<`3o03?o000co`00o`3oool40?ooo`030000003oool0oooo
0100oooo000G0?ooo`030?noM0000000000000X0000000<0001d0;ooo`3oool0;P3oool00`000000
oooo0?ooo`2[0?ooo`<0<ol000<0<`3o03?o000co`00o`3oool30?ooo`030000003oool0oooo0100
oooo000G0?ooo`030?noM0000000000000X0000000<0001d0;ooo`3oool0;P3oool300000:`0oooo
0`0co`000`0c0?l0<ol003?o003o0?ooo`<000004P3oool001L0oooo00<0okmd07Boo`3oool02P3o
ool00`2oM7@0_ooo0?ooo`0^0?ooo`030000003oool0oooo0:d0oooo0`0co`00100c0?l0o`0003?o
000co`3o0?ooo`030000003oool0oooo0100oooo000G0?ooo`030?noW02Lgol0oooo00X0oooo00<0
_gAd0;ooo`3oool0;P3oool00`000000oooo0?ooo`2^0?ooo`<0<ol000@0<`3o0?l0000co`00<ol0
oP3oool00`000000oooo0?ooo`0@0?ooo`00903oool00`2oM7@0_ooo0?ooo`0^0?ooo`030000003o
ool0oooo0:l0oooo0`0co`00100c0?l0o`0003?o000co`3m0?ooo`030000003oool0oooo0100oooo
000T0?ooo`030;mdM02oool0oooo02h0oooo00<000000?ooo`3oool0/@3oool203?o000403<0o`3o
0000<ol003?o0?`0oooo00<000000?ooo`3oool0403oool002<0oooo00<0oono07@0M02oool0;`3o
ool00`000000oooo0?ooo`2b0?ooo`80<ol000@0<`3o0?l0000co`00<ol0n`3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool0103o_g@000000000M02oool_0?ooo`030000003oool0oooo0;<0oooo
0P0co`00100c0?l0o`0003?o000co`3j0?ooo`030000003oool0oooo0100oooo000Q0?ooo`030;md
000004P0W=oo0340oooo00<000000?ooo`3oool0]03oool203?o000403<0o`3o0000<ol003?o0?T0
oooo00<000000?ooo`3oool0403oool003h0oooo00<0okmd0000001d_ol01@3oool0102oM0000000
00000018W=l;0?ooo`030000003oool0oooo0;D0oooo0P0co`0203<0o`030?l0000co`00<ol00?L0
oooo00<000000?ooo`3oool0403oool003h0oooo00<0okmd0000001d_ol00`3oool01`3ooml0W4P0
001d_`3oool0oooO09a80000M;l02P3oool00`000000oooo0?ooo`2f0?ooo`<0<ol000@0<`3o0?l0
000co`00<ol0mP3oool00`000000oooo0?ooo`0@0?ooo`007@3oool00`3ooml0W4P0000000020000
0003001d_`3oool0oooo01T0oooo00<0okmd0000001d_ol00`3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00T0oooo00<000000?ooo`3oool0]`3oool303?o000403<0o`3o0000<ol0
03?o0?D0oooo00<000000?ooo`3oool0403oool001`0oooo00<0okmd000000000000100000000`00
07@0_ooo0?ooo`0C0?ooo`030=nLB0000000000000D0000000H0001809cOo`3ooml0W4P00018W03O
ool20?ooo`030?oog`2LB00007Bo00T0oooo00<000000?ooo`3oool0^@3oool203?o000303<0o`3o
0000<ol00080<ol0l`3oool00`000000oooo0?ooo`0@0?ooo`006`3oool00`3ookl0M01809cOo`04
0?ooo`030?noM000000007Bo01@0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`02
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0203oool00`000000oooo0?ooo`2j
0?ooo`80<ol000<0<`3o0?l0000co`000P0co`3b0?ooo`030000003oool0oooo0100oooo000K0?oo
o`030?noM01d_ol0oooo00D0oooo00<0oooO09a8M02oool0503oool01`3OW4P0M;oo0?ooo`3oool0
okmd0000001d_ol00P3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00P0oooo00<0
00000?ooo`3oool0^`3oool203?o000303<0o`3o0000<ol00080<ol0l@3oool00`000000oooo0?oo
o`0@0?ooo`006`3oool00`3o_g@0B9cO0?ooo`060?ooo`030;mdM02oool0oooo01<0oooo00L0oono
07@0M02oool0oooo0?noM0000000M;oo0080oooo00<0omnL04P00018W=l0103oool00`3OW4P00018
09cOo`080?ooo`@00000_03oool00`0co`00<`3o0?l0000403?o0>`0oooo1000000B0?ooo`006`3o
ool0103ookl0M0000018W03Oool40?ooo`030?noM000M;l0oooo01D0oooo00H0okmd001d_`3oool0
okmd0000001d_ol20?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0203oool00`00
0000oooo0?ooo`2n0?ooo`0303?o000c0?l0o`0000<0<ol0k`3oool00`000000oooo0?ooo`0@0?oo
o`00703oool00`3o_g@0000000000004000000030000M02oool0oooo01H0oooo00D0_g@007Boo`3o
_g@0000007Boo`020?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0203oool00`00
0000oooo0?ooo`2o0?ooo`0403?o000c0?l0<`3o0?l00?00oooo00<000000?ooo`3oool0403oool0
01d0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0G0?ooo`050?oo_`1d07@0_kmd
0000001d_ol00`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0oooo00<00000
0?ooo`3oool0`@3oool00`0co`00<`3o0?l0003_0?ooo`030000003oool0oooo0100oooo000m0?oo
o`040?noM0000000000007Boo`<0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`09
0?ooo`030000003oool0oooo0<<0oooo00<0<`3o0?l0003oool0k@3oool00`000000oooo0?ooo`0@
0?ooo`009@3oool0103ogi`0B0000000001d_olD0?ooo`040?oog`2LB000000007Boo`@0oooo00H0
_g@00018W03Oool0oooo0;md0000M;l:0?ooo`030000003oool0oooo0<@0oooo00<0<`3o0?l0003o
ool0k03oool00`000000oooo0?ooo`0@0?ooo`00703oool03P3ooml0W4P000000000000007Bo0?oo
g`2LB000000004RL_`2LM9`0gooo0=nLB000B9`0gooo503oool00`3ogi`0B00007Boo`050?ooo`04
0;md000000000000001d_`/0oooo00<000000?ooo`3oool0a@3oool00`0c0?l0o`000?ooo`3[0?oo
o`030000003oool0oooo0100oooo000K0?ooo`030?oog`2LB000000000<0000000T0B7BL0;oOo`3O
W4P0001809cOo`3oool0omnL04P0B02Lgol0:`3oool00`000000oooo0?ooo`360?ooo`0303<0o`3o
0000oooo0>X0oooo00<000000?ooo`3oool0403oool001/0oooo00<0omnL04Qd_`3oool00P3oool0
2P3ogi`0B4RL0=ooo`3o_g@0001d0;ooo`3oool0oono07@0001d_ol[0?ooo`030000003oool0oooo
0<L0oooo00<0<`3o0?l0003oool0j@3oool00`000000oooo0?ooo`0@0?ooo`006`3oool00`3o_i`0
W=oo0?ooo`030?ooo`090=nLW02oool0okmd0000B02Lgol0oooo0?oog`2LB000M;oo02/0oooo00<0
00000?ooo`3oool0b03oool00`0c0?l0o`000?ooo`3X0?ooo`030000003oool0oooo0100oooo000K
0?ooo`030?oOW018B9`0gooo0080oooo00X0oooO09adW03Oool0okmd0000B02Lgol0oooo0?oo_`1d
04P0W=oo:`3oool00`000000oooo0?ooo`390?ooo`80<`3oj03oool00`000000oooo0?ooo`0@0?oo
o`00703oool00`2oM0000000000000020000000904RLg`3oool0okmd0000B02Lgol0oooo0?oOW018
B9`0gooo02/0oooo00<000000?ooo`3oool0b`3oool00`0c0?l0oooo0?ooo`3U0?ooo`030000003o
ool0oooo0100oooo000L0?ooo`050;md00000000000000000018W=l00P3oool01P3ogi`0B00007Bo
o`3ooml0W4Q809cOob`0oooo00<000000?ooo`3oool0c03oool00`0c0?l0oooo0?ooo`3T0?ooo`03
0000003oool0oooo0100oooo000L0?ooo`030;mdM02oool0oooo00D0oooo00@0gia80000000004P0
W=oo;@3oool300000<d0oooo00<0<`3o0?ooo`3oool0h@3oool300000180oooo001E0?ooo`030000
003oool0oooo0<h0oooo00<0<`3o0?l0003oool0hP3oool00`000000oooo0?ooo`0@0?ooo`00E@3o
ool00`000000oooo0?ooo`3?0?ooo`0303<0o`3o0000oooo0>40oooo00<000000?ooo`3oool0403o
ool001`0oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0_0?ooo`030000003oool0
oooo0=00oooo00<0<`3o0?l0003oool0h03oool00`000000oooo0?ooo`0@0?ooo`006P3oool00`3O
W4P0000000000008000000030000B02Lgol0oooo02d0oooo00<000000?ooo`3oool0d@3oool203<0
on00oooo00<000000?ooo`3oool0403oool001T0oooo00@0_g@0000000000000M;oo1`3oool0102o
M000000000000018W=l]0?ooo`030000003oool0oooo0=<0oooo00<0<`3o0?ooo`3oool0g@3oool0
0`000000oooo0?ooo`0@0?ooo`00603oool00`2oM00007Bo0?ooo`0;0?ooo`030?oog`2LB000B9cO
02`0oooo00<000000?ooo`3oool0e03oool00`0c0?l0oooo0?ooo`3L0?ooo`030000003oool0oooo
0100oooo000G0?ooo`030?noM01d_ol0oooo00h0oooo00<0giad09cOo`3oool0:P3oool00`000000
oooo0?ooo`3E0?ooo`0303<0o`3oool0oooo0=/0oooo00<000000?ooo`3oool0403oool005D0oooo
00<000000?ooo`3oool0eP3oool00`0c0?l0oooo0?ooo`3J0?ooo`030000003oool0oooo0100oooo
000G0?ooo`030?noW02Lgol0oooo00X0oooo00<0gibL0;ooo`3oool0;P3oool00`000000oooo0?oo
o`3G0?ooo`0303<0o`3oool0oooo0=T0oooo00<000000?ooo`3oool0403oool001L0oooo00<0okmd
07Boo`3oool02P3oool00`2oM7@0_ooo0?ooo`0^0?ooo`030000003oool0oooo0=P0oooo00<0<`3o
0?ooo`3oool0f03oool00`000000oooo0?ooo`0@0?ooo`005`3oool00`3o_g@000000000000:0000
00030000M02oool0oooo02h0oooo00<000000?ooo`3oool0f@3oool00`0c0?l0oooo0?ooo`3G0?oo
o`030000003oool0oooo0100oooo000G0?ooo`030?noM0000000000000X0000000<0001d0;ooo`3o
ool0;P3oool00`000000oooo0?ooo`3J0?ooo`80<`3oe`3oool00`000000oooo0?ooo`0@0?ooo`00
5`3oool00`3o_g@0M;oo0?ooo`030?ooo`030?oOW01dW=l0oooo00<0oooo00<0oooO09a8M02oool0
;`3oool300000=/0oooo00<0o`0003<0o`3oool0d`3oool300000180oooo000G0?ooo`030?noM01d
_ol0oooo00<0oooo00<0omnL07BLg`3oool0103oool00`3OW9`0_ooo0?ooo`0^0?ooo`030000003o
ool0oooo0=d0oooo00<0<`3o0?ooo`3oool0d`3oool00`000000oooo0?ooo`0@0?ooo`005`3oool0
0`3o_g@0M;oo0?ooo`030?ooo`030?oOW01dW=l0oooo03D0oooo00<000000?ooo`3oool0gP3oool0
0`0c0?l0oooo0?ooo`3B0?ooo`030000003oool0oooo0100oooo000G0?ooo`030?noM01d_ol0oooo
00<0oooo00<0okmd04RLg`3oool0=@3oool00`000000oooo0?ooo`3O0?ooo`0303<0o`3oool0oooo
0=40oooo00<000000?ooo`3oool0403oool001L0oooo00H0okmd07Boo`3oool0oooo0?oo_`1d0003
0000000307Boo`3oool0oooo0380oooo00<000000?ooo`3oool0h03oool00`0c0?l0oooo0?ooo`3@
0?ooo`030000003oool0oooo0100oooo000G0?ooo`030?noM00007@0_ooo03/0oooo00<000000?oo
o`3oool0h@3oool00`0c0?l0oooo0?ooo`3?0?ooo`030000003oool0oooo0100oooo000G0?ooo`04
0?noM0000000000004RLgcX0oooo00<000000?ooo`3oool0hP3oool00`0c0?l0oooo0?ooo`3>0?oo
o`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0><0oooo0P0c0?o>0?ooo`03
0000003oool0oooo0100oooo000L0?ooo`030?noM0000000000000@0000000<0001d0;ooo`3oool0
;`3oool00`000000oooo0?ooo`3T0?ooo`030?l0000c0?l0oooo0<`0oooo00<000000?ooo`3oool0
403oool001X0oooo00<0gia8000000000000200000000`0004P0W=oo0?ooo`0]0?ooo`030000003o
ool0oooo0>H0oooo00<0<`3o0?ooo`3oool0bP3oool00`000000oooo0?ooo`0@0?ooo`006@3oool0
102oM00000000000001d_ol70?ooo`040;md00000000000004RLgbd0oooo00<000000?ooo`3oool0
i`3oool00`0c0?l0oooo0?ooo`390?ooo`030000003oool0oooo0100oooo000H0?ooo`030;md0000
M;l0oooo00/0oooo00<0oooO09a80018W=l0;03oool00`000000oooo0?ooo`3X0?ooo`0303<0o`3o
ool0oooo0<P0oooo00<000000?ooo`3oool0403oool001L0oooo00<0okmd07Boo`3oool03P3oool0
0`3OW7@0W=oo0?ooo`0Z0?ooo`030000003oool0oooo0>T0oooo00<0<`3o0?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0@0?ooo`005`3oool00`3o_i`0W=oo0?ooo`0k0?ooo`<00000jP3oool00`0c
0?l0oooo0?ooo`340?ooo`<000004P3oool001L0oooo00<0okmd07Boo`3oool02P3oool00`3OW9`0
_ooo0?ooo`0^0?ooo`030000003oool0oooo0>/0oooo00<0<`3o0?ooo`3oool0a@3oool00`000000
oooo0?ooo`0@0?ooo`005`3oool00`3o_g@004RL0=ooo`0:0?ooo`030;mdM02oool0oooo02h0oooo
00<000000?ooo`3oool0k03oool203<0olD0oooo00<000000?ooo`3oool0403oool001L0oooo00<0
okmd0000000000002P0000000`0007@0_ooo0?ooo`0^0?ooo`030000003oool0oooo0>h0oooo00<0
<`3o0?ooo`3oool0`P3oool00`000000oooo0?ooo`0@0?ooo`00603oool0102oM00000000000B02L
gol80?ooo`030;mdM02oool0oooo02h0oooo00<000000?ooo`3oool0k`3oool00`0c0?l0oooo0?oo
o`310?ooo`030000003oool0oooo0100oooo000I0?ooo`040=nLB0000000000007Boo`L0oooo00<0
gibL0;ooo`3oool0;P3oool00`000000oooo0?ooo`3`0?ooo`0303<0o`3oool0oooo0<00oooo00<0
00000?ooo`3oool0403oool001X0oooo00@0okmd00000000000007Bo=`3oool00`000000oooo0?oo
o`3a0?ooo`0303<0o`3oool0oooo0;l0oooo00<000000?ooo`3oool0403oool001/0oooo00D0omnL
04P00000000004RL0=ooo`0K0?ooo`060?oog`2LB00000000000000007@0_ooo1@3oool0102oM000
000000000018W=l;0?ooo`030000003oool0oooo0?80oooo00<0<`3o0?l0003oool0_P3oool00`00
0000oooo0?ooo`0@0?ooo`00703oool01@3ookl0M0000000000004P0W=oo01T0oooo00P0oono07@0
0000B9`0gooo0?ooo`3OW4P0001809cOo`80oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo
00X0oooo00<000000?ooo`3oool0l`3oool00`0c0?l0o`000?ooo`2m0?ooo`030000003oool0oooo
0100oooo000M0?ooo`050?oog`2LB00000000000001d_ol0603oool00`2oM000001d0;ooo`030?oo
o`070;md0000M;l0oooo0?ooo`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00T0oooo00<0
00000?ooo`3oool0m03oool00`0c0?l0o`000?ooo`2l0?ooo`030000003oool0oooo0100oooo000G
0?ooo`030?noW02Lgol0oooo00D0oooo00@0_g@000000000000007Bo5P3oool00`3ookl0M000001d
_`040?ooo`070=nLB00007@0_ooo0?oog`2LB00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0
oooo00<000000?ooo`3oool0m@3oool203<0ok`0oooo00<000000?ooo`3oool0403oool001L0oooo
00<0okmd07Boo`3oool01P3oool01@3OW4P0000000000000B9`0gooo01@0oooo00<0omnL04P00018
W=l0103oool01P2oM000001809cOo`3ookl0M000001d_`@0oooo00<0_g@00000M02oool0203oool0
0`000000oooo0?ooo`3g0?ooo`0303<0o`3oool0oooo0;T0oooo00<000000?ooo`3oool0403oool0
01L0oooo00<0okmd0000000000002P0000000`0004P0W=oo0?ooo`0B0?ooo`030?oOW0180000B9cO
00<0oooo00L0oono07@0000007@0_ooo0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0203o
ool00`000000oooo0?ooo`3h0?ooo`0303<0o`3o0000oooo0;P0oooo00<000000?ooo`3oool0403o
ool001L0oooo00<0okmd07Boo`3oool07`3oool03@3ookl0M00000000000B9`0gooo0?ooo`2oM000
000004RLg`3oool0omnL04P00018W=l0103oool00`3OW4P0001809cOo`080?ooo`@00000n03oool0
0`0c0?l0o`000?ooo`2d0?ooo`@000004P3oool001L0oooo00<0oknL09cOo`3oool07`3oool01@3o
oml0W4P00000M02ogi`0B0000080000000H0B9cO0?ooo`3oool0omnL04P00018W=l40?ooo`030=nL
B00004P0W=oo00P0oooo00<000000?ooo`3oool0nP3oool00`0c0?l0o`000?ooo`2f0?ooo`030000
003oool0oooo0100oooo000G0?ooo`030?noM01d_ol0oooo00h0oooo00<0_gA809cOo`3oool03`3o
ool00`3o_g@0000004RLg`060?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0203o
ool00`000000oooo0?ooo`3k0?ooo`0303<0o`3o0000oooo0;D0oooo00<000000?ooo`3oool0403o
ool001P0oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P007Boo`0A0?ooo`040?oog`2LB000
001809cOo`H0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`090?ooo`030000003o
ool0oooo0?`0oooo00<0<`3o0?l0003oool0]03oool00`000000oooo0?ooo`0@0?ooo`006@3oool0
102oM00000000000001d_ol70?ooo`040;md00000000000004RLga<0oooo00@0oono07@0000007@0
_ooo1@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00T0oooo00<000000?ooo`3o
ool0o@3oool00`0c0?l0o`000?ooo`2c0?ooo`030000003oool0oooo0100oooo000J0?ooo`030=nL
B0000000000000P0000000<0001809cOo`3oool0503oool0103ooml0W4P000000000M;l50?ooo`06
0;md0000B9`0gooo0?ooo`2oM00007Bo2P3oool00`000000oooo0?ooo`3n0?ooo`80<`3o00<0o`00
0?ooo`3oool0/03oool00`000000oooo0?ooo`0@0?ooo`00703oool00`3o_g@00000000000040000
00030000M02oool0oooo01P0oooo00D0omnL04P00000000004RL0=ooo`030?ooo`040;md00000000
0000001d_`/0oooo00<000000?ooo`3oool0o`3oool10?ooo`0303<0o`3o0000oooo0;00oooo00<0
00000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3oool20?ooo`0303<0o`3o0000
oooo0:l0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3oool30?oo
o`0303<0o`3o0000oooo0:h0oooo00<000000?ooo`3oool0403oool001L0oooo00<0okmd07Boo`3o
ool03P3oool00`2oM4P0W=oo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo103oool00`0c0?l0
o`000?ooo`2]0?ooo`030000003oool0oooo0100oooo000H0?ooo`030;md0000M;l0oooo00/0oooo
00<0oooO09a8001d_ol0;03oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<0<`3o0?l0000co`00
[03oool00`000000oooo0?ooo`0@0?ooo`006@3oool0102oM00000000000001d_ol70?ooo`040;md
00000000000004RLgbd0oooo00<000000?ooo`3oool0o`3oool60?ooo`0303<0o`3o0000<ol00:/0
oooo00<000000?ooo`3oool0403oool001X0oooo00<0gia8000000000000200000000`0004P0W=oo
0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo1@3oool203?o0080<`3o00<0o`0003?o003oool0
Z03oool00`000000oooo0?ooo`0@0?ooo`00703oool00`3o_g@0000000000004000000030000M02o
ool0oooo02l0oooo0`00003o0?ooo`H0oooo0`0co`000`0c0?l0o`0003?o002V0?ooo`<000004P3o
ool005D0oooo00<000000?ooo`3oool0o`3oool70?ooo`<0<ol000@0<`3o0?l0000co`00<ol0YP3o
ool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo0P0co`00
100c0?l0o`0003?o000co`2U0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0
oooo0?l0oooo2P3oool203?o000403<0o`3o0000<ol003?o0:@0oooo00<000000?ooo`3oool0403o
ool005D0oooo00<000000?ooo`3oool0o`3oool<0?ooo`0303?o000c0?l0o`000080<ol0X`3oool0
0`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooo``0oooo0P0co`0203<0
o`030?l0000co`00oooo0:40oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3o
ool0o`3oool=0?ooo`<0<ol000@0<`3o0?l0000co`00<ol0X03oool00`000000oooo0?ooo`0@0?oo
o`00E@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo0P0co`00100c0?l0o`0003?o000co`2O0?oo
o`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0oooo403oool203?o0080
<`3o0`0co`2M0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0oooo
4P3oool203?o000403<0o`0co`00<ol003?o09`0oooo00<000000?ooo`3oool0403oool005D0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`80<ol000@0<`3o0?l0000co`00<ol0V`3oool00`000000
oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<0<ol003<0o`3o0000
0P0co`2J0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0oooo5@3o
ool203?o0080<`3o0P0co`2I0?ooo`030000003oool0oooo0100oooo001E0?ooo`<00000o`3ooolF
0?ooo`<0<ol000@0<`3o03?o000co`00<ol0U@3oool300000180oooo001E0?ooo`030000003oool0
oooo0?l0oooo603oool203?o000403<0o`0co`00<ol003?o09H0oooo00<000000?ooo`3oool0403o
ool005D0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`80<ol00P0c0?l203?o09D0oooo00<00000
0?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`80<ol000<0<`3o03?o
000co`00U03oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o0?oooa/0
oooo0`0co`000`0c0?l0<ol003?o002C0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000
003oool0oooo0?l0oooo703oool303?o000403<0o`0co`00<ol003?o0940oooo00<000000?ooo`3o
ool0403oool005D0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`80<ol00P0c0?l203?o0900oooo
00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`<0<ol000@0
<`3o03?o000co`00<ol0SP3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooob40oooo0P0co`00100c0?l0<ol003?o000co`2=0?ooo`030000003oool0oooo0100oooo
001E0?ooo`030000003oool0oooo0?l0oooo8P3oool203?o0080<`3o0P0co`2<0?ooo`030000003o
ool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0oooo903oool203?o000303<0o`0co`00
<ol008/0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`<0<ol000<0<`3o03?o000co`00RP3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000
oooo0?ooo`3o0?ooobD0oooo0`0co`0203<0o`80<ol0R03oool00`000000oooo0?ooo`0@0?ooo`00
E@3oool300000?l0oooo9`3oool303?o000303<0o`0co`00<ol008D0oooo0`00000B0?ooo`00E@3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo0`0co`00100c0?l0<ol003?o000co`250?ooo`030000
003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0oooo:P3oool203?o0080<`3o0P0c
o`240?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0oooo:`3oool3
03?o000303<0o`0co`00<ol008<0oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?oo
o`3oool0o`3oool]0?ooo`80<ol000<0<`3o03?o000co`00PP3oool00`000000oooo0?ooo`0@0?oo
o`00E@3oool00`000000oooo0?ooo`3o0?ooobd0oooo0`0co`0203<0o`0303?o003oool0oooo07l0
oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3oool^0?ooo`<0<ol0
00@0o`0003<0o`0co`00<ol0O`3oool00`000000oooo0?ooo`0@0?ooo`00>`3oool01P3ogi`0B000
000000000000001809cOo`D0oooo00@0_g@0000000000000B9cO2`3oool00`000000oooo0?ooo`3o
0?oooc00oooo0`0co`000`0c0?l0<ol003?o001n0?ooo`030000003oool0oooo0100oooo000j0?oo
o`080?oOW018000004RL0=ooo`3oool0omnL04P0001d_ol20?ooo`070?oog`2LB00007Bo0?ooo`3o
oml0W4P0001d_`0:0?ooo`030000003oool0oooo0?l0oooo<@3oool303?o0080<`3o0P0co`1l0?oo
o`030000003oool0oooo0100oooo000j0?ooo`030;md000007@0_ooo00<0oooo00L0gia80018W03O
ool0oooo0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`3o
0?oooc<0oooo0P0co`00103o0000<`3o03?o000co`1k0?ooo`030000003oool0oooo0100oooo000j
0?ooo`030;md000007@0_ooo00<0oooo00L0_g@00018W03Oool0oooO09a80000B9`0gooo0080oooo
00<0oooO09a80000M;l02@3oool00`000000oooo0?ooo`3o0?oooc@0oooo0`0co`0203<0o`0303?o
003oool0oooo07P0oooo00<000000?ooo`3oool0403oool003X0oooo00<0okmd0000B02Lgol00P3o
ool01`3OW4P00000001d_`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`080?ooo`03
0000003oool0oooo0?l0oooo=P3oool203?o00030?l0000c0?l0<ol007T0oooo00<000000?ooo`3o
ool0403oool003/0oooo00/0gia8001d_`3oool0_g@00000000007@0_ooo0?ooo`3ogi`0B00004RL
g`040?ooo`030;md000007@0_ooo00P0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`<0<ol000<0
o`0003<0o`0c0?l0N03oool00`000000oooo0?ooo`0@0?ooo`00?03oool01@3o_g@0000000000000
B9`0gooo0080oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`080?ooo`@00000o`3o
oolf0?ooo`<0<ol00P3o00000`0c0?l0<ol00?ooo`1b0?ooo`@000004P3oool003/0oooo00D0omnL
04P000000000000004RLg`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0203o
ool00`000000oooo0?ooo`3o0?ooocT0oooo0`0co`000`3o0000<`3o03?o001e0?ooo`030000003o
ool0oooo0100oooo000j0?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`020?ooo`030?oo
_`1d000007Bo00@0oooo00<0_g@00000M02oool0203oool00`000000oooo0?ooo`3o0?ooocX0oooo
0`0co`00103o0000<`3o03<0o`0co`1c0?ooo`030000003oool0oooo0100oooo000j0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a8001d_ol00P3oool00`2oM00004RL0=ooo`020?ooo`030?oo
g`2LB00007Bo00T0oooo00<000000?ooo`3oool0o`3oooll0?ooo`80<ol00P3o00000`0c0?l0<ol0
0?ooo`1a0?ooo`030000003oool0oooo0100oooo000j0?ooo`030=nLB000B9`0gooo0080oooo00<0
oooO09a80018W=l00P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00T0oooo00<0
00000?ooo`3oool0o`3ooolm0?ooo`<0<ol000@0o`0003<0o`0co`00<ol0L03oool00`000000oooo
0?ooo`0@0?ooo`00>P3oool00`3ogi`0B00004RLg`020?ooo`030?noM00004P0W=oo00<0oooo00H0
_g@00018W03Oool0oooo0;md0000M;l:0?ooo`030000003oool0oooo0?l0oooo?`3oool203?o0004
0?l0000c0?l0<`3o03?o06l0oooo00<000000?ooo`3oool0403oool003/0oooo00H0oono07@00000
000000000000B02Lgol50?ooo`040;md000000000000001d_`/0oooo00<000000?ooo`3oool0o`3o
oom00?ooo`80<ol00P3o00000`0c0?l0<ol00?ooo`1]0?ooo`030000003oool0oooo0100oooo001E
0?ooo`030000003oool0oooo0?l0oooo@@3oool303?o00040?l0000c0?l0<ol003?o06`0oooo00<0
00000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3ooom30?ooo`80<ol000@0o`00
03<0o`0co`00<ol0J`3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o
0?oood@0oooo0P0co`000`3o0000<`3o03?o000203?o06T0oooo00<000000?ooo`3oool0403oool0
05D0oooo00<000000?ooo`3oool0o`3ooom60?ooo`80<ol00P0c0?l203?o06P0oooo00<000000?oo
o`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3ooom70?ooo`80<ol000@0o`0003<0o`0c
o`00<ol0I`3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooodT0
oooo00<0<ol00?l0000c0?l00P0co`1V0?ooo`030000003oool0oooo0100oooo001E0?ooo`<00000
o`3ooom90?ooo`<0<ol000<0<`3o03?o000co`00H`3oool300000180oooo001E0?ooo`030000003o
ool0oooo0?l0ooooBP3oool303?o000303<0o`3o0000<ol006@0oooo00<000000?ooo`3oool0403o
ool005D0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`<0<ol00P0c0?l00`0co`00oooo0?ooo`1Q
0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0ooooC03oool403?o
000303<0o`0co`00oooo0640oooo00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3o
ool0o`3ooom=0?ooo`@0<ol000<0<`3o0?l0003oool0H03oool00`000000oooo0?ooo`0@0?ooo`00
E@3oool00`000000oooo0?ooo`3o0?ooodh0oooo0P0co`020?ooo`0303<0o`3o0000oooo05l0oooo
00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`80<`3oG`3o
ool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<0<`3o
0?l0003oool0G03oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o0?oo
oeH0oooo00<0<`3o0?l0003oool0F`3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000
oooo0?ooo`3o0?oooeL0oooo0P0c0?mK0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000
003oool0oooo0?l0ooooF@3oool00`0c0?l0o`000?ooo`1H0?ooo`030000003oool0oooo0100oooo
001E0?ooo`030000003oool0oooo0?l0ooooFP3oool203<0oeP0oooo00<000000?ooo`3oool0403o
ool005D0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`80<`3oEP3oool00`000000oooo0?ooo`0@
0?ooo`00E@3oool300000?l0ooooGP3oool00`0c0?l0o`000?ooo`1A0?ooo`<000004P3oool005D0
oooo00<000000?ooo`3oool0o`3ooomO0?ooo`0303<0o`3o0000oooo0580oooo00<000000?ooo`3o
ool0403oool005D0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`0303<0o`3o0000oooo0540oooo
00<000000?ooo`3oool0403oool005D0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`@0<`3oC`3o
ool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooof@0oooo00<0o`00
03<0o`0c0?l00`0c0?m:0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo
0?l0ooooIP3oool20?l00080oooo100c0?m60?ooo`030000003oool0oooo0100oooo001E0?ooo`03
0000003oool0oooo0?l0ooooJ03oool20?l000@0oooo100c0?m20?ooo`030000003oool0oooo0100
oooo001E0?ooo`030000003oool0oooo0?l0ooooJP3oool20?l000H0oooo1@0c0?lm0?ooo`030000
003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0ooooK03oool30?l000P0oooo1@0c
0?lh0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0ooooK`3oool3
0?l000X0oooo100c0?ld0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo
0?l0ooooLP3oool30?l000/0oooo1@0c0?l_0?ooo`030000003oool0oooo0100oooo001E0?ooo`03
0000003oool0oooo0?l0ooooM@3oool40?l000`0oooo1@0c0?lZ0?ooo`030000003oool0oooo0100
oooo001E0?ooo`030000003oool0oooo0?l0ooooN@3oool40?l000d0oooo100c0?lV0?ooo`030000
003oool0oooo0100oooo001E0?ooo`<00000o`3ooomm0?ooo`@0o`003@3oool403<0ob00oooo0`00
000B0?ooo`00E@3oool00`000000oooo0?ooo`3o0?oooh40oooo103o000=0?ooo`@0<`3o7P3oool0
0`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooohD0oooo1@3o000603?o
00H0oooo1@0c0?lI0?ooo`030000003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0
ooooRP3oool40?l000D0<ol0203oool403<0oaD0oooo00<000000?ooo`3oool0403oool005D0oooo
00<000000?ooo`3oool0o`3ooon:0?ooo`@0<ol01@3o000503?o00L0oooo100c0?lA0?ooo`030000
003oool0oooo0100oooo001E0?ooo`030000003oool0oooo0?l0ooooRP3oool903?o00@0o`001P0c
o`060?ooo`@0<`3o3@3oool00`000000oooo0?ooo`0@0?ooo`00E@3oool00`000000oooo0?ooo`3o
0?ooohh0oooo2@0co`040?l000H0<ol01P3oool303<0o`X0oooo00<000000?ooo`3oool0403oool0
0340oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`030?ooo`040;md000000000000
04RLg`H0oooo00@0_g@0000000000000B9cO2`3oool00`000000oooo0?ooo`3o0?oooi40oooo2P0c
o`040?l000H0<ol03`3oool00`000000oooo0?ooo`0@0?ooo`00<`3oool00`2oM000001d0;ooo`04
0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`070?oog`2LB00007Bo0?ooo`3o
oml0W4P0001d_`0:0?ooo`030000003oool0oooo0?l0ooooUP3oool903?o00@0o`001P0co`0;0?oo
o`030000003oool0oooo0100oooo000c0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol02@3oool00`000000oooo0?ooo`3o0?oooi/0oooo200co`040?l000@0<ol02@3oool00`000000
oooo0?ooo`0@0?ooo`00<`3oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB00004RL0=ooo`80
oooo00P0oooO09a80000M;l0oooo0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02@3o
ool00`000000oooo0?ooo`3o0?oooil0oooo200co`030?l0000303?o003oool0oooo00L0oooo00<0
00000?ooo`3oool0403oool003<0oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`04
0?ooo`060;md000007@0_ooo0?oo_`1d000007Bo103oool00`2oM000001d0;ooo`080?ooo`030000
003oool0oooo0?l0ooooX`3oool803?o00T0oooo00<000000?ooo`3oool0403oool003<0oooo00<0
_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`060;md000007@0_ooo0?oOW0180000
B9cO103oool00`2oM000001d0;ooo`080?ooo`030000003oool0oooo0?l0ooooY`3oool403?o00T0
oooo00<000000?ooo`3oool0403oool003<0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B000
04RLg`040?ooo`060=nLB00004P0W=oo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`080?oo
o`@000001P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0100oooo1000000B0?oo
o`00<`3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00H0gia80000B02L
gol0omnL04P00018W=l40?ooo`030=nLB00004P0W=oo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool0
03<0oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`060;md000007@0_ooo
0?oo_`1d000007Bo103oool00`2oM000001d0;ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`00<`3oool00`2oM000001d0;ooo`04
0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l00P3oool00`2oM00004RL0=ooo`02
0?ooo`030?oog`2LB00007Bo00T0ooooo`00002h00000180oooo000c0?ooo`030;md000007@0_ooo
00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`020?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol0o`3ooooC0?ooo`00<@3oool01@3OW4P000000000000007@0_ooo
00D0oooo00H0_g@00018W03Oool0oooo0;md0000M;l40?ooo`060;md0000B9`0gooo0?ooo`2oM000
07Boo`3ooooD0?ooo`00<P3oool0103ookl0M0000000M02oool60?ooo`040;md000000000000001d
_`H0oooo00@0_g@000000000000007Boo`3ooooE0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0
oooo803oool00?l0ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803oool0
0?l0ooooo`3ooolP0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 541.75}, {334.438, 0}} -> {-38.2758, -23.3765, \
0.0863509, 0.382972}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 6\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(pr = 
        ParametricPlot[{Log[
              RN[nn]], \((\(Log[\(-\((fF[N] - 3.0615687034879134`*^39)\)\)] /. 
                  f1\) /. N \[Rule] nn)\)}, {nn, \(-22\), \(-14\)}, 
          PlotRange \[Rule] All, Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.008], 
              Hue[0.3]}];\)\), "\[IndentingNewLine]", 
    \(\(pr1 = 
        ParametricPlot[{Log[
              RN[nn]], \((\(Log[\(-\((fF[N] - 2.1931186765357185`*^39)\)\)] /. 
                  f2\) /. N \[Rule] nn)\)}, {nn, \(-8\), \(-2\)}, 
          PlotRange \[Rule] All, Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.008], Hue[0.3]}];\)\), "\n", 
    \(\(pr2 = 
        ParametricPlot[{Log[
              RN[nn]], \((\(Log[\(-\((fF[N] - 6.832478089303318`*^40)\)\)] /. 
                  f3\) /. N \[Rule] nn)\)}, {nn, 3, 6}, 
          PlotRange \[Rule] All, Frame \[Rule] True, Axes \[Rule] False, 
          DisplayFunction \[Rule] Identity, 
          PlotStyle \[Rule] {Thickness[0.008], 
              Hue[0.3]}];\)\), "\[IndentingNewLine]", 
    \(\(qq = 
        Table[{Log[RN[N]], Log[\(-fNacc[N]\)]}, {N, \(-24.3\), \(-1\), 
            2.5}];\)\), "\n", 
    \(pr3 = 
      ListPlot[qq, PlotJoined \[Rule] True, PlotStyle \[Rule] Hue[ .7], 
        DisplayFunction \[Rule] Identity]; Clear[qq];\), "\n", 
    \(\(pr4 = 
        ParametricPlot[{Log[RN[N]], Log[\(-fN[N]\)]}, {N, \(-24.6\), \(-2\)}, 
          PlotRange \[Rule] {{0, 80}, {85, 100}}, Frame \[Rule] True, 
          PlotStyle \[Rule] Hue[0], Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<Log(R)\>", "\<Log(-f(R))\>"}, 
          DisplayFunction \[Rule] Identity];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{"(*", " ", 
      RowBox[{
        StyleBox["Numeric",
          FontColor->RGBColor[1, 0, 0]], " ", "-", " ", 
        StyleBox["Semi",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["-",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["analytic",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[" ",
        FontColor->RGBColor[0, 0, 1]], "*)"}]], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Note\ that\ f[R]\ below\ is\ in\ units\ H\_0^2\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig6f = 
        Show[pr, pr1, pr2, pr3, pr4, 
          DisplayFunction \[Rule] $DisplayFunction, 
          PlotRange \[Rule] {{3, 80}, {86, 96}}, 
          FrameLabel \[Rule] {"\<Log(R)\>", "\<Log(-f(R))\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig6_f\>" <> "\<.m\>", fig6f];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.038961 0.012987 -5.31509 0.0618034 [
[.09091 -0.0125 -12.0625 -24.5625 ]
[.09091 -0.0125 12.0625 0 ]
[.22078 -0.0125 -12.0625 -24.5625 ]
[.22078 -0.0125 12.0625 0 ]
[.35065 -0.0125 -12.0625 -24.5625 ]
[.35065 -0.0125 12.0625 0 ]
[.48052 -0.0125 -12.0625 -24.5625 ]
[.48052 -0.0125 12.0625 0 ]
[.61039 -0.0125 -12.0625 -24.5625 ]
[.61039 -0.0125 12.0625 0 ]
[.74026 -0.0125 -12.0625 -24.5625 ]
[.74026 -0.0125 12.0625 0 ]
[.87013 -0.0125 -12.0625 -24.5625 ]
[.87013 -0.0125 12.0625 0 ]
[1 -0.0125 -12.0625 -24.5625 ]
[1 -0.0125 12.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -31.4063 -49.125 ]
[.5 -0.0125 31.4063 -24.5625 ]
[-0.0125 .12361 -24.125 -12.2813 ]
[-0.0125 .12361 0 12.2813 ]
[-0.0125 .24721 -24.125 -12.2813 ]
[-0.0125 .24721 0 12.2813 ]
[-0.0125 .37082 -24.125 -12.2813 ]
[-0.0125 .37082 0 12.2813 ]
[-0.0125 .49443 -24.125 -12.2813 ]
[-0.0125 .49443 0 12.2813 ]
[-0.0125 .61803 -24.125 -12.2813 ]
[-0.0125 .61803 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -48.6875 -48.75 ]
[-0.01875 .30902 -24.125 48.75 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .00625 L
s
gsave
.09091 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.22078 0 m
.22078 .00625 L
s
gsave
.22078 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.35065 0 m
.35065 .00625 L
s
gsave
.35065 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.48052 0 m
.48052 .00625 L
s
gsave
.48052 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.61039 0 m
.61039 .00625 L
s
gsave
.61039 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.74026 0 m
.74026 .00625 L
s
gsave
.74026 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.87013 0 m
.87013 .00625 L
s
gsave
.87013 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.11688 0 m
.11688 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.16883 0 m
.16883 .00375 L
s
.19481 0 m
.19481 .00375 L
s
.24675 0 m
.24675 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.2987 0 m
.2987 .00375 L
s
.32468 0 m
.32468 .00375 L
s
.37662 0 m
.37662 .00375 L
s
.4026 0 m
.4026 .00375 L
s
.42857 0 m
.42857 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.50649 0 m
.50649 .00375 L
s
.53247 0 m
.53247 .00375 L
s
.55844 0 m
.55844 .00375 L
s
.58442 0 m
.58442 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.66234 0 m
.66234 .00375 L
s
.68831 0 m
.68831 .00375 L
s
.71429 0 m
.71429 .00375 L
s
.76623 0 m
.76623 .00375 L
s
.79221 0 m
.79221 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.84416 0 m
.84416 .00375 L
s
.8961 0 m
.8961 .00375 L
s
.92208 0 m
.92208 .00375 L
s
.94805 0 m
.94805 .00375 L
s
.97403 0 m
.97403 .00375 L
s
.06494 0 m
.06494 .00375 L
s
.03896 0 m
.03896 .00375 L
s
.01299 0 m
.01299 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -92.4063 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.375 23.000 moveto
(H) show
101.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.375 23.000 moveto
(L) show
121.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(88) show
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(92) show
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(94) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -85.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(96) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -146.156 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
109.75 16.2813 translate
90 rotate
-109.75 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.375 23.000 moveto
(H) show
101.813 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
114.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.625 23.000 moveto
(H) show
130.063 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.625 23.000 moveto
(L) show
150.063 23.000 moveto
(L) show
156.500 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09091 .61178 m
.09091 .61803 L
s
.22078 .61178 m
.22078 .61803 L
s
.35065 .61178 m
.35065 .61803 L
s
.48052 .61178 m
.48052 .61803 L
s
.61039 .61178 m
.61039 .61803 L
s
.74026 .61178 m
.74026 .61803 L
s
.87013 .61178 m
.87013 .61803 L
s
.125 Mabswid
.11688 .61428 m
.11688 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.16883 .61428 m
.16883 .61803 L
s
.19481 .61428 m
.19481 .61803 L
s
.24675 .61428 m
.24675 .61803 L
s
.27273 .61428 m
.27273 .61803 L
s
.2987 .61428 m
.2987 .61803 L
s
.32468 .61428 m
.32468 .61803 L
s
.37662 .61428 m
.37662 .61803 L
s
.4026 .61428 m
.4026 .61803 L
s
.42857 .61428 m
.42857 .61803 L
s
.45455 .61428 m
.45455 .61803 L
s
.50649 .61428 m
.50649 .61803 L
s
.53247 .61428 m
.53247 .61803 L
s
.55844 .61428 m
.55844 .61803 L
s
.58442 .61428 m
.58442 .61803 L
s
.63636 .61428 m
.63636 .61803 L
s
.66234 .61428 m
.66234 .61803 L
s
.68831 .61428 m
.68831 .61803 L
s
.71429 .61428 m
.71429 .61803 L
s
.76623 .61428 m
.76623 .61803 L
s
.79221 .61428 m
.79221 .61803 L
s
.81818 .61428 m
.81818 .61803 L
s
.84416 .61428 m
.84416 .61803 L
s
.8961 .61428 m
.8961 .61803 L
s
.92208 .61428 m
.92208 .61803 L
s
.94805 .61428 m
.94805 .61803 L
s
.97403 .61428 m
.97403 .61803 L
s
.06494 .61428 m
.06494 .61803 L
s
.03896 .61428 m
.03896 .61803 L
s
.01299 .61428 m
.01299 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 1 0 r
.008 w
.81681 .30406 m
.80417 .30406 L
.79038 .30406 L
.77743 .30406 L
.76497 .30406 L
.75172 .30406 L
.73896 .30406 L
.72539 .30406 L
.71232 .30406 L
.69975 .30406 L
.68638 .30406 L
.6735 .30406 L
.66112 .30406 L
.64793 .30406 L
.63524 .30406 L
.62175 .30406 L
.60875 .30406 L
.59626 .30406 L
.58295 .30406 L
.57015 .30407 L
.55654 .30407 L
.54343 .30407 L
.53081 .30408 L
.51739 .30409 L
.50513 .3041 L
s
.27136 .31981 m
.26188 .32291 L
.25153 .3265 L
.24182 .33007 L
.23248 .33369 L
.22254 .33774 L
.21297 .34182 L
.20279 .34635 L
.19299 .35091 L
.18356 .35546 L
.17353 .36047 L
.16387 .36545 L
.15459 .37039 L
.1447 .37578 L
.13518 .38111 L
.12506 .38691 L
.11532 .39261 L
.10594 .39821 L
.09597 .40426 L
.08637 .41019 L
.07617 .41658 L
.06635 .42282 L
.05692 .42889 L
.04694 .43542 L
.03789 .44145 L
s
.2 0 1 r
.5 Mabswid
.90642 .33317 m
.80902 .30845 L
.71162 .30845 L
.61422 .30846 L
.51681 .30856 L
.41941 .30983 L
.32201 .32343 L
.22461 .33807 L
.1272 .38303 L
.03034 .44195 L
s
1 0 0 r
.91811 .30406 m
.91703 .30406 L
.91604 .30406 L
.91489 .30406 L
.91382 .30406 L
.91282 .30406 L
.9119 .30406 L
.91089 .30406 L
.90981 .30406 L
.90874 .30406 L
.90758 .30406 L
.90649 .30406 L
.90549 .30406 L
.90432 .30406 L
.90366 .30406 L
.90305 .30406 L
.90192 .30406 L
.90072 .30406 L
.90012 .30406 L
.89948 .30406 L
.89835 .30406 L
.89771 .30406 L
.89712 .30406 L
.89647 .30406 L
.89577 .30406 L
.89517 .30406 L
.89452 .30406 L
.89333 .30406 L
.89218 .30406 L
.89111 .30406 L
.89007 .30406 L
.8891 .30406 L
.88803 .30406 L
.88688 .30406 L
.88574 .30406 L
.88454 .30406 L
.88351 .30406 L
.88239 .30406 L
.88174 .30406 L
.88113 .30406 L
.88047 .30406 L
.87976 .30406 L
.87858 .30406 L
.87791 .30406 L
.87728 .30406 L
.87611 .30406 L
.87504 .30406 L
.87445 .30406 L
.87381 .30406 L
.87264 .30406 L
Mistroke
.87193 .30406 L
.87126 .30406 L
.87066 .30406 L
.87002 .30406 L
.86931 .30406 L
.86856 .30406 L
.86792 .30406 L
.86723 .30406 L
.86657 .30406 L
.86597 .30406 L
.86528 .30406 L
.86463 .30406 L
.86347 .30406 L
.86282 .30406 L
.86221 .30406 L
.86111 .30406 L
.85995 .30406 L
.85934 .30406 L
.85868 .30406 L
.85751 .30406 L
.8564 .30406 L
.85522 .30406 L
.85411 .30406 L
.8531 .30406 L
.85197 .30406 L
.85133 .30406 L
.85074 .30406 L
.84965 .30406 L
.8485 .30406 L
.8479 .30406 L
.84726 .30406 L
.84609 .30406 L
.84538 .30406 L
.8447 .30406 L
.8441 .30406 L
.84344 .30406 L
.84231 .30406 L
.84128 .30406 L
.84015 .30406 L
.83896 .30406 L
.83792 .30406 L
.83696 .30406 L
.8359 .30406 L
.83476 .30406 L
.83412 .30406 L
.83352 .30406 L
.83287 .30406 L
.83218 .30406 L
.83102 .30406 L
.83036 .30406 L
Mistroke
.82974 .30406 L
.82859 .30406 L
.82754 .30406 L
.82633 .30406 L
.82518 .30406 L
.82455 .30406 L
.82395 .30406 L
.82284 .30406 L
.82165 .30406 L
.82098 .30406 L
.82036 .30406 L
.81932 .30406 L
.81819 .30406 L
.817 .30406 L
.81589 .30406 L
.81526 .30406 L
.81458 .30406 L
.81393 .30406 L
.81333 .30406 L
.8122 .30406 L
.811 .30406 L
.81038 .30406 L
.80972 .30406 L
.80851 .30406 L
.80781 .30406 L
.80708 .30406 L
.80645 .30406 L
.80576 .30406 L
.80454 .30406 L
.80341 .30406 L
.80277 .30406 L
.80218 .30406 L
.80155 .30406 L
.80087 .30406 L
.79971 .30406 L
.79864 .30406 L
.79806 .30406 L
.79742 .30406 L
.79625 .30406 L
.79511 .30406 L
.79408 .30406 L
.79289 .30406 L
.79177 .30406 L
.79073 .30406 L
.78977 .30406 L
.78872 .30406 L
.78762 .30406 L
.78641 .30406 L
.78531 .30406 L
.7847 .30406 L
Mistroke
.78403 .30406 L
.78283 .30406 L
.78171 .30406 L
.78051 .30406 L
.77949 .30406 L
.77837 .30406 L
.7777 .30406 L
.77706 .30406 L
.77585 .30406 L
.77518 .30406 L
.77456 .30406 L
.77387 .30406 L
.77314 .30406 L
.77251 .30406 L
.77182 .30406 L
.77121 .30406 L
.77057 .30406 L
.76936 .30406 L
.76824 .30406 L
.76712 .30406 L
.76648 .30406 L
.76589 .30406 L
.76481 .30406 L
.76366 .30406 L
.76264 .30406 L
.76168 .30406 L
.76062 .30406 L
.75949 .30406 L
.75835 .30406 L
.7577 .30406 L
.7571 .30406 L
.75589 .30406 L
.75521 .30406 L
.75459 .30406 L
.75348 .30406 L
.75228 .30406 L
.75115 .30406 L
.75009 .30406 L
.74911 .30406 L
.74806 .30406 L
.74688 .30406 L
.74581 .30406 L
.7447 .30406 L
.74349 .30406 L
.74234 .30406 L
.74128 .30406 L
.74021 .30406 L
.73921 .30406 L
.73831 .30406 L
.73734 .30406 L
Mistroke
.73628 .30406 L
.73516 .30406 L
.7342 .30406 L
.73315 .30406 L
.73194 .30406 L
.73082 .30406 L
.73019 .30406 L
.72959 .30406 L
.72897 .30406 L
.72829 .30406 L
.72713 .30406 L
.72608 .30406 L
.72548 .30406 L
.72484 .30406 L
.72369 .30406 L
.72264 .30406 L
.72169 .30406 L
.72056 .30406 L
.7195 .30406 L
.71839 .30406 L
.71738 .30406 L
.71626 .30406 L
.71508 .30406 L
.71388 .30406 L
.71278 .30406 L
.71218 .30406 L
.71152 .30406 L
.71032 .30406 L
.7092 .30406 L
.70801 .30406 L
.70699 .30406 L
.70587 .30406 L
.70523 .30406 L
.70456 .30406 L
.70335 .30406 L
.70268 .30406 L
.70206 .30406 L
.70138 .30406 L
.70064 .30406 L
.69574 .30406 L
.67736 .30406 L
.67671 .30406 L
.6761 .30406 L
.6754 .30406 L
.67476 .30406 L
.67359 .30406 L
.67293 .30406 L
.67232 .30406 L
.67168 .30406 L
.671 .30406 L
Mistroke
.66978 .30406 L
.66909 .30406 L
.66834 .30406 L
.66763 .30406 L
.66698 .30406 L
.66584 .30406 L
.66477 .30406 L
.66359 .30406 L
.66293 .30406 L
.66233 .30406 L
.66112 .30406 L
.66044 .30406 L
.6598 .30406 L
.65864 .30406 L
.65806 .30406 L
.65741 .30406 L
.64803 .30406 L
.63815 .30406 L
.629 .30406 L
.6279 .30406 L
.6267 .30406 L
.62558 .30406 L
.62454 .30406 L
.6236 .30406 L
.62257 .30406 L
.62149 .30406 L
.62049 .30406 L
.61945 .30406 L
.61849 .30406 L
.6174 .30406 L
.61635 .30406 L
.61194 .30406 L
.60259 .30406 L
.59337 .30406 L
.58331 .30406 L
.57374 .30407 L
.56508 .30407 L
.55508 .30407 L
.54568 .30407 L
.53662 .30408 L
.52707 .30408 L
.50998 .3041 L
.50119 .30411 L
.49178 .30412 L
.47482 .30416 L
.46538 .30419 L
.45514 .30422 L
.44546 .30427 L
.43652 .30432 L
.41923 .30447 L
Mistroke
.40939 .30459 L
.40016 .30473 L
.39058 .30492 L
.38146 .30514 L
.36434 .30571 L
.35549 .30612 L
.34605 .30665 L
.32905 .30796 L
.31955 .30893 L
.30927 .31022 L
.29063 .31332 L
.27221 .31754 L
.25274 .3234 L
.21766 .33751 L
.18031 .3564 L
.14436 .37672 L
.10614 .39939 L
.06935 .42165 L
.03789 .44097 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500.625, 309.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001=B000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3oool90?ooo`030?noM0000000000000800000
00<0001d0;ooo`3oool01P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`030=nLB018W=l0oooo0</0oooo
003o0?ooo`P0oooo00<0gia80000001d_ol00`3oool00`3ookl0M4RL0=ooo`050?ooo`030?noM018
W=l0oooo00l0oooo00<0gia807Boo`3oool0bP3oool00?l0oooo203oool00`3o_g@004RL0=ooo`04
0?ooo`030?oOW02L_ol0oooo00<0oooo00<0okmd0018W03Oool0403oool00`3ooml0W4P007Boo`3:
0?ooo`00o`3oool90?ooo`030=nLM02Lgol0oooo00<0oooo00<0omnL07BLg`3oool00P3oool00`3o
oml0W4P007Boo`0B0?ooo`030?noM00007@0_ooo0<T0oooo003a0?ooo`030?oog`2LB000000000L0
000000H0M;oo0?ooo`3oool0oooo0?oOW0180002000000030000M02oool0oooo0080oooo00<0gia8
000000000000100000001`18W=l0oooo0?ooo`3oool0okmd0000M02oool00P3oool00`3ooml0W4P0
000000030000000504RLg`3oool0oooo0?ooo`2oM0000P0000001P0004P0W=oo0?ooo`3ookl0M000
07BoolT0oooo003c0?ooo`030?oOW018000007Bo00@0oooo00l0_g@0001d_`3oool0oooo0?noM000
000004RL0=ooo`3oool0okmd0000B02Lgol0oooo0?oog`2LB0001@0000000`00B9`0gooo0?ooo`02
0?ooo`030;md0000B9`0gooo00@0oooo00@0oono07@00000B9`0gooo0`3oool0103o_g@000000000
B02Lgol30?ooo`030?oog`2LB00007Bo0<T0oooo003c0?ooo`030?oOW0180000B9cO00@0oooo00L0
oooO09adW03Oool0oooO09a8000004P0W=oo00<0oooo00H0_g@00018W03Oool0oooo0=nLB018W=l8
0?ooo`030?oog`2LB00007Bo00D0oooo00<0oono07@00000M;l00`3oool0103ookl0M0000000M02o
ool50?ooo`030;md000007@0_ooo0<P0oooo003c0?ooo`030?oOW0180000B9cO00D0oooo00D0oknL
09cOo`3ogi`0B000001d_`040?ooo`030=nLB00004P0W=oo0080oooo00D0_g@00000000000000000
07Boo`040?ooo`030?oo_`1d0000B9cO00D0oooo00<0oono07@00000M;l00P3oool0103ooml0W4P0
0000001d_ol60?ooo`030=nLB00007@0_ooo0<P0oooo003c0?ooo`030?oOW0180000B9cO00L0oooo
00<0okmd00000018W=l0103oool02`3OW4P0000007Boo`3oool0okmd0000001d_ol0oooo0=nLB000
0000M;oo00<0oooo00<0omnL04P00018W=l01@3oool00`3ookl0M000001d_`020?ooo`030=nLB000
0000B9cO00L0oooo00<0gia80000B02Lgol0b03oool00?<0oooo00<0omnL04P00018W=l01`3oool0
0`3ogi`0B00004RLg`040?ooo`0;0;md000004P0W=oo0?oog`2LB00004RL0=ooo`3oool0omnL04P0
0018W=l00`3oool00`3ogi`0B00004RLg`050?ooo`080?oo_`1d000007Bo0?ooo`3o_g@000000018
W03Oool70?ooo`030=nLB00004P0W=oo0<P0oooo003c0?ooo`030?oOW0180000B9cO00L0oooo00<0
oooO09a80000M;l00`3oool01`3ookl0M0000000M02oool0oono07@00000M;l00P3oool00`3ogi`0
B00007Boo`030?ooo`030?oo_`1d0000B9cO00D0oooo00<0oono07@0000000000`0000000`18W=l0
oooo0?ooo`060?ooo`030=nLB00004P0W=oo0<P0oooo003c0?ooo`030?oOW0180000B9cO00P0oooo
00P0omnL04P0001d_ol0oooo0?oog`2LB000000007Boo`80oooo00D0gia80000B02Lgol0oooo0;md
0002000000060018W03Oool0oooo0?oo_`1d000007Bo1@3oool00`3ookl0M000001d_`020?ooo`04
0?oo_`1d0000000004RLg`H0oooo00<0_g@00000M02oool0b03oool00?<0oooo00<0omnL04P00018
W=l02@3oool01P3ookl0M000000000000000001809cOo`@0oooo00D0gia800000000000004RL0=oo
o`050?ooo`030;md0000B9`0gooo00@0oooo00<0oono07@00000M;l00`3oool0103ookl0M0000000
001d_ol40?ooo`030?oog`2LB00007Bo0<T0oooo003c0?ooo`030?oOW0180000B9cO01d0oooo00<0
okmd0000M02oool0103oool00`3ookl0M000001d_`040?ooo`030;md00000000B9cO00@0oooo00<0
oono07@0001d_ol0b@3oool00?<0oooo00<0omnL04P00018W=l07@3oool00`3ooml0W4P007Boo`04
0?ooo`030?oo_`1d000007Bo00<0oooo00@0oooO09a800000000M;oo103oool00`3o_g@0001d0;oo
o`390?ooo`00l`3oool00`3ogi`0B00004RLg`0N0?ooo`030?noM000B9`0gooo00<0oooo00<0oono
07@00000M;l00`3oool0102oM00000000018W03Oool30?ooo`030?oog`2LB000M;oo0<X0oooo003a
0?ooo`030?oog`2LB000000000<0000000<0M;oo0?ooo`3oool06`3oool01@3o_g@004RL0=ooo`3o
oml0W4P000L0000000<007Bo0?ooo`3oool00P3oool00`3ooml0W4P004RLg`3;0?ooo`00o`3ooolG
0?ooo`030?oOW01dW=l0oooo00d0oooo00<0giad09cOo`3oool0b`3oool00?l0oooom@3oool00?l0
oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0
oooom@3oool00?l0oooom@3oool00?l0oooom@3oool00?l0oooom@3oool006L0oooo00<0okmd0000
000000000P0000000`00M;l0oooo0?ooo`030?ooo`040;md00000000000004RLgb80oooo00<0gia8
0000000000001@0000000`1d_ol0oooo0?ooo`020?ooo`040;md00000000000004RLgb80oooo00<0
oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`040;md00000000000004RLgbL0oooo
00<0okmd0000001d_ol01@3oool0102oM000000000000018W=lR0?ooo`060;md0000000000000000
0000B9`0gooo1P3oool0102oM000000000000018W=lT0?ooo`060?oog`2LB00000000000000007@0
_ooo1@3oool0102oM000000000000018W=lU0?ooo`030?oOW01807@0_ooo00L0oooo00@0_g@00000
00000000B9cO903oool01P3ogi`0B000000000000000001809cOo`D0oooo00@0_g@0000000000000
B9cO6P3oool006T0oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3oool0oooO09a8
0000M;l08P3oool00`3OW4P00000000000040000000:001d_`3oool0oooo0?oog`2LB00007Bo0?oo
o`3ooml0W4P0001d_b40oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`<0oooo00L0
oooO09a80000M;l0oooo0?oog`2LB00007Bo02H0oooo00<0okmd0000001d_ol00`3oool01`3ooml0
W4P0001d_`3oool0oooO09a80000M;l0803oool00`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0
gooo00<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo0280oooo00P0oono07@00000B9`0
gooo0?ooo`3OW4P0001809cOo`80oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo02D0oooo
00<0_g@007Boo`3oool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l08P3oool0203o
gi`0B0000018W03Oool0oooo0?oOW0180000M;oo0P3oool01`3ooml0W4P0001d_`3oool0oooO09a8
0000M;l06@3oool006T0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo0280oooo00<0gia804RLg`3oool00P3oool01`3ooml0W4Qd0;ooo`3oool0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0V0?ooo`030?noM000B9`0gooo0080oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0U0?ooo`030?noM0000000M;oo00<0oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0U0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0Q0?ooo`030;md000007@0_ooo00<0oooo00L0_g@0
001d_`3oool0oooo0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0903oool00`3o_g@007Bo
0?ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol08@3oool00`2oM000001d
0;ooo`030?ooo`070=nLB000B9`0gooo0?ooo`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo
01P0oooo001Y0?ooo`030;md000007@0_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3o
oml0W4P0001d_`0S0?ooo`030=nLB018W=l0oooo00@0oooo00@0oooO09a80000B9`0gooo0P3oool0
0`3ooml0W4P0001d_`0V0?ooo`080?noM00004P0W=oo0?ooo`3ooml0W4P00018W03Oool20?ooo`03
0?oog`2LB00007Bo0200oooo00<0gia80000000000001@0000001P0004P0W=oo0?oog`2LB00004RL
0=ooo`80oooo00<0oooO09a80000M;l09@3oool0203ookl0M01809cOo`3oool0oooO09a80000B9`0
gooo0P3oool00`3ooml0W4P0001d_`0P0?ooo`030?oo_`1d000007Bo00@0oooo00L0gia80000M02o
ool0oooO09a80000B9`0gooo0080oooo00<0oooO09a80000M;l0903oool00`3ookl0M01d0;ooo`03
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l08@3oool00`2oM000001d0;oo
o`030?ooo`070;md0000B9`0gooo0?oog`2LB00004RL0=ooo`020?ooo`030?oog`2LB00007Bo01P0
oooo001Y0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`0S0?ooo`030=nLB01d_ol0oooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`0U0?ooo`070;md000004P0W=oo0?ooo`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
01l0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`020?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool0903oool01`3ookl0M00007Boo`3oool0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`0O0?ooo`030?oOW0180000B9cO00@0oooo00H0_g@00000B02Lgol0oono
07@00000M;l40?ooo`030;md000007@0_ooo02@0oooo00<0_g@007Boo`3oool00P3oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo0200oooo00<0okmd0000B02Lgol00P3oool01`3OW4P0
0000001d_`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`0G0?ooo`00J@3oool00`2o
M000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool08`3oool00`3o
oml0W4Q809cOo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0903oool0202o
M00000000000M02oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`0P0?ooo`070=nL
B01d_ol0oooo0?ooo`3o_g@0000007Boo`020?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000
M02oool0903oool01`3o_g@0000007Boo`3oool0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`0O0?ooo`030?oOW0180000B9cO00<0oooo00L0oono07@0000007@0_ooo0?oOW0180000B9cO00@0
oooo00<0_g@00000M02oool0903oool00`3o_g@007Bo0?ooo`020?ooo`030?oOW0180000B9cO00@0
oooo00<0_g@00000M02oool08@3oool02`3OW4P007Bo0?ooo`2oM00000000000M02oool0oooo0?oO
W0180000B9cO00@0oooo00<0_g@00000M02oool05`3oool006T0oooo00<0_g@00000M02oool00`3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02@0oooo00<0omnL04P0M02oool00P3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo0240oooo00<0oono07@0000000000P00
00001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02Lgol0803oool01`3ookl0
M01d0;ooo`3oool0okmd0000001d_ol00P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0
W=oo02<0oooo00P0omnL04P0000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02L
gol07`3oool03@3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`3oool0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`0T0?ooo`030?oo_`1d07@0_ooo0080oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`0R0?ooo`050?noM000000000000018W03Oool00P3oool00`3o
gi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01L0oooo001Y0?ooo`030;md000007@0_ooo00<0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0U0?ooo`070;md0018W=l0oooo0?oo
o`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02<0oooo00<0okmd0000B02Lgol00`3oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo0240oooo00H0okmd001d_`3oool0okmd0000
001d_ol20?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol07`3oool0103Ogml0oooo
0?ooo`2oM0020000000604RLg`3oool0oooo0?oOW0180000B9cO103oool00`3OW4P0001809cOo`0O
0?ooo`050?oog`2LB000001d0;oOW01800000P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0
oooo00<0gia80000B02Lgol09@3oool01`2oM000M;oo0?ooo`3oool0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`0Q0?ooo`050?oOW0180000000000000018W=l00`3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo01L0oooo001Y0?ooo`030;md000007@0_ooo00<0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`0U0?ooo`070=nLB00007@0_ooo0?ooo`3ookl0M000
001d_`040?ooo`030;md000007@0_ooo02@0oooo00<0omnL04Qd_`3oool00P3oool00`3ookl0M000
001d_`040?ooo`030;md000007@0_ooo0280oooo00D0_g@007Boo`3o_g@0000007Boo`020?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool07`3oool00`3o_g@000000000000200000007
001d_`3oool0oooo0?ooo`3ookl0M000001d_`040?ooo`030;md000007@0_ooo0200oooo00<0okmd
00000018W=l01P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02D0oooo00L0okmd
001d_`3oool0oooo0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0803oool01`3ogi`0B000
0000B02Lgol0oooo0=nLB000M;l00P3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo
01L0oooo001Y0?ooo`030;md000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`0V0?ooo`030?noM0000000M;oo0080oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`0U0?ooo`030?oog`2LB000B9cO00<0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`0S0?ooo`050?oo_`1d07@0_kmd0000001d_ol00`3oool00`2oM00004RL0=ooo`020?oo
o`030?oog`2LB00007Bo0200oooo00D0oooO09a800000000001d0;ooo`050?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l08@3oool0103ooml0W4P00000B02Lgol60?ooo`030;md0000
B9`0gooo0080oooo00<0oooO09a80000M;l0803oool00`3ogkl0_moo0?ooo`030?ooo`030?oo_`1d
07@0_ooo0080oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0Q0?ooo`030=nLB000
04P0W=oo0080oooo00<0oooO09a8001d_ol00P3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2L
B00007Bo01P0oooo001Y0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`0P0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol00P3oool0
0`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo0200oooo00<0oooO09adW03Oool00P3oool0
0`3ooml0W4P0001d_`030?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0903oool0
103o_g@000000000001d_ol30?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol08@3o
ool00`3o_g@007Bo0?ooo`060?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol08P3o
ool0103ookl0M0000000M02oool50?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0
803oool00`3ooml0W4Qd0;ooo`040?ooo`070;md001d_ol0oooo0?ooo`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo0240oooo00<0gia80018W03Oool00P3oool00`3ooml0W4P004RLg`020?oo
o`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0603oool006L0oooo00D0gia800000000
0000001d0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo8P3oool0202oM000M;oo0?oo
o`3oool0gia800000000B9`0gooo0`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_b80oooo00L0
omnL04Q8W03Oool0oooo0=nLB0000000M;oo00@0oooo00H0_g@00018W03Oool0oooo0;md0000M;lU
0?ooo`040?oog`2LB000000007Boo`@0oooo00H0_g@00018W03Oool0oooo0;md0000M;lR0?ooo`03
0?oog`2LB00000000080000000<0001d0;ooo`3oool00P3oool01P2oM00004RL0=ooo`3oool0_g@0
001d_b@0oooo00@0oooO09a80000000007Bo1@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_b80
oooo00<0gia8000000000000100000002P00M;l0oooo0?ooo`3oool0_g@00018W03Oool0oooo0;md
0000M;lR0?ooo`030?oOW0180000B9cO0080oooo00<0okmd0000B02Lgol00`3oool01P2oM00004RL
0=ooo`3oool0_g@0001d_aT0oooo001X0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00@0_g@00000
0000000007Bo903oool01@2oM000000000000000000007Bo00H0oooo00@0_g@000000000000007Bo
903oool01@3ogi`0B000000000000000B9cO00H0oooo00@0_g@000000000000007Bo9`3oool00`3o
gi`0B00007Boo`050?ooo`040;md000000000000001d_b@0oooo00<0okmd0000000000000P000000
0`1d_ol0oooo0?ooo`020?ooo`040;md000000000000001d_bL0oooo00D0omnL04P00000000004RL
0=ooo`030?ooo`040;md000000000000001d_b<0oooo00<0omnL04P000000000100000000`0004P0
W=oo0?ooo`020?ooo`040;md000000000000001d_b@0oooo00H0oono07@00000000000000000B02L
gol50?ooo`040;md000000000000001d_aX0oooo003o0?ooooD0oooo003o0?ooooD0oooo003o0?oo
ooD0oooo003o0?ooooD0oooo003o0?ooooD0oooo003o0?ooooD0oooo003o0?ooooD0oooo003o0?oo
ooD0oooo003o0?ooooD0oooo003o0?ooooD0oooo001;0?ooool00000RP00000P0?ooo`00B`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool07P3oool004/0oooo
00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003o
ool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o
0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?oo
o`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool0
7P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;
0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool30000
0?l0ooooQ@3oool200000200oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool0
7P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;
0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`00
0000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3o
ool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0oooo
QP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<0
00000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0
oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?oo
o`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo
0`00003o0?ooohD0oooo0P00000P0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<0
00000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0
oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?oo
o`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo
00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003o
ool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o
0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?oo
o`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool0
7P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;
0?ooo`<00000o`3ooon50?ooo`800000803oool004/0oooo00<000000?ooo`3oool0o`3ooon60?oo
o`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool0
7P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;
0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`00
0000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool00380oooo00H0omnL04P00000
000000000000B02Lgol40?ooo`060?oOW018000000000000000004P0W=oo2@3oool00`000000oooo
0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool00340oooo00P0omnL04P00000B9`0gooo
0?ooo`3ogi`0B00007Boo`80oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`P0oooo
00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000a0?ooo`030;md0000
07@0_ooo00<0oooo00L0gia80018W03Oool0oooo0;md000007@0_ooo00<0oooo00<0gia80018W03O
ool01`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool00340oooo
00<0_g@00000M02oool00`3oool01`2oM00004RL0=ooo`3oool0_g@00000M02oool00`3oool00`2o
M00004RL0=ooo`070?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?oo
o`00<@3oool00`3o_g@0001809cOo`020?ooo`030=nLB000000007Bo0080oooo00<0okmd0000B02L
gol00P3oool00`3OW4P00000001d_`080?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0N0?ooo`00<P3oool01`3OW4P007Bo0?ooo`2oM00000000000M02oool00`3oool01`3O
W4P007Bo0?ooo`2oM00000000000M02oool0203oool00`000000oooo0?ooo`3o0?ooohH0oooo00<0
00000?ooo`3oool07P3oool003<0oooo00D0okmd00000000000004RL0=ooo`050?ooo`050?noM000
000000000018W03Oool02@3oool400000?l0ooooP`3oool300000200oooo000b0?ooo`050?oOW018
0000000000000018W=l01@3oool01@3ogi`0B000000000000000B9cO00X0oooo00<000000?ooo`3o
ool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000a0?ooo`070?oOW0180000001809cOo`3o
ool0gia8001d_`030?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`090?ooo`030000003o
ool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00<@3oool00`3OW4P0001809cOo`02
0?ooo`030?oog`2LB000M;oo0080oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Boo`08
0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00<@3oool00`3O
W4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO0080oooo00<0gia80018W03Oool00P3oool00`3o
oml0W4P004RLg`080?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?oo
o`00<@3oool00`3ogi`0B00004RLg`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P00018
W=l00P3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0N0?ooo`00<P3oool01P3ookl0M000000000000000001809cOo`@0oooo00H0oono07@0
0000000000000000B02Lgol90?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?oo
o`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool0
04/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`03
0000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo
0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3o
oon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`<00000o`3ooon50?ooo`800000803oool0
04/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`03
0000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo
0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3o
oon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool0
0`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?oo
o`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0
oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3o
ool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<00000
0?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo
0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool300000?l0ooooQ@3oool200000200
oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00603o
ool00`3o_i`0W=oo0?ooo`0:0?ooo`030=nLW02oool0oooo02<0oooo00<000000?ooo`3oool0o`3o
oon60?ooo`030000003oool0oooo01h0oooo000H0?ooo`030?noM01d_ol0oooo00X0oooo00<0_gAd
0;ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool0
01P0oooo00<0okmd0000000000002P0000000`0007@0_ooo0?ooo`0S0?ooo`030000003oool0oooo
0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00603oool00`3o_g@000000000000:00000003
0000M02oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0
oooo000H0?ooo`030?noM01d_ol0oooo00X0oooo00<0_gAd0;ooo`3oool08`3oool00`000000oooo
0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool001P0oooo00<0oknL09cOo`3oool02P3o
ool00`2oM7@0_ooo0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?oo
o`0N0?ooo`009@3oool00`2oM7@0_ooo0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooQP3oool0
0`000000oooo0?ooo`0N0?ooo`009@3oool00`2oM7@0_ooo0?ooo`0S0?ooo`030000003oool0oooo
0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00903oool00`3ookl0M01d0;ooo`0T0?ooo`03
0000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`008`3oool0103o_g@00000
0000M02ooolT0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00
8P3oool00`2oM000001809cOo`0V0?ooo`<00000o`3ooon50?ooo`800000803oool004/0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0
oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`007P3oool00`3ooml0W4P0000000020000
0003001d_`3oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo
01h0oooo000M0?ooo`030?noM0000000000000@0000000<0001d0;ooo`3oool0903oool00`000000
oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool001`0oooo00<0oono07@0B02Lgol0
103oool00`3o_g@00000001d_`0U0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo
0?ooo`0N0?ooo`00703oool00`3o_g@0M;oo0?ooo`050?ooo`030?oog`2LB7@0_ooo00T0oooo00D0
oooO09a800000000001809cOo`080?ooo`040;md00000000000004RLg`X0oooo00<000000?ooo`3o
ool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000L0?ooo`030?noM018W=l0oooo00H0oooo
00<0_gAd0;ooo`3oool02`3oool0103OW4P000000018W03Oool40?ooo`070?oog`2LB00007Bo0?oo
o`3ooml0W4P0001d_`090?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N
0?ooo`00703oool0103ookl0M0000018W03Oool40?ooo`030?noM000M;l0oooo00d0oooo00@0oono
07@0000007@0_ooo0`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000M0?ooo`030?noM0000000
000000@0000000<0001d0;ooo`3oool03P3oool02@3ookl0M0000018W03Oool0oooo0?oog`2LB000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo00P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`03
0000003oool0oooo01h0oooo000N0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0
403oool01`3OW4P0000007Boo`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`070?oo
o`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00<P3oool00`3OW4P0
000000000003000000050018W03Oool0omnL04P00018W=l0103oool00`2oM000001d0;ooo`070?oo
o`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`009P3oool0103ogi`0
B0000000001d_ol70?ooo`030;md0000000007Bo0080oooo00L0oono07@0000007@0_ooo0?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol01`3oool400000?l0ooooP`3oool300000200oooo000M
0?ooo`0>0?oog`2LB000000000000000M;l0oooO09a800000000B9bo09adW03Oool0gia80018W03O
ool50?ooo`040?oo_`1d000004RL0=ooo`<0oooo00H0_g@00000B02Lgol0omnL04P00018W=l40?oo
o`030=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo
01h0oooo000L0?ooo`030?oog`2LB000000000<0000000T0B7BL0;oOo`3OW4P0001809cOo`3oool0
omnL04P0B02Lgol01@3oool00`3ogi`0B00004RLg`040?ooo`060=nLB00004P0W=oo0?oo_`1d0000
07Bo103oool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0N0?ooo`00703oool00`3ogi`0B7Bo0?ooo`020?ooo`0:0?oOW018B9`0gooo0?noM000
07@0_ooo0?ooo`3ookl0M00007Boo`D0oooo00<0omnL04P00018W=l0103oool01`2oM000001d0;oo
o`3oool0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`080?ooo`030000003oool0oooo0?l0
ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00703oool00`3o_i`0W=oo0?ooo`030?ooo`090=nL
W02oool0okmd0000B02Lgol0oooo0?oog`2LB000M;oo00D0oooo00<0oooO09a80000M;l00`3oool0
0`3ookl0M00004RLg`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool0
0`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool001`0oooo00<0omnL04Q8
W03Oool00P3oool02P3ooml0W7BL0=ooo`3o_g@0001809cOo`3oool0oono07@0B02Lgol60?ooo`08
0?oOW0180000M;oo0?ooo`3ooml0W4P00018W03Oool30?ooo`060;md0000B9`0gooo0?ooo`2oM000
07Bo2@3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool001d0oooo
00<0_g@00000000000000P0000002@18W=l0oooo0?noM00004P0W=oo0?ooo`3ogi`0B4RL0=ooo`07
0?ooo`060?oo_`1d0000000000000000B9`0gooo1@3oool0102oM000000000000000M;l:0?ooo`03
0000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`007@3oool01@2oM0000000
000000000000B9cO0080oooo00H0omnL04P0001d_ol0oooO09a8B02LgolQ0?ooo`030000003oool0
oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`007@3oool00`2oM7@0_ooo0?ooo`050?oo
o`040=nLB0000000001809cOob80oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0
oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?oo
o`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo
00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000M0?ooo`030?noM000
0000000000@0000000<0001d0;ooo`3oool0903oool300000?l0ooooQ@3oool200000200oooo000K
0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool08P3oool00`000000oooo0?ooo`3o
0?ooohH0oooo00<000000?ooo`3oool07P3oool001X0oooo00@0_g@0000000000000M;oo1`3oool0
102oM000000000000018W=lR0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?oo
o`0N0?ooo`006@3oool00`2oM00007Bo0?ooo`0;0?ooo`030?oog`2LB000B9cO0240oooo00<00000
0?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000H0?ooo`030?noM01d_ol0oooo
00h0oooo00<0giad09cOo`3oool07`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?oo
o`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0
oooo000P0?ooo`030;md0018W=l0oooo02P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000
003oool0oooo01h0oooo000P0?ooo`030;md0018W=l0oooo02P0oooo00<000000?ooo`3oool0o`3o
oon60?ooo`030000003oool0oooo01h0oooo000P0?ooo`030;md0018W=l0oooo02P0oooo00<00000
0?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000P0?ooo`030;md0018W=l0oooo
02P0oooo00<000000?ooo`3oool0`P3ooomm03?o04H0oooo00<000000?ooo`3oool07P3oool00200
oooo00<0_g@004RLg`3oool0:03oool00`000000oooo0?ooo`2I0?ooold0o`007`3oool00`000000
oooo0?ooo`0N0?ooo`00803oool00`2oM000B9cO0?ooo`0X0?ooo`030000003oool0oooo0880oooo
5`3o000Y0?ooogd0<ol0AP3oool00`000000oooo0?ooo`0N0?ooo`00803oool00`2oM000B9cO0?oo
o`0X0?ooo`<00000NP3oool80?l001d0ooooW@0c0?m80?ooo`800000803oool00200oooo00<0_g@0
04RLg`3oool0:03oool00`000000oooo0?ooo`1d0?ooo`H0o`007`3oool603<0oid0oooo100c0?m5
0?ooo`030000003oool0oooo01h0oooo000P0?ooo`030;md0018W=l0oooo02P0oooo00<000000?oo
o`3oool0K03oool80?l001l0oooo1P0c0?nW0?ooo`@0<`3o@@3oool00`000000oooo0?ooo`0N0?oo
o`00803oool00`2oM000B9cO0?ooo`0X0?ooo`030000003oool0oooo06L0oooo1@3o000P0?ooo`L0
<`3o/@3oool403<0ocd0oooo00<000000?ooo`3oool07P3oool00200oooo00<0_g@004RLg`3oool0
:03oool00`000000oooo0?ooo`1U0?ooo`80o`000`0co`0L0?ooo`H0<`3o_03oool403<0ocT0oooo
00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0HP3oool30?l000D0<ol05P3o
ool603<0olH0oooo100c0?le0?ooo`030000003oool0oooo01h0oooo000L0?ooo`030?noM01d_ol0
oooo00H0oooo00<0gibL0;ooo`3oool08`3oool00`000000oooo0?ooo`1N0?ooo`0403?o003o0000
o`000?l000H0<ol04@3oool703<0om00oooo100c0?la0?ooo`030000003oool0oooo01h0oooo000L
0?ooo`030?noM01d_ol0oooo00D0oooo00<0oooO09a8M02oool0903oool00`000000oooo0?ooo`1K
0?ooo`80<ol00P3o000703?o00d0oooo1P0c0?oK0?ooo`@0<`3o;@3oool00`000000oooo0?ooo`0N
0?ooo`006@3oool00`3ookl0M00000000009000000030000M02oool0oooo02<0oooo00<000000?oo
o`3oool0F@3oool0100co`00o`000?l0003o000503?o00X0oooo1`0c0?oU0?ooo`@0<`3o:@3oool0
0`000000oooo0?ooo`0N0?ooo`00603oool00`3ogi`0B0000000000:000000030000M02oool0oooo
02<0oooo00<000000?ooo`3oool0EP3oool0100co`00o`000?l0003o000403?o00P0oooo1P0c0?o`
0?ooo`@0<`3o9@3oool00`000000oooo0?ooo`0N0?ooo`00603oool01P2oM7@0_ooo0?ooo`3oool0
okmd07Boo`L0oooo00<0_gAd0;ooo`3oool08`3oool00`000000oooo0?ooo`1D0?ooo`0303?o003o
0000o`0000D0<ol00`3oool703<0ooX0oooo0P0c0?lS0?ooo`030000003oool0oooo01h0oooo000G
0?ooo`030?oo_`1dM;l0oooo0080oooo00<0okmd07Boo`3oool01P3oool00`3OW9`0_ooo0?ooo`0S
0?ooo`030000003oool0oooo0580oooo00<0<ol00?l0003o0000100co`0603<0ool0oooo9`3oool0
0`000000oooo0?ooo`0N0?ooo`005`3oool00`3ookl0M01d0;ooo`0a0?ooo`<00000D03oool0100c
o`00o`000?l0000co`0503<0ool0oooo;03oool200000200oooo000G0?ooo`040?oog`2LB0000018
09cOoc00oooo00<000000?ooo`3oool0CP3oool0100co`00o`000?l0000co`0203<0o`0303?o003o
ool0oooo0?l0oooo;`3oool00`000000oooo0?ooo`0N0?ooo`00603oool00`3o_g@0001809cOo`0`
0?ooo`030000003oool0oooo04`0oooo00@0<ol00?l0003o0000<ol00P0c0?l00`0co`00oooo0?oo
o`3o0?oooc40oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0BP3oool0
100co`00o`000?l0000co`0203<0o`0303?o003oool0oooo0?l0oooo<`3oool00`000000oooo0?oo
o`0N0?ooo`007@3oool00`3o_g@0000000000004000000030000M02oool0oooo02@0oooo00<00000
0?ooo`3oool0A`3oool203?o0080o`000`0c0?l00`0co`00oooo0?ooo`3o0?ooocD0oooo00<00000
0?ooo`3oool07P3oool001/0oooo00<0gia8000000000000200000000`0004P0W=oo0?ooo`0R0?oo
o`030000003oool0oooo04@0oooo0`0co`020?l00080<`3o0P0co`3o0?ooocT0oooo00<000000?oo
o`3oool07P3oool001X0oooo00@0_g@0000000000000M;oo1`3oool0102oM000000000000018W=lR
0?ooo`030000003oool0oooo0480oooo0`0co`020?l00080<`3o0P0co`3o0?oooc/0oooo00<00000
0?ooo`3oool07P3oool001T0oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P004RLg`060?oo
o`050?oog`2LB00000000000B02Lgol01@3oool00`3OW4P00000000000050000000307Boo`3oool0
oooo00H0oooo00<000000?ooo`3oool0@03oool403?o00030?l0000c0?l0<`3o0?l0oooo?`3oool0
0`000000oooo0?ooo`0N0?ooo`00603oool00`3o_g@0M;oo0?ooo`0>0?ooo`030=nLM02Lgol0oooo
00L0oooo00@0gia800000000B9`0gooo103oool00`3OW4P000000000000400000003001d_`3oool0
oooo00H0oooo00<000000?ooo`3oool0?`3oool303?o0080o`0000<0<`3o0?ooo`3oool0o`3ooolo
0?ooo`030000003oool0oooo01h0oooo000H0?ooo`030?noW02Lgol0oooo00X0oooo00<0gibL0;oo
o`3oool0303oool0103ookl0M0000000M02oool40?ooo`030=nLB018W=l0oooo0080oooo00<0oooO
09a8M02oool01`3oool00`000000oooo0?ooo`0m0?ooo`<0<ol00P3o00000`0c0?l0oooo0?ooo`3o
0?oood40oooo00<000000?ooo`3oool07P3oool001P0oooo00<0okmd07Boo`3oool02P3oool00`2o
M7@0_ooo0?ooo`0=0?ooo`040?oo_`1d000004RL0=ooo`@0oooo00<0gia804RLg`3oool02`3oool0
0`000000oooo0?ooo`0k0?ooo`<0<ol00P3o00000`0co`00oooo0?ooo`3o0?oood<0oooo00<00000
0?ooo`3oool07P3oool001P0oooo00<0okmd0000000000002P0000000`0007@0_ooo0?ooo`0>0?oo
o`030=nLB0000000M;oo00D0oooo00<0gia807Boo`3oool02P3oool00`000000oooo0?ooo`0i0?oo
o`<0<ol000@0<`3o0?l0000co`00<ol0o`3ooom60?ooo`030000003oool0oooo01h0oooo000H0?oo
o`030?noM0000000000000X0000000<0001d0;ooo`3oool02P3oool00`3OW4P00000000000030000
00030018W03Oool0oooo00<0oooo00<0oooO09a8B02Lgol02P3oool4000003H0oooo0`0co`00100c
0?l0o`000?l0000co`3o0?ooodH0oooo0`00000P0?ooo`00603oool00`3o_g@0M;oo0?ooo`030?oo
o`030?oog`2LM9`0gooo00@0oooo00<0_gAd0;ooo`3oool02@3oool00`2oM0000000001d_`020?oo
o`040?oo_`1d0000001d0;ooo`D0oooo00<0omnL04P0M02oool02@3oool00`000000oooo0?ooo`0e
0?ooo`80<ol00P0c0?l20?l0000303?o003oool0oooo0?l0ooooB03oool00`000000oooo0?ooo`0N
0?ooo`00603oool00`3o_g@0M;oo0?ooo`030?ooo`030?oo_`1d07@0_ooo00@0oooo00<0gibL0;oo
o`3oool0203oool0103ookl0M0000018W03Oool30?ooo`030;md000004P0W=oo00H0oooo00<0_g@0
04RLg`3oool0203oool00`000000oooo0?ooo`0c0?ooo`80<ol00P0c0?l20?l0000303?o003oool0
oooo0?l0ooooBP3oool00`000000oooo0?ooo`0N0?ooo`00603oool00`3o_g@0B9cO0?ooo`030?oo
o`040?noM0000000000007Boo`h0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`06
0?ooo`030=nLB00007@0_ooo00P0oooo00<000000?ooo`3oool0<@3oool203?o0080<`3o00<0<ol0
0?l0000co`00o`3ooom>0?ooo`030000003oool0oooo01h0oooo000H0?ooo`030?oOW0180000M;oo
0080oooo00<0omnL04P0001dM7@00P0000000`00M;l0oooo0?ooo`0;0?ooo`030?oOW0180000B9cO
00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo
0300oooo00@0<ol003<0o`0c0?l0<ol00P3o003o0?oooe00oooo00<000000?ooo`3oool07P3oool0
01T0oooo00<0_g@00000000000000P0000001`00B9`0gooo0?oo_`1d000000000000M02oool02`3o
ool00`3ooml0W4P0001d_`030?ooo`060?oo_`1d0000B9cO0?ooo`3ogi`0W;oo103oool00`2oM000
000007Boo`080?ooo`030000003oool0oooo02l0oooo0P0c0?l00`0co`00o`000?l0003o0?oooe80
oooo00<000000?ooo`3oool07P3oool001X0oooo00D0_g@000000000000004RL0=ooo`030?ooo`04
0;md00000000000004RLg`/0oooo00P0omnL04P0001d_ol0oooo0?oog`2LB00004RL0=ooo`80oooo
00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo`P0oooo00<000000?ooo`3oool0;@3oool2
03<0o`80<ol000<0o`000?ooo`3oool0o`3ooomB0?ooo`030000003oool0oooo01h0oooo000S0?oo
o`040?noM0000000001d0;ooo`/0oooo00H0oono07@00000000000000018W03Oool40?ooo`050;md
00000000000000000000M;l02P3oool00`000000oooo0?ooo`0[0?ooo`80<`3o0P0co`020?l00?l0
ooooE@3oool00`000000oooo0?ooo`0N0?ooo`00903oool00`3ogi`0B01d0;ooo`0T0?ooo`030000
003oool0oooo02X0oooo00<0<`3o03?o000co`000P3o00000`0co`00oooo0?ooo`3o0?oooe@0oooo
00<000000?ooo`3oool07P3oool002D0oooo00<0_gAd0;ooo`3oool08`3oool00`000000oooo0?oo
o`0X0?ooo`80<`3o0P0co`000`3o0000<ol00?ooo`3o0?oooeL0oooo00<000000?ooo`3oool07P3o
ool002D0oooo00<0gibL0;ooo`3oool08`3oool00`000000oooo0?ooo`0V0?ooo`80<`3o0P0co`02
0?l0000303?o003oool0oooo0?l0ooooE`3oool00`000000oooo0?ooo`0N0?ooo`00603oool00`3o
_g@0M;oo0?ooo`0>0?ooo`030;mdB02Lgol0oooo01l0oooo00<000000?ooo`3oool0903oool0100c
o`00<`3o03?o000co`020?l0000303?o003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`0N
0?ooo`006@3oool00`2oM00007Bo0?ooo`0;0?ooo`030?oog`2LB000M;oo0240oooo0`00000R0?oo
o`0303?o000c0?l0<`3o0080<ol000<0o`0003?o003oool0o`3ooomK0?ooo`800000803oool001X0
oooo00@0_g@0000000000000M;oo1`3oool0102oM000000000000018W=lR0?ooo`030000003oool0
oooo0240oooo0P0c0?l203?o0080o`00o`3ooomO0?ooo`030000003oool0oooo01h0oooo000K0?oo
o`030=nLB0000000000000P0000000<0001809cOo`3oool08P3oool00`000000oooo0?ooo`0P0?oo
o`0303<0o`0co`00<ol00080o`00o`3ooomQ0?ooo`030000003oool0oooo01h0oooo000M0?ooo`03
0?noM0000000000000@0000000<0001d0;ooo`3oool0903oool00`000000oooo0?ooo`0N0?ooo`80
<`3o00<0<ol00?l0003o0000o`3ooomS0?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000
003oool0oooo01`0oooo00H0<ol003<0o`0co`00<ol00?l0000co`3o0?ooof@0oooo00<000000?oo
o`3oool07P3oool001P0oooo00<0okmd07Boo`3oool03P3oool00`2oM4P0W=oo0?ooo`0O0?ooo`03
0000003oool0oooo01X0oooo00@0<ol003<0o`0c0?l0<ol00P3o00000`0co`00oooo0?ooo`3o0?oo
of<0oooo00<000000?ooo`3oool07P3oool001T0oooo00<0_g@0001d_`3oool02`3oool00`3ooml0
W4P007Boo`0Q0?ooo`030000003oool0oooo01T0oooo0P0c0?l0100co`00o`000?l0000co`3o0?oo
ofL0oooo00<000000?ooo`3oool07P3oool001X0oooo00@0_g@0000000000000M;oo1`3oool0102o
M000000000000018W=lR0?ooo`030000003oool0oooo01P0oooo00D0<`3o03?o003o0000o`0003?o
003o0?ooofT0oooo00<000000?ooo`3oool07P3oool001/0oooo00<0gia800000000000020000000
0`0004P0W=oo0?ooo`0R0?ooo`030000003oool0oooo01H0oooo0P0c0?l00`0co`00o`0003?o003o
0?ooof/0oooo00<000000?ooo`3oool07P3oool001d0oooo00<0okmd000000000000100000000`00
07@0_ooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo0P0c0?l0100co`00o`000?l0000co`3o
0?ooof`0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool04`3oool0100c
0?l0<ol00?l0003o000203?o0?l0ooooK@3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`00
0000oooo0?ooo`0A0?ooo`80<`3o00@0<ol00?l0000co`00<ol0o`3ooom_0?ooo`030000003oool0
oooo01h0oooo001;0?ooo`030000003oool0oooo00l0oooo0P0c0?l00`0co`00o`000?l0000203?o
0?l0ooooL03oool00`000000oooo0?ooo`0N0?ooo`00B`3oool3000000h0oooo00@0<`3o03?o000c
o`00o`000P0co`3o0?ooog40oooo0P00000P0?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`80
<`3o00<0<ol00?l0003o00000P0co`3o0?ooog<0oooo00<000000?ooo`3oool07P3oool004/0oooo
00<000000?ooo`3oool02P3oool203<0o`0303?o003o0000o`0000<0<ol0o`3ooomd0?ooo`030000
003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo00T0oooo00@0<`3o0?ooo`0co`00o`00
0`0co`3o0?ooogH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool02`3o
ool303?o0?l0ooooN03oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o
0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?oo
o`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool0
7P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;
0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`00
0000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo0`00003o0?ooohD0
oooo0P00000P0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool0
7P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;
0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`00
0000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3o
ool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000`0?ooo`050?oog`2LB00000000000B02L
gol02P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0N0?ooo`00<`3oool0103OW4P000000018W03Oool80?ooo`030?noM0000000M;oo00T0
oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000d0?ooo`040?oo
_`1d0000001d0;ooo`L0oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`3o0?ooohH0
oooo00<000000?ooo`3oool07P3oool003D0oooo00H0oono07@00000B9`0gooo0?ooo`3OW4P70000
00030000B02Lgol0oooo00H0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo
01h0oooo000f0?ooo`060=nLB0000000M;oo0?ooo`3ogi`0B7Bo0`3oool00`3o_g@0000007Boo`09
0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00<P3oool00`3O
W4P0000000000003000000050018W03Oool0oooo0=nLB01d_ol00P3oool00`3o_g@0000007Boo`09
0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00<@3oool00`2o
M0000000001d_`020?ooo`0<0?oo_`1d0000001d0;ooo`3oool0oono07@0M02oool0oooo0?noM000
0000M;oo2@3oool400000?l0ooooP`3oool300000200oooo000`0?ooo`040?oo_`1d000004RL0=oo
o`<0oooo00<0_g@00000B02Lgol00P3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`T0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000`0?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol00`3oool01@2oM000M;oo0?noM0000000M;oo00T0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000`0?ooo`030?oOW0180000
B9cO00@0oooo00<0_g@00000M02oool00`3oool01@3ookl0M01d0;noM0000000M;oo00T0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo000`0?ooo`030?oog`2LB000
07Bo00<0oooo00<0oono07@00018W=l01@3oool0103o_g@000000000001d_ol90?ooo`030000003o
ool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00<@3oool0203ogi`0B00007Boo`3o
ool0oooO09a80000B9`0gooo1@3oool0103ooml0W4P00000001d_ol90?ooo`030000003oool0oooo
0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00<P3oool01P3ookl0M00000000000000004RL
0=ooo`L0oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<00000
0?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo
01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00
B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0
oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool300000?l0ooooQ@3oool20000
0200oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00
B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0
oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?oo
ohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`03
0000003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo
0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3o
ool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?oo
o`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000
oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo0`00003o0?ooohD0oooo
0P00000P0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3o
ool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?oo
o`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000
oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0
o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3o
ool00`000000oooo0?ooo`0N0?ooo`00B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<00000
0?ooo`3oool07P3oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo
01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00
B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`<00000o`3ooon5
0?ooo`800000803oool004/0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo
01h0oooo001;0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00
B`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool07P3oool004/0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo001;0?ooo`030000003oool0
oooo0?l0ooooQP3oool00`000000oooo0?ooo`0N0?ooo`00<03oool01@3ooml0W4P00000000004P0
W=oo00L0oooo00H0oooO09a80000000000000000M02oool90?ooo`030000003oool0oooo0?l0oooo
QP3oool00`000000oooo0?ooo`0N0?ooo`00<`3oool0103OW4P000000018W03Oool40?ooo`080?oo
_`1d000004RL0=ooo`3oool0gia80000B02Lgol80?ooo`030000003oool0oooo0?l0ooooQP3oool0
0`000000oooo0?ooo`0N0?ooo`00=03oool0103ookl0M0000000M02oool30?ooo`030;md000007@0
_ooo00<0oooo00<0_g@0001d_`3oool01`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<00000
0?ooo`3oool07P3oool003D0oooo00P0oono07@00000B9`0gooo0?ooo`3ookl0M000001d_`@0oooo
00<0gia80000M02oool01`3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool0
7P3oool003H0oooo00L0gia80000001d_ol0oooo0?oOW0180000B9cO00@0oooo00<0_g@00000B02L
gol01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool07P3oool00380oooo00<0gia80000000000000`0000001@00B9`0gooo0?oOW0180000B9cO00<0
oooo00@0oono07@0000007@0_ooo1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`00<@3oool00`2oM000
0000001d_`020?ooo`0=0?oo_`1d0000001d0;ooo`3ookl0M00000000000B9`0gooo0?ooo`2oM000
000004RLg`080?ooool00000RP00000P0?ooo`00<03oool0103ookl0M0000018W03Oool30?ooo`08
0;md000004P0W=oo0?oog`2LB000001d0;oOW01800020000000304RLg`3oool0oooo0?l0oooo/@3o
ool00300oooo00<0omnL04P00018W=l0103oool01`3OW4P0001809cOo`3oool0okmd00000018W=l0
o`3ooong0?ooo`00<03oool00`3ogi`0B00004RLg`040?ooo`080;md000007@0_ooo0?ooo`3ooml0
W4P00000B02Lgooo0?oookH0oooo000`0?ooo`030?oog`2LB00007Bo00<0oooo00<0oono07@00018
W=l00`3oool0103ookl0M0000000M02ooooo0?oookD0oooo000a0?ooo`080?oOW0180000M;oo0?oo
o`3ooml0W4P00018W03Oool40?ooo`040?oog`2LB0000000001d_ol0oooo]03oool00380oooo00H0
oono07@00000000000000018W03Oool70?ooo`050?oOW018000000000018W03Oool0o`3ooona0?oo
o`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?oo
o`00o`3ooooe0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499.625}, {308.438, 0}} -> {-11.9189, 83.7688, \
0.196539, 0.0412996}}]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 717}},
CellGrouping->Manual,
WindowSize->{1272, 205},
WindowMargins->{{0, Automatic}, {Automatic, 239}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 157, 4, 35, "Input"],

Cell[CellGroupData[{
Cell[1936, 59, 109, 2, 35, "Input"],
Cell[2048, 63, 202, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[2275, 71, 1595, 32, 373, "Input"],
Cell[3873, 105, 175, 3, 25, "Print"],
Cell[4051, 110, 208, 4, 25, "Print"]
}, Open  ]],
Cell[4274, 117, 583, 10, 171, "Input"],
Cell[4860, 129, 59, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4956, 135, 89, 2, 32, "Input"],
Cell[5048, 139, 83, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[5156, 144, 364, 6, 50, "Input"],
Cell[5523, 152, 73504, 1962, 309, 28833, 1406, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[79076, 2120, 89, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[79190, 2126, 1758, 34, 190, "Input"],
Cell[80951, 2162, 273349, 7780, 591, 115285, 5825, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[354349, 9948, 89, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[354463, 9954, 1098, 20, 150, "Input"],
Cell[355564, 9976, 115570, 3703, 295, 55431, 2956, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[471183, 13685, 89, 2, 32, "Input"],
Cell[471275, 13689, 1307, 36, 30, "Input"],

Cell[CellGroupData[{
Cell[472607, 13729, 494, 9, 70, "Input"],
Cell[473104, 13740, 99789, 3708, 318, 55002, 3151, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[572942, 17454, 89, 2, 32, "Input"],
Cell[573034, 17458, 2003, 39, 363, "Input"],

Cell[CellGroupData[{
Cell[575062, 17501, 928, 20, 170, "Input"],
Cell[575993, 17523, 113, 2, 29, "Output"],
Cell[576109, 17527, 43805, 1259, 186, 18739, 945, "GraphicsData", \
"PostScript", "Graphics"],
Cell[619917, 18788, 74, 1, 29, "Output"],
Cell[619994, 18791, 197, 4, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[620228, 18800, 929, 20, 170, "Input"],
Cell[621160, 18822, 113, 2, 29, "Output"],
Cell[621276, 18826, 43153, 1273, 186, 19080, 971, "GraphicsData", \
"PostScript", "Graphics"],
Cell[664432, 20101, 74, 1, 29, "Output"],
Cell[664509, 20104, 197, 4, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[664743, 20113, 878, 18, 170, "Input"],
Cell[665624, 20133, 113, 2, 29, "Output"],
Cell[665740, 20137, 41091, 1147, 186, 15891, 831, "GraphicsData", \
"PostScript", "Graphics"],
Cell[706834, 21286, 74, 1, 29, "Output"],
Cell[706911, 21289, 197, 4, 25, "Print"]
}, Open  ]],
Cell[707123, 21296, 287, 8, 30, "Input"],
Cell[707413, 21306, 1325, 25, 130, "Input"],

Cell[CellGroupData[{
Cell[708763, 21335, 272, 5, 50, "Input"],
Cell[709038, 21342, 78877, 2108, 344, 29601, 1495, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[787964, 23456, 89, 2, 32, "Input"],
Cell[788056, 23460, 1825, 35, 210, "Input"],
Cell[789884, 23497, 418, 12, 30, "Input"],
Cell[790305, 23511, 119, 2, 35, "Input"],

Cell[CellGroupData[{
Cell[790449, 23517, 341, 7, 50, "Input"],
Cell[790793, 23526, 73662, 2010, 318, 28196, 1444, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

