(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    882900,      25696]*)
(*NotebookOutlinePosition[    883566,      25719]*)
(*  CellTagsIndexPosition[    883522,      25715]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\( (*\ 
        This\ file\ deals\ with\ the\ \[CapitalLambda]CDM\ case\ \((see\ eqs\ \
\((2.29)\), \ \(\((2.30)\)\  &\)\ \((2.31)\)\ of\ the\ paper)\)\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ This\ part\ defines\ various\ quantities\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(Off[
      General::"\<spell1\>"]; $TextStyle = {FontFamily \[Rule] "\<Times\>", 
        FontSize \[Rule] 20}; SetDirectory["\<D:\mathfiles\>"];\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nmin = \(-30\);\)\), "\[IndentingNewLine]", 
    \(\(nmax = 10;\)\), "\n", 
    \(\(om0 =  .3;\)\), "\n", 
    \(\(\(or0 = 10^\(-4\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(R[z_] := 
      6 \((2  h[z]^2 - \((1 + z)\) 
              h[z] \(h'\)[z])\)\), "\[IndentingNewLine]", 
    \(h[z_] := \@\(om\ \((1 + z)\)^3 + or \((1 + z)\)^4 + 1 - om - or\)\), "\n\
", 
    \(\(tt = 
        2 - \((1 + z)\) \(h'\)[z]/h[z] /. z \[Rule] \((Exp[\(-n\)] - 1)\) // 
          Simplify;\)\), "\n", 
    \(\(\(x3[N_] := \(\(tt /. n \[Rule] N\) /. om \[Rule] om0\) /. 
        or \[Rule] or0\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(RN[N_] := \(\(R[z] /. z \[Rule] \((Exp[\(-N\)] - 1)\)\) /. 
          om \[Rule] om0\) /. or \[Rule] or0\), "\n", 
    \(hN[N_] := \(\(h[z] /. z \[Rule] \((Exp[\(-N\)] - 1)\)\) /. 
          om \[Rule] om0\) /. or \[Rule] or0\), "\n", 
    \(x2anal[
        N_] := \(-\(\(RN[N] - 6 \((1 - om0 - or0)\)\)\/\(6 
               hN[N]^2\)\)\)\), "\n", 
    \(x3anal[N_] := RN[N]\/\(6  hN[N]^2\)\), "\n", 
    \(\(\(x4anal[
        N_] := \(or0\ Exp[\(-4\) N]\)\/hN[N]^2\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Om0 = \(om0\ \ \[ExponentialE]\^\(\(-3\)\ N\)\)\/hN[N]^2 /. 
          N \[Rule] nmin;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3min = x3[nmin];\)\), "\n", 
    \(\(x1min = 0;\)\), "\n", 
    \(\(x4min = x4anal[nmin];\)\), "\[IndentingNewLine]", 
    \(\(\(x2min = 1 - Om0 - x3min - x4min;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Print["\<x2min-x2anal[nmin]] = \>", x2min - x2anal[nmin]]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("x2min-x2anal[nmin]] = \
"\[InvisibleSpace]\(-3.542005068332055`*^-16\)\),
      SequenceForm[ "x2min-x2anal[nmin]] = ", -.35420050683320548*^-15],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ 
        Case\ 1\ for\ \[CapitalLambda]CDM\ when\ we\ consider\ that\ the\ \
system\ decouples\ \ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[{
    \(\(eqns = {\(-2\) x3[N] x4[N] \[Equal] \(x4'\)[N]};\)\), "\n", 
    \(\(nsol = \(NDSolve[\((Flatten[{eqns, x4[nmin] \[Equal] x4min}])\), 
            x4[N], {N, nmin, nmax}]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(eqns1 = {4\ x3[N] - 2\ x3[N]\^2 - \(x3'\)[N] - 
              x2[N] \((2  x3[N] - 4)\) \[Equal] \(x2'\)[N]};\)\), "\n", 
    \(\(nsol1 = \(NDSolve[\((Flatten[{eqns1, x2[nmin] \[Equal] x2min}])\), 
            x2[N], {N, nmin, nmax}]\)[\([1]\)];\)\)}], "Input"],

Cell[BoxData[{
    \(\(x1[N_] := 0;\)\), "\[IndentingNewLine]", 
    \(xx1[N_] := x1[N]\), "\n", 
    \(xx2[N_] := x2[N] /. nsol1\), "\[IndentingNewLine]", 
    \(xx4[N_] := x4[N] /. nsol\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ 
        There\ seems\ to\ be\ a\ problem\ with\ x2[N]\ \((?)\)\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pl1 = 
        Plot[{xx2[N], x2anal[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] All, Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", "\<x2[N]\>"}, 
          PlotStyle \[Rule] {Hue[0], Hue[ .7]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(pl2 = 
        Plot[{xx4[N], x4anal[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] All, Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", "\<x4[N]\>"}, 
          PlotStyle \[Rule] {Hue[0], Hue[ .7]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{pl1, pl2}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .30902 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00735755 0.47619 [
[ 0 0 0 0 ]
[ 1 .30902 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .30902 L
0 .30902 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00735755 0.5 0.301659 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.0238095 0.603319 5.41918e-036 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.2619 -0.0125 -19.0313 -24.5625 ]
[.2619 -0.0125 19.0313 0 ]
[.5 -0.0125 -19.0313 -24.5625 ]
[.5 -0.0125 19.0313 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -12.0625 -24.5625 ]
[.97619 -0.0125 12.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .0614 -81.4375 -12.2813 ]
[-0.0125 .0614 0 12.2813 ]
[-0.0125 .16978 -81.4375 -12.2813 ]
[-0.0125 .16978 0 12.2813 ]
[-0.0125 .27817 -81.4375 -12.2813 ]
[-0.0125 .27817 0 12.2813 ]
[-0.0125 .38655 -81.4375 -12.2813 ]
[-0.0125 .38655 0 12.2813 ]
[-0.0125 .49494 -81.4375 -12.2813 ]
[-0.0125 .49494 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -106 -26.0938 ]
[-0.01875 .30902 -81.4375 26.0938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0614 m
.00625 .0614 L
s
gsave
-0.0125 .0614 -142.438 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
89.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
105.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
125.813 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
1.000 setlinewidth
grestore
0 .16978 m
.00625 .16978 L
s
gsave
-0.0125 .16978 -142.438 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
89.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
105.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
125.813 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
1.000 setlinewidth
grestore
0 .27817 m
.00625 .27817 L
s
gsave
-0.0125 .27817 -142.438 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
89.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
105.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
125.813 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
1.000 setlinewidth
grestore
0 .38655 m
.00625 .38655 L
s
gsave
-0.0125 .38655 -142.438 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
89.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
105.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
125.813 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
1.000 setlinewidth
grestore
0 .49494 m
.00625 .49494 L
s
gsave
-0.0125 .49494 -142.438 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
89.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
105.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
125.813 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0885 m
.00375 .0885 L
s
0 .11559 m
.00375 .11559 L
s
0 .14269 m
.00375 .14269 L
s
0 .19688 m
.00375 .19688 L
s
0 .22398 m
.00375 .22398 L
s
0 .25107 m
.00375 .25107 L
s
0 .30526 m
.00375 .30526 L
s
0 .33236 m
.00375 .33236 L
s
0 .35946 m
.00375 .35946 L
s
0 .41365 m
.00375 .41365 L
s
0 .44074 m
.00375 .44074 L
s
0 .46784 m
.00375 .46784 L
s
0 .52203 m
.00375 .52203 L
s
0 .54913 m
.00375 .54913 L
s
0 .57622 m
.00375 .57622 L
s
0 .03431 m
.00375 .03431 L
s
0 .00721 m
.00375 .00721 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -180.813 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
87.0938 16.2813 translate
90 rotate
-87.0938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.125 23.000 moveto
(@) show
90.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
104.500 23.000 moveto
(D) show
111.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0614 m
1 .0614 L
s
.99375 .16978 m
1 .16978 L
s
.99375 .27817 m
1 .27817 L
s
.99375 .38655 m
1 .38655 L
s
.99375 .49494 m
1 .49494 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .0885 m
1 .0885 L
s
.99625 .11559 m
1 .11559 L
s
.99625 .14269 m
1 .14269 L
s
.99625 .19688 m
1 .19688 L
s
.99625 .22398 m
1 .22398 L
s
.99625 .25107 m
1 .25107 L
s
.99625 .30526 m
1 .30526 L
s
.99625 .33236 m
1 .33236 L
s
.99625 .35946 m
1 .35946 L
s
.99625 .41365 m
1 .41365 L
s
.99625 .44074 m
1 .44074 L
s
.99625 .46784 m
1 .46784 L
s
.99625 .52203 m
1 .52203 L
s
.99625 .54913 m
1 .54913 L
s
.99625 .57622 m
1 .57622 L
s
.99625 .03431 m
1 .03431 L
s
.99625 .00721 m
1 .00721 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07012 .60332 L
.07295 .60332 L
.07536 .60332 L
.07796 .60332 L
.08041 .60332 L
.08265 .60332 L
.084 .60332 L
.08544 .60332 L
.08802 .60332 L
.08961 .60332 L
.0911 .60332 L
.09246 .60332 L
.09389 .60332 L
.09517 .60332 L
.09657 .60332 L
.09903 .60332 L
.10041 .60332 L
.1019 .60332 L
.10317 .60332 L
.10458 .60332 L
.10714 .60332 L
.10855 .60332 L
.10986 .60332 L
.11222 .60332 L
.11354 .60332 L
.11475 .60332 L
.116 .60332 L
.11733 .60332 L
.11879 .60332 L
.12014 .60332 L
.12167 .60332 L
.12312 .60332 L
.1244 .60332 L
.12582 .60332 L
.12826 .60332 L
.12959 .60332 L
.13084 .60332 L
.13308 .60332 L
.13433 .60332 L
.13547 .60332 L
.13804 .60332 L
Mistroke
.1395 .60332 L
.14084 .60332 L
.14331 .60332 L
.14469 .60332 L
.14594 .60332 L
.14827 .60332 L
.1496 .60332 L
.15083 .60332 L
.15332 .60332 L
.15472 .60332 L
.15599 .60332 L
.15827 .60332 L
.15955 .60332 L
.16074 .60332 L
.16291 .60332 L
.16401 .60332 L
.16523 .60332 L
.16654 .60332 L
.16793 .60332 L
.1704 .60332 L
.17178 .60332 L
.17307 .60332 L
.17448 .60332 L
.17598 .60332 L
.17728 .60332 L
.1787 .60332 L
.17995 .60332 L
.18126 .60332 L
.18245 .60332 L
.18376 .60332 L
.18606 .60332 L
.18736 .60332 L
.18856 .60332 L
.18986 .60332 L
.19129 .60332 L
.19369 .60332 L
.19501 .60332 L
.19625 .60332 L
.19738 .60332 L
.19858 .60332 L
.20072 .60332 L
.20191 .60332 L
.20302 .60332 L
.20555 .60332 L
.20685 .60332 L
.20827 .60332 L
.20951 .60332 L
.21084 .60332 L
.21203 .60332 L
.21334 .60332 L
Mistroke
.21565 .60332 L
.21705 .60332 L
.21834 .60332 L
.21982 .60332 L
.22123 .60332 L
.22373 .60332 L
.22514 .60332 L
.22645 .60332 L
.22774 .60332 L
.2291 .60332 L
.23153 .60332 L
.23289 .60332 L
.23415 .60332 L
.23554 .60332 L
.23703 .60332 L
.23831 .60332 L
.23971 .60332 L
.24094 .60332 L
.24224 .60332 L
.24341 .60332 L
.24471 .60332 L
.24699 .60332 L
.24816 .60332 L
.2494 .60332 L
.25161 .60332 L
.25284 .60332 L
.25399 .60332 L
.25533 .60332 L
.25659 .60332 L
.25769 .60332 L
.25887 .60332 L
.26095 .60332 L
.26212 .60332 L
.26337 .60332 L
.2656 .60332 L
.26681 .60332 L
.26813 .60332 L
.2693 .60332 L
.27054 .60332 L
.27177 .60332 L
.27288 .60332 L
.27505 .60332 L
.27636 .60332 L
.27756 .60332 L
.27886 .60332 L
.28027 .60332 L
.28267 .60332 L
.28397 .60332 L
.28519 .60332 L
.28633 .60332 L
Mistroke
.28757 .60332 L
.28866 .60332 L
.28982 .60332 L
.29087 .60332 L
.29202 .60332 L
.29404 .60332 L
.29527 .60332 L
.29639 .60332 L
.29761 .60332 L
.29893 .60332 L
.30015 .60332 L
.30128 .60332 L
.30351 .60332 L
.30479 .60332 L
.30615 .60332 L
.30858 .60332 L
.30993 .60332 L
.3112 .60332 L
.31258 .60332 L
.31407 .60332 L
.31535 .60332 L
.31674 .60332 L
.31797 .60332 L
.31927 .60332 L
.32045 .60332 L
.32174 .60332 L
.32402 .60332 L
.32519 .60332 L
.32643 .60332 L
.32864 .60332 L
.32987 .60332 L
.33101 .60332 L
.33235 .60332 L
.33362 .60332 L
.33471 .60332 L
.3359 .60332 L
.33797 .60332 L
.33915 .60332 L
.34039 .60332 L
.34263 .60332 L
.34383 .60332 L
.34515 .60332 L
.34632 .60332 L
.34755 .60332 L
.34878 .60332 L
.34989 .60332 L
.35206 .60332 L
.35336 .60332 L
.35457 .60332 L
.35586 .60332 L
Mistroke
.35728 .60332 L
.35967 .60332 L
.36097 .60332 L
.36219 .60332 L
.36333 .60332 L
.36457 .60332 L
.36566 .60332 L
.36682 .60332 L
.36786 .60332 L
.36901 .60332 L
.37103 .60332 L
.37226 .60332 L
.37338 .60332 L
.3746 .60332 L
.37592 .60332 L
.37815 .60332 L
.37937 .60332 L
.3805 .60332 L
.38178 .60332 L
.38314 .60332 L
.38556 .60332 L
.38691 .60332 L
.38817 .60332 L
.38956 .60332 L
.39104 .60332 L
.39232 .60332 L
.39371 .60332 L
.39494 .60332 L
.39624 .60332 L
.39741 .60332 L
.39871 .60332 L
.40099 .60332 L
.40216 .60332 L
.40339 .60332 L
.4056 .60332 L
.40683 .60332 L
.40797 .60332 L
.40931 .60332 L
.41058 .60332 L
.41167 .60332 L
.41286 .60332 L
.41493 .60332 L
.4161 .60332 L
.41735 .60332 L
.41959 .60332 L
.42079 .60332 L
.42211 .60332 L
.42327 .60332 L
.4245 .60332 L
.42573 .60332 L
Mistroke
.42684 .60332 L
.429 .60332 L
.43031 .60332 L
.43151 .60332 L
.4328 .60332 L
.43421 .60332 L
.4366 .60332 L
.43791 .60332 L
.43913 .60332 L
.44026 .60332 L
.4415 .60332 L
.44259 .60332 L
.44375 .60332 L
.44479 .60332 L
.44594 .60332 L
.44796 .60332 L
.44919 .60332 L
.45031 .60332 L
.45152 .60332 L
.45284 .60332 L
.45508 .60332 L
.4563 .60332 L
.45743 .60332 L
.45871 .60332 L
.46006 .60332 L
.46248 .60332 L
.46383 .60332 L
.46509 .60332 L
.46656 .60332 L
.46796 .60332 L
.46915 .60332 L
.47046 .60332 L
.47275 .60332 L
.47404 .60332 L
.47542 .60332 L
.47671 .60332 L
.47789 .60332 L
.48031 .60332 L
.48158 .60332 L
.48292 .60332 L
.48518 .60332 L
.48646 .60332 L
.48765 .60332 L
.48988 .60332 L
.49191 .60332 L
.49304 .60332 L
.49426 .60332 L
.49648 .60332 L
.4977 .60332 L
.49882 .60332 L
Mistroke
.50003 .60332 L
.50135 .60332 L
.50256 .60332 L
.50369 .60332 L
.50591 .60332 L
.50727 .60332 L
.50855 .60332 L
.51094 .60332 L
.51228 .60332 L
.51351 .60332 L
.51486 .60332 L
.5163 .60332 L
.51762 .60332 L
.51882 .60332 L
.52117 .60332 L
.52249 .60332 L
.52392 .60332 L
.52652 .60332 L
.52781 .60332 L
.52924 .60332 L
.53063 .60332 L
.53213 .60332 L
.53353 .60332 L
.53481 .60332 L
.5361 .60332 L
.53732 .60332 L
.5398 .60332 L
.54206 .60332 L
.54448 .60332 L
.54585 .60332 L
.54711 .60332 L
.54922 .60332 L
.55154 .60332 L
.55396 .60332 L
.55623 .60332 L
.55751 .60332 L
.5589 .60332 L
.56144 .60332 L
.56391 .60332 L
.5662 .60332 L
.56893 .60332 L
.57139 .60332 L
.57276 .60332 L
.57424 .60332 L
.57692 .60332 L
.5793 .60332 L
.58185 .60332 L
.58425 .60332 L
.58644 .60332 L
.58901 .60332 L
Mistroke
.59037 .60332 L
.5918 .60332 L
.59444 .60332 L
.59688 .60332 L
.59937 .60332 L
.60205 .60332 L
.60458 .60332 L
.6069 .60332 L
.60947 .60332 L
.61229 .60332 L
.61371 .60332 L
.61522 .60332 L
.61795 .60332 L
.62055 .60332 L
.62329 .60332 L
.62563 .60332 L
.62821 .60332 L
.63098 .60332 L
.63253 .60332 L
.63395 .60332 L
.63671 .60332 L
.63932 .60331 L
.64175 .60331 L
.64433 .60331 L
.64676 .60331 L
.64897 .6033 L
.65157 .60329 L
.65439 .60328 L
.65704 .60327 L
.65948 .60325 L
.66195 .60323 L
.6642 .6032 L
.6668 .60315 L
.66925 .60309 L
.67152 .60301 L
.67362 .60291 L
.67592 .60278 L
.67836 .60258 L
.68081 .60232 L
.68344 .60192 L
.68593 .60141 L
.6882 .60078 L
.69086 .59978 L
.69376 .59822 L
.6965 .59615 L
.69905 .59348 L
.70169 .58968 L
.70412 .58494 L
.70679 .57791 L
.70961 .56772 L
Mistroke
.71206 .55585 L
.71436 .54163 L
.71687 .52182 L
.71956 .49492 L
.72456 .42813 L
.7293 .34734 L
.73817 .19018 L
.74276 .12797 L
.74537 .10086 L
.74782 .08052 L
.7504 .06381 L
.75276 .05198 L
.75535 .04208 L
.75808 .03438 L
.76028 .02974 L
.76263 .02596 L
.76485 .02325 L
.76687 .02136 L
.76925 .01965 L
.77182 .01829 L
.77425 .01735 L
.7765 .01671 L
.77894 .01618 L
.78117 .01582 L
.78374 .01552 L
.78619 .0153 L
.78844 .01516 L
.79053 .01506 L
.79282 .01497 L
.79526 .0149 L
.79794 .01485 L
.79935 .01483 L
.80084 .01481 L
.80357 .01478 L
.80609 .01476 L
.80851 .01475 L
.81076 .01474 L
.81324 .01473 L
.81589 .01473 L
.81847 .01473 L
.82119 .01472 L
.82352 .01472 L
.82609 .01472 L
.82885 .01472 L
.83039 .01472 L
.83181 .01472 L
.83442 .01472 L
.83717 .01472 L
.83958 .01472 L
.84216 .01472 L
Mistroke
.84459 .01472 L
.84679 .01472 L
.84939 .01472 L
.8522 .01472 L
.85486 .01472 L
.8573 .01472 L
.85975 .01472 L
.86199 .01472 L
.86457 .01472 L
.86702 .01472 L
.86928 .01472 L
.87137 .01472 L
.87366 .01472 L
.87482 .01472 L
.8761 .01472 L
.87877 .01472 L
.88122 .01472 L
.88251 .01472 L
.88391 .01472 L
.88675 .01472 L
.88925 .01472 L
.89065 .01472 L
.89193 .01472 L
.89442 .01472 L
.89675 .01472 L
.89906 .01472 L
.90159 .01472 L
.90406 .01472 L
.90545 .01472 L
.90672 .01472 L
.90897 .01472 L
.91016 .01472 L
.91143 .01472 L
.91375 .01472 L
.91591 .01472 L
.91861 .01472 L
.92013 .01472 L
.92153 .01472 L
.92275 .01472 L
.92345 .01472 L
.9241 .01472 L
.92541 .01472 L
.92615 .01472 L
.92682 .01472 L
.92925 .01472 L
.93189 .01472 L
.9367 .01472 L
.9379 .01472 L
.93902 .01472 L
.94018 .01472 L
Mistroke
.94145 .01472 L
.94275 .01472 L
.94347 .01472 L
.94413 .01472 L
.94658 .01472 L
.95103 .01472 L
.95225 .01472 L
.95354 .01472 L
.95464 .01472 L
.95585 .01472 L
.95709 .01472 L
.95779 .01472 L
.95842 .01472 L
.95966 .01472 L
.96083 .01472 L
.9631 .01472 L
.96437 .01472 L
.96552 .01472 L
.96618 .01472 L
.96689 .01472 L
.96817 .01472 L
.96945 .01472 L
.97063 .01472 L
.97619 .01472 L
Mfstroke
.2 0 1 r
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07295 .60332 L
.08265 .60332 L
.08804 .60332 L
.09308 .60332 L
.09862 .60332 L
.10458 .60332 L
.11468 .60332 L
.1204 .60332 L
.12571 .60332 L
.13544 .60332 L
.14087 .60332 L
.1458 .60332 L
.15068 .60332 L
.15583 .60332 L
.16505 .60332 L
.17018 .60332 L
.17498 .60332 L
.18019 .60332 L
.18587 .60332 L
.1913 .60332 L
.19632 .60332 L
.20103 .60332 L
.20622 .60332 L
.21522 .60332 L
.22015 .60332 L
.22478 .60332 L
.23461 .60332 L
.23955 .60332 L
.24496 .60332 L
.2496 .60332 L
.25455 .60332 L
.26347 .60332 L
.2688 .60332 L
.27371 .60332 L
.279 .60332 L
.28481 .60332 L
.2946 .60332 L
.29996 .60332 L
.30496 .60332 L
.30994 .60332 L
.31537 .60332 L
Mistroke
.32016 .60332 L
.32525 .60332 L
.3303 .60332 L
.33487 .60332 L
.34379 .60332 L
.34868 .60332 L
.35384 .60332 L
.36307 .60332 L
.36822 .60332 L
.37301 .60332 L
.37823 .60332 L
.38391 .60332 L
.38935 .60332 L
.39439 .60332 L
.3991 .60332 L
.4043 .60332 L
.41331 .60332 L
.41824 .60332 L
.42287 .60332 L
.43273 .60332 L
.43768 .60332 L
.44309 .60332 L
.44773 .60332 L
.45269 .60332 L
.46161 .60332 L
.46695 .60332 L
.47188 .60332 L
.47717 .60332 L
.48299 .60332 L
.49279 .60332 L
.50316 .60332 L
.51335 .60332 L
.52264 .60332 L
.54355 .60332 L
.56422 .60332 L
.57332 .60332 L
.58336 .60332 L
.59293 .60332 L
.60192 .60332 L
.61142 .60332 L
.61676 .60332 L
.62166 .60332 L
.62639 .60332 L
.63145 .60332 L
.64056 .60332 L
.64613 .60332 L
.6514 .60332 L
.66125 .60332 L
.67096 .60332 L
.67627 .60332 L
Mistroke
.68124 .60332 L
.68547 .60332 L
.68785 .60332 L
.69002 .60332 L
.69239 .60332 L
.69498 .60332 L
.69742 .60332 L
.69969 .60332 L
.70233 .60332 L
.70477 .60332 L
.70744 .60332 L
.71026 .60332 L
.71272 .60332 L
.71501 .60332 L
.71753 .60332 L
.72022 .60332 L
.72523 .60332 L
.72996 .60332 L
.73884 .60332 L
.74343 .60332 L
.74604 .60332 L
.7485 .60332 L
.75108 .60332 L
.75344 .60332 L
.75603 .60332 L
.75876 .60332 L
.76097 .60332 L
.76332 .60332 L
.76554 .60332 L
.76756 .60332 L
.76994 .60332 L
.77251 .60332 L
.77494 .60332 L
.77718 .60332 L
.77963 .60332 L
.78186 .60332 L
.78444 .60332 L
.78689 .60332 L
.78914 .60332 L
.79123 .60332 L
.79352 .60332 L
.79596 .60332 L
.79865 .60332 L
.80016 .60332 L
.80155 .60332 L
.8041 .60332 L
.8068 .60332 L
.80922 .60332 L
.81148 .60332 L
.81396 .60332 L
Mistroke
.81661 .60332 L
.81918 .60332 L
.82192 .60332 L
.82425 .60332 L
.82682 .60332 L
.82957 .60332 L
.83112 .60332 L
.83254 .60332 L
.83529 .60332 L
.8379 .60332 L
.84032 .60332 L
.84289 .60332 L
.84533 .60332 L
.84753 .60332 L
.85013 .60332 L
.85294 .60332 L
.8556 .60332 L
.85804 .60332 L
.8605 .60332 L
.86274 .60332 L
.86532 .60332 L
.86777 .60332 L
.87003 .60332 L
.87212 .60332 L
.87442 .60332 L
.87686 .60332 L
.87929 .60332 L
.88192 .60332 L
.8844 .60332 L
.88668 .60332 L
.8892 .60332 L
.89196 .60332 L
.89335 .60332 L
.89484 .60332 L
.89752 .60332 L
.9001 .60332 L
.90284 .60332 L
.90518 .60332 L
.90775 .60332 L
.91052 .60332 L
.91207 .60332 L
.91349 .60332 L
.91624 .60332 L
.91885 .60332 L
.92127 .60332 L
.92385 .60332 L
.92629 .60332 L
.92849 .60332 L
.93109 .60332 L
.93391 .60332 L
Mistroke
.93656 .60332 L
.939 .60332 L
.94132 .60332 L
.94343 .60332 L
.94587 .60332 L
.94818 .60332 L
.95031 .60332 L
.95228 .60332 L
.95444 .60332 L
.95674 .60332 L
.95904 .60332 L
.96151 .60332 L
.96385 .60332 L
.96599 .60332 L
.96837 .60332 L
.97096 .60332 L
.97227 .60332 L
.97299 .60332 L
.97367 .60332 L
.97499 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00735755 0.97619 0.301659 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.0238095 0.0147151 0.588604 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.2619 -0.0125 -19.0313 -24.5625 ]
[.2619 -0.0125 19.0313 0 ]
[.5 -0.0125 -19.0313 -24.5625 ]
[.5 -0.0125 19.0313 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -12.0625 -24.5625 ]
[.97619 -0.0125 12.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -14.0625 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .13244 -29.125 -12.2813 ]
[-0.0125 .13244 0 12.2813 ]
[-0.0125 .25016 -29.125 -12.2813 ]
[-0.0125 .25016 0 12.2813 ]
[-0.0125 .36788 -29.125 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .4856 -29.125 -12.2813 ]
[-0.0125 .4856 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -26.0938 ]
[-0.01875 .30902 -29.125 26.0938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -128.5 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
87.0938 16.2813 translate
90 rotate
-87.0938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x4) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.125 23.000 moveto
(@) show
90.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
104.500 23.000 moveto
(D) show
111.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.03053 .60332 L
.03279 .60332 L
.0379 .60332 L
.04262 .60332 L
.06244 .60332 L
.0829 .60332 L
.08787 .60332 L
.08918 .60332 L
.09061 .60332 L
.09196 .60332 L
.09322 .60332 L
.09628 .60332 L
.09908 .60332 L
.10458 .60332 L
.10966 .60332 L
.11515 .60332 L
.11767 .60332 L
.11894 .60332 L
.12033 .60332 L
.1251 .60332 L
.13466 .60332 L
.14371 .60332 L
.1486 .60332 L
.15391 .60332 L
.16322 .60332 L
.16849 .60332 L
.17408 .60332 L
.17933 .60332 L
.18413 .60332 L
.1935 .60332 L
.19842 .60332 L
.2036 .60332 L
.21233 .60332 L
.21728 .60332 L
.22188 .60332 L
.22693 .60332 L
.23241 .60332 L
.23723 .60332 L
.24234 .60332 L
.24695 .60332 L
.25201 .60332 L
.26093 .60332 L
.26614 .60331 L
.27109 .60331 L
.28038 .60331 L
Mistroke
.28556 .60331 L
.29037 .60331 L
.29561 .6033 L
.30127 .6033 L
.30679 .60329 L
.31186 .60329 L
.31662 .60328 L
.32183 .60327 L
.33089 .60325 L
.33584 .60324 L
.34045 .60322 L
.34547 .6032 L
.35093 .60317 L
.35574 .60313 L
.36084 .60309 L
.36543 .60304 L
.37049 .60297 L
.37941 .60281 L
.38434 .6027 L
.38953 .60255 L
.3988 .60218 L
.40397 .6019 L
.40877 .60159 L
.414 .60116 L
.41967 .60059 L
.42516 .59988 L
.43022 .59907 L
.43496 .59815 L
.44016 .59689 L
.44921 .59397 L
.45415 .59186 L
.45876 .58947 L
.46376 .58633 L
.4692 .58212 L
.47399 .5776 L
.47909 .57179 L
.48872 .5573 L
.49764 .53869 L
.507 .51239 L
.51709 .47486 L
.53536 .38228 L
.55498 .26295 L
.56537 .20333 L
.57647 .14909 L
.5872 .10805 L
.59697 .08014 L
.60678 .05972 L
.61606 .04598 L
.62068 .04071 L
.62576 .03589 L
Mistroke
.63072 .03203 L
.63605 .02864 L
.64102 .02606 L
.64557 .02412 L
.65449 .02121 L
.65926 .02004 L
.66435 .01903 L
.67349 .01766 L
.67909 .01704 L
.68437 .01658 L
.68907 .01624 L
.69422 .01594 L
.70399 .01551 L
.70933 .01533 L
.71431 .01519 L
.72323 .01498 L
.72787 .0149 L
.73279 .01483 L
.73531 .0148 L
.73808 .01477 L
.74061 .01476 L
.74298 .01475 L
.74433 .01474 L
.74576 .01474 L
.74831 .01473 L
.74973 .01473 L
.75105 .01472 L
.75249 .01472 L
.75405 .01472 L
.75541 .01472 L
.75667 .01472 L
.75785 .01472 L
.75915 .01472 L
.7614 .01472 L
.76263 .01472 L
.76378 .01472 L
.76512 .01472 L
.7664 .01472 L
.76879 .01472 L
.77013 .01472 L
.77137 .01472 L
.77273 .01472 L
.77417 .01472 L
.77544 .01472 L
.77683 .01472 L
.77927 .01472 L
.78065 .01472 L
.78212 .01472 L
.78478 .01472 L
.78607 .01472 L
Mistroke
.78746 .01472 L
.78869 .01472 L
.79 .01472 L
.79117 .01472 L
.79247 .01472 L
.79475 .01472 L
.79599 .01472 L
.79717 .01472 L
.79938 .01472 L
.80062 .01472 L
.80176 .01472 L
.8031 .01472 L
.80437 .01472 L
.80665 .01472 L
.80873 .01472 L
.81096 .01472 L
.81222 .01472 L
.81338 .01472 L
.81807 .01472 L
.82065 .01472 L
.8231 .01472 L
.82538 .01472 L
.82667 .01472 L
.82786 .01472 L
.82886 .01472 L
.82996 .01472 L
.83111 .01472 L
.83219 .01472 L
.8334 .01472 L
.8347 .01472 L
.83592 .01472 L
.83703 .01472 L
.83828 .01472 L
.83947 .01472 L
.84075 .01472 L
.84147 .01472 L
.84213 .01472 L
.84485 .01472 L
.84551 .01472 L
.84622 .01472 L
.84699 .01472 L
.84772 .01472 L
.84838 .01472 L
.8491 .01472 L
.8504 .01472 L
.85167 .01472 L
.85285 .01472 L
.85414 .01472 L
.8555 .01472 L
.85666 .01472 L
Mistroke
.85794 .01472 L
.85866 .01472 L
.85931 .01472 L
.86007 .01472 L
.86078 .01472 L
.86206 .01472 L
.86277 .01472 L
.86344 .01472 L
.86462 .01472 L
.86574 .01472 L
.86696 .01472 L
.86827 .01472 L
.86958 .01472 L
.87023 .01472 L
.87095 .01472 L
.8734 .01472 L
.87807 .01472 L
.88068 .01472 L
.88305 .01472 L
.88527 .01472 L
.88652 .01472 L
.88767 .01472 L
.88867 .01472 L
.88978 .01472 L
.89094 .01472 L
.89202 .01472 L
.89328 .01472 L
.89391 .01472 L
.89461 .01472 L
.89585 .01472 L
.89701 .01472 L
.90245 .01472 L
.9076 .01472 L
.90986 .01472 L
.91234 .01472 L
.91444 .01472 L
.91559 .01472 L
.91668 .01472 L
.91792 .01472 L
.91905 .01472 L
.92011 .01472 L
.92126 .01472 L
.92241 .01472 L
.92369 .01472 L
.92626 .01472 L
.93088 .01472 L
.93337 .01472 L
.93468 .01472 L
.93608 .01472 L
.93743 .01472 L
Mistroke
.93864 .01472 L
.93987 .01472 L
.94102 .01472 L
.94215 .01472 L
.94334 .01472 L
.94436 .01472 L
.94548 .01472 L
.94668 .01472 L
.94797 .01472 L
.94919 .01472 L
.9503 .01472 L
.9603 .01472 L
.96304 .01472 L
.96595 .01472 L
.96844 .01472 L
.96912 .01472 L
.96985 .01472 L
.97049 .01472 L
.97118 .01472 L
.97245 .01472 L
.97315 .01472 L
.97379 .01472 L
.97495 .01472 L
.97619 .01472 L
Mfstroke
.2 0 1 r
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07295 .60332 L
.08265 .60332 L
.08804 .60332 L
.09308 .60332 L
.09862 .60332 L
.10458 .60332 L
.11468 .60332 L
.1204 .60332 L
.12571 .60332 L
.13544 .60332 L
.14087 .60332 L
.1458 .60332 L
.15068 .60332 L
.15583 .60332 L
.16505 .60332 L
.17018 .60332 L
.17498 .60332 L
.18019 .60332 L
.18587 .60332 L
.1913 .60332 L
.19632 .60332 L
.20103 .60332 L
.20622 .60332 L
.21522 .60332 L
.22015 .60332 L
.22478 .60332 L
.23461 .60332 L
.23955 .60332 L
.24496 .60332 L
.2496 .60332 L
.25455 .60332 L
.26347 .60332 L
.2688 .60331 L
.27371 .60331 L
.279 .60331 L
.28481 .60331 L
.2946 .6033 L
.29996 .6033 L
.30496 .6033 L
.30994 .60329 L
.31537 .60328 L
Mistroke
.32016 .60328 L
.32525 .60327 L
.3303 .60325 L
.33487 .60324 L
.34379 .60321 L
.34868 .60318 L
.35384 .60315 L
.36307 .60306 L
.36822 .603 L
.37301 .60293 L
.37823 .60284 L
.38391 .60271 L
.38935 .60255 L
.39439 .60237 L
.3991 .60216 L
.4043 .60188 L
.41331 .60122 L
.41824 .60074 L
.42287 .60019 L
.43273 .5986 L
.43768 .59753 L
.44309 .59607 L
.44773 .59453 L
.45269 .59253 L
.46161 .58776 L
.46695 .58397 L
.47188 .5797 L
.47717 .57411 L
.48299 .56653 L
.49279 .5495 L
.50316 .5241 L
.51335 .48994 L
.52264 .4499 L
.54355 .33318 L
.56422 .20954 L
.57332 .1633 L
.58336 .12143 L
.59293 .09066 L
.60192 .06898 L
.61142 .05227 L
.61676 .04512 L
.62166 .0397 L
.62639 .03536 L
.63145 .03152 L
.64056 .02628 L
.64613 .0239 L
.6514 .0221 L
.65609 .0208 L
.66125 .01962 L
.67096 .01799 L
Mistroke
.67627 .01733 L
.68124 .01684 L
.69013 .01617 L
.69512 .01589 L
.69969 .01568 L
.70954 .01533 L
.71869 .01508 L
.72385 .01497 L
.72872 .01488 L
.73142 .01484 L
.73433 .01481 L
.73678 .01478 L
.73941 .01476 L
.74199 .01475 L
.74434 .01474 L
.7467 .01473 L
.74893 .01473 L
.75019 .01473 L
.75153 .01472 L
.75393 .01472 L
.75526 .01472 L
.75652 .01472 L
.75788 .01472 L
.75937 .01472 L
.76195 .01472 L
.76335 .01472 L
.76466 .01472 L
.76701 .01472 L
.76832 .01472 L
.76951 .01472 L
.77082 .01472 L
.77221 .01472 L
.77373 .01472 L
.77513 .01472 L
.77766 .01472 L
.77909 .01472 L
.78044 .01472 L
.78169 .01472 L
.78302 .01472 L
.78542 .01472 L
.78689 .01472 L
.78827 .01472 L
.78953 .01472 L
.79085 .01472 L
.79204 .01472 L
.79333 .01472 L
.79561 .01472 L
.79689 .01472 L
.79826 .01472 L
.79955 .01472 L
Mistroke
.80074 .01472 L
.80313 .01472 L
.80439 .01472 L
.80573 .01472 L
.80797 .01472 L
.80925 .01472 L
.81045 .01472 L
.81159 .01472 L
.81267 .01472 L
.8147 .01472 L
.81584 .01472 L
.81689 .01472 L
.81928 .01472 L
.82057 .01472 L
.82192 .01472 L
.82435 .01472 L
.82571 .01472 L
.82697 .01472 L
.82844 .01472 L
.82984 .01472 L
.83104 .01472 L
.83235 .01472 L
.83464 .01472 L
.83594 .01472 L
.83732 .01472 L
.83861 .01472 L
.83979 .01472 L
.84199 .01472 L
.84314 .01472 L
.84435 .01472 L
.8464 .01472 L
.84756 .01472 L
.84864 .01472 L
.84991 .01472 L
.85111 .01472 L
.85336 .01472 L
.85461 .01472 L
.85577 .01472 L
.85712 .01472 L
.8584 .01472 L
.85957 .01472 L
.86084 .01472 L
.86307 .01472 L
.86433 .01472 L
.86567 .01472 L
.86809 .01472 L
.86926 .01472 L
.87054 .01472 L
.87166 .01472 L
.87284 .01472 L
Mistroke
.87391 .01472 L
.87509 .01472 L
.87715 .01472 L
.87854 .01472 L
.87985 .01472 L
.88231 .01472 L
.88368 .01472 L
.88496 .01472 L
.88644 .01472 L
.88783 .01472 L
.89013 .01472 L
.89135 .01472 L
.89266 .01472 L
.89397 .01472 L
.89534 .01472 L
.89779 .01472 L
.89903 .01472 L
.90037 .01472 L
.90155 .01472 L
.9028 .01472 L
.90393 .01472 L
.90517 .01472 L
.90735 .01472 L
.90868 .01472 L
.9099 .01472 L
.91121 .01472 L
.91263 .01472 L
.91394 .01472 L
.91516 .01472 L
.91632 .01472 L
.91756 .01472 L
.9187 .01472 L
.91974 .01472 L
.92179 .01472 L
.92288 .01472 L
.92407 .01472 L
.92532 .01472 L
.92647 .01472 L
.92884 .01472 L
.93014 .01472 L
.93137 .01472 L
.93356 .01472 L
.9348 .01472 L
.93594 .01472 L
.93719 .01472 L
.93837 .01472 L
.9406 .01472 L
.94184 .01472 L
.94299 .01472 L
.94434 .01472 L
Mistroke
.94561 .01472 L
.94671 .01472 L
.94791 .01472 L
.94999 .01472 L
.95118 .01472 L
.95243 .01472 L
.95467 .01472 L
.95595 .01472 L
.95712 .01472 L
.95838 .01472 L
.95976 .01472 L
.96102 .01472 L
.96219 .01472 L
.9645 .01472 L
.96579 .01472 L
.96699 .01472 L
.96842 .01472 L
.96974 .01472 L
.97241 .01472 L
.97382 .01472 L
.9753 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{730.688, 225.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;J0000hB000`400?l00000o`00003oo`3ooooo
0?ooom`0oooo003o0?ooool0oooog03oool00?l0ooooo`3ooooL0?ooo`00o`3ooooo0?ooom`0oooo
003o0?ooool0oooog03oool00?l0ooooo`3ooooL0?ooo`00o`3ooooo0?ooom`0oooo003o0?ooool0
oooog03oool00?l0ooooo`3ooooL0?ooo`00o`3ooooo0?ooom`0oooo003o0?ooool0oooog03oool0
0?l0ooooo`3ooooL0?ooo`00o`3ooooo0?ooobh0oooo00H0_g@000000000000000000018W03Oool4
0?ooo`030?oo_`1d07@0_ooo0:40oooo003o0?ooool0oooo;`3oool00`3ookl0M01d0;ooo`050?oo
o`040?oog`2LB000001d0;oooj40oooo003o0?ooool0oooo;`3oool00`3ooml0W4Qd0;ooo`050?oo
o`040;md00000000001d0;oooj40oooo003o0?ooool0oooo;`3oool00`3ooml0W4Qd0;ooo`040?oo
o`050=nLB0000000001804Q8M02oool0X@3oool00?l0ooooo`3oool_0?ooo`030?oog`2LB7@0_ooo
00<0oooo00H0okmd0000000007@0_ooO09a8M02ooonQ0?ooo`00k03oool01P2oM000000000000000
000004RL0=ooo`@0oooo00<0oono07@0M02oool0o`3ooole0?ooo`030?oog`2LB7@0_ooo0080oooo
00L0omnL04P0000004P0W=oo0?oog`2LB7@0_ooo0:40oooo003]0?ooo`030?oo_`1d07@0_ooo00D0
oooo00@0oooO09a8000007@0_oooo`3ooole0?ooo`0<0?oog`2LB7@0_ooo0?ooo`3ookl0M0000000
001d_ol0oooo0?oog`2LB7@0_oooX@3oool00>d0oooo00<0oooO09a8M02oool01@3oool0102oM000
00000000M02ooooo0?ooocD0oooo00L0oooO09a8M02oool0oooO09a800000000B9cO0080oooo00<0
oooO09a8M02oool0X@3oool00>d0oooo00<0oooO09a8M02oool0103oool01@3OW4P000000000B018
B7@0_ooo0?l0oooo=@3oool01P3ooml0W4Qd0;oog`2LB0000000001d_`<0oooo00<0oooO09a8M02o
ool0X@3oool00>d0oooo00<0oooO09a8M02oool00`3oool01P3o_g@000000000M02ooml0W4Qd0;oo
ool0oooo=@3oool01P3ooml0W4Qd07Ad0000000004RL0=ooo`<0oooo00<0oooO09a8M02oool0X@3o
ool00>d0oooo00<0oooO09a8M02oool00P3oool01`3ogi`0B0000000B02Lgol0oooO09a8M02oool0
o`3ooole0?ooo`050?oog`2LB00000000000M02oool0103oool00`3ooml0W4Qd0;ooo`2Q0?ooo`00
k@3oool0303ooml0W4Qd0;ooo`3oool0oono07@000000000M;oo0?ooo`3ooml0W4Qd0;ooool0oooo
=@3oool0103OW4P000000000M02oool50?ooo`030?oo_`1d07@0_ooo0:40oooo003]0?ooo`070?oo
g`2LB7@0_ooo0?oog`2LB000000004RLg`020?ooo`030?oog`2LB7@0_ooo0?l0oooo<`3oool01@3O
W4P000000000000004P0W=oo00@0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`2N
0?ooo`00k@3oool01P3ooml0W4Qd0;oog`2LB0000000001d_`<0oooo00<0oooO09a8M02oool0o`3o
oooR0?ooo`00k@3oool01P3ooml0W4Qd07Ad0000000004RL0=ooo`<0oooo00<0oooO09a8M02oool0
o`3ooooR0?ooo`00k@3oool01@3ooml0W4P00000000007@0_ooo00@0oooo00<0oooO09a8M02oool0
o`3ooooR0?ooo`00k@3oool0103OW4P000000000M02oool50?ooo`030?oo_`1d07@0_ooo0?l0oooo
hP3oool00>/0oooo00D0gia8000000000000001809cOo`040?ooo`030?oog`2LB000000000800000
00<004RL0=ooo`3oool0o`3ooooO0?ooo`00o`3ooooo0?ooom`0oooo003o0?ooool0oooog03oool0
0?l0ooooo`3ooooL0?ooo`00o`3ooooo0?ooom`0oooo003o0?ooool0oooog03oool00?l0ooooo`3o
oooL0?ooo`00o`3ooonk0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool0
102oM000000000000018W=lZ0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool00P3o
ool0102oM000000000000018W=l]0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0
0`3oool0102oM000000000000018W=l[0?ooo`040;md00000000000004RLgc40oooo00<0okmd0000
000000000P0000000`00M;l0oooo0?ooo`030?ooo`040;md00000000000004RLgbT0oooo003o0?oo
ok/0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`<0oooo00L0oooO09a80000M;l0
oooo0?oog`2LB00007Bo02X0oooo00<0gia8000000000000100000002P00M;l0oooo0?ooo`3ooml0
W4P0001d_`3oool0oooO09a80000M;l^0?ooo`030;md000007@0_ooo00@0oooo00L0oooO09a80000
M;l0oooo0?oog`2LB00007Bo02P0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo0380oooo
00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0:03oool00?l0
oooo`@3oool00`3o_g@004RL0=ooo`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol0:P3oool00`3OW4P0B9cO0?ooo`020?ooo`070?oog`2LB7@0_ooo0?ooo`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo02d0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo02L0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0a
0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0W
0?ooo`00o`3oooo10?ooo`080?noM00004P0W=oo0?ooo`3ooml0W4P00018W03Oool20?ooo`030?oo
g`2LB00007Bo02/0oooo00<0gia804RLg`3oool0103oool0103ooml0W4P00018W03Oool20?ooo`03
0?oog`2LB00007Bo02d0oooo00<0_g@00000M02oool00`3oool0103ooml0W4P00018W03Oool20?oo
o`030?oog`2LB00007Bo02H0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0a
0?ooo`030;md000007@0_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d
_`0W0?ooo`00o`3oooo10?ooo`070;md000004P0W=oo0?ooo`3ookl0M000001d_`040?ooo`030;md
000007@0_ooo02/0oooo00<0gia807Boo`3oool00`3oool00`3ookl0M000001d_`040?ooo`030;md
000007@0_ooo02`0oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md
000007@0_ooo02D0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0`0?ooo`030;md
000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0V0?ooo`00o`3o
oon_0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool0202oM00000000000
M02oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`0K0?ooo`030;md000000000000
00L0000000<0B9cO0?ooo`3oool00`3oool00`3ooml0W4Q809cOo`030?ooo`030?oOW0180000B9cO
00@0oooo00<0_g@00000M02oool06`3oool00`2oM0000000000000070000000304RLg`3oool0oooo
00@0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo
02D0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0`0?ooo`030;md000007@0_ooo
00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0V0?ooo`00P`3oool00`3ooml0
W4P000000002000000030018W03Oool0oooo00D0oooo00@0_g@0000000000000B9cO9@3oool00`3O
W4P00000000000050000000307Boo`3oool0oooo0080oooo00@0_g@0000000000000B9cO:03oool0
0`3o_g@000000000000200000003001d_`3oool0oooo00<0oooo00@0_g@0000000000000B9cO9`3o
ool0102oM000000000000018W=l/0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0
0`3oool0102oM000000000000018W=mE0?ooo`030?oo_`1d000000000080000000H0B9cO0?ooo`3o
ool0omnL04P00018W=l40?ooo`030=nLB00004P0W=oo02`0oooo00<0omnL04P0M02oool00P3oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02`0oooo00<0_g@00000M02oool00`3oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02D0oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`0`0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`0V0?ooo`00P`3oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0W=oo
0`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l09@3oool00`3OW4P00000000000040000
000:001d_`3oool0oooo0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_bT0oooo00<0_g@00000M02o
ool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0903oool01`3ooml0W4P0001d_`3o
ool0oooO09a80000M;l0;@3oool00`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo0?ooo`3o
oml0W4P0001d_`1F0?ooo`030?noM00004P0W=oo00<0oooo00<0omnL04P00018W=l0103oool00`3O
W4P0001809cOo`0]0?ooo`070;md0018W=l0oooo0?ooo`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo02`0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo02D0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0`0?ooo`030;md0000
07@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0V0?ooo`00R@3oool0
0`3o_g@004RL0=ooo`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol09@3oool0
0`3OW4P0B9cO0?ooo`020?ooo`070?oog`2LB7@0_ooo0?ooo`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo02P0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo02<0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0/0?ooo`030;md
000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1F0?ooo`030?oO
W018M;l0oooo0080oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0]0?ooo`070=nL
B00007@0_ooo0?ooo`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02`0oooo00<0_g@00000
M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02D0oooo00<0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`0`0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`0V0?ooo`00R@3oool0203o_g@0001809cOo`3oool0oooO
09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0V0?ooo`030=nLB018W=l0oooo00@0oooo00@0
oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0X0?ooo`030;md000007@0_ooo00<0oooo
00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0R0?ooo`040?oog`2LB00004RL0=oo
o`80oooo00<0oooO09a80000M;l0;03oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB00004RL
0=ooo`80oooo00<0oooO09a80000M;l0EP3oool00`3ooml0W4P004RLg`030?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l0;P3oool00`3o_g@0000007Boo`020?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l0;@3oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l09`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo0340oooo00<0_g@00000M02oool0103oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB000
07Bo02L0oooo00290?ooo`070;md000004P0W=oo0?ooo`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo02H0oooo00<0gia807Boo`3oool00`3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo02L0oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo0240oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0[0?ooo`030;md0000
07@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`1@0?ooo`030?oog`2L
M9`0gooo0080oooo00<0oooO09a80000M;l00`3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02P0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`020?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol0;@3oool00`2oM000001d0;ooo`040?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol09`3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo0340oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02L0oooo001f0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool01@3oool0
202oM00000000000M02oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`0E0?ooo`03
0;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`030?ooo`03
0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool05P3oool00`2oM00000000000000700000003
04RLg`3oool0oooo00@0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`03
0;md000007@0_ooo0240oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0[0?ooo`03
0;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`1A0?ooo`07
0?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`040?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo
:P3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0`3oool01P2oM00004RL0=ooo`3o
ool0_g@0001d_b`0oooo00D0gia8000000000000001d0;ooo`050?ooo`060;md0000B9`0gooo0?oo
o`2oM00007Bo:@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_c00oooo00D0gia8000000000000
001d0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo:03oool008D0oooo00<0oono07@0
000000000P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02Lgol09`3o
ool00`3ogi`0B01d0;ooo`020?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol09`3o
ool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol08@3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02/0oooo00<0_g@00000M02oool00`3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo0580oooo00D0omnL04P0000000000000
04RLg`060?ooo`040;md000000000000001d_b`0oooo00D0_g@00000000000000000001d_`060?oo
o`040;md000000000000001d_bh0oooo00@0oono07@0000007@0_ooo1P3oool0102oM00000000000
0000M;l[0?ooo`040;md000000000000001d_c80oooo00@0oono07@0000007@0_ooo1P3oool0102o
M000000000000000M;lY0?ooo`00Q`3oool00`3o_g@0001809cOo`030?ooo`030?oOW0180000B9cO
00@0oooo00<0gia80000B02Lgol0:03oool01`2oM000B9cO0?ooo`3oool0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`0W0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`0Q0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0:`3o
ool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0o`3o
ooma0?ooo`00R03oool00`3ogi`0B7Bo0?ooo`020?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool0:03oool01`3OW4P0001d0;ooo`3oool0oono07@00000M;l0103oool00`2oM000001d
0;ooo`0W0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`0Q0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0:`3oool00`2oM000001d
0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0o`3oooma0?ooo`00R03o
ool00`3ooml0W4P004RLg`030?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0:@3o
ool00`3o_g@0000007Boo`020?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0:03o
ool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l08`3o
ool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo02`0oooo00<0_g@00000M02oool0103o
ool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo0?l0ooooLP3oool008<0oooo00<0oooO
09adW03Oool00P3oool00`3ooml0W4P0001d_`030?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol08`3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo0080oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0X0?ooo`030;md000007@0_ooo00@0oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`0S0?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol0;03oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol0o`3ooomb0?ooo`00Q03oool01`3ogi`0B4RL0=ooo`3oool0gia80000001d_ol0103o
ool01P2oM00004RL0=ooo`3oool0_g@0001d_bD0oooo00P0_g@007Boo`3oool0oooo0=nLB0000000
04RL0=ooo`<0oooo00H0_g@00018W03Oool0oooo0;md0000M;lW0?ooo`050=nLB000000000000000
M02oool01@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_bD0oooo00H0_g@00018W03Oool0oooo
0;md0000M;l[0?ooo`050=nLB000000000000000M02oool01@3oool01P2oM00004RL0=ooo`3oool0
_g@0001d_ol0ooooL`3oool008D0oooo00D0omnL04P000000000000004RLg`060?ooo`040;md0000
00000000001d_bL0oooo00D0_g@00000000000000000001d_`060?ooo`040;md000000000000001d
_bT0oooo00@0oono07@0000007@0_ooo1P3oool0102oM000000000000000M;lW0?ooo`040;md0000
00000000001d_bd0oooo00@0oono07@0000007@0_ooo1P3oool0102oM000000000000000M;oo0?oo
og@0oooo003o0?oooj`0oooo00@0_g@0000000000000B9cOo`3oool/0?ooo`00o`3ooonZ0?ooo`07
0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`3o0?ooob/0oooo003o0?ooojX0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooooT00000:@3oool00?l0ooooZ@3oool0103ooml0
W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0W0?ooo`00o`3ooonY0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0W0?ooo`00o`3ooonY0?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool01P3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo02L0oooo
003o0?ooojT0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`800000Y`3o
oom:03<0o`<0oooo0`00000Y0?ooo`00o`3ooonY0?ooo`030?oOW0180000B9cO00@0oooo00<0gia8
0000B02Lgol01P3oool00`000000oooo0?ooo`2O0?ooo`L0<`3oC`3oool00`000000oooo0?ooo`0W
0?ooo`00P03ooooW00000440oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?oo
o`030000003oool0oooo09d0oooo0P0c0?l00`3o0000oooo0?ooo`1C0?ooo`030000003oool0oooo
02L0oooo00200?ooo`800000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool200000480oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`070?ooo`030000003oool0oooo09X0oooo00<0o`0003<0o`0c0?l0F03oool00`000000
oooo0?ooo`0W0?ooo`00P03oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0400oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030000003oool0oooo09T0oooo
0P0c0?mJ0?ooo`030000003oool0oooo02L0oooo00200?ooo`030000003oool0oooo0;00oooo;P3o
00050?ooo`030000003oool0oooo0440oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`03
0000003oool0oooo09P0oooo00<0<`3o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0W0?ooo`00
P03oool00`000000oooo0?ooo`2^0?ooo`80o`00<`3oool00`000000oooo0?ooo`120?ooo`040;md
000000000000001d_`T0oooo00<000000?ooo`3oool0U`3oool00`0c0?l0oooo0?ooo`1K0?ooo`03
0000003oool0oooo02L0oooo00200?ooo`030000003oool0oooo0:d0oooo00<0o`000?ooo`3oool0
<`3oool00`000000oooo0?ooo`1?0?ooo`800000U`3oool00`0c0?l0oooo0?ooo`1K0?ooo`800000
:@3oool00800oooo00<000000?ooo`3oool0[03oool00`3o0000oooo0?ooo`0d0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0U@3oool00`0c0?l0oooo0?ooo`1M0?ooo`030000003o
ool0oooo02L0oooo00200?ooo`030000003oool0oooo0:`0oooo00<0o`000?ooo`3oool0=03oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo09@0oooo00<0<`3o0?ooo`3oool0GP3oool0
0`000000oooo0?ooo`0W0?ooo`00?P3oool00`3o_g@000000000000200000003001d_`3oool0oooo
00@0oooo00<0_gA809cOo`3oool01P3oool00`3o_i`0M;oO0?ooo`050?ooo`030?noM00000000000
0080000000<007Bo0?ooo`3oool00`3oool0102oM000000000000018W=lF0?ooo`800000[03oool0
0`3o0000oooo0?ooo`0d0?ooo`800000D@3oool00`000000oooo0?ooo`2C0?ooo`0303<0o`3o0000
oooo05l0oooo00<000000?ooo`3oool09`3oool00400oooo00<0_g@00000M02oool01`3oool00`3o
_g@0001809cOo`050?ooo`030?noM00004P0W=oo00P0oooo00<0_g@00000M02oool0103oool01`3o
oml0W4P0001d_`3oool0oooO09a80000M;l05@3oool00`000000oooo0?ooo`2[0?ooo`030?l0003o
ool0oooo03D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2C0?ooo`0303<0o`3o
ool0oooo05l0oooo00<000000?ooo`3oool09`3oool00400oooo00<0_g@00000M02oool0203oool0
0`3o_g@0001809cOo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_g@00000M02oool0103oool0
0`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo01@0oooo00<000000?ooo`3oool0Z`3oool0
0`3o0000oooo0?ooo`0e0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0TP3oool0
0`0c0?l0o`000?ooo`1P0?ooo`030000003oool0oooo02L0oooo00100?ooo`030;md000007@0_ooo
00T0oooo00L0okmd0000B02Lgol0oooo0?noM00004P0W=oo00X0oooo00<0_g@00000M02oool00`3o
ool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo01@0oooo00<000000?ooo`3oool0
ZP3oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
TP3oool00`0c0?l0oooo0?ooo`1P0?ooo`030000003oool0oooo02L0oooo00100?ooo`030;md0000
07@0_ooo00X0oooo00D0okmd0000B02LW7@0001809cOo`0;0?ooo`030;md000007@0_ooo00<0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0C0?ooo`030000003oool0oooo0:X0oooo
00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0980oooo
00<0<`3o0?ooo`3oool0H03oool00`000000oooo0?ooo`0W0?ooo`00;`3oool00`2oM00000000000
00070000000304RLg`3oool0oooo00@0oooo00<0_g@00000M02oool02`3oool00`3o_g@0001809cO
o`0<0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`0C0?ooo`030000003oool0oooo0:T0oooo00<0o`000?ooo`3oool0=`3oool00`000000oooo0?oo
o`1?0?ooo`800000TP3oool00`0c0?l0oooo0?ooo`1P0?ooo`800000:@3oool00400oooo00<0_g@0
0000M02oool02P3oool01@3o_g@0001809bLM00004P0W=oo00/0oooo00<0_g@00000M02oool00`3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01<0oooo0`00002Y0?ooo`030?l0003o
ool0oooo03D0oooo0`00001A0?ooo`030000003oool0oooo0940oooo00<0<`3o0?ooo`3oool0H@3o
ool00`000000oooo0?ooo`0W0?ooo`00@03oool00`2oM000001d0;ooo`090?ooo`070?noM00004P0
W=oo0?ooo`3o_g@0001809cOo`0:0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0
103oool00`3OW4P0001809cOo`0C0?ooo`030000003oool0oooo0:T0oooo00<0o`000?ooo`3oool0
=`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0940oooo00<0<`3o0?ooo`3oool0
H@3oool00`000000oooo0?ooo`0W0?ooo`00@03oool00`2oM000001d0;ooo`080?ooo`030?noM000
04P0W=oo00<0oooo00<0okmd0000B02Lgol02@3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d
000007Bo00@0oooo00@0_g@00000M02oool0gia80P0000001P0004P0W=oo0?ooo`3oool0omnL04P0
0080000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`2Y0?ooo`030?l0003oool0oooo
03L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2@0?ooo`0303<0o`3oool0oooo
0680oooo00<000000?ooo`3oool09`3oool00400oooo00<0_g@00000M02oool01`3oool00`2oM000
001809cOo`050?ooo`030?noM0000000B9cO00P0oooo00<0_g@00000M02oool0103oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo00@0oooo00<0oooO09a8B02Lgol01@3oool00`2oM4P0
W=oo0?ooo`050?ooo`030000003oool0oooo0:T0oooo00<0o`000?ooo`3oool0=`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0900oooo00<0<`3o0?ooo`3oool0HP3oool00`000000
oooo0?ooo`0W0?ooo`00@03oool00`2oM000001d0;ooo`070?ooo`030?noW02Lgol0oooo00H0oooo
00<0oknL09cOo`3oool01`3oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol01@3oool00`3o_g@007Bo0?ooo`040?ooo`030?oOW018M;l0oooo00D0oooo
00<000000?ooo`3oool0Z@3oool00`3o0000oooo0?ooo`0g0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0S`3oool00`3o0000<`3o0?ooo`1S0?ooo`030000003oool0oooo02L0oooo
000n0?ooo`050=nLB000000000000000M02oool0603oool01@3OW4P000000000000007@0_ooo00D0
oooo00H0_g@00018W03Oool0oooo0;md0000M;l60?ooo`030=nLB000M;l0oooo00@0oooo00<0omnL
04Q8W03Oool01@3oool00`000000oooo0?ooo`2Y0?ooo`030?l0003oool0oooo03L0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`2?0?ooo`0303<0o`3oool0oooo06<0oooo00<00000
0?ooo`3oool09`3oool003l0oooo00@0oono07@0000007@0_ooo6@3oool0103ookl0M0000000M02o
ool60?ooo`040;md000000000000001d_`H0oooo00<0omnL04P00018W=l01@3oool00`3OW4P007Bo
0?ooo`050?ooo`800000ZP3oool00`3o0000oooo0?ooo`0f0?ooo`800000D@3oool2000008l0oooo
00<0o`0003<0o`3oool0H`3oool2000002T0oooo001^0?ooo`040?oog`2LB0000000001d_`D0oooo
00<0_g@00000B02Lgol01P3oool00`000000oooo0?ooo`2X0?ooo`030?l0003oool0oooo03P0oooo
00<000000?ooo`3oool0<`3oool0102oM000000000000018W=l40?ooo`050=nLB0000000B9cO0?oo
o`3OW4P01`0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00<0<`3o0?oo
o`3oool0I03oool00`000000oooo0?ooo`0W0?ooo`00L03oool02@3OW4P007Bo0?ooo`3oool0oooO
09a80000000004RL0=ooo`070?ooo`030000003oool0oooo0:P0oooo00<0o`000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0a0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`03
0=nLB0000000B9cO0080oooo00<0gia8000000000000100000000`00M;l0oooo0?ooo`050?ooo`03
0000003oool0oooo08h0oooo00<0<`3o0?ooo`3oool0I03oool00`000000oooo0?ooo`0W0?ooo`00
K@3oool01P3ogml0gooo0?ooo`3oool0_g@007Boo`80oooo00<0oknL09cOo`3oool0203oool00`00
0000oooo0?ooo`2X0?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3oool0<@3oool00`3o
_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00<0gia804RLg`3oool00P3oool00`3o
oml0W4Qd0;ooo`060?ooo`030000003oool0oooo08d0oooo00<0<`3o0?l0003oool0I@3oool00`00
0000oooo0?ooo`0W0?ooo`00K@3oool01P3ookl0M7Bo0?ooo`3ookl0M00007Boo`80oooo00<0oono
07Ad_`3oool0203oool00`000000oooo0?ooo`2X0?ooo`030?l0003oool0oooo03P0oooo00<00000
0?ooo`3oool0<03oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00T0oooo00<0
gia804RLg`3oool02P3oool00`000000oooo0?ooo`2=0?ooo`0303<0o`3oool0oooo06D0oooo00<0
00000?ooo`3oool09`3oool006h0oooo00@0okmd00000000000007Bo103oool01@3OW4P000000000
0000B9`0gooo00D0oooo00<000000?ooo`3oool0Z03oool00`3o0000oooo0?ooo`0h0?ooo`030000
003oool0oooo0300oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`090?ooo`030=nL
B01d_ol0oooo00T0oooo00<000000?ooo`3oool0S@3oool00`0c0?l0oooo0?ooo`1U0?ooo`030000
003oool0oooo02L0oooo00200?ooo`800000Z@3oool00`3o0000oooo0?ooo`0g0?ooo`800000<P3o
ool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00T0oooo00<0oooO09a8B02Lgol02@3o
ool00`000000oooo0?ooo`2=0?ooo`0303<0o`3oool0oooo06D0oooo00<000000?ooo`3oool09`3o
ool00800oooo00<000000?ooo`3oool0Z03oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0
oooo0300oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`030?oOW01807@0
_ooo00P0oooo0P00002=0?ooo`0303<0o`3o0000oooo06@0oooo0`00000Y0?ooo`00P03oool00`00
0000oooo0?ooo`2X0?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3oool0<03oool00`3o
gi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3oool01`3oool00`00
0000oooo0?ooo`2<0?ooo`0303<0o`3o0000oooo06H0oooo00<000000?ooo`3oool09`3oool00800
oooo00<000000?ooo`3oool0Z03oool00`3o0000oooo0?ooo`0h0?ooo`030000003oool0oooo0300
oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`030=nLB00007@0_ooo00L0
oooo00<000000?ooo`3oool0S03oool00`0c0?l0oooo0?ooo`1V0?ooo`030000003oool0oooo02L0
oooo00200?ooo`030000003oool0oooo0:P0oooo00<0o`000?ooo`3oool0>03oool00`000000oooo
0?ooo`0a0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0303oool00`3o_g@00000
07Boo`070?ooo`030000003oool0oooo08`0oooo00<0<`3o0?ooo`3oool0IP3oool00`000000oooo
0?ooo`0W0?ooo`00P03oool00`000000oooo0?ooo`2X0?ooo`030?l0003oool0oooo03P0oooo00<0
00000?ooo`3oool0<@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0
omnL09boo`3oool00`3oool00`2oM000000007Boo`070?ooo`030000003oool0oooo08`0oooo00<0
<`3o0?ooo`3oool0IP3oool00`000000oooo0?ooo`0W0?ooo`00P03oool200000:T0oooo00<0o`00
0?ooo`3oool0=`3oool2000003@0oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`080;md
001d_ol0oooo0?ooo`3OW4P000000018W03Oool70?ooo`030000003oool0oooo08`0oooo00<0<`3o
0?ooo`3oool0IP3oool00`000000oooo0?ooo`0W0?ooo`00?P3oool01P3ogi`0B000000000000000
001809cOo`H0oooo00<0_gA809cOo`3oool01P3oool00`3o_i`0M;oO0?ooo`050?ooo`030?noM000
000000000080000000<007Bo0?ooo`3oool00`3oool0102oM000000000000018W=lF0?ooo`030000
003oool0oooo0:P0oooo00<0o`000?ooo`3oool0>03oool00`000000oooo0?ooo`0c0?ooo`040;md
000000000000001d_`X0oooo00D0_g@00000000000000000001d_`090?ooo`030000003oool0oooo
08/0oooo00<0<`3o0?l0003oool0I`3oool00`000000oooo0?ooo`0W0?ooo`00?@3oool0203ogi`0
B0000018W03Oool0oooo0?oOW0180000M;oo1@3oool00`3o_g@0001809cOo`050?ooo`030?noM000
04P0W=oo00P0oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000
M;l05@3oool00`000000oooo0?ooo`2X0?ooo`030?l0003oool0oooo03P0oooo00<000000?ooo`3o
ool0C`3oool2000008`0oooo00<0<`3o0?ooo`3oool0IP3oool2000002T0oooo000m0?ooo`030;md
000007@0_ooo00<0oooo00<0gia80018W03Oool01@3oool00`3o_g@0001809cOo`030?ooo`030?no
M00004P0W=oo00T0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oO
W0180000M;oo01@0oooo00<000000?ooo`3oool0Z03oool00`3o0000oooo0?ooo`0h0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0R`3oool00`0c0?l0oooo0?ooo`1W0?ooo`030000
003oool0oooo02L0oooo000m0?ooo`030;md000007@0_ooo00<0oooo00<0_g@00018W03Oool01P3o
ool01`3o_g@0001809cOo`3oool0okmd0000B02Lgol02P3oool00`2oM000001d0;ooo`030?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0503oool00`000000oooo0?ooo`2W0?oo
o`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2;0?oo
o`0303<0o`3oool0oooo06L0oooo00<000000?ooo`3oool09`3oool003d0oooo00<0okmd0000B02L
gol00P3oool00`3OW4P00000001d_`080?ooo`050?noM00004P0W9ad0000B02Lgol02`3oool00`2o
M000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool04`3oool00`00
0000oooo0?ooo`2W0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`2;0?ooo`0303<0o`3oool0oooo06L0oooo00<000000?ooo`3oool09`3oool002l0
oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`020?ooo`070=nLB000M;l0oooo0;md
00000000001d0;ooo`090?ooo`030?noM00004P0W=oo00`0oooo00<0_g@00000M02oool00`3oool0
0`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo01<0oooo00<000000?ooo`3oool0Y`3oool0
0`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0RP3oool0
0`0c0?l0oooo0?ooo`1X0?ooo`030000003oool0oooo02L0oooo000o0?ooo`050?noM00000000000
0018W03Oool02@3oool01@3o_g@0001809bLM00004P0W=oo00/0oooo00<0_g@00000M02oool00`3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01<0oooo0`00002W0?ooo`030?l0003o
ool0oooo03L0oooo0`00001A0?ooo`030000003oool0oooo08X0oooo00<0<`3o0?ooo`3oool0J03o
ool00`000000oooo0?ooo`0W0?ooo`00?P3oool01@3ogi`0B000000000000000B9cO00T0oooo00L0
okmd0000B02Lgol0oooo0?noM00004P0W=oo00X0oooo00<0_g@00000M02oool00`3oool00`3ogi`0
B00004RLg`040?ooo`030=nLB00004P0W=oo01<0oooo00<000000?ooo`3oool0Y`3oool00`3o0000
oooo0?ooo`0i0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0RP3oool00`0c0?l0
oooo0?ooo`1X0?ooo`030000003oool0oooo02L0oooo000m0?ooo`070?oOW0180000001809cOo`3o
ool0gia8001d_`070?ooo`030?noM00004P0W=oo00<0oooo00<0okmd0000B02Lgol02@3oool00`2o
M000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00@0_g@00000M02oool0gia80P000000
0`0004P0W=oo0?ooo`040?ooo`030?oo_`1d04P0W=oo00H0oooo00<000000?ooo`3oool0Y`3oool0
0`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0RP3oool0
0`0c0?l0oooo0?ooo`1X0?ooo`030000003oool0oooo02L0oooo000m0?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a8001d_ol01@3oool00`2oM000001809cOo`050?ooo`030?noM0000000B9cO
00P0oooo00<0_g@00000M02oool0103oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo
00@0oooo00<0oooO09a8B02Lgol0103oool00`3ookl0M01809cOo`060?ooo`030000003oool0oooo
0:L0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`1?0?ooo`800000R`3oool00`0c
0?l0oooo0?ooo`1W0?ooo`800000:@3oool003d0oooo00<0gia80018W03Oool00P3oool00`3ooml0
W4P004RLg`050?ooo`030?noW02Lgol0oooo00H0oooo00<0oknL09cOo`3oool01`3oool00`2oM000
001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01@3oool00`3o_g@0
07Bo0?ooo`030?ooo`030?oo_`1d04P0W=oo00H0oooo00<000000?ooo`3oool0Y`3oool00`3o0000
oooo0?ooo`0i0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0R@3oool00`3o0000
<`3o0?ooo`1Y0?ooo`030000003oool0oooo02L0oooo000m0?ooo`030?oOW0180000B9cO0080oooo
00<0okmd0000B02Lgol05P3oool01@3OW4P000000000000007@0_ooo00D0oooo00H0_g@00018W03O
ool0oooo0;md0000M;l60?ooo`040=nLB000M;l0oooO09a800D0000000<0M;oo0?ooo`3oool00`3o
ool00`000000oooo0?ooo`2W0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`290?ooo`0303<0o`3oool0oooo06T0oooo00<000000?ooo`3oool09`3o
ool003h0oooo00H0oono07@00000000000000000B02LgolH0?ooo`040?oo_`1d0000001d0;ooo`H0
oooo00@0_g@000000000000007Bo1P3oool02P3ogi`0B00004RLg`3oool0okmd07Boo`3oool0oono
07@0B02Lgol60?ooo`800000Z03oool00`3o0000oooo0?ooo`0h0?ooo`800000D@3oool00`000000
oooo0?ooo`290?ooo`0303<0o`3oool0oooo06T0oooo00<000000?ooo`3oool09`3oool006h0oooo
00@0oooO09a80000000007Bo0`3oool01@2oM7@0_ooo0?oo_`1d04P0W=oo00H0oooo00<000000?oo
o`3oool0Y`3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0R@3oool00`0c0?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo02L0oooo001`0?ooo`03
0=nLB000M;l0oooo0080oooo00D0oono07Ad_`3ookl0M01809cOo`060?ooo`030000003oool0oooo
0:L0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
08T0oooo00<0<`3o0?ooo`3oool0J@3oool00`000000oooo0?ooo`0W0?ooo`006`3oool00`3o_g@0
M;oo0?ooo`060?ooo`030;mdM02oool0oooo04H0oooo00H0omoO0=ooo`3oool0oooo0;md001d_ol3
0?ooo`040?noM01d_kl0M01809cOo`H0oooo00<000000?ooo`3oool0Y`3oool00`3o0000oooo0?oo
o`0i0?ooo`030000003oool0oooo01d0oooo00<0okmd07Boo`3oool01P3oool00`2oM7@0_ooo0?oo
o`0V0?ooo`030000003oool0oooo08P0oooo00<0o`0003<0o`3oool0JP3oool00`000000oooo0?oo
o`0W0?ooo`006`3oool00`3o_g@0001d0;ooo`040?ooo`040?oog`2LB000001d0;ooodL0oooo00H0
oono07Ad_`3oool0oono07@0001d_ol40?ooo`030;md000004P0W=oo00H0oooo00<000000?ooo`3o
ool0Y`3oool00`3o0000oooo0?ooo`0i0?ooo`030000003oool0oooo01d0oooo00<0okmd0000M02o
ool0103oool0103ooml0W4P00000M02ooolW0?ooo`800000R@3oool00`0c0?l0oooo0?ooo`1Y0?oo
o`800000:@3oool001/0oooo00@0okmd000000000000B9cO0P3oool01@3ookl0M01809cOo`3OW9`0
_ooo04P0oooo00@0okmd00000000000007Bo1@3oool00`3ookl0M01809cOo`060?ooo`030000003o
ool0oooo0:L0oooo00<0o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0M0?ooo`040?noM000
0000000004RLg`80oooo00D0oono07@0B02Lgol0gibL0;ooo`0W0?ooo`030000003oool0oooo08P0
oooo00<0<`3o0?ooo`3oool0JP3oool00`000000oooo0?ooo`0W0?ooo`006`3oool0203o_i`0W=oo
0=nLB0000000001807AdB00007@0_oooG@3oool200000:P0oooo00<0o`000?ooo`3oool0>03oool2
000001l0oooo00P0oknL09cOo`3OW4P000000000B01dM4P0001d0;ooo`h0oooo00@0_g@000000000
0000B9cO103oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo00P0oooo00<000000?oo
o`3oool0R03oool00`0c0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo02L0oooo000N0?ooo`04
0?oo_`1d00000000001d_eh0oooo00<000000?ooo`3oool0YP3oool00`3o0000oooo0?ooo`0j0?oo
o`030000003oool0oooo0200oooo00@0oono07@00000000007Bo3@3oool01`3ooml0W4P0001d_`3o
ool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo00P0oooo
00<000000?ooo`3oool0Q`3oool00`3o0000<`3o0?ooo`1[0?ooo`030000003oool0oooo02L0oooo
000K0?ooo`0;0?noW02Lgol0okmd0000B02Lgol0gia80000000004P0W=oo0=nLW02oool0FP3oool0
0`000000oooo0?ooo`2V0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool0
2`3o_i`0W=oo0?noM00004P0W=oo0=nLB0000000001809cOo`3OW9`0_ooo00T0oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`0;0?ooo`030?noM0000000M;oo00P0oooo00<000000?oo
o`3oool0Q`3oool00`3o0000<`3o0?ooo`1[0?ooo`030000003oool0oooo02L0oooo000K0?ooo`03
0?noM000000007Bo00<0oooo00D0oono07@000000000001d0;ooo`1J0?ooo`030000003oool0oooo
0:H0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`030?noM000000007Bo
00<0oooo00D0oono07@000000000001d0;ooo`080?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
oooO09a80000M;l01P3oool00`3OW4P0000000000005000000030000B02Lgol0oooo00D0oooo00<0
00000?ooo`3oool0Q`3oool00`0c0?l0oooo0?ooo`1[0?ooo`030000003oool0oooo02L0oooo000K
0?ooo`030?noM018W=l0oooo00D0oooo00<0gia80000M02oool0FP3oool00`000000oooo0?ooo`2V
0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool07@3oool00`3o_g@0B9cO0?ooo`05
0?ooo`030=nLB00007@0_ooo00P0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`05
0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`27
0?ooo`0303<0o`3oool0oooo06/0oooo00<000000?ooo`3oool09`3oool001/0oooo00<0oknL09cO
o`3oool01P3oool00`2oM7@0_ooo0?ooo`1I0?ooo`030000003oool0oooo0:H0oooo00<0o`000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`030?noW02Lgol0oooo00H0oooo00<0_gAd0;oo
o`3oool01`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo00L0gia807Bo
o`3oool0oooo0?noM0000000M;oo00P0oooo0P0000280?ooo`0303<0o`3oool0oooo06T0oooo0`00
000Y0?ooo`00P03oool200000:L0oooo00<0o`000?ooo`3oool0>@3oool200000380oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@00000
07Boo`080?ooo`030000003oool0oooo08H0oooo00<0o`0003<0o`3oool0K03oool00`000000oooo
0?ooo`0W0?ooo`00?P3oool01P3ooml0W4P0000000000000001d0;ooo`H0oooo00<0_gA809cOo`3o
ool01P3oool00`3o_i`0M;oO0?ooo`050?ooo`030?noM000000000000080000000<007Bo0?ooo`3o
ool00`3oool0102oM000000000000018W=lF0?ooo`030000003oool0oooo0:H0oooo00<0o`000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0Q0?ooo`030;md00000000B9cO00`0oooo00<0omnL04P0
0018W=l0103oool00`3OW4P0001809cOo`070?ooo`060?noM000M;l0oooo0?noM0000000M;oo203o
ool00`000000oooo0?ooo`260?ooo`030?l0000c0?l0oooo06`0oooo00<000000?ooo`3oool09`3o
ool001T0oooo00<0gia80000B02Lgol01`3oool00`3ookl0M01d0;ooo`0G0?ooo`080?oo_`1d0000
04RL0=ooo`3oool0gia80000B02Lgol50?ooo`030?noM00004P0W=oo00D0oooo00<0okmd0000B02L
gol0203oool00`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0E
0?ooo`030000003oool0oooo0:H0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0O
0?ooo`050?oOW0180000M;oO09a80018W=l0303oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo00P0oooo00D0_g@007Boo`3o_g@0000007Boo`080?ooo`030000003oool0oooo08H0oooo
00<0<`3o0?ooo`3oool0K03oool00`000000oooo0?ooo`0W0?ooo`00603oool00`2oM000B9cO0?oo
o`070?ooo`040?oOW0180000001d0;oooaL0oooo00<0_g@00000M02oool00`3oool00`2oM00007Bo
0?ooo`050?ooo`030?noM00004P0W=oo00<0oooo00<0okmd0000B02Lgol02@3oool00`2oM000001d
0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0503oool00`000000oooo
0?ooo`2V0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool07P3oool01P2oM00004RL
0=ooo`3ooml0W4P004RLg`d0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`090?oo
o`050?oo_`1d07@0_kmd0000001d_ol0203oool00`000000oooo0?ooo`260?ooo`0303<0o`3oool0
oooo06`0oooo00<000000?ooo`3oool09`3oool001L0oooo00<0omnL04P0B02Lgol01`3oool01@3O
W4P004RL0;nLB00007@0_ooo01H0oooo00<0oono07@00000M;l0103oool00`3OW4P0001d0;ooo`06
0?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`0:0?ooo`030;md000007@0_ooo00<0oooo
00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0D0?ooo`030000003oool0oooo0:H0
oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0L0?ooo`030?oOW0180000M;oo0080
oooo00<0oooO09a80018W=l03@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00X0
oooo00@0okmd000000000000M;oo203oool00`000000oooo0?ooo`260?ooo`0303<0o`3oool0oooo
06`0oooo00<000000?ooo`3oool09`3oool001L0oooo00<0okmd0000001d_ol01@3oool01`3ooml0
W4P004RLg`3oool0gia80000M02oool05P3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0
W=oo00L0oooo00D0okmd0000B02LW7@0001809cOo`0;0?ooo`030;md000007@0_ooo00<0oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`0C0?ooo`030000003oool0oooo0:H0oooo00<0
o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0K0?ooo`030=nLB000B9`0gooo00<0oooo00<0
oooO09a80018W=l03P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`/0oooo00@0oooO09a80000
0000M;oo203oool00`000000oooo0?ooo`250?ooo`030?l0000c0?l0oooo06d0oooo00<000000?oo
o`3oool09`3oool001L0oooo00@0omnL04P0000004P0W=oo0P3oool0103ooml0W4P00000001d_ol2
0?ooo`030=nLB00007@0_ooo00T0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3o
gi`0B00004RLg`<0oooo00@0oono07@0000007@0_ooo203oool00`3o_g@0001809cOo`0<0?ooo`03
0;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0C0?ooo`03
0000003oool0oooo0:H0oooo00<0o`000?ooo`3oool0>P3oool00`000000oooo0?ooo`0I0?ooo`03
0?oOW0180000000000X0000000<0001d0;ooo`3oool02P3oool0102oM000000000000000M;l=0?oo
o`030?oOW0180000M;oo00P0oooo00<000000?ooo`3oool0Q@3oool00`3o0000<`3o0?ooo`1]0?oo
o`030000003oool0oooo02L0oooo000G0?ooo`030?oog`2LB000000000@0000000<0001d0;ooo`3o
ool00P3oool00`3OW4P0001d0;ooo`0F0?ooo`090?oo_`1d000000000018W03Oool0oooo0;md0000
0000B9cO00P0oooo00D0okmd0000B02LW7@0001809cOo`0;0?ooo`030;md000007@0_ooo00<0oooo
00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0C0?ooo`<00000YP3oool00`3o0000oooo
0?ooo`0h0?ooo`<000006`3oool00`3o_g@000000000000:000000030000M02oool0oooo02H0oooo
0P0000260?ooo`030?l0000c0?l0oooo06`0oooo0P00000Y0?ooo`00603oool01P3ooml0W4P00000
00000000001809cOo`@0oooo00@0oooO09a8000007@0_ooo5P3oool01@3ooml0W4P00000M02ogi`0
B0000080000000<0B9cO0?ooo`3oool01P3oool01`3o_g@0001809cOo`3oool0okmd0000B02Lgol0
2P3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
4`3oool00`000000oooo0?ooo`2V0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool0
8@3oool00`3ooml0W4P004RLg`0[0?ooo`030000003oool0oooo08D0oooo00<0<`3o0?ooo`3oool0
K@3oool00`000000oooo0?ooo`0W0?ooo`008P3oool00`3OW4P0001d0;ooo`0H0?ooo`030?noM000
0000B9cO00/0oooo00<0okmd0000B02Lgol00`3oool00`3o_g@0001809cOo`090?ooo`030;md0000
07@0_ooo00<0oooo00<0oono07@00000M;l0103oool0102oM000001d0;ooo`3OW4P2000000030000
B02Lgol0oooo00@0oooo00<0oono07@0B02Lgol01P3oool00`000000oooo0?ooo`2V0?ooo`030?l0
003oool0oooo03X0oooo00<000000?ooo`3oool08@3oool00`3ooml0W4P004RLg`0[0?ooo`030000
003oool0oooo08D0oooo00<0<`3o0?ooo`3oool0K@3oool00`000000oooo0?ooo`0W0?ooo`00?@3o
ool0103ooml0W4P00000B02Lgol90?ooo`030;md000004P0W=oo00D0oooo00<0okmd00000018W=l0
203oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0
103oool00`3ooml0W4Q809cOo`040?ooo`030?oo_`1d04P0W=oo00H0oooo00<000000?ooo`3oool0
YP3oool00`3o0000oooo0?ooo`0j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
Q@3oool00`0c0?l0oooo0?ooo`1]0?ooo`030000003oool0oooo02L0oooo000n0?ooo`040?oo_`1d
0000001d0;ooo`P0oooo00<0oknL09cOo`3oool01P3oool00`3o_i`0W=oo0?ooo`070?ooo`030;md
000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`050?ooo`030?no
M000M;l0oooo00<0oooo00<0oono07@0B02Lgol01P3oool00`000000oooo0?ooo`2V0?ooo`030?l0
003oool0oooo03X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`240?ooo`030?l0
000c0?l0oooo06h0oooo00<000000?ooo`3oool09`3oool001L0oooo00<0gia80000000000003`00
00000`1d_ol0oooo0?ooo`0C0?ooo`040?oog`2LB0000000001d_aP0oooo00D0gia8000000000000
001d0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo1P3oool0103OW4P007Bo0?oog`2L
B0050000000307Boo`3oool0oooo00<0oooo00<000000?ooo`3oool0YP3oool00`3o0000oooo0?oo
o`0j0?ooo`030000003oool0oooo01T0oooo00<0gia80000000000003`0000000`1d_ol0oooo0?oo
o`0Q0?ooo`030000003oool0oooo08@0oooo00<0o`0003<0o`3oool0KP3oool00`000000oooo0?oo
o`0W0?ooo`005`3oool00`3OW9`0_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo01H0oooo00D0omnL
04P00000000004RL0=ooo`0F0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00@0_g@0000000000000
07Bo1P3oool02P3ogi`0B00004RLg`3oool0okmd07Boo`3oool0oono07@0B02Lgol60?ooo`800000
YP3oool00`3o0000oooo0?ooo`0j0?ooo`8000006`3oool00`3OW9`0_ooo0?ooo`0>0?ooo`030?no
M01d_ol0oooo0280oooo00<000000?ooo`3oool0Q03oool00`0c0?l0oooo0?ooo`1^0?ooo`030000
003oool0oooo02L0oooo000G0?ooo`030=nLW02oool0oooo00h0oooo00<0okmd07Boo`3oool0@`3o
ool0103ooml0W4P000000000M;l30?ooo`050;mdM02oool0oono07@0B02Lgol01P3oool00`000000
oooo0?ooo`2U0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool06@3oool00`3OW9`0
_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo0280oooo0P0000250?ooo`0303<0o`3oool0oooo06d0
oooo0P00000Y0?ooo`005`3oool00`3OW9`0_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo04D0oooo
00<0gia8001d_`3oool00P3oool01@3ookl0M7Bo0?oo_`1d04P0W=oo00H0oooo00<000000?ooo`3o
ool0Y@3oool00`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo01T0oooo00<0gibL0;ooo`3o
ool03P3oool00`3o_g@0M;oo0?ooo`0R0?ooo`030000003oool0oooo08@0oooo00<0<`3o0?ooo`3o
ool0KP3oool00`000000oooo0?ooo`0W0?ooo`00K@3oool01P3ogml0gooo0?ooo`3oool0_g@007Bo
o`<0oooo00@0okmd07Bo_`1d04P0W=oo1P3oool00`000000oooo0?ooo`2U0?ooo`030?l0003oool0
oooo03/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`240?ooo`0303<0o`3oool0
oooo06h0oooo00<000000?ooo`3oool09`3oool001L0oooo00<0oknL09cOo`3oool0D`3oool01P3o
okl0M7Bo0?ooo`3ookl0M00007Boo`@0oooo00<0_g@00000B02Lgol01P3oool00`000000oooo0?oo
o`2U0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool06@3oool00`3o_i`0W=oo0?oo
o`0c0?ooo`030000003oool0oooo08<0oooo00<0o`0003<0o`3oool0K`3oool00`000000oooo0?oo
o`0W0?ooo`005`3oool00`3o_g@0M;oo0?ooo`0:0?ooo`030=nLW02oool0oooo04L0oooo00@0okmd
00000000000007Bo1@3oool00`3ookl0M01809cOo`060?ooo`030000003oool0oooo0:D0oooo00<0
o`000?ooo`3oool0>`3oool00`000000oooo0?ooo`0I0?ooo`030?noM01d_ol0oooo00X0oooo00<0
gibL0;ooo`3oool09P3oool00`000000oooo0?ooo`230?ooo`0303<0o`3oool0oooo06l0oooo00<0
00000?ooo`3oool09`3oool001L0oooo00<0okmd0018W03Oool02P3oool00`2oM7@0_ooo0?ooo`1I
0?ooo`800000YP3oool00`3o0000oooo0?ooo`0j0?ooo`8000006`3oool00`3o_g@004RL0=ooo`0:
0?ooo`030;mdM02oool0oooo02H0oooo00<000000?ooo`3oool0P`3oool00`0c0?l0oooo0?ooo`1_
0?ooo`030000003oool0oooo02L0oooo000G0?ooo`030?noM0000000000000X0000000<0001d0;oo
o`3oool0F@3oool00`000000oooo0?ooo`2U0?ooo`030?l0003oool0oooo03/0oooo00<000000?oo
o`3oool06@3oool00`3o_g@000000000000:000000030000M02oool0oooo02H0oooo00<000000?oo
o`3oool0P`3oool00`0c0?l0oooo0?ooo`1_0?ooo`030000003oool0oooo02L0oooo000H0?ooo`04
0;md00000000001809cOo`P0oooo00<0_gAd0;ooo`3oool0F@3oool00`000000oooo0?ooo`2U0?oo
o`030?l0003oool0oooo03/0oooo00<000000?ooo`3oool06P3oool0102oM00000000000B02Lgol8
0?ooo`030;mdM02oool0oooo02H0oooo0P0000240?ooo`0303<0o`3oool0oooo06h0oooo0P00000Y
0?ooo`006@3oool0103OW4P000000000001d_ol70?ooo`030=nLW02oool0oooo05T0oooo00<00000
0?ooo`3oool0Y@3oool00`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo01/0oooo00@0gia8
000000000000M;oo1`3oool00`3OW9`0_ooo0?ooo`0V0?ooo`030000003oool0oooo08<0oooo00<0
<`3o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0W0?ooo`006P3oool0103o_g@0000000000000
M;mR0?ooo`030000003oool0oooo0:D0oooo00<0o`000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0L0?ooo`040?noM00000000000001d_a<0oooo00@0_g@0000000000000B9cO103oool00`3OW4P0
000004RLg`030?ooo`060?oog`2LB00000000000000007@0_ooo203oool00`000000oooo0?ooo`22
0?ooo`0303<0o`3oool0oooo0700oooo00<000000?ooo`3oool09`3oool001/0oooo00D0omnL04P0
0000000004RL0=ooo`1P0?ooo`030000003oool0oooo0:D0oooo00<0o`000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0M0?ooo`050?oOW018000000000018W03Oool03`3oool01`3ooml0W4P0001d
_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`080?oo_`1d000004RL0=oo
o`3oool0gia80000B02Lgol70?ooo`030000003oool0oooo0880oooo00<0<`3o0?ooo`3oool0L03o
ool00`000000oooo0?ooo`0W0?ooo`00703oool01@3ookl0M0000000000004P0W=oo05l0oooo0P00
002V0?ooo`030?l0003oool0oooo03X0oooo0P00000P0?ooo`050?oo_`1d000000000000B02Lgol0
3P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0_g@00000M02oool0
0`3oool00`2oM00007Bo0?ooo`060?ooo`030000003oool0oooo0880oooo00<0<`3o0?ooo`3oool0
L03oool00`000000oooo0?ooo`0W0?ooo`007@3oool01@3ooml0W4P0000000000000M;oo01l0oooo
00<0okmd0000001d_ol01P3oool00`2oM4P0W=oo0?ooo`060?ooo`030?noW01d_ml0oooo00D0oooo
00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`030?ooo`040;md00000000000004RLgaH0
oooo00<000000?ooo`3oool0Y@3oool00`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo01l0
oooo00D0oooO09a800000000000007Boo`0<0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO
09a80000M;l01P3oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0_ooo00H0oooo00<00000
0?ooo`3oool0PP3oool00`0c0?l0oooo0?ooo`1`0?ooo`030000003oool0oooo02L0oooo000G0?oo
o`030?noW02Lgol0oooo00D0oooo00@0_g@000000000000007Bo7P3oool00`3o_g@0000007Boo`06
0?ooo`030?noM00004P0W=oo00D0oooo00<0okmd0000B02Lgol0203oool00`2oM000001d0;ooo`04
0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0E0?ooo`030000003oool0oooo0:@0oooo
00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`0I0?ooo`030?noW02Lgol0oooo00D0oooo
00@0_g@000000000000007Bo2`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0
oooo00<0omnL04P00018W=l0103oool00`2oM000001809cOo`060?ooo`030000003oool0oooo0880
oooo00<0<`3o0?ooo`3oool0L03oool00`000000oooo0?ooo`0W0?ooo`005`3oool00`3o_g@0M;oo
0?ooo`060?ooo`050=nLB000000000000018W03Oool0703oool00`3o_g@0000007Boo`070?ooo`03
0?noM00004P0W=oo00<0oooo00<0okmd0000B02Lgol02@3oool00`2oM000001d0;ooo`040?ooo`03
0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0503oool00`000000oooo0?ooo`2T0?ooo`03
0?l0003oool0oooo03`0oooo00<000000?ooo`3oool06@3oool00`3o_g@0M;oo0?ooo`060?ooo`05
0=nLB000000000000018W03Oool02@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo
00D0oooo00<0omnL04P00018W=l00`3oool0103ookl0M0000000M02oool60?ooo`030000003oool0
oooo0880oooo00<0<`3o0?ooo`3oool0L03oool00`000000oooo0?ooo`0W0?ooo`005`3oool00`3o
_g@000000000000:000000030000B02Lgol0oooo01D0oooo00<0gia80000000000001@0000000`00
04P0W=oo0?ooo`050?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`0:0?ooo`030;md0000
07@0_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0D0?ooo`030000
003oool0oooo0:@0oooo00<0o`000?ooo`3oool0?03oool00`000000oooo0?ooo`0I0?ooo`030?no
M0000000000000X0000000<0001809cOo`3oool01`3oool00`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo00D0oooo00T0oono07@00000000004RL0=ooo`3oool0_g@000000018W=l01`3oool2
00000880oooo00<0<`3o0?ooo`3oool0K`3oool3000002T0oooo000G0?ooo`030?noM01d_ol0oooo
0280oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`090?ooo`050?noM00004P0W9ad
0000B02Lgol02`3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool04`3oool00`000000oooo0?ooo`2T0?ooo`030?l0003oool0oooo03`0oooo00<00000
0?ooo`3oool06@3oool00`3o_g@0M;oo0?ooo`0D0?ooo`030?oOW0180000B9cO00@0oooo00<0gia8
0000B02Lgol01@3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3oool01P3o
ool00`000000oooo0?ooo`210?ooo`0303<0o`3oool0oooo0740oooo00<000000?ooo`3oool09`3o
ool001L0oooo00<0oknL09cOo`3oool05@3oool00`2oM0000000000000070000000604RLg`3oool0
oooo0?ooo`3OW4P0M;oo0P3oool00`3o_g@0000007Boo`0:0?ooo`030?noM00004P0W=oo00`0oooo
00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo01<0oooo
0`00002T0?ooo`030?l0003oool0oooo03X0oooo0`00000K0?ooo`030?noW02Lgol0oooo01@0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?noM0000000B9cO00`0oooo
00<000000?ooo`3oool0P@3oool00`0c0?l0oooo0?ooo`1a0?ooo`030000003oool0oooo02L0oooo
000m0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`090?ooo`050?noM00004P0W9ad0000
B02Lgol02`3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000
B02Lgol04`3oool00`000000oooo0?ooo`2T0?ooo`030?l0003oool0oooo03`0oooo00<000000?oo
o`3oool0<@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00@0oooO09a8
000004P0W=oo2`3oool00`000000oooo0?ooo`210?ooo`0303<0o`3oool0oooo0740oooo00<00000
0?ooo`3oool09`3oool003h0oooo00H0okmd001d_`3oool0okmd0000001d_ol80?ooo`070?noM000
04P0W=oo0?ooo`3o_g@0001809cOo`0:0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`0C0?ooo`030000003oool0oooo0:@0oooo00<0o`000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0a0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol0203oool0103ookl0M0000000M02oool:0?ooo`030000003oool0oooo0840oooo00<0<`3o0?oo
o`3oool0L@3oool00`000000oooo0?ooo`0W0?ooo`005`3oool00`3OW9`0_ooo0?ooo`0>0?ooo`03
0?noM01d_ol0oooo01@0oooo00D0_g@007Boo`3o_g@0000007Boo`070?ooo`030?noM00004P0W=oo
00<0oooo00<0okmd0000B02Lgol02@3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo
00@0oooo00@0_g@00000M02oool0gia80P0000000`0004P0W=oo0?ooo`040?ooo`030?oo_`1d04P0
W=oo00H0oooo00<000000?ooo`3oool0Y03oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0
oooo01T0oooo00<0gibL0;ooo`3oool03P3oool00`3o_g@0M;oo0?ooo`050?ooo`060;md0000B9`0
gooo0?ooo`2oM00007Bo2P3oool0103ooml0W4P000000000M;l90?ooo`030000003oool0oooo0840
oooo00<0<`3o0?ooo`3oool0L@3oool00`000000oooo0?ooo`0W0?ooo`005`3oool00`3OW9`0_ooo
0?ooo`0>0?ooo`030?noM01d_ol0oooo01@0oooo00D0oono07@0M02o_g@0000007Boo`060?ooo`03
0;md000004P0W=oo00D0oooo00<0okmd00000018W=l0203oool00`2oM000001d0;ooo`040?ooo`03
0;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0103oool00`3ooml0W4Q809cOo`040?ooo`03
0?oo_`1d04P0W=oo00H0oooo00<000000?ooo`3oool0Y03oool00`3o0000oooo0?ooo`0l0?ooo`03
0000003oool0oooo01T0oooo00<0gibL0;ooo`3oool03P3oool00`3o_g@0M;oo0?ooo`060?ooo`04
0;md000000000000001d_`d0oooo00D0omnL04P00000000004RL0=ooo`060?ooo`030000003oool0
oooo0800oooo00<0<`3o0?ooo`3oool0LP3oool00`000000oooo0?ooo`0W0?ooo`005`3oool00`3O
W9`0_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo01D0oooo00@0okmd000000000000M;oo1P3oool0
0`3o_i`0W=oo0?ooo`060?ooo`030?noW02Lgol0oooo00L0oooo00<0_g@00000M02oool0103oool0
0`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00D0oooo00<0okmd001d_`3oool00`3oool0
0`3ookl0M01809cOo`060?ooo`030000003oool0oooo0:@0oooo00<0o`000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0I0?ooo`030=nLW02oool0oooo00h0oooo00<0okmd07Boo`3oool08P3oool2
00000840oooo00<0<`3o0?ooo`3oool0L@3oool2000002T0oooo000G0?ooo`030=nLB00000000000
00l0000000<0M;oo0?ooo`3oool0503oool0103ooml0W4P00000001d_olG0?ooo`050=nLB0000000
00000000M02oool01@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`H0oooo00@0gia8001d_`3o
oml0W4P01@0000000`1d_ol0oooo0?ooo`030?ooo`030000003oool0oooo0:<0oooo00<0o`000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0I0?ooo`030=nLB0000000000000l0000000<0M;oo0?oo
o`3oool08@3oool00`000000oooo0?ooo`200?ooo`0303<0o`3oool0oooo0780oooo00<000000?oo
o`3oool09`3oool00440oooo00<0omnL04P0001d_ol0603oool0103ookl0M0000000M02oool60?oo
o`040;md000000000000001d_`H0oooo00X0omnL04P00018W=l0oooo0?noM01d_ol0oooo0?oo_`1d
04P0W=oo1P3oool200000:@0oooo00<0o`000?ooo`3oool0?03oool200000540oooo00<000000?oo
o`3oool0P03oool00`0c0?l0oooo0?ooo`1b0?ooo`030000003oool0oooo02L0oooo001^0?ooo`04
0?oog`2LB0000000001d_`<0oooo00D0_gAd0;ooo`3ookl0M01809cOo`060?ooo`030000003oool0
oooo0:<0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0800oooo00<0<`3o0?ooo`3oool0LP3oool00`000000oooo0?ooo`0W0?ooo`00L03oool00`3O
W4P007Bo0?ooo`020?ooo`050?oo_`1dM;l0oono07@0B02Lgol01P3oool00`000000oooo0?ooo`2S
0?ooo`030?l0003oool0oooo03d0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`20
0?ooo`0303<0o`3oool0oooo0780oooo00<000000?ooo`3oool09`3oool006d0oooo00H0omoO0=oo
o`3oool0oooo0;md001d_ol30?ooo`040?noM01d_kl0M01809cOo`H0oooo00<000000?ooo`3oool0
X`3oool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
O`3oool00`0c0?l0oooo0?ooo`1c0?ooo`030000003oool0oooo02L0oooo001]0?ooo`060?oo_`1d
M;l0oooo0?oo_`1d0000M;oo103oool00`2oM000001809cOo`060?ooo`030000003oool0oooo0:<0
oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo07l0
oooo00<0<`3o0?ooo`3oool0L`3oool00`000000oooo0?ooo`0W0?ooo`00KP3oool0103o_g@00000
00000000M;l50?ooo`030?oo_`1d04P0W=oo00H0oooo00<000000?ooo`3oool0X`3oool00`3o0000
oooo0?ooo`0m0?ooo`030000003oool0oooo04l0oooo0P0000200?ooo`0303<0o`3oool0oooo0780
oooo0P00000Y0?ooo`00P03oool200000:@0oooo00<0o`000?ooo`3oool0?03oool200000540oooo
00<000000?ooo`3oool0O`3oool00`0c0?l0oooo0?ooo`1c0?ooo`030000003oool0oooo02L0oooo
00200?ooo`030000003oool0oooo0:<0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo07l0oooo00<0<`3o0?ooo`3oool0L`3oool00`000000oooo0?oo
o`0W0?ooo`00P03oool00`000000oooo0?ooo`2S0?ooo`030?l0003oool0oooo03d0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`1o0?ooo`0303<0o`3oool0oooo07<0oooo00<00000
0?ooo`3oool09`3oool00800oooo00<000000?ooo`3oool0X`3oool00`3o0000oooo0?ooo`0m0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0OP3oool00`0c0?l0oooo0?ooo`1d0?oo
o`030000003oool0oooo02L0oooo00200?ooo`030000003oool0oooo0:<0oooo00<0o`000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo07h0oooo00<0<`3o0?ooo`3o
ool0M03oool00`000000oooo0?ooo`0W0?ooo`00P03oool00`000000oooo0?ooo`2R0?ooo`030?l0
003oool0oooo03h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1n0?ooo`0303<0
o`3oool0oooo07@0oooo00<000000?ooo`3oool09`3oool00800oooo0P00002S0?ooo`030?l0003o
ool0oooo03d0oooo0P00001A0?ooo`800000O`3oool00`0c0?l0oooo0?ooo`1c0?ooo`800000:@3o
ool003`0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`030?ooo`030;mdB02Lgol0
oooo00H0oooo00<0oknL07Bog`3oool01@3oool00`3o_g@000000000000200000003001d_`3oool0
oooo00<0oooo00@0_g@0000000000000B9cO5P3oool00`000000oooo0?ooo`2R0?ooo`030?l0003o
ool0oooo03h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1n0?ooo`0303<0o`3o
ool0oooo07@0oooo00<000000?ooo`3oool09`3oool003d0oooo00<0gia800000000000010000000
0`00M;l0oooo0?ooo`030?ooo`030?noM00004P0W=oo00D0oooo00<0okmd0000B02Lgol0203oool0
0`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0E0?ooo`030000
003oool0oooo0:80oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0c0?ooo`040;md
00000000000004RLg`@0oooo00<0gia800000018W=l00`3oool01P3ogi`0B0000000000000000018
09cOo`P0oooo00<000000?ooo`3oool0O@3oool00`0c0?l0o`000?ooo`1e0?ooo`030000003oool0
oooo02L0oooo000n0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01@3oool00`3o
_g@0001809cOo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_g@00000M02oool0103oool00`3o
_g@0001809cOo`020?ooo`030?oOW0180000M;oo01@0oooo00<000000?ooo`3oool0XP3oool00`3o
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0340oooo00L0oooO09a80000M;l0oooo0?oog`2L
B00007Bo00<0oooo00<0gia800000018W=l00P3oool0203ogi`0B0000018W03Oool0oooo0?oOW018
0000M;oo1`3oool00`000000oooo0?ooo`1m0?ooo`0303<0o`3oool0oooo07D0oooo00<000000?oo
o`3oool09`3oool003l0oooo00<0gia804RLg`3oool02P3oool01`3o_g@0001809cOo`3oool0okmd
0000B02Lgol02P3oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
oooO09a80000M;l0503oool00`000000oooo0?ooo`2R0?ooo`030?l0003oool0oooo03h0oooo00<0
00000?ooo`3oool0<@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0
_g@00000M02oool00`3oool00`3OW4P004RL0=ooo`060?ooo`030000003oool0oooo07d0oooo00<0
<`3o0?ooo`3oool0M@3oool00`000000oooo0?ooo`0W0?ooo`00@03oool00`3OW4P0M;oo0?ooo`0:
0?ooo`050?noM00004P0W9ad0000B02Lgol02`3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool04`3oool00`000000oooo0?ooo`2R0?ooo`030?l0003o
ool0oooo03h0oooo00<000000?ooo`3oool0<03oool0103ooml0W4P00018W03Oool20?ooo`030?oo
g`2LB00007Bo00L0oooo00<0_g@00000M02oool00`3oool00`2oM00004RL0=ooo`060?ooo`030000
003oool0oooo07d0oooo00<0<`3o0?ooo`3oool0M@3oool00`000000oooo0?ooo`0W0?ooo`00;`3o
ool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol02`3o
ool00`3o_g@0001809cOo`0<0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103o
ool00`2oM000001d0;ooo`0C0?ooo`<00000XP3oool00`3o0000oooo0?ooo`0l0?ooo`<00000<P3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3o
ool00`3OW4P00000001d_`070?ooo`030000003oool0oooo07d0oooo00<0<`3o0?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0W0?ooo`00@@3oool00`3ogi`0B01d0;ooo`090?ooo`050?noM00004P0
W9ad0000B02Lgol02`3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol04`3oool00`000000oooo0?ooo`2R0?ooo`030?l0003oool0oooo03h0oooo00<0
00000?ooo`3oool0<03oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00L0oooo00L0
gia8001d_`3oool0_g@00000000007@0_ooo00L0oooo00<000000?ooo`3oool0O03oool00`0c0?l0
oooo0?ooo`1f0?ooo`030000003oool0oooo02L0oooo00120?ooo`030;md0018W=l0oooo00L0oooo
00L0okmd0000B02Lgol0oooo0?noM00004P0W=oo00X0oooo00<0_g@00000M02oool00`3oool00`3o
gi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01<0oooo00<000000?ooo`3oool0XP3oool00`3o
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0300oooo00<0omnL04P00018W=l0103oool00`3O
W4P0001809cOo`080?ooo`050?noM000000000000018W03Oool0203oool2000007d0oooo00<0<`3o
0?ooo`3oool0M03oool3000002T0oooo00120?ooo`030=nLB00007@0_ooo00H0oooo00<0okmd0000
B02Lgol00`3oool00`3o_g@0001809cOo`090?ooo`030;md000007@0_ooo00<0oooo00<0oono07@0
0000M;l0103oool0102oM000001d0;ooo`3OW4P2000000030000B02Lgol0oooo00@0oooo00<0oono
07@0B02Lgol01P3oool00`000000oooo0?ooo`2R0?ooo`030?l0003oool0oooo03h0oooo00<00000
0?ooo`3oool0<03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL
04P000000000000004RLg`090?ooo`030000003oool0oooo07`0oooo00<0<`3o0?ooo`3oool0MP3o
ool00`000000oooo0?ooo`0W0?ooo`00@P3oool00`3o_g@0000007Boo`050?ooo`030;md000004P0
W=oo00D0oooo00<0okmd00000018W=l0203oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l0103oool00`3ooml0W4Q809cOo`040?ooo`030?oo_`1d04P0
W=oo00H0oooo00<000000?ooo`3oool0XP3oool00`3o0000oooo0?ooo`0n0?ooo`030000003oool0
oooo0300oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`070?oOW0180000
001809cOo`3oool0gia8001d_`080?ooo`030000003oool0oooo07/0oooo00<0o`0003<0o`3oool0
M`3oool00`000000oooo0?ooo`0W0?ooo`00?03oool00`3ogi`0W;oo0?ooo`030?ooo`030;md0000
0000M;oo00D0oooo00<0oknL09cOo`3oool01P3oool00`3o_i`0W=oo0?ooo`070?ooo`030;md0000
07@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`050?ooo`030?noM000
M;l0oooo00<0oooo00<0oono07@0B02Lgol01P3oool00`000000oooo0?ooo`2R0?ooo`030?l0003o
ool0oooo03h0oooo00<000000?ooo`3oool0<@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2L
B00007Bo00L0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Boo`070?ooo`030000003o
ool0oooo07/0oooo00<0<`3o0?ooo`3oool0M`3oool00`000000oooo0?ooo`0W0?ooo`00?@3oool0
202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo5P3oool01@3OW4P000000000000007@0_ooo
00D0oooo00H0_g@00018W03Oool0oooo0;md0000M;l60?ooo`040=nLB000M;l0oooO09a800D00000
00<0M;oo0?ooo`3oool00`3oool00`000000oooo0?ooo`2R0?ooo`030?l0003oool0oooo03h0oooo
00<000000?ooo`3oool0<@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo
00<0gia80018W03Oool00P3oool00`3ooml0W4P004RLg`070?ooo`030000003oool0oooo07/0oooo
00<0<`3o0?ooo`3oool0M`3oool00`000000oooo0?ooo`0W0?ooo`00?P3oool01@2oM00000000000
0000000007Bo01T0oooo00@0oono07@0000007@0_ooo1P3oool0102oM000000000000000M;l60?oo
o`0:0?oOW0180000B9cO0?ooo`3o_g@0M;oo0?ooo`3ookl0M01809cOo`H0oooo0P00002S0?ooo`03
0?l0003oool0oooo03d0oooo0P00000d0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool0
0`3ogi`0B00004RLg`020?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0NP3oool0
0`0c0?l0oooo0?ooo`1h0?ooo`030000003oool0oooo02L0oooo001^0?ooo`040?oog`2LB0000000
001d_`<0oooo00D0_gAd0;ooo`3ookl0M01809cOo`060?ooo`030000003oool0oooo0:80oooo00<0
o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0c0?ooo`040;md000000000000001d_`X0oooo
00H0oono07@00000000000000000B02Lgol80?ooo`030000003oool0oooo07X0oooo00<0<`3o0?oo
o`3oool0N03oool00`000000oooo0?ooo`0W0?ooo`00L03oool00`3OW4P007Bo0?ooo`020?ooo`05
0?oo_`1dM;l0oono07@0B02Lgol01P3oool00`000000oooo0?ooo`2Q0?ooo`030?l0003oool0oooo
03l0oooo00<000000?ooo`3oool0C`3oool2000007/0oooo00<0<`3o0?ooo`3oool0M`3oool20000
02T0oooo001]0?ooo`060?oOg`3Oool0oooo0?ooo`2oM000M;oo0`3oool0103o_g@0M;no07@0B02L
gol60?ooo`030000003oool0oooo0:40oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo07T0oooo00<0<`3o0?ooo`3oool0N@3oool00`000000oooo0?oo
o`0W0?ooo`00K@3oool01P3ookl0M7Bo0?ooo`3ookl0M00007Boo`@0oooo00<0_g@00000B02Lgol0
1P3oool00`000000oooo0?ooo`2Q0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`1i0?ooo`0303<0o`3oool0oooo07T0oooo00<000000?ooo`3oool0
9`3oool006h0oooo00@0okmd00000000000007Bo1@3oool00`3ookl0M01809cOo`060?ooo`030000
003oool0oooo0:40oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo07T0oooo00<0<`3o0?ooo`3oool0N@3oool00`000000oooo0?ooo`0W0?ooo`00P03o
ool200000:80oooo00<0o`000?ooo`3oool0?P3oool200000540oooo00<000000?ooo`3oool0N03o
ool00`0c0?l0o`000?ooo`1j0?ooo`030000003oool0oooo02L0oooo00200?ooo`030000003oool0
oooo0:40oooo00<0o`000?ooo`3oool0?`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo07P0oooo00<0<`3o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0W0?ooo`00P03oool00`00
0000oooo0?ooo`2Q0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`1h0?ooo`0303<0o`3oool0oooo07X0oooo00<000000?ooo`3oool09`3oool00800
oooo00<000000?ooo`3oool0X03oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo04l0
oooo0P00001h0?ooo`030?l0000c0?l0oooo07X0oooo0P00000Y0?ooo`00P03oool00`000000oooo
0?ooo`2P0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1g0?ooo`0303<0o`3oool0oooo07/0oooo00<000000?ooo`3oool09`3oool00800oooo00<0
00000?ooo`3oool0W`3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0MP3oool00`3o0000<`3o0?ooo`1l0?ooo`030000003oool0oooo02L0oooo0020
0?ooo`800000X03oool00`3o0000oooo0?ooo`100?ooo`800000D@3oool00`000000oooo0?ooo`1f
0?ooo`0303<0o`3oool0oooo07`0oooo00<000000?ooo`3oool09`3oool007@0oooo00@0_g@00000
00000000B9cO203oool00`000000oooo0?ooo`2O0?ooo`030?l0003oool0oooo0440oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`1e0?ooo`0303<0o`3oool0oooo07d0oooo00<00000
0?ooo`3oool09`3oool00780oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00L0oooo00<0
00000?ooo`3oool0W`3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0M03oool00`3o0000<`3o0?ooo`1n0?ooo`030000003oool0oooo02L0oooo001b
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`2N
0?ooo`030?l0003oool0oooo0480oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1d
0?ooo`0303<0o`3oool0oooo07h0oooo00<000000?ooo`3oool09`3oool00740oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030000003oool0oooo09h0oooo00<0o`00
0?ooo`3oool0@P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo07<0oooo00<0<`3o
0?ooo`3oool0O`3oool00`000000oooo0?ooo`0W0?ooo`00L@3oool00`3ookl0M000001d_`040?oo
o`030;md000007@0_ooo00D0oooo00<000000?ooo`3oool0W03oool20?l004D0oooo00<000000?oo
o`3oool0C`3oool2000007<0oooo00<0o`0003<0o`3oool0O`3oool2000002T0oooo001a0?ooo`03
0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01@3oool3000000<0oooof`0c0?l30?ooo`<0
0000@`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00H0oooo00<000000?ooo`3o
ool0LP3oool00`0c0?l0oooo0?ooo`200?ooo`030000003oool0oooo02L0oooo001a0?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool00`000000oooo0?ooo`3S0?ooo`030000
003oool0oooo04<0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`1`0?ooo`80<`3o
P`3oool00`000000oooo0?ooo`0W0?ooo`00L@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0@`3oool00`2oM000001d0;ooo`090?ooo`030000003o
ool0oooo06h0oooo00<0o`0003<0o`3o0000Q03oool00`000000oooo0?ooo`0W0?ooo`00L@3oool0
0`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`130?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0K@3oool2
03<0ohH0oooo00<000000?ooo`3oool09`3oool00780oooo00<0_g@00018W03Oool00P3oool00`3o
oml0W4P0001d_`060?ooonL00000A@3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo
06T0oooo100c0?n80?ooo`030000003oool0oooo02L0oooo001b0?ooo`030?noM00004P0W=oo0080
oooo00<0omnL04P0001d_ol0o`3ooolc0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3o
ool0HP3oool00`3o0000<`3o03<0o`0403<0o`030?l0003oool0oooo08T0oooo00<000000?ooo`3o
ool09`3oool007<0oooo00H0_g@00018W03Oool0oooo0;md0000M;oo0?oooc@0oooo00<0_g@00000
M02oool02@3oool2000000@0ooooH00c0?n@0?ooo`<00000:@3oool007@0oooo00@0_g@000000000
000007Boo`3ooole0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0m@3oool00`00
0000oooo0?ooo`0W0?ooo`00o`3ooon]0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool09`3oool00?l0oooo[@3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool09`3oool00?l0oooo[@3oool00`2oM000001d0;ooo`090?ooooT00000:@3o
ool00?l0ooooZ`3oool01@3OW4P000000000000007@0_ooo0?l0oooo;03oool00?l0oooo[03oool0
103ookl0M0000000M02ooooo0?ooob`0oooo003o0?ooool0oooog03oool00?l0ooooo`3ooooL0?oo
o`00o`3ooooo0?ooom`0oooo003o0?ooool0oooog03oool00?l0ooooo`3ooooL0?ooo`00o`3ooooo
0?ooom`0oooo003o0?ooool0oooog03oool00?l0ooooo`3ooooL0?ooo`00o`3ooooo0?ooom`0oooo
003o0?ooool0oooog03oool00?l0ooooo`3ooooL0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 729.688}, {224.813, 0}} -> {-0.0531656, -0.0154541, \
0.00288662, 0.00288662}, {{18.375, 364.813}, {219.438, 5.3125}} -> {-54.5458, \
-1.6202*^31, 0.182979, 8.03932*^28}, {{364.813, 711.25}, {219.438, 5.3125}} -> \
{-105.541, -0.419612, 0.169362, 0.00685082}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\( (*\ 
        Case\ 2\ for\ \[CapitalLambda]CDM\ when\ the\ system\ is\ not\ \
decoupled\ as\ we\ take\ into\ acount\ the\ constraint\ equations\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ 
          Use\ constraint\ equation\ \((\(x1'\)[N] = \(0\ since\ x1[N] = 
                  0\))\)\ and\ make\ it\ a\ Differential\ algebraic\ \
equations\ system\ \((see\ NDSolve\ documentation)\)\ *) \),
        FontSize->18], 
      "\[IndentingNewLine]", \(Solve[\(-1\) - x3 - 3  x2 + x4 \[Equal] 0, 
        x2]\)}]], "Input"],

Cell[BoxData[
    \({{x2 \[Rule] 1\/3\ \((\(-1\) - x3 + x4)\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(eqns = {\(-1\) - x3[N] - 3  x2[N] + x4[N] \[Equal] 
            0, \(-2\) x3[N] x4[N] \[Equal] \(x4'\)[N]};\)\), "\n", 
    \(\(nsol = \(NDSolve[\((Flatten[{eqns, x2[nmin] \[Equal] x2min, 
                  x4[nmin] \[Equal] x4min}])\), {x2[N], x4[N]}, {N, nmin, 
              nmax}]\)[\([1]\)];\)\)}], "Input"],

Cell[BoxData[{
    \(\(x1[N_] := 0;\)\), "\[IndentingNewLine]", 
    \(xx1[N_] := x1[N]\), "\n", 
    \(xx2[N_] := x2[N] /. nsol\), "\[IndentingNewLine]", 
    \(xx4[N_] := x4[N] /. nsol\)}], "Input"],

Cell[BoxData[
    \(\(flnm = "\<figs_lcdm\>";\)\)], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 2\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig2x1 = 
        Plot[xx1[N], {N, nmin, 6}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_1\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(fig2x2 = 
        Plot[xx2[N], {N, nmin, 6}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_2\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(fig2x3 = 
        Plot[x3[N], {N, nmin, 6}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_3\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(fig2x4 = 
        Plot[xx4[N], {N, nmin, 6}, Frame -> True, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", \*"\"\<\!\(x\_4\)(N)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{fig2x1, fig2x2}, {fig2x3, fig2x4}}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] \(-0.05\)];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x1\>" <> "\<.m\>", 
        fig2x1];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x2\>" <> "\<.m\>", 
        fig2x2];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x3\>" <> "\<.m\>", 
        fig2x3];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig2_x4\>" <> "\<.m\>", fig2x4];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.51221 0.316563 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.0147151 0.294302 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -14.0625 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .16187 -29.125 -12.2813 ]
[-0.0125 .16187 0 12.2813 ]
[-0.0125 .30902 -14.0625 -12.2813 ]
[-0.0125 .30902 0 12.2813 ]
[-0.0125 .45617 -29.125 -12.2813 ]
[-0.0125 .45617 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -24.5938 ]
[-0.01875 .30902 -29.125 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .16187 m
.00625 .16187 L
s
gsave
-0.0125 .16187 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .45617 m
.00625 .45617 L
s
gsave
-0.0125 .45617 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03793 .01472 L
.04262 .01472 L
.0522 .01472 L
.05746 .01472 L
.06244 .01472 L
.06754 .01472 L
.07295 .01472 L
.08265 .01472 L
.08804 .01472 L
.09308 .01472 L
.09858 .01472 L
.10458 .01472 L
.10996 .01472 L
.11496 .01472 L
.12013 .01472 L
.12483 .01472 L
.13379 .01472 L
.14335 .01472 L
.14823 .01472 L
.15338 .01472 L
.1626 .01472 L
.16773 .01472 L
.17252 .01472 L
.17774 .01472 L
.18342 .01472 L
.18885 .01472 L
.19387 .01472 L
.19858 .01472 L
.20377 .01472 L
.21277 .01472 L
.2177 .01472 L
.22233 .01472 L
.23216 .01472 L
.2371 .01472 L
.24251 .01472 L
.2521 .01472 L
.26101 .01472 L
.26606 .01472 L
.27154 .01472 L
.27636 .01472 L
.28147 .01472 L
.29114 .01472 L
.30006 .01472 L
.3095 .01472 L
.31479 .01472 L
.31963 .01472 L
.32903 .01472 L
Mistroke
.33795 .01472 L
.34299 .01472 L
.34756 .01472 L
.35248 .01473 L
.35779 .01473 L
.36727 .01473 L
.37619 .01474 L
.38572 .01475 L
.39113 .01476 L
.39617 .01477 L
.40635 .01479 L
.41205 .01481 L
.41725 .01483 L
.42207 .01486 L
.42719 .01489 L
.43637 .01496 L
.44147 .01501 L
.44625 .01507 L
.45146 .01515 L
.45714 .01525 L
.467 .01549 L
.47238 .01566 L
.47737 .01586 L
.48633 .01632 L
.49588 .017 L
.50123 .0175 L
.50615 .01806 L
.51145 .01878 L
.51727 .01975 L
.52707 .02189 L
.53743 .02509 L
.54762 .02948 L
.55692 .03485 L
.56765 .04298 L
.57783 .05281 L
.61612 .10267 L
.63548 .12587 L
.64651 .13599 L
.65687 .14332 L
.66672 .14856 L
.67575 .15215 L
.68566 .15505 L
.69113 .15627 L
.69611 .1572 L
.70564 .15858 L
.71582 .15962 L
.72526 .16031 L
.73418 .16081 L
.74389 .16132 L
.74878 .16164 L
Mistroke
.7516 .16186 L
.75417 .16212 L
.75876 .16273 L
.76129 .16321 L
.7637 .16379 L
.76591 .16448 L
.76796 .16527 L
.77022 .16637 L
.77262 .16787 L
.77523 .17002 L
.77798 .17304 L
.78033 .17643 L
.78291 .18124 L
.78569 .18808 L
.78867 .19783 L
.79148 .20993 L
.79404 .2239 L
.79901 .26042 L
.80441 .31487 L
.81422 .43448 L
.81875 .48397 L
.82363 .52579 L
.82642 .54402 L
.82898 .55741 L
.83159 .56822 L
.83401 .57613 L
.83637 .58222 L
.8389 .58728 L
.8417 .59153 L
.84425 .59443 L
.84691 .59671 L
.84979 .59853 L
.85251 .59979 L
.85502 .60066 L
.85747 .6013 L
.8597 .60175 L
.86228 .60215 L
.86473 .60243 L
.86698 .60263 L
.86907 .60278 L
.87136 .6029 L
.8738 .603 L
.87649 .60308 L
.87938 .60315 L
.88212 .6032 L
.88464 .60323 L
.88691 .60325 L
.88941 .60326 L
.89202 .60328 L
.89444 .60329 L
Mistroke
.89706 .6033 L
.89947 .6033 L
.90212 .60331 L
.90493 .60331 L
.90737 .60331 L
.90965 .60331 L
.91216 .60331 L
.91485 .60332 L
.91723 .60332 L
.91982 .60332 L
.92227 .60332 L
.92455 .60332 L
.9268 .60332 L
.92885 .60332 L
.9312 .60332 L
.93343 .60332 L
.93583 .60332 L
.93808 .60332 L
.94054 .60332 L
.94318 .60332 L
.94595 .60332 L
.94858 .60332 L
.95093 .60332 L
.95349 .60332 L
.9557 .60332 L
.95814 .60332 L
.96069 .60332 L
.96309 .60332 L
.96531 .60332 L
.96736 .60332 L
.9696 .60332 L
.97196 .60332 L
.97415 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.48779 0.0147151 0.97619 0.316563 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.0147151 0.588604 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -14.0625 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .13244 -29.125 -12.2813 ]
[-0.0125 .13244 0 12.2813 ]
[-0.0125 .25016 -29.125 -12.2813 ]
[-0.0125 .25016 0 12.2813 ]
[-0.0125 .36788 -29.125 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .4856 -29.125 -12.2813 ]
[-0.0125 .4856 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -24.5938 ]
[-0.01875 .30902 -29.125 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03754 .60332 L
.04262 .60332 L
.04518 .60332 L
.04795 .60332 L
.05058 .60332 L
.053 .60332 L
.06244 .60332 L
.06713 .60332 L
.06848 .60332 L
.06977 .60332 L
.07218 .60332 L
.07482 .60332 L
.07771 .60332 L
.0829 .60332 L
.09427 .60332 L
.10458 .60332 L
.10945 .60332 L
.11201 .60332 L
.11329 .60332 L
.11471 .60332 L
.11968 .60332 L
.12425 .60332 L
.12989 .60332 L
.13522 .60332 L
.13755 .60332 L
.14001 .60332 L
.14272 .60332 L
.14523 .60332 L
.15529 .60332 L
.16022 .60332 L
.16473 .60332 L
.16707 .60332 L
.16952 .60332 L
.17468 .60332 L
.18565 .60332 L
.19519 .60332 L
.20539 .60332 L
.21501 .60332 L
.22376 .60332 L
.23374 .60332 L
.24294 .60332 L
.24775 .60332 L
.25304 .60332 L
.25853 .60332 L
.26374 .60332 L
.2739 .60332 L
.28319 .60332 L
Mistroke
.29318 .60331 L
.29884 .60331 L
.30408 .60331 L
.30917 .60331 L
.31467 .60331 L
.31952 .60331 L
.32464 .6033 L
.33435 .6033 L
.34326 .60329 L
.35276 .60328 L
.35809 .60327 L
.36294 .60326 L
.37237 .60323 L
.38129 .6032 L
.38589 .60317 L
.39097 .60314 L
.39591 .60311 L
.40123 .60306 L
.41075 .60295 L
.41967 .6028 L
.42926 .60257 L
.4347 .6024 L
.43975 .60221 L
.44996 .60169 L
.45567 .60129 L
.46086 .60086 L
.46572 .60036 L
.47087 .59973 L
.48008 .59825 L
.48521 .59718 L
.49 .59598 L
.49522 .5944 L
.50089 .59231 L
.50631 .58986 L
.51133 .58713 L
.52122 .58008 L
.53021 .57118 L
.53977 .55827 L
.54912 .54118 L
.55922 .51657 L
.56874 .48642 L
.57749 .45238 L
.61708 .24642 L
.62733 .19474 L
.63702 .15246 L
.64645 .11843 L
.65516 .09323 L
.66455 .07205 L
.67474 .05497 L
.68491 .04274 L
Mistroke
.69004 .03799 L
.69569 .03366 L
.70089 .03037 L
.70583 .02776 L
.71511 .02396 L
.72029 .02234 L
.7251 .02109 L
.73033 .01995 L
.73599 .01895 L
.7415 .01816 L
.74657 .01756 L
.75132 .01709 L
.75653 .01667 L
.76558 .0161 L
.77514 .01567 L
.78536 .01534 L
.79467 .01511 L
.79981 .01501 L
.80541 .01491 L
.8107 .01484 L
.81325 .01481 L
.81559 .01479 L
.8178 .01477 L
.82023 .01476 L
.82266 .01475 L
.82522 .01474 L
.82749 .01473 L
.82991 .01473 L
.83219 .01472 L
.83427 .01472 L
.83555 .01472 L
.83691 .01472 L
.83935 .01472 L
.84071 .01472 L
.84198 .01472 L
.84346 .01472 L
.84487 .01472 L
.84607 .01472 L
.84739 .01472 L
.84969 .01472 L
.851 .01472 L
.85238 .01472 L
.85487 .01472 L
.85612 .01472 L
.85749 .01472 L
.85883 .01472 L
.86025 .01472 L
.86159 .01472 L
.86281 .01472 L
.86519 .01472 L
Mistroke
.86662 .01472 L
.86794 .01472 L
.86936 .01472 L
.87092 .01472 L
.87355 .01472 L
.87499 .01472 L
.87634 .01472 L
.87758 .01472 L
.87894 .01472 L
.88014 .01472 L
.88142 .01472 L
.88268 .01472 L
.88383 .01472 L
.88606 .01472 L
.88741 .01472 L
.88865 .01472 L
.88999 .01472 L
.89145 .01472 L
.89392 .01472 L
.89527 .01472 L
.89653 .01472 L
.89779 .01472 L
.89912 .01472 L
.90153 .01472 L
.90286 .01472 L
.90412 .01472 L
.90551 .01472 L
.90697 .01472 L
.90816 .01472 L
.90946 .01472 L
.91173 .01472 L
.91302 .01472 L
.91439 .01472 L
.91568 .01472 L
.91687 .01472 L
.91927 .01472 L
.92053 .01472 L
.92187 .01472 L
.92412 .01472 L
.92539 .01472 L
.92659 .01472 L
.92881 .01472 L
.93085 .01472 L
.93197 .01472 L
.93319 .01472 L
.93542 .01472 L
.93676 .01472 L
.93798 .01472 L
.9393 .01472 L
.94 .01472 L
Mistroke
.94075 .01472 L
.94201 .01472 L
.94319 .01472 L
.94442 .01472 L
.94507 .01472 L
.94576 .01472 L
.94707 .01472 L
.94828 .01472 L
.94941 .01472 L
.95066 .01472 L
.95177 .01472 L
.95297 .01472 L
.95513 .01472 L
.95789 .01472 L
.95924 .01472 L
.96046 .01472 L
.96176 .01472 L
.96315 .01472 L
.96467 .01472 L
.96608 .01472 L
.96728 .01472 L
.96856 .01472 L
.96983 .01472 L
.97056 .01472 L
.97124 .01472 L
.97247 .01472 L
.97359 .01472 L
.97488 .01472 L
.97611 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.301471 0.51221 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.309017 0.294302 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -28 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .16187 -43.0625 -12.2813 ]
[-0.0125 .16187 0 12.2813 ]
[-0.0125 .30902 -14.0625 -12.2813 ]
[-0.0125 .30902 0 12.2813 ]
[-0.0125 .45617 -29.125 -12.2813 ]
[-0.0125 .45617 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -24.5938 ]
[-0.01875 .30902 -43.0625 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .16187 m
.00625 .16187 L
s
gsave
-0.0125 .16187 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .45617 m
.00625 .45617 L
s
gsave
-0.0125 .45617 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -140.938 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04588 .30902 L
.04652 .30902 L
.04722 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.07956 .30902 L
.0802 .30902 L
.08095 .30902 L
.08166 .30902 L
.08291 .30902 L
.08362 .30902 L
.08427 .30902 L
.08544 .30902 L
.08669 .30902 L
.08787 .30902 L
.08896 .30902 L
.09016 .30902 L
.09148 .30902 L
.09214 .30902 L
.09285 .30902 L
.09413 .30902 L
.09483 .30902 L
.09548 .30902 L
.09619 .30902 L
.09695 .30902 L
.09821 .30902 L
.09893 .30902 L
.09961 .30902 L
.10086 .30902 L
.10201 .30902 L
.10333 .30902 L
.10458 .30902 L
.10572 .30902 L
.10694 .30902 L
.1081 .30902 L
.10916 .30902 L
.11033 .30902 L
.11162 .30902 L
.11227 .30902 L
.11297 .30902 L
.11422 .30902 L
.11491 .30902 L
.11554 .30902 L
.11624 .30902 L
.11698 .30902 L
.11822 .30902 L
.11892 .30902 L
Mistroke
.11958 .30902 L
.12081 .30902 L
.12194 .30902 L
.12323 .30902 L
.12446 .30902 L
.12562 .30902 L
.12668 .30902 L
.12789 .30902 L
.12903 .30902 L
.13009 .30902 L
.13107 .30902 L
.13214 .30902 L
.13327 .30902 L
.13441 .30902 L
.13564 .30902 L
.1368 .30902 L
.13785 .30902 L
.13909 .30902 L
.13979 .30902 L
.14043 .30902 L
.14162 .30902 L
.14288 .30902 L
.14402 .30902 L
.14526 .30902 L
.14656 .30902 L
.14777 .30902 L
.14891 .30902 L
.14994 .30902 L
.15113 .30902 L
.15226 .30902 L
.15348 .30902 L
.15478 .30902 L
.15589 .30902 L
.15711 .30902 L
.15842 .30902 L
.15915 .30902 L
.15982 .30902 L
.16113 .30902 L
.16236 .30902 L
.16352 .30902 L
.16456 .30902 L
.16577 .30902 L
.1669 .30902 L
.16796 .30902 L
.16893 .30902 L
.16999 .30902 L
.17111 .30902 L
.17225 .30902 L
.17347 .30902 L
.17462 .30902 L
Mistroke
.17566 .30902 L
.17689 .30902 L
.17758 .30902 L
.17823 .30902 L
.1794 .30902 L
.18065 .30902 L
.18185 .30902 L
.18316 .30902 L
.18441 .30902 L
.18556 .30902 L
.1867 .30902 L
.18773 .30902 L
.18893 .30902 L
.19005 .30902 L
.19128 .30902 L
.19258 .30902 L
.19369 .30902 L
.19491 .30902 L
.19623 .30902 L
.19696 .30902 L
.19763 .30902 L
.19894 .30902 L
.20017 .30902 L
.20122 .30902 L
.20238 .30902 L
.20359 .30902 L
.20472 .30902 L
.20578 .30902 L
.20675 .30902 L
.20781 .30902 L
.20894 .30902 L
.21008 .30902 L
.21129 .30902 L
.21244 .30902 L
.21349 .30902 L
.21472 .30902 L
.21541 .30902 L
.21605 .30902 L
.21723 .30902 L
.21847 .30902 L
.21968 .30902 L
.221 .30902 L
.22224 .30902 L
.2234 .30902 L
.22454 .30902 L
.22558 .30902 L
.22677 .30902 L
.2279 .30902 L
.22914 .30902 L
.23044 .30902 L
Mistroke
.23155 .30902 L
.23277 .30902 L
.23409 .30902 L
.23482 .30902 L
.2355 .30902 L
.2368 .30902 L
.23804 .30902 L
.23909 .30902 L
.24025 .30902 L
.24146 .30902 L
.2426 .30902 L
.24365 .30902 L
.24462 .30902 L
.24569 .30902 L
.24681 .30902 L
.24795 .30902 L
.24917 .30902 L
.25032 .30902 L
.25137 .30902 L
.2526 .30902 L
.25329 .30902 L
.25393 .30902 L
.2551 .30902 L
.25635 .30902 L
.25756 .30902 L
.25888 .30902 L
.26013 .30902 L
.26129 .30902 L
.26233 .30902 L
.26348 .30902 L
.26467 .30902 L
.2658 .30902 L
.26704 .30902 L
.26835 .30902 L
.26946 .30902 L
.27068 .30902 L
.272 .30902 L
.27274 .30902 L
.27341 .30902 L
.27472 .30902 L
.27595 .30902 L
.27701 .30902 L
.27817 .30902 L
.27938 .30902 L
.28052 .30902 L
.28158 .30902 L
.28255 .30902 L
.28367 .30902 L
.28474 .30902 L
.28588 .30902 L
Mistroke
.2871 .30902 L
.28825 .30902 L
.2893 .30902 L
.29053 .30902 L
.29122 .30902 L
.29186 .30902 L
.29303 .30902 L
.29427 .30902 L
.29549 .30902 L
.29618 .30902 L
.29682 .30902 L
.29799 .30902 L
.29923 .30902 L
.30034 .30902 L
.30138 .30902 L
.30252 .30902 L
.30375 .30902 L
.30499 .30902 L
.30569 .30902 L
.30634 .30902 L
.30765 .30902 L
.30839 .30902 L
.30906 .30902 L
.31026 .30902 L
.31156 .30902 L
.31278 .30902 L
.31392 .30902 L
.31497 .30902 L
.31611 .30902 L
.31718 .30902 L
.31816 .30902 L
.3193 .30902 L
.32055 .30902 L
.32173 .30902 L
.32282 .30902 L
.32406 .30902 L
.32522 .30902 L
.32626 .30902 L
.32739 .30902 L
.32862 .30902 L
.32992 .30902 L
.33103 .30902 L
.33225 .30902 L
.33356 .30902 L
.33477 .30902 L
.33541 .30902 L
.3361 .30902 L
.33683 .30902 L
.33751 .30902 L
.33876 .30902 L
Mistroke
.33991 .30902 L
.34123 .30902 L
.34249 .30902 L
.3436 .30902 L
.3448 .30902 L
.34592 .30902 L
.34694 .30902 L
.34814 .30902 L
.34945 .30902 L
.35067 .30902 L
.35181 .30902 L
.35302 .30902 L
.35431 .30902 L
.35554 .30902 L
.35665 .30902 L
.35796 .30902 L
.3587 .30902 L
.35939 .30902 L
.36064 .30902 L
.36128 .30902 L
.36198 .30902 L
.36266 .30902 L
.36337 .30902 L
.36465 .30902 L
.36536 .30902 L
.36602 .30902 L
.36675 .30902 L
.36753 .30902 L
.3682 .30902 L
.36893 .30902 L
.36962 .30902 L
.37026 .30902 L
.37146 .30902 L
.37274 .30902 L
.37394 .30902 L
.37526 .30902 L
.37651 .30902 L
.37766 .30902 L
.3788 .30902 L
.37984 .30902 L
.38103 .30902 L
.38216 .30902 L
.38339 .30902 L
.3847 .30902 L
.38581 .30902 L
.38703 .30902 L
.38834 .30902 L
.38908 .30902 L
.38975 .30902 L
.39106 .30902 L
Mistroke
.39229 .30902 L
.39334 .30902 L
.3945 .30902 L
.39571 .30902 L
.39685 .30902 L
.39791 .30902 L
.39888 .30902 L
.39994 .30902 L
.40106 .30902 L
.40221 .30902 L
.40342 .30902 L
.40457 .30902 L
.40562 .30902 L
.40685 .30902 L
.40754 .30902 L
.40818 .30902 L
.40936 .30902 L
.4106 .30902 L
.41181 .30902 L
.41313 .30902 L
.41438 .30902 L
.41554 .30902 L
.41669 .30902 L
.41772 .30902 L
.41892 .30902 L
.42005 .30902 L
.42129 .30902 L
.42259 .30902 L
.42371 .30902 L
.42493 .30902 L
.42624 .30902 L
.42698 .30902 L
.42765 .30902 L
.42896 .30902 L
.43019 .30902 L
.43125 .30902 L
.43241 .30902 L
.43362 .30902 L
.43476 .30902 L
.43582 .30902 L
.43679 .30902 L
.43791 .30902 L
.43898 .30902 L
.44012 .30902 L
.44134 .30902 L
.44249 .30902 L
.44354 .30902 L
.44477 .30902 L
.44546 .30902 L
.4461 .30902 L
Mistroke
.44727 .30902 L
.44851 .30902 L
.44973 .30902 L
.45042 .30902 L
.45106 .30902 L
.45223 .30902 L
.45347 .30902 L
.45458 .30902 L
.45562 .30902 L
.45676 .30902 L
.45799 .30902 L
.45922 .30902 L
.45992 .30902 L
.46057 .30902 L
.46188 .30902 L
.46262 .30902 L
.46329 .30902 L
.46449 .30902 L
.46579 .30902 L
.46702 .30902 L
.46815 .30902 L
.4692 .30902 L
.47034 .30902 L
.47141 .30902 L
.47239 .30902 L
.47353 .30902 L
.47478 .30902 L
.47596 .30902 L
.47705 .30902 L
.47829 .30902 L
.47945 .30902 L
.48049 .30902 L
.48162 .30902 L
.48285 .30902 L
.48415 .30902 L
.48526 .30902 L
.48648 .30902 L
.48779 .30902 L
.489 .30902 L
.48963 .30902 L
.49033 .30902 L
.49105 .30902 L
.49174 .30902 L
.49299 .30902 L
.49413 .30902 L
.49539 .30902 L
.49671 .30902 L
.49783 .30902 L
.49902 .30902 L
.50014 .30902 L
Mistroke
.50116 .30902 L
.50236 .30902 L
.50366 .30902 L
.50489 .30902 L
.50603 .30902 L
.50723 .30902 L
.50853 .30902 L
.50975 .30902 L
.51087 .30902 L
.51218 .30902 L
.51292 .30902 L
.51361 .30902 L
.51486 .30902 L
.5155 .30902 L
.5162 .30902 L
.51687 .30902 L
.51759 .30902 L
.51886 .30902 L
.51958 .30902 L
.52024 .30902 L
.52096 .30902 L
.52174 .30902 L
.52241 .30902 L
.52314 .30902 L
.52383 .30902 L
.52447 .30902 L
.52568 .30902 L
.52695 .30902 L
.52816 .30902 L
.52947 .30902 L
.53072 .30902 L
.53187 .30902 L
.53301 .30902 L
.53405 .30902 L
.53525 .30902 L
.53637 .30902 L
.5376 .30902 L
.53891 .30902 L
.54002 .30902 L
.54124 .30902 L
.54255 .30902 L
.54329 .30902 L
.54396 .30902 L
.54526 .30902 L
.5465 .30902 L
.54755 .30902 L
.54871 .30902 L
.54992 .30902 L
.55105 .30902 L
.55211 .30902 L
Mistroke
.55308 .30902 L
.55415 .30902 L
.55527 .30902 L
.55641 .30902 L
.55763 .30902 L
.55878 .30902 L
.55982 .30902 L
.56105 .30902 L
.56175 .30902 L
.56238 .30902 L
.56356 .30902 L
.5648 .30902 L
.56601 .30902 L
.56734 .30902 L
.56858 .30902 L
.56974 .30902 L
.57088 .30902 L
.57192 .30902 L
.57312 .30902 L
.57425 .30902 L
.57548 .30902 L
.57679 .30902 L
.5779 .30902 L
.57912 .30902 L
.58044 .30902 L
.58118 .30902 L
.58185 .30902 L
.58315 .30902 L
.58439 .30902 L
.58544 .30902 L
.5866 .30902 L
.58782 .30902 L
.58895 .30902 L
.59001 .30902 L
.59098 .30902 L
.5921 .30902 L
.59317 .30902 L
.59431 .30902 L
.59553 .30902 L
.59668 .30902 L
.59773 .30902 L
.59896 .30902 L
.59965 .30902 L
.60029 .30902 L
.60146 .30902 L
.60271 .30902 L
.60392 .30902 L
.60461 .30902 L
.60525 .30902 L
.60642 .30902 L
Mistroke
.60766 .30902 L
.60876 .30902 L
.6098 .30902 L
.61094 .30902 L
.61217 .30902 L
.61341 .30902 L
.6141 .30902 L
.61475 .30902 L
.61607 .30902 L
.6168 .30902 L
.61747 .30902 L
.61867 .30902 L
.61997 .30902 L
.6212 .30902 L
.62233 .30902 L
.62339 .30902 L
.62452 .30902 L
.62559 .30902 L
.62657 .30902 L
.62771 .30902 L
.62896 .30902 L
.63014 .30902 L
.63123 .30902 L
.63247 .30902 L
.63363 .30902 L
.63467 .30902 L
.6358 .30902 L
.63703 .30902 L
.63833 .30902 L
.63944 .30902 L
.64066 .30902 L
.64197 .30902 L
.64318 .30902 L
.64381 .30902 L
.6445 .30902 L
.64523 .30902 L
.64591 .30902 L
.64716 .30902 L
.64831 .30902 L
.64956 .30902 L
.65088 .30902 L
.652 .30902 L
.65319 .30902 L
.65431 .30902 L
.65533 .30902 L
.65653 .30902 L
.65784 .30902 L
.65906 .30902 L
.6602 .30902 L
.6614 .30902 L
Mistroke
.6627 .30902 L
.66392 .30902 L
.66504 .30902 L
.66635 .30902 L
.66709 .30902 L
.66777 .30902 L
.66903 .30902 L
.66966 .30902 L
.67036 .30902 L
.67104 .30902 L
.67175 .30902 L
.67303 .30902 L
.67374 .30902 L
.6744 .30902 L
.67513 .30902 L
.67591 .30902 L
.67658 .30902 L
.67731 .30902 L
.678 .30902 L
.67864 .30902 L
.67984 .30902 L
.68112 .30902 L
.68232 .30902 L
.68364 .30902 L
.68488 .30902 L
.68603 .30902 L
.68718 .30902 L
.68821 .30902 L
.68941 .30902 L
.69053 .30902 L
.69176 .30902 L
.69307 .30902 L
.69418 .30902 L
.6954 .30902 L
.69671 .30902 L
.69745 .30902 L
.69812 .30902 L
.69942 .30902 L
.70066 .30902 L
.70171 .30902 L
.70286 .30902 L
.70407 .30902 L
.70521 .30902 L
.70627 .30902 L
.70724 .30902 L
.7083 .30902 L
.70942 .30902 L
.71056 .30902 L
.71178 .30902 L
.71293 .30902 L
Mistroke
.71398 .30902 L
.71521 .30902 L
.7159 .30902 L
.71654 .30902 L
.71771 .30902 L
.71896 .30902 L
.72017 .30902 L
.72149 .30902 L
.72273 .30902 L
.72389 .30902 L
.72503 .30902 L
.72607 .30902 L
.72727 .30902 L
.7284 .30902 L
.72963 .30902 L
.73094 .30902 L
.73205 .30902 L
.73327 .30902 L
.73458 .30902 L
.73532 .30902 L
.73599 .30902 L
.7373 .30902 L
.73853 .30902 L
.73959 .30902 L
.74075 .30902 L
.74196 .30902 L
.7431 .30902 L
.74416 .30902 L
.74513 .30902 L
.74619 .30902 L
.74731 .30902 L
.74846 .30902 L
.74967 .30902 L
.75083 .30902 L
.75187 .30902 L
.7531 .30902 L
.75379 .30902 L
.75443 .30902 L
.75561 .30902 L
.75685 .30902 L
.75806 .30902 L
.75875 .30902 L
.75939 .30902 L
.76056 .30902 L
.7618 .30902 L
.7629 .30902 L
.76394 .30902 L
.76508 .30902 L
.76631 .30902 L
.76754 .30902 L
Mistroke
.76824 .30902 L
.76889 .30902 L
.7702 .30902 L
.77094 .30902 L
.77161 .30902 L
.7728 .30902 L
.7741 .30902 L
.77533 .30902 L
.77646 .30902 L
.77752 .30902 L
.77865 .30902 L
.77972 .30902 L
.7807 .30902 L
.78184 .30902 L
.78309 .30902 L
.78427 .30902 L
.78536 .30902 L
.7866 .30902 L
.78776 .30902 L
.7888 .30902 L
.78993 .30902 L
.79116 .30902 L
.79246 .30902 L
.79357 .30902 L
.79479 .30902 L
.7961 .30902 L
.7973 .30902 L
.79793 .30902 L
.79863 .30902 L
.79936 .30902 L
.80004 .30902 L
.80129 .30902 L
.80243 .30902 L
.80369 .30902 L
.80501 .30902 L
.80612 .30902 L
.80731 .30902 L
.80843 .30902 L
.80945 .30902 L
.81066 .30902 L
.81196 .30902 L
.81318 .30902 L
.81432 .30902 L
.81552 .30902 L
.81682 .30902 L
.81804 .30902 L
.81916 .30902 L
.82047 .30902 L
.8212 .30902 L
.82189 .30902 L
Mistroke
.82315 .30902 L
.82385 .30902 L
.82448 .30902 L
.82516 .30902 L
.82587 .30902 L
.82715 .30902 L
.82786 .30902 L
.82852 .30902 L
.82925 .30902 L
.83002 .30902 L
.8307 .30902 L
.83143 .30902 L
.83212 .30902 L
.83275 .30902 L
.83396 .30902 L
.83524 .30902 L
.83644 .30902 L
.83775 .30902 L
.839 .30902 L
.84015 .30902 L
.84129 .30902 L
.84232 .30902 L
.84352 .30902 L
.84464 .30902 L
.84587 .30902 L
.84718 .30902 L
.84829 .30902 L
.8495 .30902 L
.85082 .30902 L
.85155 .30902 L
.85222 .30902 L
.85353 .30902 L
.85476 .30902 L
.85581 .30902 L
.85697 .30902 L
.85818 .30902 L
.85932 .30902 L
.86037 .30902 L
.86134 .30902 L
.86241 .30902 L
.86353 .30902 L
.86467 .30902 L
.86589 .30902 L
.86704 .30902 L
.86808 .30902 L
.86931 .30902 L
.87 .30902 L
.87064 .30902 L
.87182 .30902 L
.87306 .30902 L
Mistroke
.87427 .30902 L
.87559 .30902 L
.87684 .30902 L
.87799 .30902 L
.87914 .30902 L
.88017 .30902 L
.88137 .30902 L
.88249 .30902 L
.88373 .30902 L
.88503 .30902 L
.88615 .30902 L
.88737 .30902 L
.88868 .30902 L
.88942 .30902 L
.89009 .30902 L
.89139 .30902 L
.89263 .30902 L
.89368 .30902 L
.89484 .30902 L
.89605 .30902 L
.89719 .30902 L
.89825 .30902 L
.89922 .30902 L
.90029 .30902 L
.90141 .30902 L
.90255 .30902 L
.90377 .30902 L
.90492 .30902 L
.90596 .30902 L
.90719 .30902 L
.90789 .30902 L
.90852 .30902 L
.9097 .30902 L
.91094 .30902 L
.91216 .30902 L
.91284 .30902 L
.91348 .30902 L
.91464 .30902 L
.91589 .30902 L
.91699 .30902 L
.91803 .30902 L
.91917 .30902 L
.9204 .30902 L
.92163 .30902 L
.92233 .30902 L
.92297 .30902 L
.92429 .30902 L
.92502 .30902 L
.92569 .30902 L
.92689 .30902 L
Mistroke
.92819 .30902 L
.92941 .30902 L
.93055 .30902 L
.9316 .30902 L
.93273 .30902 L
.9338 .30902 L
.93478 .30902 L
.93592 .30902 L
.93717 .30902 L
.93835 .30902 L
.93944 .30902 L
.94068 .30902 L
.94184 .30902 L
.94288 .30902 L
.94401 .30902 L
.94524 .30902 L
.94654 .30902 L
.94765 .30902 L
.94887 .30902 L
.94975 .30902 L
.95057 .30902 L
.95146 .30902 L
.95241 .30902 L
.95324 .30902 L
.95401 .30902 L
.95486 .30902 L
.95577 .30902 L
.95653 .30902 L
.95737 .30902 L
.95824 .30902 L
.95905 .30902 L
.95981 .30902 L
.9605 .30902 L
.9613 .30902 L
.96206 .30902 L
.96287 .30902 L
.96377 .30902 L
.96471 .30902 L
.96559 .30902 L
.96641 .30902 L
.96716 .30902 L
.96802 .30902 L
.96884 .30902 L
.96972 .30902 L
.97067 .30902 L
.97155 .30902 L
.97236 .30902 L
.97331 .30902 L
.97433 .30902 L
.9753 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.48779 0.301471 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.81746 0.026455 0.603319 0.588604 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.15608 -0.0125 -19.0313 -24.5625 ]
[.15608 -0.0125 19.0313 0 ]
[.28836 -0.0125 -19.0313 -24.5625 ]
[.28836 -0.0125 19.0313 0 ]
[.42063 -0.0125 -19.0313 -24.5625 ]
[.42063 -0.0125 19.0313 0 ]
[.55291 -0.0125 -19.0313 -24.5625 ]
[.55291 -0.0125 19.0313 0 ]
[.68519 -0.0125 -14 -24.5625 ]
[.68519 -0.0125 14 0 ]
[.81746 -0.0125 -7.03125 -24.5625 ]
[.81746 -0.0125 7.03125 0 ]
[.94974 -0.0125 -7.03125 -24.5625 ]
[.94974 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -28 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .13244 -43.0625 -12.2813 ]
[-0.0125 .13244 0 12.2813 ]
[-0.0125 .25016 -43.0625 -12.2813 ]
[-0.0125 .25016 0 12.2813 ]
[-0.0125 .36788 -43.0625 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .4856 -43.0625 -12.2813 ]
[-0.0125 .4856 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -24.5938 ]
[-0.01875 .30902 -43.0625 24.5938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.15608 0 m
.15608 .00625 L
s
gsave
.15608 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.28836 0 m
.28836 .00625 L
s
gsave
.28836 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.42063 0 m
.42063 .00625 L
s
gsave
.42063 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.55291 0 m
.55291 .00625 L
s
gsave
.55291 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.68519 0 m
.68519 .00625 L
s
gsave
.68519 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.94974 0 m
.94974 .00625 L
s
gsave
.94974 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -140.938 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
85.5938 16.2813 translate
90 rotate
-85.5938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.625 23.000 moveto
(H) show
87.250 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.750 23.000 moveto
(L) show
108.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.04485 .60332 L
.04721 .60332 L
.0498 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.065 .60332 L
.06743 .60332 L
.06877 .60332 L
.07023 .60332 L
.0728 .60332 L
.07523 .60332 L
.07783 .60332 L
.0825 .60332 L
.0931 .60332 L
.10458 .60332 L
.11 .60332 L
.11273 .60332 L
.11428 .60332 L
.11573 .60332 L
.12599 .60332 L
.13573 .60332 L
.13707 .60332 L
.13853 .60332 L
.14118 .60332 L
.14616 .60332 L
.15636 .60332 L
.16136 .60332 L
.16354 .60332 L
.16594 .60332 L
.16828 .60332 L
.17074 .60332 L
.17592 .60332 L
.18163 .60332 L
.18694 .60332 L
.19747 .60332 L
.2074 .60332 L
.21632 .60332 L
.22599 .60332 L
.23545 .60332 L
.24083 .60332 L
.24587 .60332 L
.25601 .60332 L
.2617 .60332 L
.26691 .60332 L
Mistroke
.27678 .60332 L
.28593 .60332 L
.2912 .60332 L
.29598 .60332 L
.30118 .60332 L
.30667 .60332 L
.31146 .60331 L
.31672 .60331 L
.32595 .60331 L
.33116 .60331 L
.33674 .60331 L
.34679 .6033 L
.35209 .6033 L
.35699 .60329 L
.36226 .60329 L
.36807 .60328 L
.37784 .60327 L
.38319 .60325 L
.3882 .60324 L
.39806 .6032 L
.40301 .60318 L
.40842 .60315 L
.41802 .60307 L
.42694 .60298 L
.43201 .6029 L
.43749 .60281 L
.44233 .60271 L
.44744 .60258 L
.45712 .60225 L
.46604 .60182 L
.4755 .60119 L
.48081 .60072 L
.48565 .6002 L
.49506 .59889 L
.50398 .59715 L
.51362 .59451 L
.51848 .5928 L
.52386 .59053 L
.53336 .58535 L
.54227 .57874 L
.55209 .56899 L
.56243 .55525 L
.57126 .54028 L
.58093 .52032 L
.60216 .46588 L
.62146 .41347 L
.63108 .39043 L
.64152 .36933 L
.65131 .3535 L
.66047 .34193 L
Mistroke
.66992 .33284 L
.68032 .32553 L
.69046 .32048 L
.69615 .31833 L
.70136 .31671 L
.71121 .31436 L
.72036 .31281 L
.73039 .31159 L
.74109 .31065 L
.75138 .30982 L
.7542 .30956 L
.75718 .30924 L
.75976 .3089 L
.76251 .30845 L
.76512 .30792 L
.76749 .30731 L
.76988 .30653 L
.77213 .30559 L
.77476 .30419 L
.77719 .3025 L
.77986 .30007 L
.78269 .29665 L
.78507 .29288 L
.78758 .28782 L
.79207 .27517 L
.79457 .26562 L
.7969 .25486 L
.80217 .22327 L
.81095 .15395 L
.81557 .11686 L
.82046 .08355 L
.82307 .06917 L
.82594 .05616 L
.82858 .0466 L
.83099 .03962 L
.83347 .03392 L
.83613 .02916 L
.83859 .02577 L
.84093 .02327 L
.84317 .0214 L
.84555 .01984 L
.8478 .01871 L
.84983 .01789 L
.85223 .01714 L
.85483 .01653 L
.85728 .01609 L
.85952 .01578 L
.862 .01552 L
.86424 .01534 L
.86684 .01518 L
Mistroke
.8693 .01507 L
.87157 .01499 L
.87366 .01493 L
.87596 .01488 L
.8784 .01484 L
.88085 .01481 L
.88348 .01479 L
.88597 .01477 L
.88824 .01476 L
.8909 .01475 L
.8938 .01474 L
.89654 .01473 L
.89908 .01473 L
.90173 .01472 L
.90416 .01472 L
.90682 .01472 L
.90964 .01472 L
.9121 .01472 L
.91439 .01472 L
.9169 .01472 L
.9196 .01472 L
.92199 .01472 L
.92459 .01472 L
.92705 .01472 L
.92933 .01472 L
.93137 .01472 L
.93363 .01472 L
.93599 .01472 L
.9382 .01472 L
.94059 .01472 L
.94281 .01472 L
.94525 .01472 L
.94785 .01472 L
.95059 .01472 L
.95318 .01472 L
.9555 .01472 L
.95802 .01472 L
.9602 .01472 L
.96261 .01472 L
.96512 .01472 L
.96747 .01472 L
.96967 .01472 L
.97167 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{953.625, 589.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>i0002CB000`400?l00000o`00003oo`3ooooo
0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00
o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl
0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0oooo
o`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?oo
ool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo
003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oo
ok`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3o
oooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooolG0?ooo`060;md000000000000
00000000B9`0gooo103oool00`3ookl0M01d0;ooo`3o0?ooojh0oooo00H0_g@00000000000000000
0018W03Oool40?ooo`030?oo_`1d07@0_ooo0=`0oooo003o0?oooaP0oooo00<0oono07@0M02oool0
1@3oool0103ooml0W4P00000M02ooooo0?ooojl0oooo00<0oono07@0M02oool01@3oool0103ooml0
W4P00000M02ooooL0?ooo`00o`3ooolH0?ooo`030?oog`2LB7@0_ooo00D0oooo00@0_g@000000000
07@0_oooo`3ooon_0?ooo`030?oog`2LB7@0_ooo00D0oooo00@0_g@00000000007@0_ooog03oool0
0?l0oooo603oool00`3ooml0W4Qd0;ooo`040?ooo`050=nLB0000000001804Q8M02oool0o`3ooon_
0?ooo`030?oog`2LB7@0_ooo00@0oooo00D0gia80000000004P0B4Qd0;ooo`3L0?ooo`00o`3ooolH
0?ooo`030?oog`2LB7@0_ooo00<0oooo00H0okmd0000000007@0_ooO09a8M02ooooo0?ooojl0oooo
00<0oooO09a8M02oool00`3oool01P3o_g@000000000M02ooml0W4Qd0;ooom`0oooo003o0?oooaP0
oooo00<0oooO09a8M02oool00P3oool01`3ogi`0B0000000B02Lgol0oooO09a8M02oool0o`3ooon_
0?ooo`030?oog`2LB7@0_ooo0080oooo00L0omnL04P0000004P0W=oo0?oog`2LB7@0_ooo0=`0oooo
003o0?oooaP0oooo00`0oooO09a8M02oool0oooo0?oo_`1d0000000007Boo`3oool0oooO09a8M02o
oooo0?ooojl0oooo00`0oooO09a8M02oool0oooo0?oo_`1d0000000007Boo`3oool0oooO09a8M02o
oooL0?ooo`00o`3ooolH0?ooo`070?oog`2LB7@0_ooo0?oog`2LB000000004RLg`020?ooo`030?oo
g`2LB7@0_ooo0?l0oooo[`3oool01`3ooml0W4Qd0;ooo`3ooml0W4P000000018W=l00P3oool00`3o
oml0W4Qd0;ooo`3L0?ooo`00o`3ooolH0?ooo`060?oog`2LB7@0_ooO09a80000000007Bo0`3oool0
0`3ooml0W4Qd0;ooo`3o0?ooojl0oooo00H0oooO09a8M02ooml0W4P000000000M;l30?ooo`030?oo
g`2LB7@0_ooo0=`0oooo003o0?oooaP0oooo00H0oooO09a8M01dM00000000018W03Oool30?ooo`03
0?oog`2LB7@0_ooo0?l0oooo[`3oool01P3ooml0W4Qd07Ad0000000004RL0=ooo`<0oooo00<0oooO
09a8M02oool0g03oool00?l0oooo603oool01@3ooml0W4P00000000007@0_ooo00@0oooo00<0oooO
09a8M02oool0o`3ooon_0?ooo`050?oog`2LB00000000000M02oool0103oool00`3ooml0W4Qd0;oo
o`3L0?ooo`00o`3ooolH0?ooo`040=nLB0000000001d0;ooo`D0oooo00<0oono07@0M02oool0o`3o
oon_0?ooo`040=nLB0000000001d0;ooo`D0oooo00<0oono07@0M02oool0g03oool00?l0oooo5P3o
ool01@3OW4P000000000000004P0W=oo00@0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`3o0?ooojX0oooo00D0gia8000000000000001809cOo`040?ooo`030?oog`2LB00000000080
000000<004RL0=ooo`3oool0f@3oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3o
oonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0
ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o
0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0
oooo003o0?ooool0ooooo`3ooonl0?ooo`00J`3oool00`3ooml0W4P000000002000000030018W03O
ool0oooo00D0oooo00@0_g@0000000000000B9cO803oool00`3OW4P00000000000050000000407Bo
o`3oool0oooo0;md00<0000000<004RL0=ooo`3oool07P3oool00`3OW4P000000000000500000003
07Boo`3oool0oooo0080oooo00@0_g@0000000000000B9cO8P3oool00`3o_g@00000000000020000
0005001d_`3oool0oooo0?ooo`2oM0000`0000000`00B9`0gooo0?ooo`0P0?ooo`030?noM0000000
00000080000000<007Bo0?ooo`3oool00`3oool0102oM000000000000018W=lV0?ooo`060;md0000
0000000000000000B9`0gooo9P3oool0102oM000000000000018W=lZ0?ooo`060;md000000000000
00000000B9`0goooH@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00@0
_g@0000000000000B9cO803oool00`3OW4P00000000000050000000407Boo`3oool0oooo0;md00<0
000000<004RL0=ooo`3oool07P3oool00`3OW4P00000000000050000000307Boo`3oool0oooo0080
oooo00@0_g@0000000000000B9cO8P3oool00`3o_g@000000000000200000005001d_`3oool0oooo
0?ooo`2oM0000`0000000`00B9`0gooo0?ooo`0P0?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool00`3oool0102oM000000000000018W=lV0?ooo`060;md00000000000000000000B9`0
gooo9@3oool0102oM000000000000018W=l[0?ooo`060;md00000000000000000000B9`0gooo>`3o
ool006/0oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cOo`<0oooo00L0oooO09a80000
M;l0oooo0?oog`2LB00007Bo0200oooo00<0gia8000000000000100000001@00M;l0oooo0?oog`2L
B000B9cO0080oooo00<0omnL04Q8W03Oool07`3oool00`3OW4P00000000000040000000:001d_`3o
ool0oooo0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_b<0oooo00<0_g@00000M02oool00`3oool0
0`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo0280oooo00<0_g@00000M02oool0103oool0
1`3ooml0W4P0001d_`3oool0oooO09a80000M;l0903oool00`3ooml0W4P004RLg`020?ooo`030?oO
W018B9`0gooo02<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo02P0oooo00<0oooO09a8
0018W=l00P3oool00`3ogi`0B4RL0=ooo`1P0?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0
B02Lgol30?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0P0?ooo`030=nLB00000000000
00@0000000D007Bo0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo01l0oooo00<0gia8
000000000000100000002P00M;l0oooo0?ooo`3ooml0W4P0001d_`3oool0oooO09a80000M;lS0?oo
o`030;md000007@0_ooo00<0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0R0?oo
o`030;md000007@0_ooo00@0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo02@0oooo00<0
oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0R0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0
W4P0001d_`0Y0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0>P3oool00740oooo
00<0okmd0018W03Oool00P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo0200oooo
00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?ooo`030?oOW018M;l0oooo01l0oooo
00<0gia804RLg`3oool00P3oool01`3ooml0W4Qd0;ooo`3oool0okmd0000B02Lgol00P3oool00`3o
gi`0B00007Boo`0R0?ooo`030;md000007@0_ooo00T0oooo00<0omnL04Qd_`3oool08@3oool00`2o
M000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0:@3oool00`3o
gi`0B7Bo0?ooo`0R0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0;@3oool00`3o
gi`0B7Bo0?ooo`1U0?ooo`030?noM000B9`0gooo0080oooo00<0okmd0000B02Lgol00P3oool00`3o
gi`0B00007Boo`0P0?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01P3oool00`3o
gi`0B7Bo0?ooo`0O0?ooo`030=nLB018W=l0oooo0080oooo00L0oooO09a8M02oool0oooo0?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol08P3oool00`2oM000001d0;ooo`090?ooo`030?oOW018
M;l0oooo0240oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02T0oooo00<0omnL04Qd_`3oool08@3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02h0oooo00<0omnL04Qd_`3oool0>@3oool00740oooo00P0okmd0000B02Lgol0oooo0?oo
g`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l08@3oool00`3OW4P0B9cO0?ooo`0:0?ooo`03
0?oo_`1d04P0W=oo0200oooo00<0gia804RLg`3oool0103oool0103ooml0W4P00018W03Oool20?oo
o`030?oog`2LB00007Bo0280oooo00<0_g@00000M02oool02@3oool00`3ookl0M01809cOo`0Q0?oo
o`030;md000007@0_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0Y
0?ooo`030?oo_`1d04P0W=oo0240oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d
_`0]0?ooo`030?oo_`1d04P0W=oo06D0oooo00P0okmd0000B02Lgol0oooo0?oog`2LB00004RL0=oo
o`80oooo00<0oooO09a80000M;l08@3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?oo_`1d04P0W=oo
0200oooo00<0gia804RLg`3oool0103oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB000
07Bo0280oooo00<0_g@00000M02oool02@3oool00`3ookl0M01809cOo`0Q0?ooo`030;md000007@0
_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0Y0?ooo`030?oo_`1d
04P0W=oo0200oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0^0?ooo`030?oo
_`1d04P0W=oo03T0oooo001a0?ooo`070;md000004P0W=oo0?ooo`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo0240oooo00<0gia807Boo`3oool02@3oool00`3ookl0M00007Boo`0Q0?ooo`03
0=nLB01d_ol0oooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0Q0?ooo`03
0;md000007@0_ooo00T0oooo00<0oono07@0001d_ol08@3oool00`2oM000001d0;ooo`030?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0:03oool00`3ookl0M00007Boo`0Q0?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0;03oool00`3ookl0M00007Boo`1U0?ooo`07
0;md000004P0W=oo0?ooo`3ookl0M000001d_`040?ooo`030;md000007@0_ooo0240oooo00<0gia8
07Boo`3oool02@3oool00`3ookl0M00007Boo`0Q0?ooo`030=nLB01d_ol0oooo00<0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`0Q0?ooo`030;md000007@0_ooo00T0oooo00<0oono
07@0001d_ol08@3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool0:03oool00`3ookl0M00007Boo`0P0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool0;@3oool00`3ookl0M00007Boo`0i0?ooo`00GP3oool00`2oM0000000000000070000
000304RLg`3oool0oooo00D0oooo00P0_g@00000000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo
00<0_g@00000M02oool0403oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo
00<0oooO09a8B02Lgol02@3oool00`3o_g@0000007Boo`0@0?ooo`030;md00000000000000L00000
00<0B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`030?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool0403oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo
00<0_g@00000M02oool02@3oool00`3o_g@0000007Boo`0A0?ooo`030;md00000000000000L00000
00<0B9cO0?ooo`3oool00`3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool05@3oool00`2oM0000000000000070000000304RLg`3oool0oooo00H0oooo
00<0okmd0000001d_ol08@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo02`0oooo
00<0okmd0000001d_ol0DP3oool00`2oM0000000000000070000000304RLg`3oool0oooo00D0oooo
00P0_g@00000000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool0403oool0
0`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol02@3oool0
0`3o_g@0000007Boo`0@0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool0
0`3ooml0W4Q809cOo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0403oool0
0`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0_g@00000M02oool02@3oool0
0`3o_g@0000007Boo`0@0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool0103oool0
0`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool05@3oool0
0`2oM0000000000000070000000304RLg`3oool0oooo00H0oooo00<0okmd0000001d_ol0803oool0
0`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo02d0oooo00<0okmd0000001d_ol0>@3oool0
06d0oooo00<0oono07@0000000000P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0
gia80000B02Lgol08P3oool00`3ogi`0B01d0;ooo`070?ooo`040?oOW0180000001d0;ooob80oooo
00<0omnL04P0M02oool00P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo0240oooo
00<0_g@00000M02oool0203oool0103ogi`0B0000000M02ooolQ0?ooo`030;md000007@0_ooo00<0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0W0?ooo`040?oOW0180000001d0;oo
ob40oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0[0?ooo`040?oOW0180000001d
0;ooof40oooo00<0oono07@0000000000P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo
00<0gia80000B02Lgol08P3oool00`3ogi`0B01d0;ooo`070?ooo`040?oOW0180000001d0;ooob80
oooo00<0omnL04P0M02oool00P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo0240
oooo00<0_g@00000M02oool0203oool0103ogi`0B0000000M02ooolQ0?ooo`030;md000007@0_ooo
00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0W0?ooo`040?oOW0180000001d
0;ooob00oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0/0?ooo`040?oOW0180000
001d0;ooocT0oooo001_0?ooo`030?noM00004P0W=oo00<0oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`0S0?ooo`030;md0018W=l0oooo0080oooo00@0gmoO0?ooo`3oool0_g@00P00
00000`18W=l0oooo0?ooo`0R0?ooo`070;md0018W=l0oooo0?ooo`3ogi`0B00004RLg`040?ooo`03
0=nLB00004P0W=oo0240oooo00<0_g@00000M02oool0103oool0103Ogml0oooo0?ooo`2oM0020000
000304RLg`3oool0oooo0200oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?oo
o`030=nLB00004P0W=oo02<0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0P
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol09`3oool0103Ogml0oooo0?ooo`2o
M0020000000304RLg`3oool0oooo0680oooo00<0okmd0000B02Lgol00`3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo02<0oooo00<0_g@004RLg`3oool00P3oool0103Ogml0oooo0?oo
o`2oM0020000000304RLg`3oool0oooo0280oooo00L0_g@004RLg`3oool0oooo0?oOW0180000B9cO
00@0oooo00<0gia80000B02Lgol08@3oool00`2oM000001d0;ooo`040?ooo`040=oOg`3oool0oooo
0;md0080000000<0B9cO0?ooo`3oool0803oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol08`3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3o
ool0oooo01l0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0X0?ooo`040=oOg`3o
ool0oooo0;md0080000000<0B9cO0?ooo`3oool0>03oool00700oooo00<0omnL04Qd_`3oool00P3o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02<0oooo00<0gia80000M02oool00P3o
ool00`3o_g@000000000000200000003001d_`3oool0oooo02<0oooo00L0gia80000M02oool0oooo
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool08@3oool00`2oM000001d0;ooo`040?ooo`03
0?noM000000000000080000000<007Bo0?ooo`3oool08@3oool00`2oM000001d0;ooo`030?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool08`3oool00`3o_g@000000000000200000003
001d_`3oool0oooo0240oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0W0?ooo`03
0?noM000000000000080000000<007Bo0?ooo`3oool0I03oool00`3ogi`0B7Bo0?ooo`020?ooo`03
0?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool08`3oool00`3OW4P0001d0;ooo`020?ooo`03
0?noM000000000000080000000<007Bo0?ooo`3oool08`3oool01`3OW4P0001d0;ooo`3oool0oono
07@00000M;l0103oool00`2oM000001d0;ooo`0Q0?ooo`030;md000007@0_ooo00@0oooo00<0okmd
0000000000000P0000000`00M;l0oooo0?ooo`0Q0?ooo`030;md000007@0_ooo00<0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`0S0?ooo`030?noM000000000000080000000<007Bo
0?ooo`3oool0803oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02P0oooo00<0okmd
0000000000000P0000000`00M;l0oooo0?ooo`0i0?ooo`00L03oool00`3ooml0W4P004RLg`030?oo
o`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0903oool00`3o_g@0000007Boo`020?oo
o`050?oog`2LB00000000000M02oool09P3oool00`3o_g@0000007Boo`020?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l08P3oool00`2oM000001d0;ooo`040?ooo`050?oog`2LB000
00000000M02oool0903oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0gooo0080oooo00<0
oooO09a80000M;l0903oool01@3ooml0W4P00000000007@0_ooo02D0oooo00<0_g@00018W03Oool0
0P3oool00`3ooml0W4P0001d_`0X0?ooo`050?oog`2LB00000000000M02oool0I`3oool00`3ooml0
W4P004RLg`030?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0903oool00`3o_g@0
000007Boo`020?ooo`050?oog`2LB00000000000M02oool09P3oool00`3o_g@0000007Boo`020?oo
o`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l08P3oool00`2oM000001d0;ooo`040?oo
o`050?oog`2LB00000000000M02oool0903oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0
gooo0080oooo00<0oooO09a80000M;l0903oool01@3ooml0W4P00000000007@0_ooo02@0oooo00<0
_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0Y0?ooo`050?oog`2LB00000000000M02oool0
?03oool006/0oooo00<0oooO09adW03Oool00P3oool00`3ooml0W4P0001d_`030?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol07P3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md0000
0000M;oo00<0oooo00<0okmd001d_`3oool08@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md0000
0000M;oo0080oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0R0?ooo`030;md0000
07@0_ooo00D0oooo00<0okmd001d_`3oool09@3oool00`2oM000001d0;ooo`040?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol09@3oool00`3o_g@007Bo0?ooo`0V0?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol0:@3oool00`3o_g@007Bo0?ooo`1S0?ooo`030?oog`2L
M9`0gooo0080oooo00<0oooO09a80000M;l00`3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo01h0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`030?ooo`030?noM000
M;l0oooo0240oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`020?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol08P3oool00`2oM000001d0;ooo`050?ooo`030?noM000
M;l0oooo02D0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02D0oooo00<0okmd001d_`3oool09@3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo02X0oooo00<0okmd001d_`3oool0?@3oool006`0oooo00L0omnL04Q8W03Oool0oooo0=nL
B0000000M;oo00@0oooo00H0_g@00018W03Oool0oooo0;md0000M;lP0?ooo`080;md001d_ol0oooo
0?ooo`3OW4P000000018W03Oool30?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0
7@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0`3oool01P2oM00004RL0=ooo`3o
ool0_g@0001d_b40oooo00D0gia8000000000000001d0;ooo`050?ooo`030?oog`2LB00000000080
000000<0001d0;ooo`3oool07P3oool01@3OW4P000000000000007@0_ooo00D0oooo00H0_g@00018
W03Oool0oooo0;md0000M;lV0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool08P3o
ool01P2oM00004RL0=ooo`3oool0_g@0001d_bX0oooo00<0oooO09a8000000000P0000000`0007@0
_ooo0?ooo`1O0?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`040?ooo`060;md0000B9`0
gooo0?ooo`2oM00007Bo803oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo0`3oool0
0`3ooml0W4P000000002000000030000M02oool0oooo01d0oooo00P0_g@007Boo`3oool0oooo0=nL
B000000004RL0=ooo`<0oooo00H0_g@00018W03Oool0oooo0;md0000M;lQ0?ooo`050=nLB0000000
00000000M02oool01@3oool00`3ooml0W4P000000002000000030000M02oool0oooo01h0oooo00D0
gia8000000000000001d0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo9P3oool00`3o
oml0W4P000000002000000030000M02oool0oooo0240oooo00H0_g@00018W03Oool0oooo0;md0000
M;l[0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0>03oool006d0oooo00D0omnL
04P000000000000004RLg`060?ooo`040;md000000000000001d_b80oooo00D0_g@0000000000000
0000001d_`060?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool07@3oool01@2oM000
000000000000000007Bo00H0oooo00@0_g@000000000000007Bo8`3oool0103ookl0M0000000M02o
ool60?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool07P3oool0103ookl0M0000000
M02oool60?ooo`040;md000000000000001d_bP0oooo00<0okmd0000000000000P0000000`1d_ol0
oooo0?ooo`0R0?ooo`040;md000000000000001d_b`0oooo00<0okmd0000000000000P0000000`1d
_ol0oooo0?ooo`1O0?ooo`050?oOW0180000000000000018W=l01P3oool0102oM000000000000000
M;lR0?ooo`050;md00000000000000000000M;l01P3oool00`3o_g@00000000000020000000307Bo
o`3oool0oooo01d0oooo00D0_g@00000000000000000001d_`060?ooo`040;md000000000000001d
_b<0oooo00@0oono07@0000007@0_ooo1P3oool00`3o_g@00000000000020000000307Boo`3oool0
oooo01h0oooo00@0oono07@0000007@0_ooo1P3oool0102oM000000000000000M;lX0?ooo`030?no
M000000000000080000000<0M;oo0?ooo`3oool08@3oool0102oM000000000000000M;l]0?ooo`03
0?noM000000000000080000000<0M;oo0?ooo`3oool0=`3oool00?l0ooooo`3ooooo0?oook`0oooo
003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oo
ok`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3o
oooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0
ooooo`3ooooo0?oook`0oooo001H0?ooo`040;md00000000000004RLg`X0ooooo`00001a000003`0
oooo00@0_g@0000000000000B9cO2@3ooooo000007400000:P3oool005H0oooo00L0oooO09a80000
M;l0oooo0?oog`2LB00007Bo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo03P0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo
001F0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0h0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0X0?ooo`00E@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00P0oooo00<0
00000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo03L0oooo00@0oooO09a80000B9`0gooo
0P3oool00`3ooml0W4P0001d_`070?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo
0?ooo`0X0?ooo`00E@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00L0oooo00<0
00000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo03L0oooo00<0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`060?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?oo
o`0X0?ooo`00E@3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00L0oooo0`000005
0?oooj40o`00``3oool4000003T0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`06
0?ooo`@00000o`3ooolP0?ooodD0o`001@3oool3000002X0oooo001E0?ooo`030?oOW0180000B9cO
00@0oooo00<0gia80000B02Lgol01`3oool00`000000oooo0?ooo`2V0?oooa00o`00]P3oool00`00
0000oooo0?ooo`0g0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo4@3o001<0?ooo`030000003oool0oooo02P0oooo001E0?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3oool00`000000oooo0?ooo`2f0?ooo`H0
o`00/03oool00`000000oooo0?ooo`0g0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol01P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo1P3o001M0?ooo`030000003oool0oooo02P0
oooo001E0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01`3oool00`000000oooo
0?ooo`2l0?ooo`@0o`00[03oool00`000000oooo0?ooo`0g0?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool01P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0`3o001S0?ooo`030000
003oool0oooo02P0oooo001F0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0203o
ool00`000000oooo0?ooo`300?ooo`<0o`00Z@3oool00`000000oooo0?ooo`0h0?ooo`030;md0000
B9`0gooo0080oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo0`3o
001V0?ooo`030000003oool0oooo02P0oooo001F0?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol0203oool00`000000oooo0?ooo`330?ooo`80o`00Y`3oool00`000000oooo0?ooo`0h
0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`000000oooo0?ooo`3o
0?ooo`40oooo0`3o001Y0?ooo`030000003oool0oooo02P0oooo001G0?ooo`060;md0000B9`0gooo
0?ooo`2oM00007Bo2@3oool00`000000oooo0?ooo`350?ooo`80o`00Y@3oool00`000000oooo0?oo
o`0i0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool00`000000oooo0?ooo`3o0?ooo`03
0?l0003oool0oooo06X0oooo00<000000?ooo`3oool0:03oool005P0oooo00@0_g@0000000000000
07Bo2P3oool00`000000oooo0?ooo`370?ooo`80o`00X`3oool00`000000oooo0?ooo`0j0?ooo`04
0;md000000000000001d_`T0oooo00<000000?ooo`3oool0o@3oool20?l006d0oooo00<000000?oo
o`3oool0:03oool006H0oooo00<000000?ooo`3oool0b@3oool00`3o0000oooo0?ooo`2P0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0o03oool00`3o0000oooo0?ooo`1]0?ooo`03
0000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0<X0oooo00<0o`000?ooo`3oool0
W`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?/0oooo00<0o`000?ooo`3oool0
KP3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3;0?ooo`80o`00W`3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?X0oooo00<0o`000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`0X0?ooo`00IP3oool200000<h0oooo00<0o`000?ooo`3oool0VP3oool3
000004T0oooo0`00003i0?ooo`030?l0003oool0oooo06l0oooo0P00000Z0?ooo`00IP3oool00`00
0000oooo0?ooo`3>0?ooo`030?l0003oool0oooo09/0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`3h0?ooo`030?l0003oool0oooo0740oooo00<000000?ooo`3oool0:03oool006H0
oooo00<000000?ooo`3oool0c`3oool20?l009/0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`3g0?ooo`030?l0003oool0oooo0780oooo00<000000?ooo`3oool0:03oool006H0oooo
00<000000?ooo`3oool0d@3oool00`3o0000oooo0?ooo`2H0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0mP3oool00`3o0000oooo0?ooo`1c0?ooo`030000003oool0oooo02P0oooo
001V0?ooo`030000003oool0oooo0=80oooo00<0o`000?ooo`3oool0U`3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo0?D0oooo00<0o`000?ooo`3oool0M03oool00`000000oooo0?oo
o`0X0?ooo`00IP3oool00`000000oooo0?ooo`3B0?ooo`030?l0003oool0oooo09L0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`3d0?ooo`030?l0003oool0oooo07D0oooo00<00000
0?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0d`3oool00`3o0000oooo0?ooo`2F0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0m03oool00`3o0000oooo0?ooo`1e0?oo
o`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0=@0oooo00<0o`000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?<0oooo00<0o`000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3E0?ooo`030?l0
003oool0oooo09@0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3b0?ooo`030?l0
003oool0oooo07L0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0e@3o
ool00`3o0000oooo0?ooo`2D0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0lP3o
ool00`3o0000oooo0?ooo`1g0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0
oooo0=H0oooo00<0o`000?ooo`3oool0T`3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo0?40oooo00<0o`000?ooo`3oool0N03oool00`000000oooo0?ooo`0X0?ooo`00IP3oool20000
0=P0oooo00<0o`000?ooo`3oool0T03oool3000004T0oooo0`00003a0?ooo`030?l0003oool0oooo
07L0oooo0P00000Z0?ooo`00IP3oool00`000000oooo0?ooo`3H0?ooo`030?l0003oool0oooo0940
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3`0?ooo`030?l0003oool0oooo07T0
oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0f03oool00`3o0000oooo
0?ooo`2A0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0l03oool00`3o0000oooo
0?ooo`1i0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0=T0oooo00<0
o`000?ooo`3oool0T03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0>l0oooo00<0
o`000?ooo`3oool0NP3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3J
0?ooo`030?l0003oool0oooo08l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3_
0?ooo`030?l0003oool0oooo07X0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?oo
o`3oool0f`3oool00`3o0000oooo0?ooo`2>0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0k`3oool00`3o0000oooo0?ooo`1j0?ooo`030000003oool0oooo02P0oooo001V0?ooo`03
0000003oool0oooo0=/0oooo00<0o`000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0>h0oooo00<0o`000?ooo`3oool0N`3oool00`000000oooo0?ooo`0X0?ooo`00
IP3oool00`000000oooo0?ooo`3L0?ooo`030?l0003oool0oooo08d0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`3^0?ooo`030?l0003oool0oooo07/0oooo00<000000?ooo`3oool0
:03oool006H0oooo00<000000?ooo`3oool0g@3oool00`3o0000oooo0?ooo`2<0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0kP3oool00`3o0000oooo0?ooo`1k0?ooo`030000003o
ool0oooo02P0oooo001V0?ooo`030000003oool0oooo0=h0oooo00<0o`000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo0>d0oooo00<0o`000?ooo`3oool0O03oool0
0`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3N0?ooo`030?l0003oool0oooo
08/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3]0?ooo`030?l0003oool0oooo
07`0oooo00<000000?ooo`3oool0:03oool006H0oooo0P00003P0?ooo`030?l0003oool0oooo08P0
oooo0`0000190?ooo`<00000k@3oool00`3o0000oooo0?ooo`1k0?ooo`800000:P3oool006H0oooo
00<000000?ooo`3oool0h03oool00`3o0000oooo0?ooo`290?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0k03oool00`3o0000oooo0?ooo`1m0?ooo`030000003oool0oooo02P0oooo
001V0?ooo`030000003oool0oooo0>40oooo00<0o`000?ooo`3oool0R03oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo0>`0oooo00<0o`000?ooo`3oool0O@3oool00`000000oooo0?oo
o`0X0?ooo`00IP3oool00`000000oooo0?ooo`3R0?ooo`030?l0003oool0oooo08L0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`3/0?ooo`030?l0003oool0oooo07d0oooo00<00000
0?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0hP3oool00`3o0000oooo0?ooo`270?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0j`3oool00`3o0000oooo0?ooo`1n0?oo
o`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0><0oooo00<0o`000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0[0?ooo`040;md00000000000004RLg`@0oooo00D0gia80000
0018W=l0oooo0=nLB0070000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0j`3oool0
0`3o0000oooo0?ooo`1n0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo
0>@0oooo00<0o`000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0Y0?ooo`070?oog`2LB00007Bo
0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080oooo00<0gia80000000000001000
00000`00M;l0oooo0?ooo`050?ooo`030000003oool0oooo0>/0oooo00<0o`000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3U0?ooo`030?l0003oool0
oooo08@0oooo00<000000?ooo`3oool0:@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000
M;oo00P0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`060?ooo`030000003oool0
oooo0>X0oooo00<0o`000?ooo`3oool0O`3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`00
0000oooo0?ooo`3V0?ooo`030?l0003oool0oooo08<0oooo00<000000?ooo`3oool0:03oool0103o
oml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00T0oooo00<0gia804RLg`3oool02P3oool0
0`000000oooo0?ooo`3Z0?ooo`030?l0003oool0oooo07l0oooo00<000000?ooo`3oool0:03oool0
06H0oooo00<000000?ooo`3oool0i`3oool00`3o0000oooo0?ooo`220?ooo`030000003oool0oooo
02P0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`090?ooo`030=nLB01d_ol0oooo
00T0oooo00<000000?ooo`3oool0jP3oool00`3o0000oooo0?ooo`1o0?ooo`030000003oool0oooo
02P0oooo001V0?ooo`800000j@3oool00`3o0000oooo0?ooo`1o0?ooo`<00000:P3oool00`3ogi`0
B00004RLg`040?ooo`030;md000007@0_ooo00T0oooo00<0oooO09a8B02Lgol02@3oool400000>P0
oooo00<0o`000?ooo`3oool0OP3oool3000002X0oooo001V0?ooo`030000003oool0oooo0>T0oooo
00<0o`000?ooo`3oool0P03oool00`000000oooo0?ooo`0X0?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol02P3oool00`3ogi`0B01d0;ooo`080?ooo`030000003oool0oooo0>T0oooo
00<0o`000?ooo`3oool0P03oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?oo
o`3Z0?ooo`030?l0003oool0oooo07l0oooo00<000000?ooo`3oool0:03oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3oool01`3oool00`000000oooo0?oo
o`3Y0?ooo`030?l0003oool0oooo0800oooo00<000000?ooo`3oool0:03oool006H0oooo00<00000
0?ooo`3oool0j`3oool20?l007l0oooo00<000000?ooo`3oool0:03oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo00/0oooo00<0gia80000M02oool01`3oool00`000000oooo0?ooo`3Y
0?ooo`030?l0003oool0oooo0800oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?oo
o`3oool0k@3oool20?l007d0oooo00<000000?ooo`3oool0:@3oool00`2oM00004RL0=ooo`020?oo
o`030?oog`2LB00007Bo00`0oooo00<0okmd0000001d_ol01`3oool00`000000oooo0?ooo`3X0?oo
o`030?l0003oool0oooo0840oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3o
ool0k`3oool20?l007/0oooo00<000000?ooo`3oool0:@3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo00H0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`070?ooo`03
0000003oool0oooo0>P0oooo00<0o`000?ooo`3oool0P@3oool00`000000oooo0?ooo`0X0?ooo`00
B@3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO0080oooo00H0_g@000000000
000000000018W03Oool:0?ooo`030000003oool0oooo0?40oooo00<0o`000?ooo`3oool0N03oool0
0`000000oooo0?ooo`0Z0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203oool0202oM000M;oo
0?ooo`3oool0gia800000000B9`0gooo1`3oool00`000000oooo0?ooo`3X0?ooo`030?l0003oool0
oooo0840oooo00<000000?ooo`3oool0:03oool004L0oooo00L0oooO09a80000M;l0oooo0?oog`2L
B00007Bo00<0oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03O
ool02@3oool00`000000oooo0?ooo`3b0?ooo`80o`00N03oool00`000000oooo0?ooo`0[0?ooo`04
0;md000000000000001d_`X0oooo00D0_g@00000000000000000001d_`090?ooo`030000003oool0
oooo0>L0oooo00<0o`000?ooo`3oool0PP3oool00`000000oooo0?ooo`0X0?ooo`00A`3oool00`3o
_g@0001809cOo`020?ooo`030?oOW0180000M;oo00`0oooo00<0omnL04Qd_`3oool0203oool00`00
0000oooo0?ooo`3d0?ooo`<0o`00M@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0>L0oooo00<0o`000?ooo`3oool0PP3oool00`000000oooo0?ooo`0X0?ooo`00AP3oool0103ooml0
W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00`0oooo00<0oono07@0B02Lgol0203oool00`00
0000oooo0?ooo`3g0?ooo`@0o`00L@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0>L0oooo00<0o`000?ooo`3oool0PP3oool00`000000oooo0?ooo`0X0?ooo`00AP3oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0oono07@0001d_ol0203oool00`000000
oooo0?ooo`3k0?ooo`X0o`00I`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0>L0
oooo00<0o`000?ooo`3oool0PP3oool00`000000oooo0?ooo`0X0?ooo`00AP3oool00`3ogi`0B000
04RLg`040?ooo`030;md000007@0_ooo00/0oooo00<0okmd0000001d_ol0203oool300000?l0oooo
1P3oool=0?l005L0oooo100000190?ooo`<00000iP3oool00`3o0000oooo0?ooo`220?ooo`800000
:P3oool004H0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`040?oOW018
0000001d0;ooo`P0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`D0o`00E@3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo0>H0oooo00<0o`000?ooo`3oool0P`3oool00`000000oooo
0?ooo`0X0?ooo`00AP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00@0
gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
5`3oool30?l005<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3V0?ooo`030?l0
003oool0oooo08<0oooo00<000000?ooo`3oool0:03oool004H0oooo00<0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`060?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0203o
ool00`000000oooo0?ooo`3o0?oooaX0oooo00<0o`000?ooo`3oool0D03oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo0>H0oooo00<0o`000?ooo`3oool0P`3oool00`000000oooo0?oo
o`0X0?ooo`00A`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00D0oooO
09a800000000001d0;ooo`0;0?ooo`030000003oool0oooo0?l0oooo6`3oool00`3o0000oooo0?oo
o`1?0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0iP3oool00`3o0000oooo0?oo
o`230?ooo`030000003oool0oooo02P0oooo00170?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol0203oool00`3o_g@007Bo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo6`3oool0
0`3o0000oooo0?ooo`1?0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0i@3oool0
0`3o0000oooo0?ooo`240?ooo`030000003oool0oooo02P0oooo00180?ooo`060;md0000B9`0gooo
0?ooo`2oM00007Bo2@3oool00`3ooml0W4P000000002000000030000M02oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3ooolL0?ooo`030?l0003oool0oooo04h0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`3U0?ooo`030?l0003oool0oooo08@0oooo00<000000?ooo`3oool0:03o
ool004T0oooo00@0_g@000000000000007Bo2`3oool00`3o_g@00000000000020000000307Boo`3o
ool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`030?l0003oool0oooo04d0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`3U0?ooo`030?l0003oool0oooo08@0oooo00<0
00000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`030?l0003oool0
oooo04d0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3U0?ooo`030?l0003oool0
oooo08@0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3ooolN0?oo
o`030?l0003oool0oooo04`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3U0?oo
o`030?l0003oool0oooo08@0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3o
ool0o`3ooolN0?ooo`030?l0003oool0oooo04`0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`3T0?ooo`030?l0003oool0oooo08D0oooo00<000000?ooo`3oool0:03oool006H0oooo
0P00003o0?oooal0oooo00<0o`000?ooo`3oool0BP3oool3000004T0oooo0`00003T0?ooo`030?l0
003oool0oooo08@0oooo0P00000Z0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooal0oooo00<0
o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0>@0oooo00<0
o`000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o
0?oooal0oooo00<0o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo0>@0oooo00<0o`000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`00
0000oooo0?ooo`3o0?oooal0oooo00<0o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo0>@0oooo00<0o`000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0X0?oo
o`00IP3oool00`000000oooo0?ooo`3o0?oooal0oooo00<0o`000?ooo`3oool0B`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo0><0oooo00<0o`000?ooo`3oool0QP3oool00`000000
oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooob00oooo00<0o`000?ooo`3oool0
BP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0><0oooo00<0o`000?ooo`3oool0
QP3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooob00oooo00<0
o`000?ooo`3oool0BP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0><0oooo00<0
o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o
0?ooob00oooo00<0o`000?ooo`3oool0BP3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo0><0oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`00
0000oooo0?ooo`3o0?ooob00oooo00<0o`000?ooo`3oool0BP3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo0><0oooo00<0o`000?ooo`3oool0QP3oool00`000000oooo0?ooo`0X0?oo
o`00IP3oool00`000000oooo0?ooo`3o0?ooob00oooo00<0o`000?ooo`3oool0BP3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo0>80oooo00<0o`000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooob40oooo00<0o`000?ooo`3oool0
B@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0>80oooo00<0o`000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool200000?l0oooo8P3oool00`3o0000oooo0?oo
o`170?ooo`<00000B@3oool300000>80oooo00<0o`000?ooo`3oool0QP3oool2000002X0oooo001V
0?ooo`030000003oool0oooo0?l0oooo8@3oool00`3o0000oooo0?ooo`190?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0hP3oool00`3o0000oooo0?ooo`270?ooo`030000003oool0
oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo8@3oool00`3o0000oooo0?ooo`190?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0h@3oool00`3o0000oooo0?ooo`280?oo
o`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo8@3oool00`3o0000
oooo0?ooo`190?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0h@3oool00`3o0000
oooo0?ooo`280?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo
8@3oool00`3o0000oooo0?ooo`190?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
h@3oool00`3o0000oooo0?ooo`280?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003o
ool0oooo0?l0oooo8P3oool00`3o0000oooo0?ooo`180?ooo`030000003oool0oooo02/0oooo00@0
_g@0000000000000B9cO103oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo00P0oooo
00<000000?ooo`3oool0h@3oool00`3o0000oooo0?ooo`280?ooo`030000003oool0oooo02P0oooo
001V0?ooo`030000003oool0oooo0?l0oooo8P3oool00`3o0000oooo0?ooo`180?ooo`030000003o
ool0oooo02T0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018
W=l01P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo0>40oooo00<0o`000?ooo`3o
ool0R03oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooob80oooo
00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`0Y0?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol02`3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo0>00oooo
00<0o`000?ooo`3oool0R@3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?oo
o`3o0?ooob80oooo00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`0X0?ooo`040?oog`2L
B00004RL0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3OW4P0000000000005000000030000
B02Lgol0oooo00D0oooo00<000000?ooo`3oool0h03oool00`3o0000oooo0?ooo`290?ooo`030000
003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo8P3oool00`3o0000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;oo
o`050?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d_ol0203oool00`000000oooo0?oo
o`3P0?ooo`030?l0003oool0oooo08T0oooo00<000000?ooo`3oool0:03oool006H0oooo00<00000
0?ooo`3oool0o`3ooolR0?ooo`030?l0003oool0oooo04P0oooo00<000000?ooo`3oool0:03oool0
0`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00H0oooo00L0gia807Boo`3oool0oooo0?no
M0000000M;oo00P0oooo00<000000?ooo`3oool0h03oool00`3o0000oooo0?ooo`290?ooo`030000
003oool0oooo02P0oooo000b0?ooo`030?noM01d_ol0oooo00H0oooo00<0_gAd0;ooo`3oool0:03o
ool200000?l0oooo903oool00`3o0000oooo0?ooo`150?ooo`<000005P3oool00`3o_g@0M;oo0?oo
o`060?ooo`030;mdM02oool0oooo00P0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0000007Boo`080?ooo`@00000g`3oool00`3o0000
oooo0?ooo`270?ooo`<00000:P3oool00380oooo00<0okmd0000M02oool0103oool0103ooml0W4P0
0000M02ooolY0?ooo`030000003oool0oooo0?l0oooo8`3oool00`3o0000oooo0?ooo`170?ooo`03
0000003oool0oooo01@0oooo00<0okmd0000M02oool0103oool0103ooml0W4P00000M02oool90?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3oool01P3o_g@007Bo0?ooo`3o_g@0
000007Boo`P0oooo00<000000?ooo`3oool0g`3oool00`3o0000oooo0?ooo`2:0?ooo`030000003o
ool0oooo02P0oooo000b0?ooo`040?noM0000000000004RLg`80oooo00D0oono07@0B02Lgol0gibL
0;ooo`0Y0?ooo`030000003oool0oooo0?l0oooo8`3oool00`3o0000oooo0?ooo`170?ooo`030000
003oool0oooo01@0oooo00@0okmd000000000000B9cO0P3oool01@3ookl0M01809cOo`3OW9`0_ooo
00T0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`080?ooo`050;md001d_ol0okmd
0000001d_ol0203oool00`000000oooo0?ooo`3O0?ooo`030?l0003oool0oooo08X0oooo00<00000
0?ooo`3oool0:03oool00380oooo00P0oknL09cOo`3OW4P000000000B01dM4P0001d0;ooob`0oooo
00<000000?ooo`3oool0o`3ooolS0?ooo`030?l0003oool0oooo04L0oooo00<000000?ooo`3oool0
503oool0203o_i`0W=oo0=nLB0000000001807AdB00007@0_ooo3@3oool00`2oM00004RL0=ooo`02
0?ooo`030?oog`2LB00007Bo00T0oooo00D0oono07@0M02o_g@0000007Boo`080?ooo`030000003o
ool0oooo0=l0oooo00<0o`000?ooo`3oool0RP3oool00`000000oooo0?ooo`0X0?ooo`00=@3oool0
103ookl0M00000000000M;l]0?ooo`030000003oool0oooo0?l0oooo8`3oool00`3o0000oooo0?oo
o`170?ooo`030000003oool0oooo01L0oooo00@0oono07@00000000007Bo3P3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo00X0oooo00@0okmd000000000000M;oo203oool00`000000
oooo0?ooo`3O0?ooo`030?l0003oool0oooo08X0oooo00<000000?ooo`3oool0:03oool00380oooo
00/0oknL09cOo`3o_g@0001809cOo`3OW4P000000000B02Lgol0gibL0;ooo`0Y0?ooo`030000003o
ool0oooo0?l0oooo8`3oool00`3o0000oooo0?ooo`170?ooo`030000003oool0oooo01@0oooo00/0
oknL09cOo`3o_g@0001809cOo`3OW4P000000000B02Lgol0gibL0;ooo`0;0?ooo`060;md0000B9`0
gooo0?ooo`2oM00007Bo2`3oool0103ooml0W4P00000001d_ol80?ooo`030000003oool0oooo0=l0
oooo00<0o`000?ooo`3oool0RP3oool00`000000oooo0?ooo`0X0?ooo`00<P3oool00`3o_g@00000
001d_`030?ooo`050?oo_`1d000000000000M02oool0:@3oool00`000000oooo0?ooo`3o0?ooob<0
oooo00<0o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`0D0?ooo`030?noM000000007Bo00<0
oooo00D0oono07@000000000001d0;ooo`0<0?ooo`040;md000000000000001d_`d0oooo00<0omnL
04P0001d_ol0203oool00`000000oooo0?ooo`3N0?ooo`030?l0003oool0oooo08/0oooo00<00000
0?ooo`3oool0:03oool00380oooo00<0okmd04RLg`3oool01@3oool00`3OW4P0001d0;ooo`0Y0?oo
o`030000003oool0oooo0?l0oooo8`3oool00`3o0000oooo0?ooo`170?ooo`030000003oool0oooo
01@0oooo00<0okmd04RLg`3oool01@3oool00`3OW4P0001d0;ooo`0X0?ooo`030000003oool0oooo
0=h0oooo00<0o`000?ooo`3oool0R`3oool00`000000oooo0?ooo`0X0?ooo`00<P3oool00`3o_i`0
W=oo0?ooo`060?ooo`030;mdM02oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`03
0?l0003oool0oooo04L0oooo00<000000?ooo`3oool0503oool00`3o_i`0W=oo0?ooo`060?ooo`03
0;mdM02oool0oooo02L0oooo00<000000?ooo`3oool0gP3oool00`3o0000oooo0?ooo`2;0?ooo`03
0000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo903oool00`3o0000oooo
0?ooo`160?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0gP3oool00`3o0000oooo
0?ooo`2;0?ooo`030000003oool0oooo02P0oooo001V0?ooo`800000o`3ooolU0?ooo`030?l0003o
ool0oooo04@0oooo0`00000N0?ooo`030;md00000000B9cO02P0oooo0`00003N0?ooo`030?l0003o
ool0oooo08X0oooo0P00000Z0?ooo`00=P3oool00`3OW4P0M;oo0?ooo`040?ooo`030?oOW018B9`0
gooo02H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030?l0003oool0oooo04H0oooo00<00000
0?ooo`3oool06P3oool01@3ogi`0B00007Boo`3OW4P0B9cO02P0oooo00<000000?ooo`3oool0g@3o
ool00`3o0000oooo0?ooo`2<0?ooo`030000003oool0oooo02P0oooo000e0?ooo`030?noM018W=l0
oooo00D0oooo00<0oooO09a8M02oool09P3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0o`00
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0I0?ooo`060=nLB000B9`0gooo0?ooo`3OW4P0B9cO
:03oool00`000000oooo0?ooo`3M0?ooo`030?l0003oool0oooo08`0oooo00<000000?ooo`3oool0
:03oool003D0oooo00H0gia807Boo`3oool0oooO09a8001d_ol30?ooo`030=no_`3Oool0oooo02D0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3o
ool0603oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo02L0oooo00<000000?ooo`3o
ool0g@3oool00`3o0000oooo0?ooo`2<0?ooo`030000003oool0oooo02P0oooo000e0?ooo`0:0=nL
B000B9`0gooo0;mdB02LW7@0001d0;ooo`3oool0gia804RLgbL0oooo00<000000?ooo`3oool0o`3o
oolT0?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3oool05`3oool00`3OW4P000000000
0006000000030000M02oool0oooo02@0oooo00<000000?ooo`3oool0g@3oool00`3o0000oooo0?oo
o`2<0?ooo`030000003oool0oooo02P0oooo000e0?ooo`060?oog`2LB000000007Boo`3oool0_g@0
0P0000000`18W=l0oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo903oool00`3o0000oooo
0?ooo`160?ooo`030000003oool0oooo01d0oooo00<0gia804RLg`3oool09`3oool00`000000oooo
0?ooo`3M0?ooo`030?l0003oool0oooo08`0oooo00<000000?ooo`3oool0:03oool005L0oooo00<0
okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo903o
ool00`3o0000oooo0?ooo`160?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0g03o
ool00`3o0000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo001I0?ooo`030;md000007@0
_ooo00X0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030?l0003oool0oooo04H0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`3L0?ooo`030?l0003oool0oooo08d0oooo00<00000
0?ooo`3oool0:03oool003<0oooo00<0okmd000000000000100000000`0007@0_ooo0?ooo`0L0?oo
o`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030?l0003oool0oooo
04H0oooo00<000000?ooo`3oool05@3oool00`3o_g@0000000000004000000030000M02oool0oooo
02P0oooo00<000000?ooo`3oool0g03oool00`3o0000oooo0?ooo`2=0?ooo`030000003oool0oooo
02P0oooo000a0?ooo`030=nLB0000000000000P0000000<0001809cOo`3oool06P3oool00`2oM000
001d0;ooo`0:0?ooo`030000003oool0oooo0?l0oooo9@3oool00`3o0000oooo0?ooo`150?ooo`03
0000003oool0oooo01<0oooo00<0gia8000000000000200000000`0004P0W=oo0?ooo`0V0?ooo`03
0000003oool0oooo0=`0oooo00<0o`000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`00
<03oool0102oM00000000000001d_ol70?ooo`040;md00000000000004RLgaX0oooo00<0_g@00000
M02oool02P3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0B0?ooo`040;md00000000000007Boo`L0oooo00@0_g@0000000000000B9cO9P3o
ool00`000000oooo0?ooo`3L0?ooo`030?l0003oool0oooo08d0oooo00<000000?ooo`3oool0:03o
ool002l0oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P004RLg`0I0?ooo`030;md000007@0
_ooo00X0oooo0`00003o0?ooobD0oooo00<0o`000?ooo`3oool0@P3oool4000001<0oooo00<0_g@0
001d_`3oool02`3oool00`3ooml0W4P004RLg`0U0?ooo`<00000f`3oool00`3o0000oooo0?ooo`2=
0?ooo`800000:P3oool002h0oooo00<0okmd07Boo`3oool03P3oool00`3OW7@0W=oo0?ooo`0G0?oo
o`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030?l0003oool0oooo
04D0oooo00<000000?ooo`3oool0403oool00`3o_g@0M;oo0?ooo`0>0?ooo`030=nLM02Lgol0oooo
02<0oooo00<000000?ooo`3oool0f`3oool00`3o0000oooo0?ooo`2>0?ooo`030000003oool0oooo
02P0oooo000^0?ooo`030?noW02Lgol0oooo02P0oooo00<0_g@00000M02oool02P3oool00`000000
oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3oool0A@3oool00`000000oooo0?ooo`0@0?ooo`03
0?noW02Lgol0oooo03@0oooo00<000000?ooo`3oool0f`3oool00`3o0000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02P0oooo000^0?ooo`030?noM01d_ol0oooo00X0oooo00<0gibL0;ooo`3oool0
6`3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0oooo9@3oool00`3o0000oooo
0?ooo`150?ooo`030000003oool0oooo0100oooo00<0okmd07Boo`3oool02P3oool00`3OW9`0_ooo
0?ooo`0W0?ooo`030000003oool0oooo0=/0oooo00<0o`000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0X0?ooo`00;P3oool00`3o_g@004RL0=ooo`0:0?ooo`030;mdM02oool0oooo01/0oooo00<0
_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0@0?ooo`030?noM000B9`0gooo00X0oooo00<0_gAd0;ooo`3oool09`3o
ool00`000000oooo0?ooo`3K0?ooo`030?l0003oool0oooo08h0oooo00<000000?ooo`3oool0:03o
ool002h0oooo00<0okmd0000000000002P0000000`0007@0_ooo0?ooo`0K0?ooo`030;md000007@0
_ooo00X0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030?l0003oool0oooo04D0oooo00<00000
0?ooo`3oool0403oool00`3o_g@000000000000:000000030000M02oool0oooo02L0oooo00<00000
0?ooo`3oool0fP3oool00`3o0000oooo0?ooo`2?0?ooo`030000003oool0oooo02P0oooo000_0?oo
o`040;md00000000001809cOo`P0oooo00<0_gAd0;ooo`3oool06@3oool01@3OW4P0000000000000
07@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030?l0003oool0oooo04D0oooo00<0
00000?ooo`3oool04@3oool0102oM00000000000B02Lgol80?ooo`030;mdM02oool0oooo02L0oooo
00<000000?ooo`3oool0fP3oool00`3o0000oooo0?ooo`2?0?ooo`030000003oool0oooo02P0oooo
000`0?ooo`040=nLB0000000000007Boo`L0oooo00<0gibL0;ooo`3oool06P3oool0103ookl0M000
0000M02oool:0?ooo`030000003oool0oooo0?l0oooo9@3oool00`3o0000oooo0?ooo`150?ooo`03
0000003oool0oooo0180oooo00@0gia8000000000000M;oo1`3oool00`3OW9`0_ooo0?ooo`0W0?oo
o`030000003oool0oooo0=X0oooo00<0o`000?ooo`3oool0S`3oool00`000000oooo0?ooo`0X0?oo
o`00<@3oool0103o_g@0000000000000M;la0?ooo`030000003oool0oooo0?l0oooo9@3oool00`3o
0000oooo0?ooo`150?ooo`030000003oool0oooo01<0oooo00@0okmd00000000000007Bo<03oool0
0`000000oooo0?ooo`3J0?ooo`030?l0003oool0oooo08l0oooo00<000000?ooo`3oool0:03oool0
0380oooo00D0omnL04P00000000004RL0=ooo`0_0?ooo`030000003oool0oooo0?l0oooo9@3oool0
0`3o0000oooo0?ooo`150?ooo`030000003oool0oooo01@0oooo00D0omnL04P00000000004RL0=oo
o`0^0?ooo`030000003oool0oooo0=X0oooo00<0o`000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0X0?ooo`00<`3oool01@3ookl0M0000000000004P0W=oo02h0oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool01@3ookl0M0000000
000004P0W=oo02d0oooo00<000000?ooo`3oool0f@3oool00`3o0000oooo0?ooo`2@0?ooo`030000
003oool0oooo02P0oooo000d0?ooo`050?oog`2LB00000000000001d_ol0;@3oool200000?l0oooo
9`3oool00`3o0000oooo0?ooo`120?ooo`<00000603oool01@3ooml0W4P0000000000000M;oo02`0
oooo0`00003I0?ooo`030?l0003oool0oooo08l0oooo0P00000Z0?ooo`00;P3oool00`3o_i`0W=oo
0?ooo`050?ooo`040;md000000000000001d_b`0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`03
0?l0003oool0oooo04@0oooo00<000000?ooo`3oool0403oool00`3o_i`0W=oo0?ooo`050?ooo`04
0;md000000000000001d_b/0oooo00<000000?ooo`3oool0f@3oool00`3o0000oooo0?ooo`2@0?oo
o`030000003oool0oooo02P0oooo000^0?ooo`030?noM01d_ol0oooo00H0oooo00D0gia800000000
000004RL0=ooo`0Z0?ooo`030000003oool0oooo0?l0oooo9P3oool00`3o0000oooo0?ooo`140?oo
o`030000003oool0oooo0100oooo00<0okmd07Boo`3oool01P3oool01@3OW4P0000000000000B9`0
gooo02T0oooo00<000000?ooo`3oool0f@3oool00`3o0000oooo0?ooo`2@0?ooo`030000003oool0
oooo02P0oooo000^0?ooo`030?noM0000000000000X0000000<0001809cOo`3oool0:03oool00`00
0000oooo0?ooo`3o0?ooobH0oooo00<0o`000?ooo`3oool0A03oool00`000000oooo0?ooo`0@0?oo
o`030?noM0000000000000X0000000<0001809cOo`3oool09`3oool00`000000oooo0?ooo`3I0?oo
o`030?l0003oool0oooo0900oooo00<000000?ooo`3oool0:03oool002h0oooo00<0okmd07Boo`3o
ool0=@3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<0o`000?ooo`3oool0A03oool00`000000
oooo0?ooo`0@0?ooo`030?noM01d_ol0oooo03@0oooo00<000000?ooo`3oool0f03oool00`3o0000
oooo0?ooo`2A0?ooo`030000003oool0oooo02P0oooo000^0?ooo`030?noW02Lgol0oooo03D0oooo
00<000000?ooo`3oool0o`3ooolV0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool0
403oool00`3o_i`0W=oo0?ooo`0H0?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018
W=l00`3oool01P3ooml0W4P0000000000000001d0;ooo`P0oooo00<000000?ooo`3oool0f03oool0
0`3o0000oooo0?ooo`2A0?ooo`030000003oool0oooo02P0oooo000^0?ooo`030?noM01d_ol0oooo
00h0oooo00<0_gA809cOo`3oool0903oool00`000000oooo0?ooo`3o0?ooobH0oooo00<0o`000?oo
o`3oool0A03oool00`000000oooo0?ooo`0@0?ooo`030?noM01d_ol0oooo00h0oooo00<0_gA809cO
o`3oool01@3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RL
g`020?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgol70?ooo`030000003oool0oooo
0=P0oooo00<0o`000?ooo`3oool0T@3oool00`000000oooo0?ooo`0X0?ooo`00;`3oool00`2oM000
07Bo0?ooo`0;0?ooo`030?oog`2LB000M;oo02H0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`03
0?l0003oool0oooo04@0oooo00<000000?ooo`3oool04@3oool00`2oM00007Bo0?ooo`0;0?ooo`03
0?oog`2LB000M;oo00L0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`03
0;md000007@0_ooo00<0oooo00<0_g@0001d_`3oool01P3oool00`000000oooo0?ooo`3H0?ooo`03
0?l0003oool0oooo0940oooo00<000000?ooo`3oool0:03oool00300oooo00@0_g@0000000000000
M;oo1`3oool0102oM000000000000018W=lW0?ooo`030000003oool0oooo0?l0oooo9P3oool00`3o
0000oooo0?ooo`140?ooo`030000003oool0oooo0180oooo00@0_g@0000000000000M;oo1`3oool0
102oM000000000000018W=l70?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0
1P3oool00`3ookl0M000001d_`040?ooo`030=nLB00007@0_ooo00H0oooo00<000000?ooo`3oool0
f03oool00`3o0000oooo0?ooo`2A0?ooo`030000003oool0oooo02P0oooo000a0?ooo`030=nLB000
0000000000P0000000<0001809cOo`3oool09`3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<0
o`000?ooo`3oool0A03oool00`000000oooo0?ooo`0C0?ooo`030=nLB0000000000000P0000000<0
001809cOo`3oool01`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0
omnL04P00018W=l0103oool00`2oM000001809cOo`060?ooo`030000003oool0oooo0=P0oooo00<0
o`000?ooo`3oool0T@3oool00`000000oooo0?ooo`0X0?ooo`00<`3oool00`3o_g@0000000000004
000000030000M02oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030?l0003oool0
oooo04@0oooo00<000000?ooo`3oool05@3oool00`3o_g@0000000000004000000030000M02oool0
oooo00T0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`050?ooo`030?oOW0180000
B9cO00<0oooo00@0oono07@0000007@0_ooo1P3oool00`000000oooo0?ooo`3G0?ooo`030?l0003o
ool0oooo0980oooo00<000000?ooo`3oool0:03oool006H0oooo0P00003o0?ooobL0oooo00<0o`00
0?ooo`3oool0@P3oool3000002X0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`05
0?ooo`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO00L0oooo1000003F0?ooo`03
0?l0003oool0oooo0900oooo0`00000Z0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobH0oooo
00<0o`000?ooo`3oool0A03oool00`000000oooo0?ooo`0X0?ooo`030?oOW0180000B9cO00@0oooo
00<0gia80000B02Lgol01@3oool01@3ooml0W4P00000M02ogi`0B0000080000000<0B9cO0?ooo`3o
ool01P3oool00`000000oooo0?ooo`3G0?ooo`030?l0003oool0oooo0980oooo00<000000?ooo`3o
ool0:03oool006H0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030?l0003oool0oooo04@0oooo
00<000000?ooo`3oool0:03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo
00<0okmd00000018W=l0303oool00`000000oooo0?ooo`3G0?ooo`030?l0003oool0oooo0980oooo
00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030?l0003o
ool0oooo04<0oooo00<000000?ooo`3oool0:@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2L
B00007Bo00L0oooo00@0oooO09a8000004P0W=oo2`3oool00`000000oooo0?ooo`3G0?ooo`030?l0
003oool0oooo0980oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0:@3oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00P0oooo00@0oono07@0000007@0_ooo2P3oool00`000000oooo
0?ooo`3F0?ooo`030?l0003oool0oooo09<0oooo00<000000?ooo`3oool0:03oool006H0oooo00<0
00000?ooo`3oool0o`3ooolW0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0:P3o
ool01P2oM00004RL0=ooo`3oool0_g@0001d_`X0oooo00@0oooO09a80000000007Bo2@3oool00`00
0000oooo0?ooo`3F0?ooo`030?l0003oool0oooo09<0oooo00<000000?ooo`3oool0:03oool006H0
oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3o
ool0:`3oool0102oM000000000000000M;l=0?ooo`050?oOW018000000000018W03Oool01P3oool0
0`000000oooo0?ooo`3F0?ooo`030?l0003oool0oooo09<0oooo00<000000?ooo`3oool0:03oool0
06H0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030?l0003oool0oooo04<0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`3F0?ooo`030?l0003oool0oooo09<0oooo00<000000?oo
o`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030?l0003oool0oooo04<0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3F0?ooo`030?l0003oool0oooo09<0
oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030?l0
003oool0oooo04<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3E0?ooo`030?l0
003oool0oooo09@0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`030?l0003oool0oooo04<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`3E0?ooo`030?l0003oool0oooo09@0oooo00<000000?ooo`3oool0:03oool006H0oooo0P00003o
0?ooobP0oooo00<0o`000?ooo`3oool0@@3oool3000004T0oooo0`00003E0?ooo`030?l0003oool0
oooo09<0oooo0P00000Z0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<0o`000?oo
o`3oool0@`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0=D0oooo00<0o`000?oo
o`3oool0U03oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobL0
oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0=D0
oooo00<0o`000?ooo`3oool0U03oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo
0?ooo`3o0?ooobL0oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo0=@0oooo00<0o`000?ooo`3oool0U@3oool00`000000oooo0?ooo`0X0?ooo`00IP3o
ool00`000000oooo0?ooo`3o0?ooobL0oooo00<0o`000?ooo`3oool0@`3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo0=@0oooo00<0o`000?ooo`3oool0U@3oool00`000000oooo0?oo
o`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<0o`000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo0=@0oooo00<0o`000?ooo`3oool0U@3oool0
0`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<0o`000?oo
o`3oool0@P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0=@0oooo00<0o`000?oo
o`3oool0U@3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobP0
oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0=@0
oooo00<0o`000?ooo`3oool0U@3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo
0?ooo`3o0?ooobP0oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo0=<0oooo00<0o`000?ooo`3oool0UP3oool00`000000oooo0?ooo`0X0?ooo`00IP3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo0=<0oooo00<0o`000?ooo`3oool0UP3oool00`000000oooo0?oo
o`0X0?ooo`00IP3oool200000?l0oooo:@3oool00`3o0000oooo0?ooo`100?ooo`<00000B@3oool3
00000=<0oooo00<0o`000?ooo`3oool0U@3oool2000002X0oooo001V0?ooo`030000003oool0oooo
0?l0oooo:03oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0d`3oool00`3o0000oooo0?ooo`2F0?ooo`030000003oool0oooo02P0oooo001V0?ooo`03
0000003oool0oooo0?l0oooo:03oool00`3o0000oooo0?ooo`120?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0d`3oool00`3o0000oooo0?ooo`2F0?ooo`030000003oool0oooo02P0
oooo001V0?ooo`030000003oool0oooo0?l0oooo:03oool00`3o0000oooo0?ooo`120?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0dP3oool00`3o0000oooo0?ooo`2G0?ooo`030000
003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo:03oool00`3o0000oooo0?oo
o`120?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0dP3oool00`3o0000oooo0?oo
o`2G0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo:03oool0
0`3o0000oooo0?ooo`120?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0dP3oool0
0`3o0000oooo0?ooo`2G0?ooo`030000003oool0oooo02P0oooo00180?ooo`030?noM00000000000
0080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO0080oooo00H0_g@00000000000000000
0018W03Oool:0?ooo`030000003oool0oooo0?l0oooo:03oool00`3o0000oooo0?ooo`120?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0dP3oool00`3o0000oooo0?ooo`2G0?ooo`03
0000003oool0oooo02P0oooo001:0?ooo`030;md000007@0_ooo00@0oooo00L0gia800000018W=l0
oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool02@3oool00`000000oooo0?ooo`3o0?oo
obP0oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0=80oooo00<0o`000?ooo`3oool0U`3oool00`000000oooo0?ooo`0X0?ooo`00BP3oool00`2oM000
001d0;ooo`0>0?ooo`030?oOW018M;l0oooo00P0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`03
0?l0003oool0oooo0440oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3A0?ooo`03
0?l0003oool0oooo09P0oooo00<000000?ooo`3oool0:03oool004X0oooo00<0_g@00000M02oool0
3P3oool00`3ookl0M01809cOo`080?ooo`030000003oool0oooo0?l0oooo:@3oool00`3o0000oooo
0?ooo`110?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0d@3oool00`3o0000oooo
0?ooo`2H0?ooo`030000003oool0oooo02P0oooo001:0?ooo`030;md000007@0_ooo00h0oooo00<0
oono07@0001d_ol0203oool00`000000oooo0?ooo`3o0?ooobT0oooo00<0o`000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0=40oooo00<0o`000?ooo`3oool0V03o
ool00`000000oooo0?ooo`0X0?ooo`00BP3oool00`2oM000001d0;ooo`0>0?ooo`030?noM0000000
M;oo00P0oooo0`00003o0?ooobT0oooo00<0o`000?ooo`3oool0?P3oool4000004T0oooo0`00003A
0?ooo`030?l0003oool0oooo09L0oooo0P00000Z0?ooo`00BP3oool00`2oM000001d0;ooo`0=0?oo
o`040?oOW0180000001d0;ooo`P0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030?l0003oool0
oooo0440oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3@0?ooo`030?l0003oool0
oooo09T0oooo00<000000?ooo`3oool0:03oool004X0oooo00<0_g@00000M02oool02@3oool0103O
gml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolY
0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3@
0?ooo`030?l0003oool0oooo09T0oooo00<000000?ooo`3oool0:03oool004X0oooo00<0_g@00000
M02oool02@3oool00`3o_g@000000000000200000003001d_`3oool0oooo00P0oooo00<000000?oo
o`3oool0o`3ooolY0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`3@0?ooo`030?l0003oool0oooo09T0oooo00<000000?ooo`3oool0:03oool004X0
oooo00<0_g@00000M02oool02@3oool01@3ooml0W4P00000000007@0_ooo00/0oooo00<000000?oo
o`3oool0o`3ooolY0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`3@0?ooo`030?l0003oool0oooo09T0oooo00<000000?ooo`3oool0:03oool004X0
oooo00<0_g@00000M02oool02P3oool00`3o_g@007Bo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo:@3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo02/0oooo00@0_g@000000000
0000B9cO103oool00`3OW4P0000004RLg`030?ooo`060?oOW018000000000000000004P0W=oo203o
ool00`000000oooo0?ooo`3?0?ooo`030?l0003oool0oooo09X0oooo00<000000?ooo`3oool0:03o
ool004P0oooo00D0gia8000000000000001d0;ooo`0:0?ooo`030?oog`2LB00000000080000000<0
001d0;ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<0o`000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0Y0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`03
0=nLB0000000B9cO0080oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`L0oooo00<0
00000?ooo`3oool0c`3oool00`3o0000oooo0?ooo`2J0?ooo`030000003oool0oooo02P0oooo0019
0?ooo`040?oo_`1d0000001d0;ooo`/0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?oo
o`060?ooo`030000003oool0oooo0?l0oooo:P3oool00`3o0000oooo0?ooo`100?ooo`030000003o
ool0oooo02T0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030;md0000
07@0_ooo00<0oooo00<0gia80018W03Oool01P3oool00`000000oooo0?ooo`3?0?ooo`030?l0003o
ool0oooo09X0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3ooolZ
0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0:03oool0103ooml0W4P00018W03O
ool20?ooo`030?oog`2LB00007Bo00L0oooo00<0_g@00000M02oool00`3oool00`2oM00004RL0=oo
o`060?ooo`030000003oool0oooo0<l0oooo00<0o`000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<0o`000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0X0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool0
0`3o_g@0001809cOo`020?ooo`030=nLB000000007Bo00L0oooo00<000000?ooo`3oool0cP3oool0
0`3o0000oooo0?ooo`2K0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo
0?l0oooo:P3oool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo02P0oooo00<0omnL04P0
0018W=l0103oool00`2oM000001d0;ooo`070?ooo`070=nLB000M;l0oooo0;md00000000001d0;oo
o`070?ooo`030000003oool0oooo0<h0oooo00<0o`000?ooo`3oool0V`3oool00`000000oooo0?oo
o`0X0?ooo`00IP3oool200000?l0oooo:`3oool00`3o0000oooo0?ooo`0n0?ooo`<00000:P3oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo00D0okmd00000000000004RL0=oo
o`080?ooo`@00000c@3oool00`3o0000oooo0?ooo`2I0?ooo`<00000:P3oool006H0oooo00<00000
0?ooo`3oool0o`3ooolZ0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0:03oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL04P000000000000004RL
g`090?ooo`030000003oool0oooo0<h0oooo00<0o`000?ooo`3oool0V`3oool00`000000oooo0?oo
o`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<0o`000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0X0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool0
1`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l0203oool00`000000oooo0?ooo`3=0?ooo`030?l0
003oool0oooo09`0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3o
oolZ0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool0:@3oool00`2oM00004RL0=oo
o`020?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Bo
o`070?ooo`030000003oool0oooo0<d0oooo00<0o`000?ooo`3oool0W03oool00`000000oooo0?oo
o`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<0o`000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0Y0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool0
0`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool0c@3oool0
0`3o0000oooo0?ooo`2L0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo
0?l0oooo:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo02X0oooo00H0_g@00018
W03Oool0oooo0;md0000M;l80?ooo`030?oOW0180000B9cO0080oooo00<0okmd0000B02Lgol01`3o
ool00`000000oooo0?ooo`3=0?ooo`030?l0003oool0oooo09`0oooo00<000000?ooo`3oool0:03o
ool006H0oooo00<000000?ooo`3oool0o`3oool[0?ooo`030?l0003oool0oooo03l0oooo00<00000
0?ooo`3oool0:`3oool0102oM000000000000000M;l:0?ooo`060?oo_`1d000000000000000004P0
W=oo203oool00`000000oooo0?ooo`3<0?ooo`030?l0003oool0oooo09d0oooo00<000000?ooo`3o
ool0:03oool006H0oooo00<000000?ooo`3oool0o`3oool[0?ooo`030?l0003oool0oooo03l0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3<0?ooo`030?l0003oool0oooo09d0oooo
00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3oool[0?ooo`030?l0003o
ool0oooo03l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3<0?ooo`030?l0003o
ool0oooo09d0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3oool[
0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3<
0?ooo`030?l0003oool0oooo09d0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?oo
o`3oool0o`3oool[0?ooo`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`3;0?ooo`030?l0003oool0oooo09h0oooo00<000000?ooo`3oool0:03oool006H0
oooo0P00003o0?ooob`0oooo00<0o`000?ooo`3oool0?@3oool3000004T0oooo0`00003;0?ooo`03
0?l0003oool0oooo09d0oooo0P00000Z0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooob`0oooo
00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0</0oooo
00<0o`000?ooo`3oool0WP3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?oo
o`3o0?ooob`0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0<X0oooo00<0o`000?ooo`3oool0W`3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool0
0`000000oooo0?ooo`3o0?ooob`0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo0<X0oooo00<0o`000?ooo`3oool0W`3oool00`000000oooo0?ooo`0X
0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooob`0oooo00<0o`000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo0<T0oooo00<0o`000?ooo`3oool0X03oool00`00
0000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooob`0oooo00<0o`000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0<T0oooo00<0o`000?ooo`3o
ool0X03oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooob`0oooo
00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0<P0oooo
00<0o`000?ooo`3oool0X@3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?oo
o`3o0?ooob`0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0<P0oooo00<0o`000?ooo`3oool0X@3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool0
0`000000oooo0?ooo`3o0?ooobd0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo0<L0oooo00<0o`000?ooo`3oool0XP3oool00`000000oooo0?ooo`0X
0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<0o`000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo0<L0oooo00<0o`000?ooo`3oool0XP3oool00`00
0000oooo0?ooo`0X0?ooo`00IP3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<0o`000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0<H0oooo00<0o`000?ooo`3o
ool0X`3oool00`000000oooo0?ooo`0X0?ooo`00IP3oool200000?l0oooo;P3oool00`3o0000oooo
0?ooo`0k0?ooo`<00000B@3oool300000<H0oooo00<0o`000?ooo`3oool0XP3oool2000002X0oooo
001V0?ooo`030000003oool0oooo0?l0oooo;@3oool00`3o0000oooo0?ooo`0m0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0a@3oool00`3o0000oooo0?ooo`2T0?ooo`030000003o
ool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`3o0000oooo0?ooo`0l
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0a@3oool00`3o0000oooo0?ooo`2T
0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`3o
0000oooo0?ooo`0l0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0a03oool00`3o
0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0
oooo;P3oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0a03oool00`3o0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000
003oool0oooo0?l0oooo;P3oool00`3o0000oooo0?ooo`0l0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0``3oool00`3o0000oooo0?ooo`2V0?ooo`030000003oool0oooo02P0oooo
001V0?ooo`030000003oool0oooo0?l0oooo;P3oool00`3o0000oooo0?ooo`0l0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0`P3oool00`3o0000oooo0?ooo`2W0?ooo`030000003o
ool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo;`3oool00`3o0000oooo0?ooo`0k
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0`@3oool00`3o0000oooo0?ooo`2X
0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0oooo;`3oool00`3o
0000oooo0?ooo`0k0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0`@3oool00`3o
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo0?l0
oooo;`3oool00`3o0000oooo0?ooo`0k0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0`03oool00`3o0000oooo0?ooo`2Y0?ooo`030000003oool0oooo02P0oooo001V0?ooo`800000
o`3ooola0?ooo`030?l0003oool0oooo03P0oooo0`0000190?ooo`<00000_`3oool00`3o0000oooo
0?ooo`2Y0?ooo`800000:P3oool006H0oooo00<000000?ooo`3oool0o`3oool`0?ooo`030?l0003o
ool0oooo03X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2n0?ooo`030?l0003o
ool0oooo0:/0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?ooo`3oool0o`3oool`
0?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2n
0?ooo`030?l0003oool0oooo0:/0oooo00<000000?ooo`3oool0:03oool006H0oooo00<000000?oo
o`3oool0o`3ooola0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`2m0?ooo`030?l0003oool0oooo0:`0oooo00<000000?ooo`3oool0:03oool006H0
oooo00<000000?ooo`3oool0o`3ooola0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`2k0?ooo`80o`00[`3oool00`000000oooo0?ooo`0X0?ooo`00
E@3oool00`3OW4P00000000000050000000307Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0
o`3ooola0?ooo`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`3o_g@00000
0000000200000003001d_`3oool0oooo00H0oooo00<000000?ooo`3oool0^@3oool20?l00;40oooo
00<000000?ooo`3oool0:03oool005H0oooo00<0gia8000000000000100000000`00M;l0oooo0?oo
o`060?ooo`030000003oool0oooo0?l0oooo<P3oool00`3o0000oooo0?ooo`0h0?ooo`030000003o
ool0oooo03/0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`2g0?ooo`80o`00/`3o
ool00`000000oooo0?ooo`0X0?ooo`00E`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0
_ooo00L0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030?l0003oool0oooo03L0oooo00<00000
0?ooo`3oool0>`3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo0;D0oooo0P3o002e
0?ooo`030000003oool0oooo02P0oooo001H0?ooo`030=nLB018W=l0oooo00/0oooo00<000000?oo
o`3oool0o`3ooolc0?ooo`030?l0003oool0oooo03L0oooo00<000000?ooo`3oool0>`3oool00`2o
M000001d0;ooo`090?ooo`030000003oool0oooo0;<0oooo0P3o002g0?ooo`030000003oool0oooo
02P0oooo001I0?ooo`030=nLB01d_ol0oooo00X0oooo00<000000?ooo`3oool0o`3ooold0?ooo`80
o`00=`3oool00`000000oooo0?ooo`0k0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3o
ool0[@3oool60?l00;T0oooo00<000000?ooo`3oool0:03oool005T0oooo00<0oooO09a8B02Lgol0
2P3oool00`000000oooo0?ooo`3o0?ooocH0oooo0`3o000d0?ooo`030000003oool0oooo03/0oooo
00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`2U0?ooo`P0o`00_`3oool00`000000oooo
0?ooo`0X0?ooo`00FP3oool00`3ogi`0B01d0;ooo`090?ooo`<00000o`3oooli0?ooob`0o`001@3o
ool4000003d0oooo00<0_g@00000M02oool02@3oool4000000D0ooooW`3o00350?ooo`<00000:P3o
ool005/0oooo00<0_g@004RLg`3oool0203oool00`000000oooo0?ooo`3o0?ooofd0oooo00<00000
0?ooo`3oool0>`3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo0?l0ooooK@3oool0
0`000000oooo0?ooo`0X0?ooo`00F`3oool00`3OW4P0001d0;ooo`080?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`0k0?ooo`030;md000007@0_ooo00T0oooo00<000000?oo
o`3oool0o`3ooom]0?ooo`030000003oool0oooo02P0oooo001K0?ooo`030?noM0000000M;oo00P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0>`3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02P0
oooo001E0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>`3oool00`2oM000001d
0;ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0X0?ooo`00EP3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`@0000000<004RL0=ooo`3oool00`3oool00`000000M01d0;ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0i0?oo
o`050=nLB000000000000000M02oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`@0000000<004RL
0=ooo`3oool00`3oool00`000000M01d0;ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0X0?ooo`00E`3oool01@2oM0000000000000000000
07Bo00X0ooooo`00001a000003`0oooo00@0oono07@0000007@0_ooo2@3ooooo000007400000:P3o
ool00?l0oooo7`3oool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000001d0;ooool0oooo[`3o
ool00`3ooml0W4Qd0;ooo`050?ooo`040;md00000000001d0;ooomD0oooo003o0?oooal0oooo00<0
oooO09a8M02oool0103oool01@3OW4P000000000B018B7@0_ooo0?l0oooo[`3oool00`3ooml0W4Qd
0;ooo`040?ooo`050=nLB0000000001804Q8M02oool0e@3oool00?l0oooo7`3oool00`3ooml0W4Qd
0;ooo`030?ooo`060?noM0000000001d0;oog`2LB7@0_oooo`3ooon_0?ooo`030?oog`2LB7@0_ooo
00<0oooo00H0okmd0000000007@0_ooO09a8M02ooooE0?ooo`00o`3ooolO0?ooo`030?oog`2LB7@0
_ooo0080oooo00L0omnL04P0000004P0W=oo0?oog`2LB7@0_ooo0?l0oooo[`3oool00`3ooml0W4Qd
0;ooo`020?ooo`070?oOW0180000001809cOo`3ooml0W4Qd0;ooo`3E0?ooo`00o`3ooolO0?ooo`0<
0?oog`2LB7@0_ooo0?ooo`3ookl0M0000000001d_ol0oooo0?oog`2LB7@0_oooo`3ooon_0?ooo`0<
0?oog`2LB7@0_ooo0?ooo`3ookl0M0000000001d_ol0oooo0?oog`2LB7@0_oooe@3oool00?l0oooo
7`3oool01`3ooml0W4Qd0;ooo`3ooml0W4P000000018W=l00P3oool00`3ooml0W4Qd0;ooo`3o0?oo
ojl0oooo00L0oooO09a8M02oool0oooO09a800000000B9cO0080oooo00<0oooO09a8M02oool0e@3o
ool00?l0oooo7`3oool01P3ooml0W4Qd0;oog`2LB0000000001d_`<0oooo00<0oooO09a8M02oool0
o`3ooon_0?ooo`060?oog`2LB7@0_ooO09a80000000007Bo0`3oool00`3ooml0W4Qd0;ooo`3E0?oo
o`00o`3ooolO0?ooo`060?oog`2LB7@0M7@000000000B9`0gooo0`3oool00`3ooml0W4Qd0;ooo`3o
0?ooojl0oooo00H0oooO09a8M01dM00000000018W03Oool30?ooo`030?oog`2LB7@0_ooo0=D0oooo
003o0?oooal0oooo00D0oooO09a800000000001d0;ooo`040?ooo`030?oog`2LB7@0_ooo0?l0oooo
[`3oool01@3ooml0W4P00000000007@0_ooo00@0oooo00<0oooO09a8M02oool0e@3oool00?l0oooo
7`3oool0103OW4P000000000M02oool50?ooo`030?oo_`1d07@0_ooo0?l0oooo[`3oool0103OW4P0
00000000M02oool50?ooo`030?oo_`1d07@0_ooo0=D0oooo003o0?oooad0oooo00D0gia800000000
0000001809cOo`040?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0o`3ooonZ0?oo
o`050=nLB000000000000000B02Lgol0103oool00`3ooml0W4P000000002000000030018W03Oool0
oooo0=80oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0oooo
o`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool0
0?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo
_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?oo
ool0oooo_03oool00780oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`04
0;md00000000000004RLgb00oooo00<0gia80000000000001@000000101d_ol0oooo0?ooo`2oM003
000000030018W03Oool0oooo01h0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`02
0?ooo`040;md00000000000004RLgb80oooo00<0okmd0000000000000P0000001@00M;l0oooo0?oo
o`3oool0_g@000<0000000<004RL0=ooo`3oool0803oool00`3o_g@000000000000200000003001d
_`3oool0oooo00<0oooo00@0_g@0000000000000B9cO9P3oool01P2oM000000000000000000004RL
0=ooobH0oooo00@0_g@0000000000000B9cO:P3oool01P2oM000000000000000000004RL0=ooof40
oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`040;md00000000000004RL
gb00oooo00<0gia80000000000001@000000101d_ol0oooo0?ooo`2oM003000000030018W03Oool0
oooo01h0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`020?ooo`040;md00000000
000004RLgb80oooo00<0okmd0000000000000P0000001@00M;l0oooo0?ooo`3oool0_g@000<00000
00<004RL0=ooo`3oool0803oool00`3o_g@000000000000200000003001d_`3oool0oooo00<0oooo
00@0_g@0000000000000B9cO9P3oool01P2oM000000000000000000004RL0=ooobD0oooo00@0_g@0
000000000000B9cO:`3oool01P2oM000000000000000000004RL0=oooc@0oooo001b0?ooo`080?oO
W018000004RL0=ooo`3oool0omnL04P0B02Lgol30?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0
001d_`0P0?ooo`030=nLB0000000000000@0000000D007Bo0?ooo`3ooml0W4P004RLg`020?ooo`03
0?oOW018B9`0gooo01l0oooo00<0gia8000000000000100000002P00M;l0oooo0?ooo`3ooml0W4P0
001d_`3oool0oooO09a80000M;lS0?ooo`030;md000007@0_ooo00<0oooo00<0oooO09a80018W=l0
0P3oool00`3ogi`0B4RL0=ooo`0R0?ooo`030;md000007@0_ooo00@0oooo00L0oooO09a80000M;l0
oooo0?oog`2LB00007Bo02@0oooo00<0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0S0?oo
o`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0X0?ooo`030?oog`2LB000B9cO0080oooo00<0
omnL04Q8W03Oool0H03oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0W=oo0`3oool01`3o
oml0W4P0001d_`3oool0oooO09a80000M;l0803oool00`3OW4P000000000000400000005001d_`3o
ool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0O0?ooo`030=nLB0000000000000@00000
00X007Bo0?ooo`3oool0oooO09a80000M;l0oooo0?oog`2LB00007Bo8`3oool00`2oM000001d0;oo
o`030?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool08P3oool00`2oM000001d0;oo
o`040?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0T0?ooo`030?oog`2LB000B9cO0080
oooo00<0omnL04Q8W03Oool08P3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0:@3oool0
0`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo03<0oooo001h0?ooo`030?noM000B9`0gooo
0080oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0P0?ooo`030=nLB018W=l0oooo
0080oooo00<0oooO09a8M02oool01P3oool00`3ogi`0B7Bo0?ooo`0O0?ooo`030=nLB018W=l0oooo
0080oooo00L0oooO09a8M02oool0oooo0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol08P3o
ool00`2oM000001d0;ooo`090?ooo`030?oOW018M;l0oooo0240oooo00<0_g@00000M02oool0103o
ool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo02T0oooo00<0omnL04Qd_`3oool08P3o
ool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo02d0oooo00<0omnL04Qd_`3oool0I@3o
ool00`3o_g@004RL0=ooo`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0803o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00H0oooo00<0omnL04Qd_`3oool07`3o
ool00`3OW4P0B9cO0?ooo`020?ooo`070?oog`2LB7@0_ooo0?ooo`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo0280oooo00<0_g@00000M02oool02@3oool00`3ogi`0B7Bo0?ooo`0Q0?ooo`03
0;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0Y0?ooo`03
0?oOW018M;l0oooo0240oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0^0?ooo`03
0?oOW018M;l0oooo0380oooo001h0?ooo`080?noM00004P0W=oo0?ooo`3ooml0W4P00018W03Oool2
0?ooo`030?oog`2LB00007Bo0240oooo00<0gia804RLg`3oool02P3oool00`3ookl0M01809cOo`0P
0?ooo`030=nLB018W=l0oooo00@0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d
_`0R0?ooo`030;md000007@0_ooo00T0oooo00<0oono07@0B02Lgol08@3oool00`2oM000001d0;oo
o`030?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0:@3oool00`3ookl0M018
09cOo`0Q0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0;@3oool00`3ookl0
M01809cOo`1U0?ooo`080?noM00004P0W=oo0?ooo`3ooml0W4P00018W03Oool20?ooo`030?oog`2L
B00007Bo0240oooo00<0gia804RLg`3oool02P3oool00`3ookl0M01809cOo`0P0?ooo`030=nLB018
W=l0oooo00@0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0R0?ooo`030;md
000007@0_ooo00T0oooo00<0oono07@0B02Lgol08@3oool00`2oM000001d0;ooo`030?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0:@3oool00`3ookl0M01809cOo`0P0?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0;P3oool00`3ookl0M01809cOo`0b0?oo
o`00N03oool01`2oM000001809cOo`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`0Q
0?ooo`030=nLB01d_ol0oooo00T0oooo00<0oono07@0001d_ol08@3oool00`3OW4P0M;oo0?ooo`03
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool08@3oool00`2oM000001d0;ooo`09
0?ooo`030?oo_`1d0000M;oo0240oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo02P0oooo00<0oono07@0001d_ol08@3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo02`0oooo00<0oono07@0001d_ol0I@3oool01`2oM000001809cOo`3o
ool0oono07@00000M;l0103oool00`2oM000001d0;ooo`0Q0?ooo`030=nLB01d_ol0oooo00T0oooo
00<0oono07@0001d_ol08@3oool00`3OW4P0M;oo0?ooo`030?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool08@3oool00`2oM000001d0;ooo`090?ooo`030?oo_`1d0000M;oo0240oooo
00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02P0oooo
00<0oono07@0001d_ol0803oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo02d0oooo
00<0oono07@0001d_ol0<P3oool006D0oooo00<0_g@00000000000001`0000000`18W=l0oooo0?oo
o`050?ooo`080;md00000000001d0;ooo`3oool0omnL04P00018W=l40?ooo`030;md000007@0_ooo
0100oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030?oog`2LB4P0W=oo
00T0oooo00<0okmd0000001d_ol0403oool00`2oM0000000000000070000000304RLg`3oool0oooo
00@0oooo00<0oooO09a8B02Lgol00`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo
0100oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo
00T0oooo00<0okmd0000001d_ol04@3oool00`2oM0000000000000070000000304RLg`3oool0oooo
00<0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo
01D0oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`060?ooo`030?noM0000000M;oo
0240oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0/0?ooo`030?noM0000000M;oo
0580oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`050?ooo`080;md00000000001d
0;ooo`3oool0omnL04P00018W=l40?ooo`030;md000007@0_ooo0100oooo00<0_g@0000000000000
1`0000000`18W=l0oooo0?ooo`040?ooo`030?oog`2LB4P0W=oo00T0oooo00<0okmd0000001d_ol0
403oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol0
0`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo0100oooo00<0_g@0000000000000
1`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo00T0oooo00<0okmd0000001d_ol0
403oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0_g@00000M02oool0
0`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo01D0oooo00<0_g@0000000000000
1`0000000`18W=l0oooo0?ooo`060?ooo`030?noM0000000M;oo0200oooo00<0omnL04P00018W=l0
103oool00`2oM000001d0;ooo`0]0?ooo`030?noM0000000M;oo0380oooo001d0?ooo`030?oo_`1d
000000000080000000H0B9cO0?ooo`3oool0omnL04P00018W=l40?ooo`030=nLB00004P0W=oo0280
oooo00<0omnL04P0M02oool01`3oool0103ogi`0B0000000M02ooolR0?ooo`030?oOW01807@0_ooo
0080oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0Q0?ooo`030;md000007@0_ooo
00P0oooo00@0omnL04P0000007@0_ooo8@3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000
B9cO00@0oooo00<0gia80000B02Lgol09`3oool0103ogi`0B0000000M02ooolQ0?ooo`030?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol0:`3oool0103ogi`0B0000000M02ooomQ0?ooo`030?oo
_`1d000000000080000000H0B9cO0?ooo`3oool0omnL04P00018W=l40?ooo`030=nLB00004P0W=oo
0280oooo00<0omnL04P0M02oool01`3oool0103ogi`0B0000000M02ooolR0?ooo`030?oOW01807@0
_ooo0080oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0Q0?ooo`030;md000007@0
_ooo00P0oooo00@0omnL04P0000007@0_ooo8@3oool00`2oM000001d0;ooo`030?ooo`030?oOW018
0000B9cO00@0oooo00<0gia80000B02Lgol09`3oool0103ogi`0B0000000M02ooolP0?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol0;03oool0103ogi`0B0000000M02ooolb0?ooo`00
MP3oool00`3o_g@0001809cOo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
8`3oool00`2oM000B9cO0?ooo`020?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3o
ool08P3oool01`2oM000B9cO0?ooo`3oool0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0Q
0?ooo`030;md000007@0_ooo00@0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?oo
o`0P0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`0S0?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0803oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo02L0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0
oooo0?ooo`1R0?ooo`030?noM00004P0W=oo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0
001809cOo`0S0?ooo`030;md0018W=l0oooo0080oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`0R0?ooo`070;md0018W=l0oooo0?ooo`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo0240oooo00<0_g@00000M02oool0103oool0103Ogml0oooo0?ooo`2oM0020000000304RL
g`3oool0oooo0200oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo02<0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0O0?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0:03oool0103Ogml0oooo0?ooo`2oM0020000
000304RLg`3oool0oooo0340oooo001g0?ooo`030?oOW018M;l0oooo0080oooo00<0oono07@00000
M;l0103oool00`2oM000001d0;ooo`0S0?ooo`030=nLB00007@0_ooo0080oooo00<0okmd00000000
00000P0000000`00M;l0oooo0?ooo`0S0?ooo`070=nLB00007@0_ooo0?ooo`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo0240oooo00<0_g@00000M02oool0103oool00`3o_g@0000000000002
00000003001d_`3oool0oooo0240oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo02<0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0Q
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool09`3oool00`3o_g@0000000000002
00000003001d_`3oool0oooo06@0oooo00<0omnL04Qd_`3oool00P3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo02<0oooo00<0gia80000M02oool00P3oool00`3o_g@0000000000002
00000003001d_`3oool0oooo02<0oooo00L0gia80000M02oool0oooo0?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool08@3oool00`2oM000001d0;ooo`040?ooo`030?noM0000000000000800000
00<007Bo0?ooo`3oool08@3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool08`3oool00`3o_g@000000000000200000003001d_`3oool0oooo0200oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0X0?ooo`030?noM0000000000000800000
00<007Bo0?ooo`3oool0<P3oool007L0oooo00<0oooO09a80018W=l00`3oool00`2oM00004RL0=oo
o`020?ooo`030?oog`2LB00007Bo02@0oooo00<0okmd0000001d_ol00P3oool01@3ooml0W4P00000
000007@0_ooo02H0oooo00<0okmd0000001d_ol00P3oool00`2oM00004RL0=ooo`020?ooo`030?oo
g`2LB00007Bo0280oooo00<0_g@00000M02oool0103oool01@3ooml0W4P00000000007@0_ooo02@0
oooo00<0_g@00000M02oool0103oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo02@0
oooo00D0oooO09a800000000001d0;ooo`0U0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a8
0000M;l0:03oool01@3ooml0W4P00000000007@0_ooo06L0oooo00<0oooO09a80018W=l00`3oool0
0`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo02@0oooo00<0okmd0000001d_ol00P3oool0
1@3ooml0W4P00000000007@0_ooo02H0oooo00<0okmd0000001d_ol00P3oool00`2oM00004RL0=oo
o`020?ooo`030?oog`2LB00007Bo0280oooo00<0_g@00000M02oool0103oool01@3ooml0W4P00000
000007@0_ooo02@0oooo00<0_g@00000M02oool0103oool00`2oM00004RL0=ooo`020?ooo`030?oo
g`2LB00007Bo02@0oooo00D0oooO09a800000000001d0;ooo`0T0?ooo`030;md0000B9`0gooo0080
oooo00<0oooO09a80000M;l0:@3oool01@3ooml0W4P00000000007@0_ooo03D0oooo001b0?ooo`03
0?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l00`3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo01h0oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`030?ooo`03
0?noM000M;l0oooo0240oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Boo`020?ooo`03
0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol08P3oool00`2oM000001d0;ooo`050?ooo`03
0?noM000M;l0oooo02D0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo02D0oooo00<0okmd001d_`3oool09P3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo02T0oooo00<0okmd001d_`3oool0H`3oool00`3ooml0W7BL0=ooo`020?ooo`03
0?oog`2LB00007Bo00<0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0N0?ooo`03
0?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol00`3oool00`3o_g@007Bo0?ooo`0Q0?ooo`03
0?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol00P3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo0280oooo00<0_g@00000M02oool01@3oool00`3o_g@007Bo0?ooo`0U0?ooo`03
0;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0U0?ooo`03
0?noM000M;l0oooo02D0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0Z0?ooo`03
0?noM000M;l0oooo03H0oooo001c0?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`040?oo
o`060;md0000B9`0gooo0?ooo`2oM00007Bo803oool0202oM000M;oo0?ooo`3oool0gia800000000
B9`0gooo0`3oool00`3ooml0W4P000000002000000030000M02oool0oooo01d0oooo00P0_g@007Bo
o`3oool0oooo0=nLB000000004RL0=ooo`<0oooo00H0_g@00018W03Oool0oooo0;md0000M;lQ0?oo
o`050=nLB000000000000000M02oool01@3oool00`3ooml0W4P000000002000000030000M02oool0
oooo01h0oooo00D0gia8000000000000001d0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM000
07Bo9P3oool00`3ooml0W4P000000002000000030000M02oool0oooo0280oooo00H0_g@00018W03O
ool0oooo0;md0000M;lZ0?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0G`3oool0
1`3ogi`0B4RL0=ooo`3oool0gia80000001d_ol0103oool01P2oM00004RL0=ooo`3oool0_g@0001d
_b00oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo`<0oooo00<0oooO09a800000000
0P0000000`0007@0_ooo0?ooo`0M0?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03Oool3
0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo8@3oool01@3OW4P000000000000007@0_ooo00D0
oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0N0?ooo`050=nLB000000000000000
M02oool01@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_bH0oooo00<0oooO09a8000000000P00
00000`0007@0_ooo0?ooo`0Q0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo:`3oool00`3ooml0
W4P000000002000000030000M02oool0oooo0340oooo001d0?ooo`050?oOW0180000000000000018
W=l01P3oool0102oM000000000000000M;lR0?ooo`050;md00000000000000000000M;l01P3oool0
0`3o_g@00000000000020000000307Boo`3oool0oooo01d0oooo00D0_g@00000000000000000001d
_`060?ooo`040;md000000000000001d_b<0oooo00@0oono07@0000007@0_ooo1P3oool00`3o_g@0
0000000000020000000307Boo`3oool0oooo01h0oooo00@0oono07@0000007@0_ooo1P3oool0102o
M000000000000000M;lX0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool08P3oool0
102oM000000000000000M;l/0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool0G`3o
ool01@3ogi`0B000000000000000B9cO00H0oooo00@0_g@000000000000007Bo8P3oool01@2oM000
000000000000000007Bo00H0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0M0?oo
o`050;md00000000000000000000M;l01P3oool0102oM000000000000000M;lS0?ooo`040?oo_`1d
0000001d0;ooo`H0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0N0?ooo`040?oo
_`1d0000001d0;ooo`H0oooo00@0_g@000000000000007Bo:03oool00`3o_g@00000000000020000
000307Boo`3oool0oooo0240oooo00@0_g@000000000000007Bo;@3oool00`3o_g@0000000000002
0000000307Boo`3oool0oooo0300oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0
oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo
0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00
o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl
0?ooo`00GP3oool00`3o_g@000000000000200000003001d_`3oool0oooo00L0ooooo`00001a0000
03/0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`060?ooool00000L@00000S0?oo
o`00H03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0k0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo001P0?ooo`030;md
000007@0_ooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0>`3oool00`2oM000001d0;ooo`090?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0240oooo001P0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3o
oom]0?ooo`030000003oool0oooo03/0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?oo
o`3o0?ooofd0oooo00<000000?ooo`3oool08@3oool00600oooo00<0_g@00000M02oool02P3oool0
0`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0>`3oool00`2oM000001d0;ooo`09
0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`2o
M0000000000000070000000304RLg`3oool0oooo00@0oooo00<0_g@00000M02oool02P3oool30000
0?l0ooooJP3oool4000002`0oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?oo
o`030;md000007@0_ooo00T0oooo1000003o0?oooc/0oooo:P3o00050?ooo`<000008`3oool00600
oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3o
ool0>`3oool00`2oM000001d0;ooo`090?ooo`030000003oool0oooo0?l0oooo=P3oool60?l00340
oooo00<000000?ooo`3oool08@3oool00600oooo00<0_g@00000M02oool02P3oool00`000000oooo
0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0>`3oool00`2oM000001d0;ooo`090?ooo`030000
003oool0oooo0?l0oooo=@3oool00`3o0000oooo0?ooo`0e0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003o
ool0oooo03/0oooo00<0_g@00000M02oool02@3oool00`000000oooo0?ooo`3o0?oooc<0oooo0P3o
000h0?ooo`030000003oool0oooo0240oooo001P0?ooo`030;md000007@0_ooo00X0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo03/0oooo00<0_g@00000M02oool02@3oool0
0`000000oooo0?ooo`3o0?oooc80oooo00<0o`000?ooo`3oool0>03oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooK@3oool00`00
0000oooo0?ooo`0k0?ooo`030;md000007@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooola0?oo
o`030?l0003oool0oooo03T0oooo00<000000?ooo`3oool08@3oool005h0oooo00D0gia800000000
0000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0i0?oo
o`050=nLB000000000000000M02oool02@3oool00`000000oooo0?ooo`3o0?oooc40oooo00<0o`00
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0Q0?ooo`00G`3oool0103ookl0M0000000M02oool:
0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0j0?ooo`040?oo_`1d0000
001d0;ooo`T0oooo00<000000?ooo`3oool0o`3oool`0?ooo`030?l0003oool0oooo03X0oooo00<0
00000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0o`3oool_0?ooo`030?l0003oool0oooo03/0oooo00<00000
0?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0o`3oool_0?ooo`030?l0003oool0oooo03/0oooo00<000000?oo
o`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0o`3oool_0?ooo`030?l0003oool0oooo03/0oooo00<000000?ooo`3o
ool08@3oool006d0oooo0P00003o0?ooof`0oooo0`0000190?ooo`<00000o`3oool^0?ooo`030?l0
003oool0oooo03/0oooo0P00000S0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<0o`000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<0o`000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<0o`000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<0o`000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`3o0?ooobd0oooo00<0o`000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`3o0?ooob`0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Q
0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`3o0?ooob`0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Q0?oo
o`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`3o0?ooob`0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Q0?ooo`00
K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`3o0?ooob`0oooo00<0o`000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Q0?ooo`00K@3o
ool200000?l0ooooK03oool3000004T0oooo0`00003o0?ooob`0oooo00<0o`000?ooo`3oool0?@3o
ool2000002<0oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo0?l0oooo:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0
oooo0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo0?l0oooo:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo
0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0?l0oooo:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo0240
oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo0?l0oooo:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo
001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0?l0oooo:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001]
0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo0?l0oooo:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001]0?oo
o`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0?l0oooo:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001]0?ooo`03
0000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0
oooo:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001]0?ooo`030000
003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo
:`3oool00`3o0000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003o
ool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo:P3o
ool00`3o0000oooo0?ooo`100?ooo`030000003oool0oooo0240oooo001]0?ooo`800000o`3ooom/
0?ooo`<00000B@3oool300000?l0oooo:P3oool00`3o0000oooo0?ooo`0o0?ooo`8000008`3oool0
06d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0o`3ooolZ0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool08@3oool006d0
oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0o`3ooolZ0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool08@3oool006d0oooo
00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
o`3ooolZ0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool08@3oool006d0oooo00<0
00000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3o
oolZ0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool08@3oool006d0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo02/0oooo00@0_g@0000000000000B9cO103o
ool00`3OW4P0000004RLg`030?ooo`060?oOW018000000000000000004P0W=oo203oool00`000000
oooo0?ooo`3o0?ooobX0oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?ooo`0Q0?ooo`00
K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0:@3oool01`3ooml0W4P0
001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`080?oOW018000004RL
0=ooo`3oool0omnL04P0001d_ol70?ooo`030000003oool0oooo0?l0oooo:P3oool00`3o0000oooo
0?ooo`100?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3o
ool00`000000oooo0?ooo`0Y0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3o
ool00`2oM000001d0;ooo`030?ooo`030=nLB000B9`0gooo00H0oooo00<000000?ooo`3oool0o`3o
oolZ0?ooo`030?l0003oool0oooo0400oooo00<000000?ooo`3oool08@3oool006d0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo02P0oooo00@0oooO09a80000B9`0gooo0P3o
ool00`3ooml0W4P0001d_`070?ooo`030;md000007@0_ooo00<0oooo00<0_g@00018W03Oool01P3o
ool00`000000oooo0?ooo`3o0?ooobX0oooo00<0o`000?ooo`3oool0@03oool00`000000oooo0?oo
o`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0:03oool0
0`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000B02Lgol00P3oool0
0`3OW4P00000001d_`070?ooo`030000003oool0oooo0?l0oooo:@3oool00`3o0000oooo0?ooo`11
0?ooo`030000003oool0oooo0240oooo001]0?ooo`800000o`3ooom/0?ooo`<000007@3oool00`2o
M0000000000000070000000604RLg`3oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;oo
o`070?ooo`070=nLB000M;l0oooo0;md00000000001d0;ooo`070?ooo`@00000o`3ooolX0?ooo`03
0?l0003oool0oooo03l0oooo0`00000S0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo
00<000000?ooo`3oool0:03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo
00D0okmd00000000000004RL0=ooo`080?ooo`030000003oool0oooo0?l0oooo:@3oool00`3o0000
oooo0?ooo`110?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0oooo
K@3oool00`000000oooo0?ooo`0X0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
1`3oool01@3ogi`0B000000000000000B9cO00T0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`03
0?l0003oool0oooo0440oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0
o`3ooom]0?ooo`030000003oool0oooo02P0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`060?ooo`070?oOW0180000001809cOo`3oool0gia8001d_`080?ooo`030000003oool0oooo
0?l0oooo:@3oool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo0240oooo001]0?ooo`03
0000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0Y0?ooo`030;md0000B9`0gooo0080
oooo00<0oooO09a80000M;l01`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000M;oo00L0
oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3o
ool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo02T0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030=nLB000B9`0gooo0080oooo
00<0oooO09a80018W=l01`3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<0o`000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0Q0?ooo`00D03oool0102oM000000000000018W=l40?ooo`030=nL
B0000000B9cO0080oooo00H0_g@000000000000000000018W03Oool:0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`0Z0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203o
ool00`3ogi`0B00004RLg`020?ooo`030?noM00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3o
oolX0?ooo`030?l0003oool0oooo0480oooo00<000000?ooo`3oool08@3oool004h0oooo00L0oooO
09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO
0080oooo00<0omnL04Q8W03Oool02@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?oo
o`3oool0:`3oool0102oM000000000000000M;l:0?ooo`060?oo_`1d000000000000000004P0W=oo
203oool00`000000oooo0?ooo`3o0?ooobP0oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0Q0?ooo`00CP3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00`0oooo00<0
omnL04Qd_`3oool0203oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0Q0?ooo`00C@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00`0oooo00<0
oono07@0B02Lgol0203oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0Q0?ooo`00C@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0oono
07@0001d_ol0203oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`3o0?ooobP0oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0Q
0?ooo`00@03oool00`2oM0000000000000070000000604RLg`3oool0oooo0?oOW0180000B9cO103o
ool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000M;oo00P0oooo0`00003o0?ooofX0oooo1000
00190?ooo`<00000o`3ooolX0?ooo`030?l0003oool0oooo0440oooo0P00000S0?ooo`00C@3oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00X0oooo00@0omnL04P0000007@0_ooo203o
ool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`3o0?ooobP0oooo00<0o`000?ooo`3oool0@P3oool00`000000oooo0?ooo`0Q0?ooo`00C@3oool0
0`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00@0gmoO0?ooo`3oool0_g@00P00
00000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo0?l0oooo9`3oool00`3o0000oooo0?ooo`130?ooo`030000003o
ool0oooo0240oooo001=0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool0
0`3o_g@000000000000200000003001d_`3oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooom]
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`030?l0003oool0
oooo04<0oooo00<000000?ooo`3oool08@3oool004h0oooo00<0_g@00018W03Oool00P3oool00`3o
oml0W4P0001d_`070?ooo`050?oog`2LB00000000000M02oool02`3oool00`000000oooo0?ooo`3o
0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<0o`00
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0Q0?ooo`00CP3oool00`3o_g@0001809cOo`020?oo
o`030?oOW0180000M;oo00P0oooo00<0okmd001d_`3oool0303oool00`000000oooo0?ooo`3o0?oo
ofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<0o`000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool01P2oM00004RL0=ooo`3oool0_g@0
001d_`T0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`070?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo9`3oool0
0`3o0000oooo0?ooo`130?ooo`030000003oool0oooo0240oooo001@0?ooo`040;md000000000000
001d_`/0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`060?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo9`3oool0
0`3o0000oooo0?ooo`130?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo9`3oool00`3o
0000oooo0?ooo`130?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0
ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo9`3oool00`3o0000
oooo0?ooo`130?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0oooo
K@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo9P3oool00`3o0000oooo
0?ooo`140?ooo`030000003oool0oooo0240oooo001]0?ooo`800000o`3ooom/0?ooo`<00000B@3o
ool300000?l0oooo9P3oool00`3o0000oooo0?ooo`130?ooo`8000008`3oool006d0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolV
0?ooo`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?oo
o`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolV0?oo
o`030?l0003oool0oooo04@0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3o
ool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`03
0?l0003oool0oooo04@0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0
o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030?l0
003oool0oooo04@0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3o
oom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030?l0003o
ool0oooo04@0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030?l0003oool0
oooo04@0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030?l0003oool0oooo
04@0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030?l0003oool0oooo04D0
oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030?l0003oool0oooo04D0oooo
00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030?l0003oool0oooo04D0oooo00<0
00000?ooo`3oool08@3oool006d0oooo0P00003o0?ooof`0oooo0`0000190?ooo`<00000o`3ooolU
0?ooo`030?l0003oool0oooo04@0oooo0P00000S0?ooo`00K@3oool00`000000oooo0?ooo`3o0?oo
ofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0o`000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0o`000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0o`000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<00000
0?ooo`3oool0:`3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00<0oooo00H0
oooO09a80000000000000000M02oool80?ooo`030000003oool0oooo0?l0oooo903oool00`3o0000
oooo0?ooo`160?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0oooo
K@3oool00`000000oooo0?ooo`0Y0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?oo
o`030=nLB0000000B9cO0080oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOo`L0oooo
00<000000?ooo`3oool0o`3ooolT0?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3oool0
8@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo02T0oooo00<0
okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0
_g@0001d_`3oool01P3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0o`000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<00000
0?ooo`3oool0:03oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00H0oooo00<0
oono07@00000M;l0103oool00`3OW4P0001d0;ooo`060?ooo`030000003oool0oooo0?l0oooo903o
ool00`3o0000oooo0?ooo`160?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`0X0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool01@3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo00H0oooo00<00000
0?ooo`3oool0o`3ooolT0?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3oool08@3oool0
06d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo01/0oooo00<0_g@00000
000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool01@3o
ool00`3ogi`0B00004RLg`030?ooo`040?oo_`1d0000001d0;ooo`H0oooo00<000000?ooo`3oool0
o`3ooolS0?ooo`030?l0003oool0oooo04L0oooo00<000000?ooo`3oool08@3oool002/0oooo00<0
okmd07Boo`3oool01P3oool00`2oM7@0_ooo0?ooo`0f0?ooo`800000o`3ooom/0?ooo`<00000203o
ool00`3o_g@0M;oo0?ooo`060?ooo`030;mdM02oool0oooo01H0oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`050?ooo`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO
00L0oooo1000003o0?ooob80oooo00<0o`000?ooo`3oool0A@3oool3000002<0oooo000[0?ooo`03
0?noM00007@0_ooo00@0oooo00@0oooO09a8000007@0_ooo=`3oool00`000000oooo0?ooo`3o0?oo
ofd0oooo00<000000?ooo`3oool01P3oool00`3o_g@0001d0;ooo`040?ooo`040?oog`2LB000001d
0;oooaL0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`050?oog`2LB000
001d0;oOW01800000P0000000`18W=l0oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo8`3o
ool00`3o0000oooo0?ooo`170?ooo`030000003oool0oooo0240oooo000[0?ooo`040?noM0000000
000004RLg`80oooo00D0oono07@0B02Lgol0gibL0;ooo`0g0?ooo`030000003oool0oooo0?l0oooo
K@3oool00`000000oooo0?ooo`060?ooo`040?noM0000000000004RLg`80oooo00D0oono07@0B02L
gol0gibL0;ooo`0G0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o
_g@0000004RLg`0<0?ooo`030000003oool0oooo0?l0oooo8`3oool00`3o0000oooo0?ooo`170?oo
o`030000003oool0oooo0240oooo000[0?ooo`080?noW02Lgol0gia80000000004P0M7A80000M02o
oolj0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`060?ooo`080?noW02L
gol0gia80000000004P0M7A80000M02ooolK0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a8
0000M;l01`3oool0103ooml0W4P00000B02Lgol;0?ooo`030000003oool0oooo0?l0oooo8P3oool0
0`3o0000oooo0?ooo`180?ooo`030000003oool0oooo0240oooo000^0?ooo`040?oo_`1d00000000
001d_c/0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo00T0oooo00@0oono
07@00000000007Bo703oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00@0
oono07@0000007@0_ooo2P3oool00`000000oooo0?ooo`3o0?ooob80oooo00<0o`000?ooo`3oool0
B03oool00`000000oooo0?ooo`0Q0?ooo`00:`3oool02`3o_i`0W=oo0?noM00004P0W=oo0=nLB000
0000001809cOo`3OW9`0_ooo03L0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0
oooo00H0oooo00/0oknL09cOo`3o_g@0001809cOo`3OW4P000000000B02Lgol0gibL0;ooo`0I0?oo
o`060;md0000B9`0gooo0?ooo`2oM00007Bo2P3oool0103ooml0W4P000000000M;l90?ooo`030000
003oool0oooo0?l0oooo8P3oool00`3o0000oooo0?ooo`180?ooo`030000003oool0oooo0240oooo
000[0?ooo`030?noM000000007Bo00<0oooo00D0oono07@000000000001d0;ooo`0g0?ooo`030000
003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`060?ooo`030?noM000000007Bo00<0oooo
00D0oono07@000000000001d0;ooo`0J0?ooo`040;md000000000000001d_`d0oooo00D0omnL04P0
0000000004RL0=ooo`060?ooo`030000003oool0oooo0?l0oooo8P3oool00`3o0000oooo0?ooo`18
0?ooo`030000003oool0oooo0240oooo000[0?ooo`030?noM018W=l0oooo00D0oooo00<0gia80000
M02oool0=`3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool01P3oool00`3o
_g@0B9cO0?ooo`050?ooo`030=nLB00007@0_ooo03H0oooo00<000000?ooo`3oool0o`3ooolQ0?oo
o`030?l0003oool0oooo04T0oooo00<000000?ooo`3oool08@3oool002/0oooo00<0oknL09cOo`3o
ool01P3oool00`2oM7@0_ooo0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000
oooo0?ooo`060?ooo`030?noW02Lgol0oooo00H0oooo00<0_gAd0;ooo`3oool0=@3oool00`000000
oooo0?ooo`3o0?ooob40oooo00<0o`000?ooo`3oool0B@3oool00`000000oooo0?ooo`0Q0?ooo`00
K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`3o0?ooob40oooo00<0o`000?ooo`3oool0B@3oool00`000000oooo0?ooo`0Q0?ooo`00K@3o
ool200000?l0ooooK03oool3000004T0oooo0`00003o0?ooob00oooo00<0o`000?ooo`3oool0B@3o
ool2000002<0oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0:
0?ooo`030=nLB000B9`0gooo00@0oooo00<0giad04Q8M02oool0<`3oool00`000000oooo0?ooo`3o
0?ooob00oooo00<0o`000?ooo`3oool0BP3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool00`3o
oml0W7BL0=ooo`060?ooo`030=nLW02oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooom]0?oo
o`030000003oool0oooo00T0oooo00<0okmd001d_`3oool0103oool0102oM000B9bL07@0M02ooolc
0?ooo`030000003oool0oooo0?l0oooo7`3oool00`3o0000oooo0?ooo`1;0?ooo`030000003oool0
oooo0240oooo000^0?ooo`030?noM0000000000000H0000000<0001d0;ooo`3oool0<`3oool00`00
0000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool02@3oool00`3OW4P0B9cO0?ooo`020?oo
o`060?oog`2LB000M;oo0?oo_`1d07@0_ooo<`3oool00`000000oooo0?ooo`3o0?oooal0oooo00<0
o`000?ooo`3oool0B`3oool00`000000oooo0?ooo`0Q0?ooo`00=`3oool00`3OW9`0_ooo0?ooo`0c
0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`090?ooo`0;0?noM00004P0
W=oo0?ooo`3o_g@0001809cOo`3oool0omnL04P0M02oool0<`3oool00`000000oooo0?ooo`3o0?oo
oah0oooo00<0o`000?ooo`3oool0C03oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000
oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool02P3oool0103OW4P0000000000000M;l20?oo
o`040?oog`2LB00004RL0=oooc<0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`030?l0003oool0
oooo04`0oooo00<000000?ooo`3oool08@3oool005l0oooo00@0_g@0000000000000B9cO2P3oool0
0`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o
0?oooah0oooo00<0o`000?ooo`3oool0C03oool00`000000oooo0?ooo`0Q0?ooo`00G@3oool01`3o
oml0W4P0001d_`3oool0oooO09a80000M;l02@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?oooah0oooo00<0o`000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0Q0?ooo`00;03oool00`3o_g@0000000000004000000030000M02oool0
oooo02L0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`070?ooo`030?noM0000000000000@0000000<0001d
0;ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?oooad0oooo00<0o`000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0Q0?ooo`00:P3oool00`3OW4P0000000000008000000030000B02Lgol0oooo
02@0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`080?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`050?ooo`030=nLB0000000000000P0000000<00018
09cOo`3oool0=03oool00`000000oooo0?ooo`3o0?oooa/0oooo0P3o001@0?ooo`030000003oool0
oooo0240oooo000Y0?ooo`040;md00000000000007Boo`L0oooo00@0_g@0000000000000B9cO903o
ool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00L0oooo00<000000?ooo`3oool0o`3o
oom]0?ooo`030000003oool0oooo00@0oooo00@0_g@0000000000000M;oo1`3oool0102oM0000000
00000018W=ld0?ooo`030000003oool0oooo0?l0oooo6@3oool20?l00580oooo00<000000?ooo`3o
ool08@3oool002P0oooo00<0_g@0001d_`3oool02`3oool00`3ooml0W4P004RLg`0S0?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000M02oool01`3oool3000000D0ooooo`3o001P0?l000D0oooo
100000050?ooo`030;md0000M;l0oooo00/0oooo00<0oooO09a80018W=l0<`3oool300000?l0oooo
4`3oool60?l005<0oooo0P00000S0?ooo`009`3oool00`3o_g@0M;oo0?ooo`0>0?ooo`030=nLM02L
gol0oooo0240oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`030000003o
ool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`020?ooo`030?noM01d_ol0oooo00h0oooo00<0
giad09cOo`3oool0<@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo2P3o001J0?ooo`030000003o
ool0oooo0240oooo000W0?ooo`030?noW02Lgol0oooo0380oooo00<0omnL04P00018W=l0103oool0
0`3OW4P0001809cOo`070?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`02
0?ooo`030?noW02Lgol0oooo0480oooo00<000000?ooo`3oool0o`3oool20?ooo`L0o`00I03oool0
0`000000oooo0?ooo`0Q0?ooo`009`3oool00`3o_g@0M;oo0?ooo`0:0?ooo`030=nLW02oool0oooo
02D0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`020?ooo`030?noM01d_ol0oooo00X0oooo00<0gibL0;oo
o`3oool0=@3oool00`000000oooo0?ooo`3o0?ooo`80o`00J`3oool00`000000oooo0?ooo`0Q0?oo
o`009`3oool00`3o_g@004RL0=ooo`0:0?ooo`030;mdM02oool0oooo02H0oooo00<0_g@00018W03O
ool00P3oool00`3ooml0W4P0001d_`080?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000
oooo0?ooo`020?ooo`030?noM000B9`0gooo00X0oooo00<0_gAd0;ooo`3oool0=@3oool00`000000
oooo0?ooo`3k0?ooo`@0o`00K@3oool00`000000oooo0?ooo`0Q0?ooo`009`3oool00`3o_g@00000
0000000:000000030000M02oool0oooo02H0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`080?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`020?ooo`030?no
M0000000000000X0000000<0001d0;ooo`3oool0=@3oool00`000000oooo0?ooo`3i0?ooo`80o`00
L@3oool00`000000oooo0?ooo`0Q0?ooo`00:03oool0102oM00000000000B02Lgol80?ooo`030;md
M02oool0oooo02L0oooo00H0_g@00018W03Oool0oooo0;md0000M;l90?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`030?ooo`040;md00000000001809cOo`P0oooo00<0_gAd
0;ooo`3oool0=@3oool00`000000oooo0?ooo`3g0?ooo`80o`00L`3oool00`000000oooo0?ooo`0Q
0?ooo`00:@3oool0103OW4P000000000001d_ol70?ooo`030=nLW02oool0oooo02P0oooo00@0_g@0
00000000000007Bo2P3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0103o
ool0103OW4P000000000001d_ol70?ooo`030=nLW02oool0oooo03D0oooo00<000000?ooo`3oool0
mP3oool00`3o0000oooo0?ooo`1c0?ooo`030000003oool0oooo0240oooo000Z0?ooo`040?noM000
00000000001d_cl0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo00D0oooo
00@0okmd00000000000007Bo?P3oool00`000000oooo0?ooo`3d0?ooo`80o`00MP3oool00`000000
oooo0?ooo`0Q0?ooo`00:`3oool01@3ogi`0B00000000000B9`0gooo03d0oooo00<000000?ooo`3o
ool0o`3ooom]0?ooo`030000003oool0oooo00H0oooo00D0omnL04P00000000004RL0=ooo`0l0?oo
o`030000003oool0oooo0?<0oooo00<0o`000?ooo`3oool0MP3oool00`000000oooo0?ooo`0Q0?oo
o`00;03oool01@3ookl0M0000000000004P0W=oo03`0oooo00<000000?ooo`3oool0o`3ooom]0?oo
o`030000003oool0oooo00L0oooo00D0oono07@000000000001809cOo`0k0?ooo`030000003oool0
oooo0?80oooo00<0o`000?ooo`3oool0M`3oool00`000000oooo0?ooo`0Q0?ooo`00;@3oool01@3o
oml0W4P0000000000000M;oo03/0oooo0P00003o0?ooof`0oooo0`00000:0?ooo`050?oog`2LB000
00000000001d_ol0>P3oool300000?40oooo00<0o`000?ooo`3oool0M`3oool2000002<0oooo000W
0?ooo`030?noW02Lgol0oooo00D0oooo00@0_g@000000000000007Bo>P3oool00`000000oooo0?oo
o`3o0?ooofd0oooo00<000000?ooo`3oool00P3oool00`3o_i`0W=oo0?ooo`050?ooo`040;md0000
00000000001d_cT0oooo00<000000?ooo`3oool0l03oool00`3o0000oooo0?ooo`1i0?ooo`030000
003oool0oooo0240oooo000W0?ooo`030?noM01d_ol0oooo00H0oooo00D0gia800000000000004RL
0=ooo`0h0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`020?ooo`030?no
M01d_ol0oooo00H0oooo00D0gia800000000000004RL0=ooo`0g0?ooo`030000003oool0oooo0>l0
oooo00<0o`000?ooo`3oool0NP3oool00`000000oooo0?ooo`0Q0?ooo`009`3oool00`3o_g@00000
0000000:000000030000B02Lgol0oooo03H0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000
003oool0oooo0080oooo00<0okmd0000000000002P0000000`0004P0W=oo0?ooo`0e0?ooo`030000
003oool0oooo0>h0oooo00<0o`000?ooo`3oool0N`3oool00`000000oooo0?ooo`0Q0?ooo`009`3o
ool00`3o_g@0M;oo0?ooo`130?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?oo
o`020?ooo`030?noM01d_ol0oooo0480oooo00<000000?ooo`3oool0kP3oool00`3o0000oooo0?oo
o`1k0?ooo`030000003oool0oooo0240oooo000W0?ooo`030?noW02Lgol0oooo04<0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo0080oooo00<0oknL09cOo`3oool09P3oool0
102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00H0oooo00<0okmd0000001d_ol0203o
ool00`000000oooo0?ooo`3]0?ooo`030?l0003oool0oooo07`0oooo00<000000?ooo`3oool08@3o
ool002L0oooo00<0okmd07Boo`3oool03P3oool00`2oM4P0W=oo0?ooo`0b0?ooo`030000003oool0
oooo0?l0ooooK@3oool00`000000oooo0?ooo`020?ooo`030?noM01d_ol0oooo00h0oooo00<0_gA8
09cOo`3oool04`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P00000
04RLg`060?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0k03oool00`3o0000oooo
0?ooo`1m0?ooo`030000003oool0oooo0240oooo000X0?ooo`030;md0000M;l0oooo00/0oooo00<0
oooO09a8001d_ol0=03oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool00`3o
ool00`2oM00007Bo0?ooo`0;0?ooo`030?oog`2LB000M;oo01D0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`0;0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0j`3o
ool00`3o0000oooo0?ooo`1n0?ooo`030000003oool0oooo0240oooo000Y0?ooo`040;md00000000
000007Boo`L0oooo00@0_g@0000000000000B9cO=@3oool00`000000oooo0?ooo`3o0?ooofd0oooo
00<000000?ooo`3oool0103oool0102oM00000000000001d_ol70?ooo`040;md00000000000004RL
gaD0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB0000000
000000D0000000<0001809cOo`3oool01@3oool00`000000oooo0?ooo`3[0?ooo`030?l0003oool0
oooo07h0oooo00<000000?ooo`3oool08@3oool002X0oooo00<0gia8000000000000200000000`00
04P0W=oo0?ooo`0e0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`050?oo
o`030=nLB0000000000000P0000000<0001809cOo`3oool05@3oool00`3ookl0M000001d_`040?oo
o`030;md000007@0_ooo00D0oooo00<0omnL04Qd_`3oool00P3oool00`3o_g@0000007Boo`080?oo
o`030000003oool0oooo0>X0oooo00<0o`000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Q0?oo
o`00;03oool00`3o_g@0000000000004000000030000M02oool0oooo03L0oooo00<000000?ooo`3o
ool0o`3ooom]0?ooo`030000003oool0oooo00L0oooo00<0okmd000000000000100000000`0007@0
_ooo0?ooo`0:0?ooo`030;md00000000000000L0000000H0B9cO0?ooo`3oool0omnL04P00018W=l4
0?ooo`030;md000007@0_ooo00H0oooo00L0gia807Boo`3oool0oooo0?noM0000000M;oo00P0oooo
00<000000?ooo`3oool0jP3oool00`3o0000oooo0?ooo`1o0?ooo`030000003oool0oooo0240oooo
001]0?ooo`800000o`3ooom/0?ooo`<00000:P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo00H0oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo00P0oooo1000003X0?ooo`03
0?l0003oool0oooo07h0oooo0`00000S0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo
00<000000?ooo`3oool0:03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo
00H0okmd001d_`3oool0okmd0000001d_ol80?ooo`030000003oool0oooo0>P0oooo00<0o`000?oo
o`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0
oooo00<000000?ooo`3oool0:03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00P0
oooo00D0_g@007Boo`3o_g@0000007Boo`080?ooo`030000003oool0oooo0>P0oooo00<0o`000?oo
o`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0
oooo00<000000?ooo`3oool0:@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0
oooo00D0oono07@0M02o_g@0000007Boo`080?ooo`030000003oool0oooo0>L0oooo00<0o`000?oo
o`3oool0PP3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0
oooo00<000000?ooo`3oool0:@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00X0
oooo00@0okmd000000000000M;oo203oool00`000000oooo0?ooo`3W0?ooo`030?l0003oool0oooo
0880oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`03
0000003oool0oooo02X0oooo00H0_g@00018W03Oool0oooo0;md0000M;l;0?ooo`040?oog`2LB000
000007Boo`P0oooo00<000000?ooo`3oool0iP3oool00`3o0000oooo0?ooo`230?ooo`030000003o
ool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0[
0?ooo`040;md000000000000001d_`d0oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?oo
o`3V0?ooo`030?l0003oool0oooo08<0oooo00<000000?ooo`3oool08@3oool006d0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0i@3oool0
0`3o0000oooo0?ooo`240?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0>D0oooo00<0o`000?oo
o`3oool0Q03oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3U0?ooo`030?l0003oool0oooo08@0
oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0i03oool00`3o0000oooo0?ooo`250?ooo`030000
003oool0oooo0240oooo001]0?ooo`800000o`3ooom/0?ooo`<00000B@3oool300000>@0oooo00<0
o`000?ooo`3oool0Q03oool2000002<0oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo0><0oooo00<0o`000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`3S0?ooo`030?l0003oool0oooo08H0oooo00<000000?oo
o`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0hP3oool00`3o0000oooo0?ooo`270?ooo`030000003oool0oooo0240
oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo0>80oooo00<0o`000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0Q0?ooo`00K@3o
ool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`3Q0?ooo`030?l0003oool0oooo08P0oooo00<000000?ooo`3oool08@3oool006d0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0h@3oool0
0`3o0000oooo0?ooo`280?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0>40oooo00<0o`000?oo
o`3oool0R03oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3P0?ooo`030?l0003oool0oooo08T0
oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0h03oool00`3o0000oooo0?ooo`290?ooo`030000
003oool0oooo0240oooo001]0?ooo`800000o`3ooom/0?ooo`<00000B@3oool300000>00oooo00<0
o`000?ooo`3oool0R03oool2000002<0oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo0=l0oooo00<0o`000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`3O0?ooo`030?l0003oool0oooo08X0oooo00<000000?oo
o`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0gP3oool00`3o0000oooo0?ooo`2;0?ooo`030000003oool0oooo0240
oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo0=h0oooo00<0o`000?ooo`3oool0R`3oool00`000000oooo0?ooo`0Q0?ooo`00K@3o
ool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`3N0?ooo`030?l0003oool0oooo08/0oooo00<000000?ooo`3oool08@3oool00500oooo00@0_g@0
000000000000B9cO103oool00`3OW4P0000004RLg`020?ooo`060;md00000000000000000000B9`0
gooo2P3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`3M0?ooo`030?l0003oool0oooo08`0oooo00<000000?ooo`3oool08@3oool004h0oooo
00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00L0gia800000018W=l0oooo0?oog`2L
B000B9cO0080oooo00<0omnL04Q8W03Oool02@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`3M0?ooo`030?l0003oool0oooo08`0oooo00<0
00000?ooo`3oool08@3oool004h0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0<
0?ooo`030?oOW018M;l0oooo00P0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0g@3oool00`3o0000oooo0?ooo`2<0?ooo`030000003oool0
oooo0240oooo001=0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0303oool0
0`3ookl0M01809cOo`080?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo0=`0oooo00<0o`000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Q
0?ooo`00C@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0oono07@0
001d_ol0203oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`3L0?ooo`030?l0003oool0oooo08d0oooo00<000000?ooo`3oool08@3oool004d0
oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0;0?ooo`030?noM0000000M;oo00P0
oooo0`00003o0?ooofX0oooo100000190?ooo`<00000f`3oool00`3o0000oooo0?ooo`2=0?ooo`80
00008`3oool004d0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`040?oO
W0180000001d0;ooo`P0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0f`3oool00`3o0000oooo0?ooo`2>0?ooo`030000003oool0oooo0240
oooo001=0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool0103Ogml0oooo
0?ooo`2oM0020000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0f`3oool00`3o0000oooo0?ooo`2>0?ooo`03
0000003oool0oooo0240oooo001=0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
1P3oool00`3o_g@000000000000200000003001d_`3oool0oooo00P0oooo00<000000?ooo`3oool0
o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0fP3oool00`3o0000oooo
0?ooo`2?0?ooo`030000003oool0oooo0240oooo001>0?ooo`030;md0000B9`0gooo0080oooo00<0
oooO09a80000M;l01`3oool01@3ooml0W4P00000000007@0_ooo00/0oooo00<000000?ooo`3oool0
o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0fP3oool00`3o0000oooo
0?ooo`2?0?ooo`030000003oool0oooo0240oooo001>0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol0203oool00`3o_g@007Bo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooK@3o
ool00`000000oooo0?ooo`0[0?ooo`040;md00000000000004RLg`@0oooo00D0gia800000018W=l0
oooo0=nLB0070000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0fP3oool00`3o0000
oooo0?ooo`2?0?ooo`030000003oool0oooo0240oooo001?0?ooo`060;md0000B9`0gooo0?ooo`2o
M00007Bo2@3oool00`3ooml0W4P000000002000000030000M02oool0oooo00L0oooo00<000000?oo
o`3oool0o`3ooom]0?ooo`030000003oool0oooo02T0oooo00L0oooO09a80000M;l0oooo0?oog`2L
B00007Bo00<0oooo00<0gia800000018W=l00P3oool00`3OW4P000000000000400000003001d_`3o
ool0oooo00D0oooo00<000000?ooo`3oool0f@3oool00`3o0000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0240oooo001@0?ooo`040;md000000000000001d_`/0oooo00<0okmd0000000000000P00
00000`1d_ol0oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?oo
o`0Y0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`3OW4P0B9cO0?oo
o`020?ooo`030?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0f@3oool00`3o0000oooo0?oo
o`2@0?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool0
0`000000oooo0?ooo`0X0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02@3o
ool00`3OW4P0B9cO0?ooo`0:0?ooo`030000003oool0oooo0=T0oooo00<0o`000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<00000
0?ooo`3oool0:03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00T0oooo00<0gia8
07Boo`3oool02@3oool00`000000oooo0?ooo`3H0?ooo`030?l0003oool0oooo0940oooo00<00000
0?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo
01/0oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0
_g@00000M02oool02@3oool00`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo0=P0oooo00<0
o`000?ooo`3oool0T@3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool200000?l0ooooK03oool3
000002X0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`030?oOW01807@0
_ooo00P0oooo1000003G0?ooo`030?l0003oool0oooo08l0oooo0`00000S0?ooo`00K@3oool00`00
0000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0:03oool00`3ogi`0B00004RLg`040?oo
o`030=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3oool01`3oool00`000000oooo0?ooo`3G0?oo
o`030?l0003oool0oooo0980oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3o
ool0o`3ooom]0?ooo`030000003oool0oooo02P0oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`0;0?ooo`030=nLB00007@0_ooo00L0oooo00<000000?ooo`3oool0e`3oool00`3o0000
oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0oooo
K@3oool00`000000oooo0?ooo`0Y0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0
303oool00`3o_g@0000007Boo`070?ooo`030000003oool0oooo0=H0oooo00<0o`000?ooo`3oool0
T`3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<0
00000?ooo`3oool0:@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0
omnL09boo`3oool00`3oool00`2oM000000007Boo`070?ooo`030000003oool0oooo0=H0oooo00<0
o`000?ooo`3oool0T`3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o
0?ooofd0oooo00<000000?ooo`3oool0:P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo
00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo`L0oooo00<000000?ooo`3oool0eP3oool0
0`3o0000oooo0?ooo`2C0?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo
0?l0ooooK@3oool00`000000oooo0?ooo`0[0?ooo`040;md000000000000001d_`X0oooo00D0_g@0
0000000000000000001d_`090?ooo`030000003oool0oooo0=D0oooo00<0o`000?ooo`3oool0U03o
ool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`3E0?ooo`030?l0003oool0oooo09@0oooo00<00000
0?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0e@3oool00`3o0000oooo0?ooo`2D0?ooo`030000003oool0oooo
0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0=@0oooo00<0o`000?ooo`3oool0U@3oool00`000000oooo0?ooo`0Q0?ooo`00
K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`3D0?ooo`030?l0003oool0oooo09D0oooo00<000000?ooo`3oool08@3oool006d0oooo0P00
003o0?ooof`0oooo0`0000190?ooo`<00000e03oool00`3o0000oooo0?ooo`2D0?ooo`8000008`3o
ool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0d`3oool00`3o0000oooo0?ooo`2F0?ooo`030000003oool0oooo0240oooo001]0?oo
o`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0=<0oooo00<0o`000?ooo`3oool0UP3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000
oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3B0?ooo`03
0?l0003oool0oooo09L0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0
o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0dP3oool00`3o0000oooo
0?ooo`2G0?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0=40oooo00<0o`000?ooo`3oool0V03o
ool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`3A0?ooo`030?l0003oool0oooo09P0oooo00<00000
0?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0d03oool00`3o0000oooo0?ooo`2I0?ooo`030000003oool0oooo
0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0=00oooo00<0o`000?ooo`3oool0V@3oool00`000000oooo0?ooo`0Q0?ooo`00
K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`3?0?ooo`030?l0003oool0oooo09X0oooo00<000000?ooo`3oool08@3oool006d0oooo00<0
00000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0cP3o
ool00`3o0000oooo0?ooo`2K0?ooo`030000003oool0oooo0240oooo001]0?ooo`800000o`3ooom/
0?ooo`<00000B@3oool300000<h0oooo00<0o`000?ooo`3oool0VP3oool2000002<0oooo001]0?oo
o`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0<d0oooo00<0o`000?ooo`3oool0W03oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000
oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3=0?ooo`03
0?l0003oool0oooo09`0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0
o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0c03oool00`3o0000oooo
0?ooo`2M0?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0<`0oooo00<0o`000?ooo`3oool0W@3o
ool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`3;0?ooo`030?l0003oool0oooo09h0oooo00<00000
0?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0bP3oool00`3o0000oooo0?ooo`2O0?ooo`030000003oool0oooo
0240oooo001]0?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0<X0oooo00<0o`000?ooo`3oool0W`3oool00`000000oooo0?ooo`0Q0?ooo`00
K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`390?ooo`030?l0003oool0oooo0:00oooo00<000000?ooo`3oool08@3oool006d0oooo00<0
00000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0b03o
ool00`3o0000oooo0?ooo`2Q0?ooo`030000003oool0oooo0240oooo001]0?ooo`800000o`3ooom/
0?ooo`<00000B@3oool300000<L0oooo00<0o`000?ooo`3oool0X@3oool2000002<0oooo001]0?oo
o`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0<D0oooo0P3o002U0?ooo`030000003oool0oooo0240oooo001]0?ooo`030000003oool0oooo0?l0
ooooK@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0<@0oooo00<0o`000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`3o0?ooofd0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`330?ooo`030?l0003oool0oooo0:H0oooo
00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0`P3oool00`3o0000oooo0?ooo`2W0?ooo`030000003o
ool0oooo0240oooo001N0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0>P3oool0102oM000000000000018
W=l90?ooo`030000003oool0oooo0<40oooo00<0o`000?ooo`3oool0Z03oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooK@3oool0
0`000000oooo0?ooo`0h0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`080?ooo`030000
003oool0oooo0;l0oooo0P3o002[0?ooo`030000003oool0oooo0240oooo001P0?ooo`030;md0000
07@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo03P0oooo00<0
okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030000003oool0oooo0;`0oooo0`3o
002]0?ooo`030000003oool0oooo0240oooo001P0?ooo`030;md000007@0_ooo00X0oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo03L0oooo00@0oooO09a80000B9`0gooo0P3o
ool00`3ooml0W4P0001d_`070?ooo`030000003oool0oooo0;T0oooo0`3o002`0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom]
0?ooo`030000003oool0oooo03L0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`06
0?ooo`030000003oool0oooo0;D0oooo103o002c0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000003oool0oooo
03L0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`060?ooo`030000003oool0oooo
0:/0oooo2P3o002g0?ooo`030000003oool0oooo0240oooo001P0?ooo`030;md000007@0_ooo00X0
oooo0`00003o0?ooofX0oooo1000000i0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol01P3oool4000000D0ooooY@3o002o0?ooo`<000008`3oool00600oooo00<0_g@00000M02oool0
2P3oool00`000000oooo0?ooo`3o0?ooofd0oooo00<000000?ooo`3oool0=`3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`030000
003oool0oooo0240oooo001P0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3o
oom]0?ooo`030000003oool0oooo03L0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;oo
o`060?ooo`030000003oool0oooo0?l0ooooK@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool0
0`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03P0oooo00<0_g@00018W03Oool00P3oool0
0`3ooml0W4P0001d_`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo001P0?ooo`030;md000007@0_ooo
00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
03P0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`00GP3oool01@3OW4P0
00000000000007@0_ooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo03T0oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`00G`3oool0
103ookl0M0000000M02oool:0?ooool00000L@00000l0?ooo`040;md000000000000001d_`T0oooo
o`00001a000002<0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool0
0?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo
_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3ooooo0?oo
ool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?ooo`00o`3o
oooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3ooonl0?oo
o`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0ooooo`3o
oonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00?l0ooooo`3ooooo0?oook`0oooo003o0?ooool0
ooooo`3ooonl0?ooo`00o`3ooooo0?ooool0oooo_03oool00001\
\>"],
  ImageRangeCache->{{{0, 952.625}, {588.375, 0}} -> {-0.0506812, -0.0309082, \
0.00220587, 0.00220587}, {{22.9375, 487.938}, {574.313, 287}} -> {-41.4353, \
-0.67777, 0.103044, 0.00926268}, {{464.688, 929.625}, {574.313, 287}} -> \
{-86.9517, -0.338885, 0.103044, 0.00463134}, {{22.9375, 487.938}, {301.313, \
14}} -> {-42.1534, -4.20648, 0.103044, 0.00926268}, {{464.688, 929.625}, \
{301.313, 14}} -> {-87.6698, -2.60324, 0.103044, 0.00463134}}]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ About\ Fig . \ 3\ *) \),
      FontSize->18]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fig3x1x2 = 
        ParametricPlot[{xx1[N], xx2[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] {{\(-5\), 1}, {\(-2\), 4}}, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {\*"\"\<\!\(x\_1\)\>\"", \
\*"\"\<\!\(x\_2\)\>\""}];\)\), "\[IndentingNewLine]", 
    \(\(fig3x3x4 = 
        ParametricPlot[{x3[N], xx4[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] {{\(-1\), 3}, {\(-1\), 2}}, 
          DisplayFunction \[Rule] Identity, PlotStyle \[Rule] Hue[0], 
          Axes \[Rule] False, 
          FrameLabel \[Rule] {\*"\"\<\!\(x\_3\)\>\"", \
\*"\"\<\!\(x\_4\)\>\""}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{fig3x1x2, fig3x3x4}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] \(-0.05\)];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig3_x1x2\>" <> "\<.m\>", 
        fig3x1x2];\)\), "\[IndentingNewLine]", 
    \(\(Export[flnm <> "\<_fig3_x3x4\>" <> "\<.m\>", fig3x3x4];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .31694 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0075462 0.47619 [
[ 0 0 0 0 ]
[ 1 .31694 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .31694 L
0 .31694 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0075462 0.51221 0.309394 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.833333 0.166667 0.206011 0.103006 [
[.16667 -0.0125 -14 -24.5625 ]
[.16667 -0.0125 14 0 ]
[.33333 -0.0125 -14 -24.5625 ]
[.33333 -0.0125 14 0 ]
[.5 -0.0125 -14 -24.5625 ]
[.5 -0.0125 14 0 ]
[.66667 -0.0125 -14 -24.5625 ]
[.66667 -0.0125 14 0 ]
[.83333 -0.0125 -7.03125 -24.5625 ]
[.83333 -0.0125 7.03125 0 ]
[1 -0.0125 -7.03125 -24.5625 ]
[1 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -10.8125 -49.125 ]
[.5 -0.0125 10.8125 -24.5625 ]
[-0.0125 .10301 -28 -12.2813 ]
[-0.0125 .10301 0 12.2813 ]
[-0.0125 .20601 -14.0625 -12.2813 ]
[-0.0125 .20601 0 12.2813 ]
[-0.0125 .30902 -14.0625 -12.2813 ]
[-0.0125 .30902 0 12.2813 ]
[-0.0125 .41202 -14.0625 -12.2813 ]
[-0.0125 .41202 0 12.2813 ]
[-0.0125 .51503 -14.0625 -12.2813 ]
[-0.0125 .51503 0 12.2813 ]
[-0.0125 .61803 -14.0625 -12.2813 ]
[-0.0125 .61803 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -52.5625 -10.8125 ]
[-0.01875 .30902 -28 10.8125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -75 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -71.8125 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .20601 m
.00625 .20601 L
s
gsave
-0.0125 .20601 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .41202 m
.00625 .41202 L
s
gsave
-0.0125 .41202 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .51503 m
.00625 .51503 L
s
gsave
-0.0125 .51503 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -112.094 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.8125 16.2813 translate
90 rotate
-71.8125 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.03333 .61428 m
.03333 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.13333 .61428 m
.13333 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.23333 .61428 m
.23333 .61803 L
s
.26667 .61428 m
.26667 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.43333 .61428 m
.43333 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.53333 .61428 m
.53333 .61803 L
s
.56667 .61428 m
.56667 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.76667 .61428 m
.76667 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.93333 .61428 m
.93333 .61803 L
s
.96667 .61428 m
.96667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.83333 .20601 m
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
Mistroke
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
Mistroke
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
Mistroke
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
Mistroke
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
Mistroke
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .20601 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
Mistroke
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .206 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20599 L
.83333 .20598 L
.83333 .20598 L
.83333 .20598 L
.83333 .20598 L
.83333 .20598 L
.83333 .20598 L
.83333 .20598 L
.83333 .20598 L
.83333 .20597 L
.83333 .20597 L
.83333 .20597 L
.83333 .20597 L
.83333 .20597 L
.83333 .20596 L
.83333 .20596 L
.83333 .20596 L
.83333 .20596 L
.83333 .20595 L
.83333 .20595 L
.83333 .20595 L
.83333 .20594 L
.83333 .20594 L
.83333 .20594 L
Mistroke
.83333 .20594 L
.83333 .20593 L
.83333 .20593 L
.83333 .20592 L
.83333 .20592 L
.83333 .20592 L
.83333 .20591 L
.83333 .20591 L
.83333 .2059 L
.83333 .2059 L
.83333 .20589 L
.83333 .20588 L
.83333 .20588 L
.83333 .20587 L
.83333 .20587 L
.83333 .20586 L
.83333 .20586 L
.83333 .20585 L
.83333 .20584 L
.83333 .20583 L
.83333 .20582 L
.83333 .20581 L
.83333 .2058 L
.83333 .20579 L
.83333 .20578 L
.83333 .20577 L
.83333 .20576 L
.83333 .20574 L
.83333 .20573 L
.83333 .20571 L
.83333 .2057 L
.83333 .20569 L
.83333 .20568 L
.83333 .20566 L
.83333 .20564 L
.83333 .20562 L
.83333 .2056 L
.83333 .20558 L
.83333 .20556 L
.83333 .20554 L
.83333 .20552 L
.83333 .2055 L
.83333 .20548 L
.83333 .20545 L
.83333 .20542 L
.83333 .20539 L
.83333 .20536 L
.83333 .20533 L
.83333 .20531 L
.83333 .20529 L
Mistroke
.83333 .20526 L
.83333 .20522 L
.83333 .20518 L
.83333 .20515 L
.83333 .20513 L
.83333 .20509 L
.83333 .20504 L
.83333 .20499 L
.83333 .20495 L
.83333 .2049 L
.83333 .20484 L
.83333 .20478 L
.83333 .20474 L
.83333 .20471 L
.83333 .20463 L
.83333 .20459 L
.83333 .20455 L
.83333 .20448 L
.83333 .2044 L
.83333 .20431 L
.83333 .20423 L
.83333 .20416 L
.83333 .20407 L
.83333 .20398 L
.83333 .2039 L
.83333 .2038 L
.83333 .20369 L
.83333 .20358 L
.83333 .20347 L
.83333 .20334 L
.83333 .20321 L
.83333 .20309 L
.83333 .20296 L
.83333 .20281 L
.83333 .20264 L
.83333 .20249 L
.83333 .20232 L
.83333 .20213 L
.83333 .20194 L
.83333 .20184 L
.83333 .20173 L
.83333 .20161 L
.83333 .20149 L
.83333 .20127 L
.83333 .20106 L
.83333 .20081 L
.83333 .20055 L
.83333 .20032 L
.83333 .20006 L
.83333 .19981 L
Mistroke
.83333 .19957 L
.83333 .19928 L
.83333 .19895 L
.83333 .19863 L
.83333 .19832 L
.83333 .19799 L
.83333 .19761 L
.83333 .19724 L
.83333 .1969 L
.83333 .19648 L
.83333 .19623 L
.83333 .196 L
.83333 .19557 L
.83333 .19535 L
.83333 .1951 L
.83333 .19485 L
.83333 .19459 L
.83333 .1941 L
.83333 .19383 L
.83333 .19357 L
.83333 .19328 L
.83333 .19296 L
.83333 .19268 L
.83333 .19238 L
.83333 .19208 L
.83333 .19181 L
.83333 .19129 L
.83333 .19072 L
.83333 .19016 L
.83333 .18955 L
.83333 .18896 L
.83333 .1884 L
.83333 .18784 L
.83333 .18733 L
.83333 .18673 L
.83333 .18615 L
.83333 .18552 L
.83333 .18484 L
.83333 .18426 L
.83333 .18361 L
.83333 .18291 L
.83333 .18251 L
.83333 .18215 L
.83333 .18145 L
.83333 .18078 L
.83333 .18022 L
.83333 .17959 L
.83333 .17894 L
.83333 .17832 L
.83333 .17776 L
Mistroke
.83333 .17724 L
.83333 .17667 L
.83333 .17608 L
.83333 .17548 L
.83333 .17485 L
.83333 .17426 L
.83333 .17372 L
.83333 .17311 L
.83333 .17276 L
.83333 .17245 L
.83333 .17187 L
.83333 .17128 L
.83333 .17071 L
.83333 .1701 L
.83333 .16954 L
.83333 .16902 L
.83333 .16853 L
.83333 .16809 L
.83333 .16759 L
.83333 .16713 L
.83333 .16665 L
.83333 .16614 L
.83333 .16573 L
.83333 .16528 L
.83333 .16482 L
.83333 .16457 L
.83333 .16434 L
.83333 .16391 L
.83333 .16352 L
.83333 .1632 L
.83333 .16285 L
.83333 .1625 L
.83333 .16218 L
.83333 .1619 L
.83333 .16164 L
.83333 .16136 L
.83333 .1611 L
.83333 .16083 L
.83333 .16055 L
.83333 .16029 L
.83333 .16007 L
.83333 .15982 L
.83333 .15968 L
.83333 .15956 L
.83333 .15934 L
.83333 .15912 L
.83333 .15891 L
.83333 .15879 L
.83333 .15869 L
.83333 .1585 L
Mistroke
.83333 .15832 L
.83333 .15815 L
.83333 .15801 L
.83333 .15786 L
.83333 .1577 L
.83333 .15755 L
.83333 .15746 L
.83333 .15739 L
.83333 .15724 L
.83333 .15716 L
.83333 .15709 L
.83333 .15697 L
.83333 .15685 L
.83333 .15674 L
.83333 .15664 L
.83333 .15655 L
.83333 .15646 L
.83333 .15637 L
.83333 .1563 L
.83333 .15622 L
.83333 .15614 L
.83333 .15606 L
.83333 .15599 L
.83333 .15592 L
.83333 .15585 L
.83333 .1558 L
.83333 .15574 L
.83333 .15568 L
.83333 .15562 L
.83333 .15557 L
.83333 .15552 L
.83333 .15546 L
.83333 .15542 L
.83333 .15539 L
.83333 .15537 L
.83333 .15534 L
.83333 .15532 L
.83333 .15528 L
.83333 .15524 L
.83333 .1552 L
.83333 .15517 L
.83333 .15514 L
.83333 .15511 L
.83333 .15508 L
.83333 .15505 L
.83333 .15503 L
.83333 .155 L
.83333 .15497 L
.83333 .15495 L
.83333 .15493 L
Mistroke
.83333 .1549 L
.83333 .15488 L
.83333 .15486 L
.83333 .15484 L
.83333 .15483 L
.83333 .15482 L
.83333 .1548 L
.83333 .15479 L
.83333 .15478 L
.83333 .15477 L
.83333 .15476 L
.83333 .15474 L
.83333 .15473 L
.83333 .15472 L
.83333 .15471 L
.83333 .15469 L
.83333 .15468 L
.83333 .15467 L
.83333 .15466 L
.83333 .15465 L
.83333 .15463 L
.83333 .1546 L
.83333 .15458 L
.83333 .15455 L
.83333 .15452 L
.83333 .15449 L
.83333 .15446 L
.83333 .15442 L
.83333 .15438 L
.83333 .15434 L
.83333 .15428 L
.83333 .15421 L
.83333 .15415 L
.83333 .15406 L
.83333 .15396 L
.83333 .1539 L
.83333 .15383 L
.83333 .15369 L
.83333 .15354 L
.83333 .15339 L
.83333 .1532 L
.83333 .15298 L
.83333 .15274 L
.83333 .15248 L
.83333 .15222 L
.83333 .1519 L
.83333 .15152 L
.83333 .15107 L
.83333 .15054 L
.83333 .14996 L
Mistroke
.83333 .14938 L
.83333 .14861 L
.83333 .14813 L
.83333 .14767 L
.83333 .14673 L
.83333 .14563 L
.83333 .14445 L
.83333 .14303 L
.83333 .14156 L
.83333 .1401 L
.83333 .13855 L
.83333 .13707 L
.83333 .13529 L
.83333 .13355 L
.83333 .13159 L
.83333 .12948 L
.83333 .12768 L
.83333 .12571 L
.83333 .12363 L
.83333 .12249 L
.83333 .12147 L
.83333 .11957 L
.83333 .11788 L
.83333 .11651 L
.83333 .11511 L
.83333 .11375 L
.83333 .11258 L
.83333 .11158 L
.83333 .11074 L
.83333 .1099 L
.83333 .1091 L
.83333 .10837 L
.83333 .10767 L
.83333 .10709 L
.83333 .10663 L
.83333 .10614 L
.83333 .10589 L
.83333 .10568 L
.83333 .10533 L
.83333 .105 L
.83333 .10473 L
.83333 .10459 L
.83333 .10447 L
.83333 .10428 L
.83333 .1041 L
.83333 .10396 L
.83333 .10384 L
.83333 .10373 L
.83333 .10363 L
.83333 .10354 L
Mistroke
.83333 .1035 L
.83333 .10346 L
.83333 .10339 L
.83333 .10336 L
.83333 .10333 L
.83333 .10328 L
.83333 .10324 L
.83333 .10321 L
.83333 .10318 L
.83333 .10316 L
.83333 .10314 L
.83333 .10312 L
.83333 .10311 L
.83333 .10309 L
.83333 .10308 L
.83333 .10307 L
.83333 .10306 L
.83333 .10305 L
.83333 .10305 L
.83333 .10304 L
.83333 .10304 L
.83333 .10303 L
.83333 .10303 L
.83333 .10303 L
.83333 .10302 L
.83333 .10302 L
.83333 .10302 L
.83333 .10302 L
.83333 .10302 L
.83333 .10302 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
Mistroke
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
Mistroke
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
Mistroke
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
.83333 .10301 L
Mistroke
.83333 .10301 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.48779 0.0075462 0.97619 0.309394 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.25 0.206011 0.206011 [
[.125 -0.0125 -21.5313 -24.5625 ]
[.125 -0.0125 21.5313 0 ]
[.25 -0.0125 -7.03125 -24.5625 ]
[.25 -0.0125 7.03125 0 ]
[.375 -0.0125 -14.5625 -24.5625 ]
[.375 -0.0125 14.5625 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.625 -0.0125 -14.5625 -24.5625 ]
[.625 -0.0125 14.5625 0 ]
[.75 -0.0125 -7.03125 -24.5625 ]
[.75 -0.0125 7.03125 0 ]
[.875 -0.0125 -14.5625 -24.5625 ]
[.875 -0.0125 14.5625 0 ]
[1 -0.0125 -7.03125 -24.5625 ]
[1 -0.0125 7.03125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -10.8125 -49.125 ]
[.5 -0.0125 10.8125 -24.5625 ]
[-0.0125 .10301 -43.0625 -12.2813 ]
[-0.0125 .10301 0 12.2813 ]
[-0.0125 .20601 -14.0625 -12.2813 ]
[-0.0125 .20601 0 12.2813 ]
[-0.0125 .30902 -29.125 -12.2813 ]
[-0.0125 .30902 0 12.2813 ]
[-0.0125 .41202 -14.0625 -12.2813 ]
[-0.0125 .41202 0 12.2813 ]
[-0.0125 .51503 -29.125 -12.2813 ]
[-0.0125 .51503 0 12.2813 ]
[-0.0125 .61803 -14.0625 -12.2813 ]
[-0.0125 .61803 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -10.8125 ]
[-0.01875 .30902 -43.0625 10.8125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -82.5313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -75.5625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -71.8125 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
gsave
-0.0125 .10301 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .20601 m
.00625 .20601 L
s
gsave
-0.0125 .20601 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .41202 m
.00625 .41202 L
s
gsave
-0.0125 .41202 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .51503 m
.00625 .51503 L
s
gsave
-0.0125 .51503 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127.156 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.8125 16.2813 translate
90 rotate
-71.8125 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
73.063 26.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
80.625 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.25 .41202 m
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25 .41202 L
.25002 .41198 L
.25012 .41183 L
.25065 .41095 L
.25332 .40655 L
.26474 .38773 L
.30257 .32538 L
.3484 .24985 L
.36929 .21542 L
.37253 .21008 L
.37338 .2087 L
.37393 .20785 L
.37415 .20753 L
.37439 .20725 L
.37451 .20714 L
.37464 .20703 L
.37478 .20694 L
.37493 .20686 L
.37514 .20678 L
.37541 .20671 L
.37573 .20664 L
.37612 .20658 L
.37638 .20655 L
.37671 .20653 L
.37744 .20648 L
.37795 .20645 L
.3785 .20643 L
.37921 .2064 L
.3801 .20638 L
.38103 .20636 L
.382 .20634 L
.38434 .20631 L
.38595 .20629 L
.38799 .20628 L
.39263 .20625 L
.3955 .20623 L
.39915 .20622 L
.40327 .2062 L
.4084 .20619 L
.41967 .20617 L
.43305 .20615 L
.44931 .20613 L
.47067 .20611 L
Mistroke
.49257 .20609 L
.51856 .20608 L
.5719 .20605 L
.6202 .20604 L
.67053 .20602 L
.7027 .20602 L
.7242 .20601 L
.73716 .20601 L
.74283 .20601 L
.74618 .20601 L
.74805 .20601 L
.74896 .20601 L
.74944 .20601 L
.74971 .20601 L
.74986 .20601 L
.74993 .20601 L
.74998 .20601 L
.74999 .20601 L
.74999 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
Mistroke
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
Mistroke
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
.75 .20601 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{924.438, 293},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>L00019B000`400?l00000o`00003oo`3ooooo
0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3ooonO0?ooo`00
o`3ooooo0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3ooonO
0?ooo`00o`3ooooo0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0oooo
o`3ooonO0?ooo`00o`3ooooo0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?oo
oaD0oooo00D0omnL04P000000000000007Boo`3o0?ooojh0oooo00D0gia8000000000000001809cO
o`3A0?ooo`00o`3ooolF0?ooo`030?oo_`1d04P0W=oo0?l0oooo/P3oool00`3ooml0W4Q809cOo`3@
0?ooo`00o`3ooolF0?ooo`030?oo_`1d04P0W=oo0?l0oooo/`3oool00`3o_g@007Bo0?ooo`3?0?oo
o`00o`3oool:0?ooo`060;md00000000001d0;ooo`3ookl0M0000P0000001`00B9`0gooo0?ooo`3o
ool0oono07@0B02Lgol0o`3ooonU0?ooo`060;md00000000001d0;ooo`3ookl0M0000P0000000`00
B9`0gooo0?ooo`030?ooo`030=nLB000M;l0oooo0<l0oooo003o0?ooo`X0oooo00<0oooO09a8B02L
gol00P3oool00`3ogi`0B000001d_`040?ooo`030?oo_`1d04P0W=oo0?l0ooooY@3oool00`3ooml0
W4Q809cOo`020?ooo`030?oOW018000007Bo00D0oooo00<0omnL04P00018W=l0d03oool00?l0oooo
2`3oool01`3ookl0M4RL0=ooo`3ooml0W4P00018W03Oool0103oool00`3ookl0M01809cOo`3o0?oo
ojH0oooo00L0oono07A8W03Oool0oooO09a80000B9`0gooo00<0oooo00@0oooO09a80000000007Bo
d@3oool00?l0oooo303oool01@3ogi`0B7Bo0;md000004P0W=oo00D0oooo00<0oono07@0B02Lgol0
o`3ooonW0?ooo`050?oOW018M;l0_g@00000B02Lgol01P3oool00`3OW4P007Bo0?ooo`3@0?ooo`00
o`3oool=0?ooo`030?noM0000000B9cO00H0oooo00<0oono07@0B02Lgol0o`3ooonX0?ooo`030?no
M0000000B9cO00@0oooo00H0omoO0=ooo`3oool0oooo0;md001d_oo@0?ooo`00o`3oool<0?ooo`04
0?oo_`1d0000001d0;ooo`D0oooo00@0okmd0000000004P0W=ooo`3ooonW0?ooo`040?oo_`1d0000
001d0;ooo`@0oooo00H0oono07Ad_`3oool0oono07@0001d_oo@0?ooo`00o`3oool;0?ooo`060?oo
g`2LB000001809cO_`1dB9`0gooo1@3oool00`3ogi`0B01809cOo`3o0?ooojH0oooo00H0oooO09a8
000004P0W=no07A8W03Oool40?ooo`040?noM00000000000001d_m40oooo003o0?ooo`/0oooo00L0
gia80000001d_ol0oooo0?oOW018B9`0gooo0?l0oooo[@3oool01`3OW4P0000007Boo`3oool0omnL
04Q8W03Oool0f03oool00?l0oooo2@3oool02P3ooml0W4P0000000000000001d0;oog`2LB0000000
0000M02ooooo0?ooojX0oooo00X0oooO09a80000000000000000M02ooml0W4P00000000007@0_ooo
e`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3ooonO0?ooo`00o`3ooooo0?oo
ool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3ooonO0?ooo`00o`3o
oooo0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3ooonO0?oo
o`00o`3ooooo0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3o
oonO0?ooo`00o`3ooooo0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0
ooooo`3ooonO0?ooo`00o`3ooooo0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo002V
0?ooo`030?noM0000000M;oo0340oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0a
0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool0<@3oool00`3o_g@0000000000002
00000003001d_`3oool0oooo02/0oooo00@0_g@0000000000000B9cO=03oool00`3o_g@000000000
000200000003001d_`3oool0oooo07l0oooo00@0_g@0000000000000B9cO103oool00`3OW4P00000
04RLg`020?ooo`060;md00000000000000000000B9`0gooo603oool0102oM000000000000018W=lP
0?ooo`040;md00000000000004RLg`@0oooo00<0gia800000018W=l00P3oool01P2oM00000000000
0000000004RL0=oooah0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`0L0?ooo`03
0?noM000000000000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO0080oooo00H0_g@0
00000000000000000018W03OoolL0?ooo`030=nLB0000000000000D0000000<0M;oo0?ooo`3oool0
6@3oool00`3OW4P00000000000050000000607Boo`3oool0oooo0=nLB0000000B9cO0P3oool01P2o
M000000000000000000004RL0=oooa`0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?oo
o`0Y0?ooo`00YP3oool00`3o_g@0000007Boo`0a0?ooo`080?oOW018000004RL0=ooo`3oool0omnL
04P0B02Lgolb0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0<`3oool00`2oM000
001d0;ooo`0/0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`0e0?ooo`030;md000007@0
_ooo0800oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00L0gia800000018W=l0
oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool05@3oool01`3ooml0W4P0001d_`3oool0
oooO09a80000M;l07@3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool01`3OW4P0
000004RLg`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=ooo`0O0?ooo`030;md000007@0
_ooo0240oooo00<0_g@00000M02oool0103oool01`3OW4P0000004RLg`3oool0oooO09a80018W=l0
0P3oool00`3ogi`0B4RL0=ooo`0L0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0
6P3oool00`3OW4P00000000000040000000:001d_`3oool0oooo0=nLB0000000B9cO0?ooo`3ooml0
W4P004RLg`80oooo00<0omnL04Q8W03Oool06`3oool0203ogi`0B0000018W03Oool0oooo0?oOW018
04P0W=oo:@3oool00:H0oooo00<0okmd0000001d_ol0=`3oool00`3o_g@004RL0=ooo`0b0?ooo`03
0=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool0=03oool00`2oM000001d0;ooo`0/0?ooo`03
0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0=03oool00`2oM000001d0;ooo`200?ooo`03
0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0303oool00`3ogi`0B7Bo0?ooo`0D0?ooo`03
0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0703oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo00`0oooo00<0omnL04Qd_`3oool07P3oool00`2oM000001d0;ooo`0Q0?ooo`03
0;md000007@0_ooo00h0oooo00<0omnL04Qd_`3oool0703oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?oog`2LB7@0_ooo01`0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd0;ooo`0;0?ooo`03
0?oOW018M;l0oooo0200oooo00<0okmd0018W03Oool0:03oool00:40oooo00<0gia8000000000000
1@0000000`0004P0W=oo0?ooo`0d0?ooo`030?noM00004P0W=oo03<0oooo00<0gia804RLg`3oool0
>03oool00`2oM000001d0;ooo`0[0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000
M;l0=03oool00`2oM000001d0;ooo`1o0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a8
0000M;l0303oool00`3ookl0M01809cOo`0C0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO
09a80000M;l06`3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00`0oooo00<0
oono07@0B02Lgol07P3oool00`2oM000001d0;ooo`0Q0?ooo`030;md000007@0_ooo00h0oooo00<0
oono07@0B02Lgol07@3oool00`3OW4P0B9cO0?ooo`0Q0?ooo`030=nLB018W=l0oooo00l0oooo00<0
oono07@0B02Lgol0803oool00`3o_g@0001809cOo`0X0?ooo`00X@3oool00`3ogi`0B7Bo0?ooo`02
0?ooo`030?noM0000000M;oo03L0oooo00<0_g@00000B02Lgol0=03oool00`3OW4P0M;oo0?ooo`0g
0?ooo`030;md000007@0_ooo02/0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0c
0?ooo`030;md000007@0_ooo07l0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0;
0?ooo`030?oo_`1d0000M;oo01<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0J
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02`3oool00`3ookl0M00007Boo`0N
0?ooo`030;md000007@0_ooo0240oooo00<0_g@00000M02oool03P3oool00`3ookl0M00007Boo`0N
0?ooo`030=nLB01d_ol0oooo0240oooo00<0gia807Boo`3oool03P3oool00`3ookl0M00007Boo`0P
0?ooo`030;md000004P0W=oo02P0oooo002D0?ooo`030;md00000000000000L0000000H0B9cO0?oo
o`3oool0oooo0=nLB01d_ol20?ooo`030?noM0000000M;oo02@0oooo00<0_g@00000000000001`00
00000`18W=l0oooo0?ooo`050?ooo`040;md00000000001d0;ooob<0oooo00<0_g@0000000000000
1`0000000`18W=l0oooo0?ooo`040?ooo`030?oog`2LB4P0W=oo02H0oooo00<0_g@0000000000000
1`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo02/0oooo00<0omnL04P00018W=l0
103oool00`2oM000001d0;ooo`0c0?ooo`030;md000007@0_ooo0780oooo00<0_g@0000000000000
1`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool02`3oool00`3o
_g@0000007Boo`0C0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool06P3oool00`3o
gi`0B00004RLg`040?ooo`030;md000007@0_ooo00/0oooo00<0okmd0000001d_ol07P3oool00`2o
M000001d0;ooo`0Q0?ooo`030;md000007@0_ooo00h0oooo00<0okmd0000001d_ol07P3oool00`3o
oml0W4Q809cOo`0Q0?ooo`030?oog`2LB4P0W=oo00h0oooo00<0okmd0000001d_ol07`3oool0102o
M00000000000M02ooolX0?ooo`00XP3oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0<`3o
ool00`3ookl0M000000000020000000304RLg`3oool0oooo03@0oooo00<0omnL04P0M02oool0=P3o
ool00`2oM000001d0;ooo`0[0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0<`3o
ool00`2oM000001d0;ooo`1o0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02P3o
ool0103ogi`0B0000000M02ooolC0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
6P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00X0oooo00@0omnL04P0000007@0
_ooo7P3oool00`2oM000001d0;ooo`0Q0?ooo`030;md000007@0_ooo00d0oooo00@0omnL04P00000
07@0_ooo7`3oool00`3ogi`0B01d0;ooo`0Q0?ooo`030?oOW01807@0_ooo00`0oooo00@0omnL04P0
000007@0_ooo703oool00`3ookl0M000000000020000000304RLg`3oool0oooo02L0oooo002S0?oo
o`060?noM000M;l0oooo0?noM0000000M;oo=@3oool00`3o_g@0001809cOo`0h0?ooo`030;md0018
W=l0oooo03D0oooo00<0_g@00000M02oool0:`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo03<0oooo00<0_g@00000M02oool0O`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB000
04P0W=oo00H0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0B0?ooo`030?oO
W0180000B9cO00@0oooo00<0gia80000B02Lgol06P3oool00`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo00H0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0M0?ooo`03
0;md000007@0_ooo0240oooo00<0_g@00000M02oool02@3oool0103Ogml0oooo0?ooo`2oM0020000
000304RLg`3oool0oooo01l0oooo00<0_g@004RLg`3oool08@3oool00`2oM000B9cO0?ooo`070?oo
o`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool07@3oool00`3o_g@0001809cOo`0Z
0?ooo`00Y03oool01@2oM000M;oo0?noM0000000M;oo03H0oooo00<0omnL04Qd_`3oool0=`3oool0
0`3OW4P0001d0;ooo`0e0?ooo`030;md000007@0_ooo02/0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`0c0?ooo`030;md000007@0_ooo07l0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`060?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool04`3oool0
0`3ookl0M000001d_`040?ooo`030;md000007@0_ooo01X0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`060?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool07P3oool0
0`2oM000001d0;ooo`0Q0?ooo`030;md000007@0_ooo00T0oooo00<0okmd0000000000000P000000
0`00M;l0oooo0?ooo`0P0?ooo`030=nLB00007@0_ooo0240oooo00<0gia80000M02oool01`3oool0
0`3o_g@000000000000200000003001d_`3oool0oooo01l0oooo00<0omnL04Qd_`3oool0:@3oool0
0:@0oooo00D0oono07@0M02o_g@0000007Boo`0f0?ooo`030?oog`2LB000B9cO03L0oooo00<0okmd
0000001d_ol0=@3oool00`2oM000001d0;ooo`0/0?ooo`030;md0000B9`0gooo0080oooo00<0oooO
09a80000M;l0=03oool00`2oM000001d0;ooo`200?ooo`030;md0000B9`0gooo0080oooo00<0oooO
09a80000M;l01`3oool01@3ooml0W4P00000000007@0_ooo01L0oooo00<0_g@00018W03Oool00P3o
ool00`3ooml0W4P0001d_`0L0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l01`3o
ool01@3ooml0W4P00000000007@0_ooo0240oooo00<0_g@00000M02oool08@3oool00`2oM000001d
0;ooo`090?ooo`050?oog`2LB00000000000M02oool08`3oool00`3o_g@0000007Boo`0Q0?ooo`03
0?noM0000000M;oo00L0oooo00D0oooO09a800000000001d0;ooo`0R0?ooo`030?oog`2LB000B9cO
02T0oooo002U0?ooo`040?noM0000000000007Booc40oooo00<0oooO09adW03Oool00P3oool00`3o
oml0W4P0001d_`0a0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0=@3oool00`2o
M000001d0;ooo`0/0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0=03oool00`2o
M000001d0;ooo`200?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`3o
_g@007Bo0?ooo`0H0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0703oool00`3o
_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo00<0okmd001d_`3oool08P3oool00`2o
M000001d0;ooo`0Q0?ooo`030;md000007@0_ooo00X0oooo00<0okmd001d_`3oool07P3oool00`3o
gi`0W;oo0?ooo`030?ooo`030;md00000000M;oo01/0oooo00<0omnL09boo`3oool00`3oool00`2o
M000000007Boo`080?ooo`030?noM000M;l0oooo01h0oooo00<0oooO09adW03Oool00P3oool00`3o
oml0W4P0001d_`0Y0?ooo`00Y@3oool0103ooml0W4P00000001d_olb0?ooo`070?oOW018B9`0gooo
0?ooo`3OW4P0000007Boo`0b0?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03Ooolc0?oo
o`050=nLB000000000000000M02oool0;@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_c<0oooo
00D0gia8000000000000001d0;ooo`210?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2@3oool0
0`3ooml0W4P000000002000000030000M02oool0oooo01@0oooo00H0_g@00018W03Oool0oooo0;md
0000M;lN0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2@3oool00`3ooml0W4P0000000020000
00030000M02oool0oooo01/0oooo00D0gia8000000000000001d0;ooo`0O0?ooo`050=nLB0000000
00000000M02oool02P3oool00`3ooml0W4P000000002000000030000M02oool0oooo01X0oooo00P0
_g@007Boo`3oool0oooo0=nLB000000004RL0=oooa`0oooo00P0_g@007Boo`3oool0oooo0=nLB000
000004RL0=ooo`P0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0J0?ooo`070?oO
W018B9`0gooo0?ooo`3OW4P0000007Boo`0Y0?ooo`00YP3oool00`3ogi`0B00007Boo`0c0?ooo`05
0?oOW0180000000000000018W=l0=03oool01@2oM000000000000000000007Bo03H0oooo00@0oono
07@0000007@0_ooo;P3oool0102oM000000000000000M;le0?ooo`040?oo_`1d0000001d0;oooh80
oooo00@0_g@000000000000007Bo2`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo
01@0oooo00@0_g@000000000000007Bo803oool0102oM000000000000000M;l;0?ooo`030?noM000
000000000080000000<0M;oo0?ooo`3oool06`3oool0103ookl0M0000000M02ooolP0?ooo`040?oo
_`1d0000001d0;ooo`/0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0J0?ooo`05
0;md00000000000000000000M;l07`3oool01@2oM000000000000000000007Bo00/0oooo00<0okmd
0000000000000P0000000`1d_ol0oooo0?ooo`0J0?ooo`050?oOW0180000000000000018W=l0:P3o
ool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3ooonO0?ooo`00o`3ooooo0?ooool0
ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3ooonO0?ooo`00o`3ooooo
0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3ooonO0?ooo`00
o`3ooooo0?ooool0ooooW`3oool006H0ooooo`00001I000005/0ooooo`00001I000002/0oooo001V
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y
0?ooo`00IP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3o
ool0:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003o
ool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooE@3o
ool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool0
06H0oooo0P00003o0?oooeD0oooo0P00001K0?ooo`800000o`3ooomE0?ooo`800000:`3oool006H0
oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0oooo
E@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo
0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<00000
0?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE
0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?oo
o`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo0P00003o0?oooeD0oooo
0P00001K0?ooo`800000o`3ooomE0?ooo`800000:`3oool006H0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003o
ool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`00
0000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oo
oeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0
oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?oo
o`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<0
00000?ooo`3oool0:@3oool006H0oooo0P00003o0?oooeD0oooo0P00001K0?ooo`800000o`3ooomE
0?ooo`800000:`3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`03
0000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0
ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0
:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0
oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooE@3oool0
0`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0
oooo0P00003o0?oooeD0oooo0P00001K0?ooo`800000o`3ooomE0?ooo`800000:`3oool006H0oooo
00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`030000003oool0oooo02T0oooo001G0?ooo`030?noM000000000000080000000<0
07Bo0?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0?03o
ool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO0080oooo00H0_g@0000000000000
00000018W03Oool:0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?oo
o`00F@3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000
oooo0?ooo`0j0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`070=nLB0000000
B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00T0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`030000003oool0oooo02T0oooo001I0?ooo`030;md000007@0_ooo00X0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo03X0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`0<0?ooo`030?oOW018M;l0oooo00P0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`030000003oool0oooo02T0oooo001I0?ooo`030;md000007@0_ooo00X0oooo00<00000
0?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo03T0oooo00@0oooO09a80000B9`0gooo0P3o
ool00`3ooml0W4P0001d_`0<0?ooo`030?oo_`1d04P0W=oo00P0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`030000003oool0oooo02T0oooo001I0?ooo`030;md000007@0_ooo00X0oooo00<00000
0?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo03T0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`0;0?ooo`030?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool0o`3ooomE
0?ooo`030000003oool0oooo02T0oooo00180?ooo`030;md00000000000000L0000000<0B9cO0?oo
o`3oool0103oool00`2oM000001d0;ooo`0:0?ooo`<00000o`3ooolL0?ooo`030?l0003oool0oooo
03@0oooo0`00000^0?ooo`030;md00000000000000L0000000H0B9cO0?ooo`3oool0omnL04P00018
W=l40?ooo`030;md000007@0_ooo00/0oooo00<0okmd0000001d_ol0203oool300000?l0ooooD`3o
ool3000002/0oooo001I0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooolL
0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0>@3oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo00X0oooo00@0omnL04P0000007@0_ooo203oool00`000000oooo0?oo
o`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool005T0oooo00<0_g@00000M02oool02P3oool0
0`000000oooo0?ooo`3o0?oooa`0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`0i
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01P3oool0103Ogml0oooo0?ooo`2o
M0020000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003o
ool0oooo02T0oooo001I0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooolL
0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0>@3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo00H0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`08
0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00F@3oool00`2o
M000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0oooo703oool00`3o0000oooo0?ooo`0f0?oo
o`030000003oool0oooo03X0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`070?oo
o`050?oog`2LB00000000000M02oool02`3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<00000
0?ooo`3oool0:@3oool005T0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oo
oa`0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`0j0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol0203oool00`3o_g@007Bo0?ooo`0<0?ooo`030000003oool0oooo
0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00E`3oool01@3OW4P000000000000007@0_ooo
00X0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030?l0003oool0oooo03H0oooo00<000000?oo
o`3oool0>`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00<0oooO09a8000000000P00
00000`0007@0_ooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?oo
o`0Y0?ooo`00F03oool0103ookl0M0000000M02oool:0?ooo`800000o`3ooolM0?ooo`030?l0003o
ool0oooo03D0oooo0P00000n0?ooo`040;md000000000000001d_`/0oooo00<0okmd000000000000
0P0000000`1d_ol0oooo0?ooo`060?ooo`800000o`3ooomE0?ooo`800000:`3oool006H0oooo00<0
00000?ooo`3oool0o`3ooolL0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<00000
0?ooo`3oool0o`3ooolL0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?oo
o`3oool0o`3ooolL0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3o
ool0o`3ooolL0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0
o`3ooolL0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3o
oolL0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo0P00003o0?oooad0oooo00<0o`00
0?ooo`3oool0=@3oool2000005/0oooo0P00003o0?oooeD0oooo0P00000[0?ooo`00IP3oool00`00
0000oooo0?ooo`3o0?oooa`0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000
oooo0?ooo`3o0?oooa`0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo
0?ooo`3o0?oooa`0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?oo
o`3o0?oooa`0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o
0?oooa`0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oo
oa`0oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooa`0
oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0
ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool200000?l0oooo7@3oool00`3o0000oooo
0?ooo`0e0?ooo`800000F`3oool200000?l0ooooE@3oool2000002/0oooo001V0?ooo`030000003o
ool0oooo0?l0oooo703oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0
oooo0?l0oooo703oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo
0?l0oooo703oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0
oooo703oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0oooo
703oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0oooo703o
ool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`800000o`3ooolM0?ooo`030?l0003oool0
oooo03D0oooo0P00001K0?ooo`800000o`3ooomE0?ooo`800000:`3oool005P0oooo00@0_g@00000
00000000B9cO2P3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<0o`000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1;0?ooo`040;md00000000000004RLg`X0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`030000003oool0oooo02T0oooo001F0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0
001d_`090?ooo`030000003oool0oooo0?l0oooo703oool00`3o0000oooo0?ooo`0f0?ooo`030000
003oool0oooo04T0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00T0oooo00<000000?oo
o`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001F0?ooo`030?noM00004P0W=oo0080
oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?ooo`3o0?oooa`0oooo00<0o`000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`190?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol0203oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool005D0oooo
00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`080?ooo`030000003oool0oooo0?l0
oooo703oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo04P0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3ooml0W4P0001d_`080?ooo`030000003oool0oooo0?l0ooooE@3oool00`00
0000oooo0?ooo`0Y0?ooo`00E@3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00L0
oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3o
ool0B03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00L0oooo00<000000?ooo`3o
ool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001E0?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool01`3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<0o`000?ooo`3oool0
=P3oool00`000000oooo0?ooo`180?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0
1`3oool00`000000oooo0?ooo`3o0?ooo`030?l0003oool0oooo0580oooo00<000000?ooo`3oool0
:@3oool005D0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`<00000o`3o
oolL0?ooo`030?l0003oool0oooo03@0oooo0`00001:0?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol01`3oool3000007d0ooooPP3o001C0?ooo`<00000:`3oool005D0oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo0?l0ooooE@3oool0
0`000000oooo0?ooo`180?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01`3oool0
0`000000oooo0?ooo`1m0?ooo`030?l0003oool0oooo0=@0oooo00<000000?ooo`3oool0:@3oool0
05D0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo
0?l0ooooE@3oool00`000000oooo0?ooo`180?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000
M02oool01`3oool00`000000oooo0?ooo`1l0?ooo`030?l0003oool0oooo0=D0oooo00<000000?oo
o`3oool0:@3oool005H0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`080?ooo`03
0000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`190?ooo`030;md0000B9`0gooo0080
oooo00<0oooO09a80000M;l0203oool00`000000oooo0?ooo`1l0?ooo`030?l0003oool0oooo0=D0
oooo00<000000?ooo`3oool0:@3oool005H0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`080?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`190?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?ooo`1k0?ooo`030?l0
003oool0oooo0=H0oooo00<000000?ooo`3oool0:@3oool005L0oooo00H0_g@00018W03Oool0oooo
0;md0000M;l90?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1:0?ooo`06
0;md0000B9`0gooo0?ooo`2oM00007Bo2@3oool00`000000oooo0?ooo`1k0?ooo`030?l0003oool0
oooo0=H0oooo00<000000?ooo`3oool0:@3oool005P0oooo00@0_g@000000000000007Bo2P3oool0
0`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0B`3oool0102oM000000000000000
M;l:0?ooo`030000003oool0oooo07X0oooo00<0o`000?ooo`3oool0e`3oool00`000000oooo0?oo
o`0Y0?ooo`00IP3oool200000?l0ooooE@3oool2000005/0oooo0P00001j0?ooo`030?l0003oool0
oooo0=L0oooo0P00000[0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`1i0?ooo`030?l0003oool0oooo0=P0oooo00<000000?oo
o`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool0N03oool00`3o0000oooo0?ooo`3I0?ooo`030000003oool0oooo02T0
oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo07L0oooo00<0o`000?ooo`3oool0fP3oool00`000000oooo0?ooo`0Y0?ooo`00IP3o
ool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`1g0?ooo`030?l0003oool0oooo0=X0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<00000
0?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0MP3oool0
0`3o0000oooo0?ooo`3K0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo
0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo07D0oooo00<0o`000?oo
o`3oool0g03oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool200000?l0ooooE@3oool2000005/0
oooo0P00001f0?ooo`030?l0003oool0oooo0=/0oooo0P00000[0?ooo`00IP3oool00`000000oooo
0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1d0?ooo`030?l0
003oool0oooo0=d0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0L`3oool00`3o0000oooo0?oo
o`3N0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo07<0oooo00<0o`000?ooo`3oool0gP3oool0
0`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`1b0?ooo`030?l0003oool0oooo0=l0oooo00<000000?oo
o`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`3O0?ooo`030000003oool0oooo02T0
oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo0740oooo00<0o`000?ooo`3oool0h03oool00`000000oooo0?ooo`0Y0?ooo`00IP3o
ool200000?l0ooooE@3oool2000005/0oooo0P00001b0?ooo`030?l0003oool0oooo0=l0oooo0P00
000[0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`1`0?ooo`030?l0003oool0oooo0>40oooo00<000000?ooo`3oool0:@3oool0
06H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0K`3oool00`3o0000oooo0?ooo`3R0?ooo`030000003oool0oooo02T0oooo001V0?ooo`03
0000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo06l0
oooo00<0o`000?ooo`3oool0hP3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo
0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1^0?ooo`030?l0
003oool0oooo0><0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0KP3oool00`3o0000oooo0?oo
o`3S0?ooo`030000003oool0oooo02T0oooo000d0?ooo`030?noM01d_ol0oooo00H0oooo00<0_gAd
0;ooo`3oool09P3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0603oool0
0`3o_g@0M;oo0?ooo`060?ooo`030;mdM02oool0oooo03D0oooo00<000000?ooo`3oool0K@3oool0
0`3o0000oooo0?ooo`3T0?ooo`030000003oool0oooo02T0oooo000d0?ooo`030?noM00007@0_ooo
00@0oooo00@0oooO09a8000007@0_ooo9`3oool200000?l0ooooE@3oool2000001X0oooo00<0okmd
0000M02oool0103oool0103ooml0W4P00000M02ooolf0?ooo`800000K@3oool00`3o0000oooo0?oo
o`3T0?ooo`800000:`3oool003@0oooo00@0okmd000000000000B9cO0P3oool01@3ookl0M01809cO
o`3OW9`0_ooo01P0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030000
003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0H0?ooo`040?noM0000000000004RLg`80
oooo00D0oono07@0B02Lgol0gibL0;ooo`0I0?ooo`040;md00000000000004RLg`@0oooo00<0gia8
00000018W=l00P3oool01P2oM000000000000000000004RL0=ooo`X0oooo00<000000?ooo`3oool0
K03oool00`3o0000oooo0?ooo`3U0?ooo`030000003oool0oooo02T0oooo000d0?ooo`080?noW02L
gol0gia80000000004P0M7A80000M02ooolM0?ooo`030;md000007@0_ooo00X0oooo00<000000?oo
o`3oool0o`3ooomE0?ooo`030000003oool0oooo01P0oooo00P0oknL09cOo`3OW4P000000000B01d
M4P0001d0;oooaX0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00L0gia80000
0018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool02@3oool00`000000oooo0?oo
o`1[0?ooo`030?l0003oool0oooo0>H0oooo00<000000?ooo`3oool0:@3oool003L0oooo00@0oono
07@00000000007Bo7P3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooE@3o
ool00`000000oooo0?ooo`0K0?ooo`040?oo_`1d00000000001d_a/0oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`0<0?ooo`030?oOW018M;l0oooo00P0oooo00<000000?ooo`3oool0
J`3oool00`3o0000oooo0?ooo`3V0?ooo`030000003oool0oooo02T0oooo000d0?ooo`0;0?noW02L
gol0okmd0000B02Lgol0gia80000000004P0W=oo0=nLW02oool06P3oool00`2oM000001d0;ooo`0:
0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0H0?ooo`0;0?noW02Lgol0
okmd0000B02Lgol0gia80000000004P0W=oo0=nLW02oool05P3oool0103ooml0W4P00018W03Oool2
0?ooo`030?oog`2LB00007Bo00`0oooo00<0oono07@0B02Lgol0203oool00`000000oooo0?ooo`1Z
0?ooo`030?l0003oool0oooo0>L0oooo00<000000?ooo`3oool0:@3oool003@0oooo00<0okmd0000
0000M;l00`3oool01@3ookl0M0000000000007@0_ooo01X0oooo00<0_g@00000M02oool02P3oool0
0`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0603oool00`3o_g@00000001d_`03
0?ooo`050?oo_`1d000000000000M02oool05P3oool00`3ookl0M000001d_`040?ooo`030;md0000
07@0_ooo00/0oooo00<0oono07@0001d_ol0203oool00`000000oooo0?ooo`1Z0?ooo`030?l0003o
ool0oooo0>L0oooo00<000000?ooo`3oool0:@3oool003@0oooo00<0okmd04RLg`3oool01@3oool0
0`3OW4P0001d0;ooo`0J0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooomE
0?ooo`030000003oool0oooo01P0oooo00<0okmd04RLg`3oool01@3oool00`3OW4P0001d0;ooo`0F
0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02`3oool00`3o_g@0000007Boo`08
0?ooo`030000003oool0oooo06T0oooo00<0o`000?ooo`3oool0j03oool00`000000oooo0?ooo`0Y
0?ooo`00=03oool00`3o_i`0W=oo0?ooo`060?ooo`030;mdM02oool0oooo01T0oooo00<0_g@00000
M02oool02P3oool300000?l0ooooD`3oool3000001X0oooo00<0oknL09cOo`3oool01P3oool00`2o
M7@0_ooo0?ooo`0E0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02P3oool0103o
gi`0B0000000M02oool80?ooo`<00000J03oool00`3o0000oooo0?ooo`3W0?ooo`<00000:`3oool0
05T0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?oo
o`3oool0>@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00H0oooo00@0gmoO0?oo
o`3oool0_g@00P0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo06P0oooo00<0o`00
0?ooo`3oool0j@3oool00`000000oooo0?ooo`0Y0?ooo`00F@3oool00`2oM000001d0;ooo`0:0?oo
o`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0P0?ooo`030;md00000000B9cO
01H0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?noM00000000000
0080000000<007Bo0?ooo`3oool0203oool00`000000oooo0?ooo`1W0?ooo`030?l0003oool0oooo
0>X0oooo00<000000?ooo`3oool0:@3oool003P0oooo00<0gia80018W03Oool0103oool00`3OW7@0
B4Qd0;ooo`0G0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`03
0000003oool0oooo01h0oooo00D0omnL04P0001d_ol0gia804RLg`0G0?ooo`030;md0000B9`0gooo
0080oooo00<0oooO09a80000M;l01`3oool01@3ooml0W4P00000000007@0_ooo00/0oooo00<00000
0?ooo`3oool0I`3oool00`3o0000oooo0?ooo`3Z0?ooo`030000003oool0oooo02T0oooo000g0?oo
o`030?noM000M;l0oooo00@0oooo00@0_g@004RLW01d07@0_ooo5`3oool00`2oM000001d0;ooo`0:
0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0M0?ooo`060=nLB000B9`0
gooo0?ooo`3OW4P0B9cO5`3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo
00<0okmd001d_`3oool0303oool00`000000oooo0?ooo`1V0?ooo`030?l0003oool0oooo0>/0oooo
00<000000?ooo`3oool0:@3oool003L0oooo00<0gia804RLg`3oool00P3oool01P3ooml0W4P007Bo
o`3ookl0M01d0;oooaD0oooo00D0gia8000000000000001d0;ooo`0:0?ooo`030000003oool0oooo
0?l0ooooE@3oool00`000000oooo0?ooo`0L0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RL
g`3oool05`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00<0oooO09a8000000000P00
00000`0007@0_ooo0?ooo`070?ooo`030000003oool0oooo06H0oooo00<0o`000?ooo`3oool0j`3o
ool00`000000oooo0?ooo`0Y0?ooo`00=`3oool02`3o_g@0001809cOo`3oool0okmd0000B02Lgol0
oooo0?oOW01807@0_ooo01H0oooo00@0oono07@0000007@0_ooo2P3oool00`000000oooo0?ooo`3o
0?oooeD0oooo00<000000?ooo`3oool06`3oool00`3OW4P0000000000006000000030000M02oool0
oooo01D0oooo00@0_g@000000000000007Bo2`3oool00`3o_g@00000000000020000000307Boo`3o
ool0oooo00H0oooo00<000000?ooo`3oool0I@3oool00`3o0000oooo0?ooo`3/0?ooo`030000003o
ool0oooo02T0oooo000h0?ooo`040=nLB00000000000001d_`80oooo00@0oooO09a80000B9`0gooo
903oool200000?l0ooooE@3oool2000002<0oooo00<0gia804RLg`3oool0=@3oool2000006D0oooo
00<0o`000?ooo`3oool0k03oool2000002/0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo06@0oooo00<0o`000?ooo`3oool0k@3o
ool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`1S0?ooo`030?l0003oool0oooo0>h0oooo00<00000
0?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool0H`3oool00`3o0000oooo0?ooo`3^0?ooo`030000003oool0oooo
02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo0680oooo00<0o`000?ooo`3oool0k`3oool00`000000oooo0?ooo`0Y0?ooo`00
IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`1Q0?ooo`030?l0003oool0oooo0?00oooo00<000000?ooo`3oool0:@3oool006H0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0H@3o
ool00`3o0000oooo0?ooo`3`0?ooo`030000003oool0oooo02T0oooo001V0?ooo`800000o`3ooomE
0?ooo`800000F`3oool200000640oooo00<0o`000?ooo`3oool0l03oool2000002/0oooo001V0?oo
o`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
05l0oooo00<0o`000?ooo`3oool0lP3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000
oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1O0?ooo`03
0?l0003oool0oooo0?80oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0GP3oool00`3o0000oooo
0?ooo`3c0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05h0oooo00<0o`000?ooo`3oool0l`3o
ool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`1M0?ooo`030?l0003oool0oooo0?@0oooo00<00000
0?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool0G03oool00`3o0000oooo0?ooo`3e0?ooo`030000003oool0oooo
02T0oooo001V0?ooo`800000o`3ooomE0?ooo`800000F`3oool2000005d0oooo00<0o`000?ooo`3o
ool0m03oool2000002/0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo05/0oooo00<0o`000?ooo`3oool0mP3oool00`000000oooo
0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`1J0?ooo`030?l0003oool0oooo0?L0oooo00<000000?ooo`3oool0:@3o
ool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0FP3oool00`3o0000oooo0?ooo`3g0?ooo`030000003oool0oooo02T0oooo001V0?oo
o`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
05T0oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000
oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1I0?ooo`03
0?l0003oool0oooo0?P0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0F03oool00`3o0000oooo
0?ooo`3i0?ooo`030000003oool0oooo02T0oooo001V0?ooo`800000o`3ooomE0?ooo`800000F`3o
ool2000005P0oooo00<0o`000?ooo`3oool0n@3oool2000002/0oooo001V0?ooo`030000003oool0
oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05L0oooo00<0o`00
0?ooo`3oool0nP3oool00`000000oooo0?ooo`0Y0?ooo`00E@3oool00`3OW4P00000000000050000
000307Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo
04X0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030000003oool0oooo
05H0oooo00<0o`000?ooo`3oool0n`3oool00`000000oooo0?ooo`0Y0?ooo`00EP3oool00`3OW4P0
00000000000400000003001d_`3oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`03
0000003oool0oooo04`0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`1F0?ooo`03
0?l0003oool0oooo0?/0oooo00<000000?ooo`3oool0:@3oool005L0oooo00<0gia804RLg`3oool0
0P3oool00`3ooml0W4Qd0;ooo`070?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo
0?ooo`1<0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0E@3oool00`3o0000oooo
0?ooo`3l0?ooo`030000003oool0oooo02T0oooo001H0?ooo`030=nLB018W=l0oooo00/0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo04`0oooo00<0_g@00000M02oool02P3o
ool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0oooo0?`0oooo00<000000?ooo`3oool0:@3o
ool005T0oooo00<0gia807Boo`3oool02P3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<00000
0?ooo`3oool0C03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo05@0oooo00<0o`00
0?ooo`3oool0o@3oool00`000000oooo0?ooo`0Y0?ooo`00F@3oool00`3ooml0W4Q809cOo`0:0?oo
o`<00000o`3ooomC0?ooo`<00000CP3oool00`2oM000001d0;ooo`0:0?ooo`<00000D`3oool00`3o
0000oooo0?ooo`3l0?ooo`<00000:`3oool005X0oooo00<0omnL04P0M02oool02@3oool00`000000
oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0C03oool00`2oM000001d0;ooo`0:0?ooo`03
0000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00F`3oool00`2oM000B9cO
0?ooo`080?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1<0?ooo`030;md
000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo
001K0?ooo`030=nLB00007@0_ooo00P0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003o
ool0oooo04`0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<0
00000?ooo`3oool0:@3oool005/0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`3o
0?oooeD0oooo00<000000?ooo`3oool0C03oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0
oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00E@3oool00`3ogi`0W;oo0?ooo`030?oo
o`030;md00000000M;oo00P0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo
04`0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?oo
o`3oool0:@3oool005H0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=ooo`P0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo04X0oooo00D0gia8000000000000001d
0;ooo`0:0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00E`3o
ool01@2oM000000000000000000007Bo00X0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000
003oool0oooo04/0oooo00@0oono07@0000007@0_ooo2P3oool00`000000oooo0?ooo`3o0?oooeD0
oooo00<000000?ooo`3oool0:@3oool006H0oooo0P00003o0?oooeD0oooo0P00001K0?ooo`800000
o`3ooomE0?ooo`800000:`3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V
0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oo
oeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?oo
o`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000
003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0oooo
E@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3o
ool006H0oooo0P00003o0?oooeD0oooo0P00001K0?ooo`800000o`3ooomE0?ooo`800000:`3oool0
06H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0
ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000
oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3o
oomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y
0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo0P00003o0?oooeD0
oooo0P00001K0?ooo`800000o`3ooomE0?ooo`800000:`3oool006H0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000
003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?oo
o`1I0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool0
0`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o
0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo
02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo
0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo
00<000000?ooo`3oool0:@3oool006H0oooo0P00003o0?oooeD0oooo0P00001K0?ooo`800000o`3o
oomE0?ooo`800000:`3oool005D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`09
0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0k0?ooo`030?noM0000000
00000080000000L007Bo0?ooo`3oool0oooo0=nLB0000000B9cO0080oooo00H0_g@0000000000000
00000018W03Oool:0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?oo
o`00E@3oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0W=oo2@3oool00`000000oooo0?oo
o`3o0?oooeD0oooo00<000000?ooo`3oool0?@3oool00`2oM000001d0;ooo`040?ooo`070=nLB000
0000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?oOW018B9`0gooo00T0oooo00<000000?ooo`3o
ool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001K0?ooo`030?noM000B9`0gooo00P0oooo
00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo03d0oooo00<0_g@00000M02oool0
3P3oool00`3ogi`0B7Bo0?ooo`080?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo
0?ooo`0Y0?ooo`00F`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo0?l0ooooE@3o
ool00`000000oooo0?ooo`0m0?ooo`030;md000007@0_ooo00h0oooo00<0oono07@0B02Lgol0203o
ool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool005/0oooo00<0_g@0
0000B02Lgol0203oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0?@3oool0
0`2oM000001d0;ooo`0>0?ooo`030?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool0o`3ooomE
0?ooo`030000003oool0oooo02T0oooo001J0?ooo`040;md00000000001d0;ooo`P0oooo00<00000
0?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo03d0oooo00<0_g@00000M02oool03P3oool0
0`3o_g@0000007Boo`080?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y
0?ooo`00E`3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00L0oooo0`00003o0?oo
oe<0oooo0`00000o0?ooo`030;md000007@0_ooo00d0oooo00@0omnL04P0000007@0_ooo203oool3
00000?l0ooooD`3oool3000002/0oooo001I0?ooo`030?noM00004P0W=oo00X0oooo00<000000?oo
o`3oool0o`3ooomE0?ooo`030000003oool0oooo03d0oooo00<0_g@00000M02oool02@3oool0103O
gml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomE
0?ooo`030000003oool0oooo02T0oooo001J0?ooo`030?oOW018M;l0oooo00T0oooo00<000000?oo
o`3oool0o`3ooomE0?ooo`030000003oool0oooo03d0oooo00<0_g@00000M02oool02@3oool00`3o
_g@000000000000200000003001d_`3oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomE0?oo
o`030000003oool0oooo02T0oooo001J0?ooo`030?oog`2LB000B9cO00T0oooo00<000000?ooo`3o
ool0o`3ooomE0?ooo`030000003oool0oooo03d0oooo00<0_g@00000M02oool02@3oool01@3ooml0
W4P00000000007@0_ooo00/0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo
02T0oooo001E0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l02@3oool00`000000
oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0?@3oool00`2oM000001d0;ooo`0:0?ooo`03
0?noM000M;l0oooo00`0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0
oooo001F0?ooo`070?oOW018B9`0gooo0?ooo`3OW4P0000007Boo`090?ooo`030000003oool0oooo
0?l0ooooE@3oool00`000000oooo0?ooo`0k0?ooo`050=nLB000000000000000M02oool02P3oool0
0`3ooml0W4P000000002000000030000M02oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomE
0?ooo`030000003oool0oooo02T0oooo001G0?ooo`050?oOW0180000000000000018W=l02P3oool0
0`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0?03oool0103ookl0M0000000M02o
ool;0?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo0P00003o0?oooeD0oooo0P00001K
0?ooo`800000o`3ooomE0?ooo`800000:`3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo
02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo
0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo
00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V
0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oo
oeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?oo
o`3oool0:@3oool006H0oooo0P00003o0?oooeD0oooo0P00001K0?ooo`800000o`3ooomE0?ooo`80
0000:`3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003o
ool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooE@3o
ool00`000000oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool0
06H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0
ooooE@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000
oooo0?ooo`0Y0?ooo`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo0P00
003o0?oooeD0oooo0P00001K0?ooo`800000o`3ooomE0?ooo`800000:`3oool006H0oooo00<00000
0?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE
0?ooo`030000003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?oo
o`00IP3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000
003oool0oooo02T0oooo001V0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?oo
o`1I0?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00IP3oool0
0`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o
0?oooeD0oooo00<000000?ooo`3oool0:@3oool006H0oooo0P00003o0?oooeD0oooo0P00001K0?oo
o`800000o`3ooomE0?ooo`800000:`3oool006H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0
oooo001J0?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000
003oool0oooo04P0oooo00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`060?ooo`030000
003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`0Y0?ooo`00FP3oool00`3o_g@0000007Bo
o`090?ooo`030000003oool0oooo0?l0ooooE@3oool00`000000oooo0?ooo`190?ooo`030=nLB000
0000000000@0000000<007Bo0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<0
00000?ooo`3oool0:@3oool005X0oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`3o
0?oooeD0oooo00<000000?ooo`3oool0BP3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0
_ooo00L0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo02T0oooo001E0?oo
o`030=nLB0000000000000D0000000<0001809cOo`3oool01P3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1;0?oo
o`030=nLB018W=l0oooo00/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02T0oooo001E0?ooo`030?oOW018M;l0oooo0080oooo00<0okmd0000001d
_ol02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1<0?ooo`030=nLB01d_ol0oooo00X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0Y0?ooo`00EP3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000
001d_ol02@3ooooo000005T00000CP3oool00`3ooml0W4Q809cOo`0:0?ooool00000F@00000[0?oo
o`00EP3oool01`3ookl0M01d0;ooo`3oool0okmd0000001d_ol0o`3ooona0?ooo`030?oOW01807@0
_ooo0?l0ooooS@3oool005L0oooo00H0okmd001d_`3oool0okmd0000001d_ooo0?oook80oooo00<0
_g@004RLg`3oool0o`3ooon<0?ooo`00F03oool01@2oM000M;oo0?noM0000000M;oo0?l0oooo/P3o
ool00`3OW4P0001d0;ooo`3o0?oooh`0oooo001H0?ooo`050?oo_`1d07@0_kmd0000001d_ol0o`3o
oonb0?ooo`030?noM0000000M;oo0?l0ooooS03oool005T0oooo00@0okmd000000000000M;ooo`3o
oon/0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0o`3ooon<0?ooo`00F@3oool0
103ooml0W4P00000001d_ooo0?ooojd0oooo00P0_g@007Boo`3oool0oooo0=nLB000000004RL0=oo
ool0ooooS03oool005X0oooo00<0omnL04P0001d_ol0o`3ooon^0?ooo`050;md0000000000000000
0000M;l0o`3ooon>0?ooo`00o`3ooooo0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oooil0oooo
003o0?ooool0ooooo`3ooonO0?ooo`00o`3ooooo0?ooool0ooooW`3oool00?l0ooooo`3ooooo0?oo
oil0oooo003o0?ooool0ooooo`3ooonO0?ooo`00o`3ooooo0?ooool0ooooW`3oool00?l0ooooo`3o
oooo0?oooil0oooo003o0?ooool0ooooo`3ooonO0?ooo`00o`3ooooo0?ooool0ooooW`3oool00?l0
ooooo`3ooooo0?oooil0oooo003o0?ooool0ooooo`3ooonO0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 923.438}, {292, 0}} -> {-0.0524352, -0.0158504, \
0.00227939, 0.00227939}, {{23, 472.938}, {285, 6.9375}} -> {-6.78376, \
-3.70712, 0.0174618, 0.0282538}, {{450.438, 900.375}, {285, 6.9375}} -> \
{-7.25275, -1.85357, 0.0116412, 0.014127}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pl1 = 
        Plot[{xx2[N], x2anal[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] All, Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", "\<x2[N]\>"}, 
          PlotStyle \[Rule] {Hue[0], Hue[ .7]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(pl2 = 
        Plot[{xx4[N], x4anal[N]}, {N, nmin, nmax}, Frame -> True, 
          PlotRange \[Rule] All, Axes \[Rule] False, 
          FrameLabel \[Rule] {"\<N\>", "\<x4[N]\>"}, 
          PlotStyle \[Rule] {Hue[0], Hue[ .7]}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{pl1, pl2}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] 0];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .30902 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00735755 0.47619 [
[ 0 0 0 0 ]
[ 1 .30902 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .30902 L
0 .30902 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00735755 0.5 0.301659 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.0238095 0.603319 0.588604 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.2619 -0.0125 -19.0313 -24.5625 ]
[.2619 -0.0125 19.0313 0 ]
[.5 -0.0125 -19.0313 -24.5625 ]
[.5 -0.0125 19.0313 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -12.0625 -24.5625 ]
[.97619 -0.0125 12.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -28 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .13244 -43.0625 -12.2813 ]
[-0.0125 .13244 0 12.2813 ]
[-0.0125 .25016 -43.0625 -12.2813 ]
[-0.0125 .25016 0 12.2813 ]
[-0.0125 .36788 -43.0625 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .4856 -43.0625 -12.2813 ]
[-0.0125 .4856 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67.625 -26.0938 ]
[-0.01875 .30902 -43.0625 26.0938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -89 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -142.438 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
87.0938 16.2813 translate
90 rotate
-87.0938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.125 23.000 moveto
(@) show
90.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
104.500 23.000 moveto
(D) show
111.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03754 .60332 L
.04262 .60332 L
.04518 .60332 L
.04662 .60332 L
.04795 .60332 L
.053 .60332 L
.05755 .60332 L
.06244 .60332 L
.06379 .60332 L
.06507 .60332 L
.06747 .60332 L
.06972 .60332 L
.07218 .60332 L
.0829 .60332 L
.09427 .60332 L
.09922 .60332 L
.10183 .60332 L
.10325 .60332 L
.10458 .60332 L
.10709 .60332 L
.10986 .60332 L
.11471 .60332 L
.12425 .60332 L
.12556 .60332 L
.12697 .60332 L
.12955 .60332 L
.13205 .60332 L
.13437 .60332 L
.14523 .60332 L
.14986 .60332 L
.15246 .60332 L
.15485 .60332 L
.15953 .60332 L
.16389 .60332 L
.16868 .60332 L
.17143 .60332 L
.17393 .60332 L
.17903 .60332 L
.18449 .60332 L
.18934 .60332 L
.19447 .60332 L
.20368 .60332 L
.20879 .60332 L
.21358 .60332 L
.21879 .60332 L
.22447 .60332 L
.22987 .60332 L
Mistroke
.23488 .60332 L
.24007 .60332 L
.24476 .60332 L
.25374 .60332 L
.25866 .60332 L
.2633 .60332 L
.27309 .60332 L
.27801 .60332 L
.28342 .60331 L
.28804 .60331 L
.29298 .60331 L
.3019 .60331 L
.3072 .60331 L
.3121 .6033 L
.31737 .6033 L
.32318 .60329 L
.33295 .60328 L
.3383 .60327 L
.34331 .60326 L
.35317 .60323 L
.35812 .60322 L
.36354 .60319 L
.36818 .60316 L
.37313 .60312 L
.38205 .60304 L
.3874 .60297 L
.39232 .60288 L
.39762 .60278 L
.40344 .60263 L
.41324 .60227 L
.4186 .60201 L
.4236 .60171 L
.4286 .60133 L
.43404 .60083 L
.43883 .60028 L
.44393 .59956 L
.44851 .59878 L
.45356 .59773 L
.46248 .59526 L
.46739 .59347 L
.47256 .59118 L
.4818 .58577 L
.48696 .58183 L
.49176 .57746 L
.50265 .56443 L
.51316 .54699 L
.52308 .52556 L
.54166 .47401 L
.55996 .41843 L
.57036 .39042 L
Mistroke
.5801 .36863 L
.58966 .35177 L
.59995 .33826 L
.60558 .33259 L
.61094 .32815 L
.61621 .32455 L
.62098 .32185 L
.63058 .31772 L
.63585 .31603 L
.6408 .31474 L
.64964 .31298 L
.65462 .31223 L
.6592 .31166 L
.66906 .31067 L
.67449 .3102 L
.67963 .30972 L
.68441 .30916 L
.68711 .30874 L
.68961 .30825 L
.69171 .30773 L
.69402 .307 L
.69644 .30602 L
.6987 .30481 L
.70093 .30327 L
.70335 .30106 L
.70589 .29799 L
.70825 .29421 L
.71046 .28962 L
.71248 .28439 L
.71699 .26793 L
.71952 .25522 L
.72186 .24101 L
.72713 .20042 L
.7367 .11434 L
.74138 .07976 L
.74395 .06478 L
.7464 .05324 L
.74867 .04463 L
.75114 .03723 L
.75339 .032 L
.75547 .0282 L
.75818 .02443 L
.76072 .02183 L
.76301 .02008 L
.76548 .01867 L
.76818 .01754 L
.77102 .01669 L
.77346 .01617 L
.77612 .01576 L
.77864 .01548 L
Mistroke
.78138 .01525 L
.78397 .0151 L
.78636 .015 L
.78851 .01493 L
.79088 .01488 L
.79336 .01483 L
.79568 .0148 L
.79838 .01478 L
.80095 .01476 L
.80325 .01475 L
.80577 .01474 L
.80849 .01473 L
.81001 .01473 L
.81139 .01473 L
.81408 .01472 L
.81662 .01472 L
.81902 .01472 L
.82127 .01472 L
.82373 .01472 L
.82637 .01472 L
.82914 .01472 L
.83177 .01472 L
.83412 .01472 L
.83668 .01472 L
.83889 .01472 L
.84133 .01472 L
.84388 .01472 L
.84628 .01472 L
.8485 .01472 L
.85055 .01472 L
.85279 .01472 L
.85515 .01472 L
.85772 .01472 L
.86015 .01472 L
.86233 .01472 L
.86469 .01472 L
.86592 .01472 L
.86727 .01472 L
.86858 .01472 L
.87 .01472 L
.87252 .01472 L
.87375 .01472 L
.87489 .01472 L
.87724 .01472 L
.87859 .01472 L
.87981 .01472 L
.88207 .01472 L
.88333 .01472 L
.88448 .01472 L
.88554 .01472 L
Mistroke
.88665 .01472 L
.88787 .01472 L
.889 .01472 L
.88998 .01472 L
.89103 .01472 L
.89219 .01472 L
.89325 .01472 L
.89435 .01472 L
.89554 .01472 L
.89685 .01472 L
.89807 .01472 L
.89937 .01472 L
.90002 .01472 L
.90074 .01472 L
.90202 .01472 L
.90318 .01472 L
.90437 .01472 L
.90548 .01472 L
.90666 .01472 L
.90794 .01472 L
.90906 .01472 L
.91024 .01472 L
.91236 .01472 L
.91365 .01472 L
.91483 .01472 L
.9161 .01472 L
.91748 .01472 L
.91875 .01472 L
.91993 .01472 L
.92106 .01472 L
.92226 .01472 L
.92354 .01472 L
.92426 .01472 L
.92492 .01472 L
.92614 .01472 L
.92743 .01472 L
.93314 .01472 L
.9357 .01472 L
.93812 .01472 L
.9403 .01472 L
.94152 .01472 L
.94266 .01472 L
.94387 .01472 L
.94501 .01472 L
.94626 .01472 L
.94696 .01472 L
.9476 .01472 L
.94889 .01472 L
.94961 .01472 L
.95029 .01472 L
Mistroke
.95284 .01472 L
.95524 .01472 L
.9575 .01472 L
.96173 .01472 L
.96413 .01472 L
.96666 .01472 L
.96882 .01472 L
.97005 .01472 L
.9712 .01472 L
.97246 .01472 L
.97361 .01472 L
.97424 .01472 L
.97493 .01472 L
.97619 .01472 L
Mfstroke
.2 0 1 r
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07295 .60332 L
.08265 .60332 L
.08804 .60332 L
.09308 .60332 L
.09862 .60332 L
.10458 .60332 L
.11468 .60332 L
.1204 .60332 L
.12571 .60332 L
.13544 .60332 L
.14087 .60332 L
.1458 .60332 L
.15068 .60332 L
.15583 .60332 L
.16505 .60332 L
.17018 .60332 L
.17498 .60332 L
.18019 .60332 L
.18587 .60332 L
.1913 .60332 L
.19632 .60332 L
.20103 .60332 L
.20622 .60332 L
.21522 .60332 L
.22015 .60332 L
.22478 .60332 L
.23461 .60332 L
.23955 .60332 L
.24496 .60332 L
.2496 .60332 L
.25455 .60332 L
.26347 .60332 L
.2688 .60332 L
.27371 .60332 L
.279 .60332 L
.28481 .60331 L
.2946 .60331 L
.29996 .60331 L
.30496 .60331 L
.30994 .60331 L
.31537 .6033 L
Mistroke
.32016 .6033 L
.32525 .60329 L
.3303 .60329 L
.33487 .60328 L
.34379 .60326 L
.34868 .60325 L
.35384 .60323 L
.36307 .60319 L
.36822 .60316 L
.37301 .60313 L
.37823 .60308 L
.38391 .60301 L
.38935 .60294 L
.39439 .60284 L
.3991 .60274 L
.4043 .6026 L
.41331 .60227 L
.41824 .60203 L
.42287 .60176 L
.43273 .60096 L
.43768 .60042 L
.44309 .59969 L
.44773 .59892 L
.45269 .59792 L
.46161 .59554 L
.46695 .59364 L
.47188 .59151 L
.47717 .58871 L
.48299 .58492 L
.49279 .57641 L
.50316 .56371 L
.51335 .54663 L
.52264 .52661 L
.54355 .46825 L
.56422 .40643 L
.57332 .38331 L
.58336 .36237 L
.59293 .34699 L
.60192 .33615 L
.61142 .3278 L
.61676 .32422 L
.62166 .32151 L
.62639 .31934 L
.63145 .31742 L
.64056 .3148 L
.64613 .31361 L
.6514 .3127 L
.66125 .31143 L
.67096 .31051 L
.67627 .31004 L
Mistroke
.68124 .30955 L
.68547 .30901 L
.68785 .30861 L
.69002 .30816 L
.69239 .30753 L
.69498 .30665 L
.69742 .30553 L
.69969 .30418 L
.70233 .30207 L
.70477 .29946 L
.70744 .29562 L
.71026 .29008 L
.71272 .28368 L
.71501 .27604 L
.71753 .26546 L
.72022 .25122 L
.72523 .21631 L
.72996 .17502 L
.73884 .09741 L
.74343 .06759 L
.74604 .05476 L
.7485 .04521 L
.75108 .03741 L
.75344 .03191 L
.75603 .02732 L
.75876 .02377 L
.76097 .02162 L
.76332 .01988 L
.76554 .01863 L
.76756 .01776 L
.76994 .01698 L
.77251 .01636 L
.77494 .01592 L
.77718 .01563 L
.77963 .01539 L
.78186 .01522 L
.78444 .01508 L
.78689 .01498 L
.78914 .01492 L
.79123 .01487 L
.79352 .01483 L
.79596 .0148 L
.79865 .01478 L
.80016 .01477 L
.80155 .01476 L
.8041 .01475 L
.8068 .01474 L
.80922 .01473 L
.81148 .01473 L
.81396 .01472 L
Mistroke
.81661 .01472 L
.81918 .01472 L
.82192 .01472 L
.82425 .01472 L
.82682 .01472 L
.82957 .01472 L
.83112 .01472 L
.83254 .01472 L
.83529 .01472 L
.8379 .01472 L
.84032 .01472 L
.84289 .01472 L
.84533 .01472 L
.84753 .01472 L
.85013 .01472 L
.85294 .01472 L
.8556 .01472 L
.85804 .01472 L
.8605 .01472 L
.86274 .01472 L
.86532 .01472 L
.86777 .01472 L
.87003 .01472 L
.87212 .01472 L
.87442 .01472 L
.87686 .01472 L
.87929 .01472 L
.88192 .01472 L
.8844 .01472 L
.88668 .01472 L
.8892 .01472 L
.89196 .01472 L
.89335 .01472 L
.89484 .01472 L
.89752 .01472 L
.9001 .01472 L
.90284 .01472 L
.90518 .01472 L
.90775 .01472 L
.91052 .01472 L
.91207 .01472 L
.91349 .01472 L
.91624 .01472 L
.91885 .01472 L
.92127 .01472 L
.92385 .01472 L
.92629 .01472 L
.92849 .01472 L
.93109 .01472 L
.93391 .01472 L
Mistroke
.93656 .01472 L
.939 .01472 L
.94132 .01472 L
.94343 .01472 L
.94587 .01472 L
.94818 .01472 L
.95031 .01472 L
.95228 .01472 L
.95444 .01472 L
.95674 .01472 L
.95904 .01472 L
.96151 .01472 L
.96385 .01472 L
.96599 .01472 L
.96837 .01472 L
.97096 .01472 L
.97227 .01472 L
.97299 .01472 L
.97367 .01472 L
.97499 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.00735755 0.97619 0.301659 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.0238095 0.0147151 0.588604 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.2619 -0.0125 -19.0313 -24.5625 ]
[.2619 -0.0125 19.0313 0 ]
[.5 -0.0125 -19.0313 -24.5625 ]
[.5 -0.0125 19.0313 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -12.0625 -24.5625 ]
[.97619 -0.0125 12.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .01472 -14.0625 -12.2813 ]
[-0.0125 .01472 0 12.2813 ]
[-0.0125 .13244 -29.125 -12.2813 ]
[-0.0125 .13244 0 12.2813 ]
[-0.0125 .25016 -29.125 -12.2813 ]
[-0.0125 .25016 0 12.2813 ]
[-0.0125 .36788 -29.125 -12.2813 ]
[-0.0125 .36788 0 12.2813 ]
[-0.0125 .4856 -29.125 -12.2813 ]
[-0.0125 .4856 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -53.6875 -26.0938 ]
[-0.01875 .30902 -29.125 26.0938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13244 m
.00625 .13244 L
s
gsave
-0.0125 .13244 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25016 m
.00625 .25016 L
s
gsave
-0.0125 .25016 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36788 m
.00625 .36788 L
s
gsave
-0.0125 .36788 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .4856 m
.00625 .4856 L
s
gsave
-0.0125 .4856 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -128.5 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
87.0938 16.2813 translate
90 rotate
-87.0938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x4) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.125 23.000 moveto
(@) show
90.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
104.500 23.000 moveto
(D) show
111.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03754 .60332 L
.04262 .60332 L
.04518 .60332 L
.04662 .60332 L
.04795 .60332 L
.053 .60332 L
.05755 .60332 L
.06244 .60332 L
.06309 .60332 L
.06379 .60332 L
.06507 .60332 L
.06631 .60332 L
.06747 .60332 L
.07218 .60332 L
.07737 .60332 L
.0829 .60332 L
.09331 .60332 L
.09879 .60332 L
.10179 .60332 L
.10325 .60332 L
.10458 .60332 L
.10715 .60332 L
.1099 .60332 L
.11573 .60332 L
.12106 .60332 L
.12599 .60332 L
.1284 .60332 L
.13095 .60332 L
.13635 .60332 L
.14616 .60332 L
.15553 .60332 L
.1608 .60332 L
.16563 .60332 L
.17025 .60332 L
.17454 .60332 L
.17901 .60332 L
.18391 .60332 L
.18896 .60332 L
.19444 .60332 L
.19926 .60332 L
.20437 .60332 L
.20898 .60332 L
.21404 .60332 L
.22296 .60332 L
.22817 .60332 L
.23312 .60332 L
.24241 .60332 L
Mistroke
.24759 .60332 L
.2524 .60332 L
.25764 .60332 L
.2633 .60331 L
.26882 .60331 L
.27389 .60331 L
.27865 .60331 L
.28386 .60331 L
.29292 .60331 L
.29787 .6033 L
.30248 .6033 L
.3075 .60329 L
.31296 .60329 L
.31777 .60328 L
.32287 .60327 L
.32746 .60326 L
.33252 .60325 L
.34144 .60322 L
.34637 .60319 L
.35156 .60316 L
.36083 .60309 L
.366 .60303 L
.3708 .60297 L
.37603 .60288 L
.3817 .60276 L
.38719 .60262 L
.39225 .60245 L
.39699 .60226 L
.40219 .602 L
.41123 .6014 L
.41618 .60096 L
.42079 .60045 L
.42579 .59979 L
.43123 .59889 L
.43602 .59791 L
.44112 .59663 L
.4457 .59524 L
.45075 .59336 L
.45967 .58894 L
.46458 .58575 L
.46975 .58165 L
.47899 .57191 L
.48415 .56482 L
.48894 .5569 L
.49984 .53318 L
.51035 .50103 L
.52027 .46092 L
.53885 .36168 L
.55715 .25 L
.56755 .19178 L
Mistroke
.57729 .14555 L
.58685 .10921 L
.59714 .07972 L
.60277 .06725 L
.60813 .05744 L
.6134 .04945 L
.61817 .04345 L
.62777 .03423 L
.63304 .03046 L
.63799 .02757 L
.64683 .02364 L
.65181 .02198 L
.65639 .02072 L
.66109 .01965 L
.66613 .01872 L
.67523 .01745 L
.68078 .01688 L
.68604 .01645 L
.69072 .01614 L
.69589 .01585 L
.70556 .01546 L
.71582 .01515 L
.72039 .01504 L
.72532 .01494 L
.72964 .01487 L
.73424 .01481 L
.73685 .01478 L
.73921 .01477 L
.74158 .01475 L
.74382 .01474 L
.74644 .01473 L
.74885 .01473 L
.75011 .01473 L
.7515 .01472 L
.75294 .01472 L
.7543 .01472 L
.75561 .01472 L
.75705 .01472 L
.75956 .01472 L
.76098 .01472 L
.76249 .01472 L
.7652 .01472 L
.76653 .01472 L
.76796 .01472 L
.76923 .01472 L
.77056 .01472 L
.77176 .01472 L
.77308 .01472 L
.7754 .01472 L
.77672 .01472 L
Mistroke
.77793 .01472 L
.77923 .01472 L
.78067 .01472 L
.78308 .01472 L
.78441 .01472 L
.78565 .01472 L
.78685 .01472 L
.78799 .01472 L
.79013 .01472 L
.79133 .01472 L
.79244 .01472 L
.79497 .01472 L
.79628 .01472 L
.7977 .01472 L
.79895 .01472 L
.80028 .01472 L
.80147 .01472 L
.80279 .01472 L
.8051 .01472 L
.80651 .01472 L
.80779 .01472 L
.80918 .01472 L
.81068 .01472 L
.81207 .01472 L
.81336 .01472 L
.8146 .01472 L
.8159 .01472 L
.81705 .01472 L
.81831 .01472 L
.82053 .01472 L
.82178 .01472 L
.82311 .01472 L
.82552 .01472 L
.82669 .01472 L
.82795 .01472 L
.82907 .01472 L
.83025 .01472 L
.83132 .01472 L
.83249 .01472 L
.83456 .01472 L
.83593 .01472 L
.83723 .01472 L
.83968 .01472 L
.84105 .01472 L
.84232 .01472 L
.84371 .01472 L
.8452 .01472 L
.84649 .01472 L
.84789 .01472 L
.84921 .01472 L
Mistroke
.85042 .01472 L
.85169 .01472 L
.8529 .01472 L
.85398 .01472 L
.85515 .01472 L
.85986 .01472 L
.86231 .01472 L
.86491 .01472 L
.86599 .01472 L
.86716 .01472 L
.86844 .01472 L
.86964 .01472 L
.87075 .01472 L
.87192 .01472 L
.87292 .01472 L
.87401 .01472 L
.87531 .01472 L
.87602 .01472 L
.87668 .01472 L
.8774 .01472 L
.87819 .01472 L
.87886 .01472 L
.87958 .01472 L
.88026 .01472 L
.881 .01472 L
.88169 .01472 L
.88233 .01472 L
.88355 .01472 L
.88484 .01472 L
.88709 .01472 L
.88827 .01472 L
.88952 .01472 L
.89018 .01472 L
.89091 .01472 L
.89218 .01472 L
.89347 .01472 L
.89468 .01472 L
.89591 .01472 L
.8966 .01472 L
.89724 .01472 L
.89839 .01472 L
.89965 .01472 L
.90078 .01472 L
.90185 .01472 L
.90297 .01472 L
.90417 .01472 L
.90547 .01472 L
.90621 .01472 L
.90689 .01472 L
.90814 .01472 L
Mistroke
.90884 .01472 L
.90947 .01472 L
.91067 .01472 L
.91197 .01472 L
.91319 .01472 L
.91432 .01472 L
.91553 .01472 L
.91683 .01472 L
.91806 .01472 L
.91918 .01472 L
.92049 .01472 L
.92123 .01472 L
.92192 .01472 L
.92318 .01472 L
.92381 .01472 L
.92451 .01472 L
.92582 .01472 L
.92719 .01472 L
.92791 .01472 L
.92869 .01472 L
.9294 .01472 L
.93007 .01472 L
.93139 .01472 L
.93259 .01472 L
.93325 .01472 L
.93397 .01472 L
.93528 .01472 L
.93764 .01472 L
.94017 .01472 L
.9414 .01472 L
.94256 .01472 L
.94371 .01472 L
.94475 .01472 L
.946 .01472 L
.94668 .01472 L
.94733 .01472 L
.94848 .01472 L
.94973 .01472 L
.95038 .01472 L
.9511 .01472 L
.95186 .01472 L
.95256 .01472 L
.95381 .01472 L
.95515 .01472 L
.96081 .01472 L
.9636 .01472 L
.96482 .01472 L
.96617 .01472 L
.96737 .01472 L
.9685 .01472 L
Mistroke
.96969 .01472 L
.97097 .01472 L
.97164 .01472 L
.97237 .01472 L
.97306 .01472 L
.9737 .01472 L
.97619 .01472 L
Mfstroke
.2 0 1 r
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07295 .60332 L
.08265 .60332 L
.08804 .60332 L
.09308 .60332 L
.09862 .60332 L
.10458 .60332 L
.11468 .60332 L
.1204 .60332 L
.12571 .60332 L
.13544 .60332 L
.14087 .60332 L
.1458 .60332 L
.15068 .60332 L
.15583 .60332 L
.16505 .60332 L
.17018 .60332 L
.17498 .60332 L
.18019 .60332 L
.18587 .60332 L
.1913 .60332 L
.19632 .60332 L
.20103 .60332 L
.20622 .60332 L
.21522 .60332 L
.22015 .60332 L
.22478 .60332 L
.23461 .60332 L
.23955 .60332 L
.24496 .60332 L
.2496 .60332 L
.25455 .60332 L
.26347 .60332 L
.2688 .60331 L
.27371 .60331 L
.279 .60331 L
.28481 .60331 L
.2946 .6033 L
.29996 .6033 L
.30496 .6033 L
.30994 .60329 L
.31537 .60328 L
Mistroke
.32016 .60328 L
.32525 .60327 L
.3303 .60325 L
.33487 .60324 L
.34379 .60321 L
.34868 .60318 L
.35384 .60315 L
.36307 .60306 L
.36822 .603 L
.37301 .60293 L
.37823 .60284 L
.38391 .60271 L
.38935 .60255 L
.39439 .60237 L
.3991 .60216 L
.4043 .60188 L
.41331 .60122 L
.41824 .60074 L
.42287 .60019 L
.43273 .5986 L
.43768 .59753 L
.44309 .59607 L
.44773 .59453 L
.45269 .59253 L
.46161 .58776 L
.46695 .58397 L
.47188 .5797 L
.47717 .57411 L
.48299 .56653 L
.49279 .5495 L
.50316 .5241 L
.51335 .48994 L
.52264 .4499 L
.54355 .33318 L
.56422 .20954 L
.57332 .1633 L
.58336 .12143 L
.59293 .09066 L
.60192 .06898 L
.61142 .05227 L
.61676 .04512 L
.62166 .0397 L
.62639 .03536 L
.63145 .03152 L
.64056 .02628 L
.64613 .0239 L
.6514 .0221 L
.65609 .0208 L
.66125 .01962 L
.67096 .01799 L
Mistroke
.67627 .01733 L
.68124 .01684 L
.69013 .01617 L
.69512 .01589 L
.69969 .01568 L
.70954 .01533 L
.71869 .01508 L
.72385 .01497 L
.72872 .01488 L
.73142 .01484 L
.73433 .01481 L
.73678 .01478 L
.73941 .01476 L
.74199 .01475 L
.74434 .01474 L
.7467 .01473 L
.74893 .01473 L
.75019 .01473 L
.75153 .01472 L
.75393 .01472 L
.75526 .01472 L
.75652 .01472 L
.75788 .01472 L
.75937 .01472 L
.76195 .01472 L
.76335 .01472 L
.76466 .01472 L
.76701 .01472 L
.76832 .01472 L
.76951 .01472 L
.77082 .01472 L
.77221 .01472 L
.77373 .01472 L
.77513 .01472 L
.77766 .01472 L
.77909 .01472 L
.78044 .01472 L
.78169 .01472 L
.78302 .01472 L
.78542 .01472 L
.78689 .01472 L
.78827 .01472 L
.78953 .01472 L
.79085 .01472 L
.79204 .01472 L
.79333 .01472 L
.79561 .01472 L
.79689 .01472 L
.79826 .01472 L
.79955 .01472 L
Mistroke
.80074 .01472 L
.80313 .01472 L
.80439 .01472 L
.80573 .01472 L
.80797 .01472 L
.80925 .01472 L
.81045 .01472 L
.81159 .01472 L
.81267 .01472 L
.8147 .01472 L
.81584 .01472 L
.81689 .01472 L
.81928 .01472 L
.82057 .01472 L
.82192 .01472 L
.82435 .01472 L
.82571 .01472 L
.82697 .01472 L
.82844 .01472 L
.82984 .01472 L
.83104 .01472 L
.83235 .01472 L
.83464 .01472 L
.83594 .01472 L
.83732 .01472 L
.83861 .01472 L
.83979 .01472 L
.84199 .01472 L
.84314 .01472 L
.84435 .01472 L
.8464 .01472 L
.84756 .01472 L
.84864 .01472 L
.84991 .01472 L
.85111 .01472 L
.85336 .01472 L
.85461 .01472 L
.85577 .01472 L
.85712 .01472 L
.8584 .01472 L
.85957 .01472 L
.86084 .01472 L
.86307 .01472 L
.86433 .01472 L
.86567 .01472 L
.86809 .01472 L
.86926 .01472 L
.87054 .01472 L
.87166 .01472 L
.87284 .01472 L
Mistroke
.87391 .01472 L
.87509 .01472 L
.87715 .01472 L
.87854 .01472 L
.87985 .01472 L
.88231 .01472 L
.88368 .01472 L
.88496 .01472 L
.88644 .01472 L
.88783 .01472 L
.89013 .01472 L
.89135 .01472 L
.89266 .01472 L
.89397 .01472 L
.89534 .01472 L
.89779 .01472 L
.89903 .01472 L
.90037 .01472 L
.90155 .01472 L
.9028 .01472 L
.90393 .01472 L
.90517 .01472 L
.90735 .01472 L
.90868 .01472 L
.9099 .01472 L
.91121 .01472 L
.91263 .01472 L
.91394 .01472 L
.91516 .01472 L
.91632 .01472 L
.91756 .01472 L
.9187 .01472 L
.91974 .01472 L
.92179 .01472 L
.92288 .01472 L
.92407 .01472 L
.92532 .01472 L
.92647 .01472 L
.92884 .01472 L
.93014 .01472 L
.93137 .01472 L
.93356 .01472 L
.9348 .01472 L
.93594 .01472 L
.93719 .01472 L
.93837 .01472 L
.9406 .01472 L
.94184 .01472 L
.94299 .01472 L
.94434 .01472 L
Mistroke
.94561 .01472 L
.94671 .01472 L
.94791 .01472 L
.94999 .01472 L
.95118 .01472 L
.95243 .01472 L
.95467 .01472 L
.95595 .01472 L
.95712 .01472 L
.95838 .01472 L
.95976 .01472 L
.96102 .01472 L
.96219 .01472 L
.9645 .01472 L
.96579 .01472 L
.96699 .01472 L
.96842 .01472 L
.96974 .01472 L
.97241 .01472 L
.97382 .01472 L
.9753 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1052.69, 325.313},
  ImageMargins->{{29, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@L0001AB000`400?l00000o`00003oo`3ooooo
0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0
ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3o
oolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?oo
o`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3o
oooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?oo
ool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0oooo
o`3ooolP0?ooo`00o`3ooolb0?ooo`060;md00000000000000000000B9`0gooo103oool00`3ookl0
M01d0;ooo`3o0?ooon00oooo00H0_g@000000000000000000018W03Oool40?ooo`030?oo_`1d07@0
_ooo0?80oooo003o0?oooc<0oooo00<0oono07@0M02oool01@3oool0103ooml0W4P00000M02ooooo
0?ooon40oooo00<0oono07@0M02oool01@3oool0103ooml0W4P00000M02oooob0?ooo`00o`3ooolc
0?ooo`030?oog`2LB7@0_ooo00D0oooo00@0_g@00000000007@0_oooo`3ooooQ0?ooo`030?oog`2L
B7@0_ooo00D0oooo00@0_g@00000000007@0_ooolP3oool00?l0oooo<`3oool00`3ooml0W4Qd0;oo
o`040?ooo`050=nLB0000000001804Q8M02oool0o`3ooooQ0?ooo`030?oog`2LB7@0_ooo00@0oooo
00D0gia80000000004P0B4Qd0;ooo`3b0?ooo`00o`3ooolc0?ooo`030?oog`2LB7@0_ooo00<0oooo
00H0okmd0000000007@0_ooO09a8M02ooooo0?ooon40oooo00<0oooO09a8M02oool00`3oool01P3o
_g@000000000M02ooml0W4Qd0;oooo80oooo003o0?oooc<0oooo00<0oooO09a8M02oool00P3oool0
1`3ogi`0B0000000B02Lgol0oooO09a8M02oool0o`3ooooQ0?ooo`030?oog`2LB7@0_ooo0080oooo
00L0omnL04P0000004P0W=oo0?oog`2LB7@0_ooo0?80oooo003o0?oooc<0oooo00`0oooO09a8M02o
ool0oooo0?oo_`1d0000000007Boo`3oool0oooO09a8M02ooooo0?ooon40oooo00`0oooO09a8M02o
ool0oooo0?oo_`1d0000000007Boo`3oool0oooO09a8M02oooob0?ooo`00o`3ooolc0?ooo`070?oo
g`2LB7@0_ooo0?oog`2LB000000004RLg`020?ooo`030?oog`2LB7@0_ooo0?l0ooooh@3oool01`3o
oml0W4Qd0;ooo`3ooml0W4P000000018W=l00P3oool00`3ooml0W4Qd0;ooo`3b0?ooo`00o`3ooolc
0?ooo`060?oog`2LB7@0_ooO09a80000000007Bo0`3oool00`3ooml0W4Qd0;ooo`3o0?ooon40oooo
00H0oooO09a8M02ooml0W4P000000000M;l30?ooo`030?oog`2LB7@0_ooo0?80oooo003o0?oooc<0
oooo00H0oooO09a8M01dM00000000018W03Oool30?ooo`030?oog`2LB7@0_ooo0?l0ooooh@3oool0
1P3ooml0W4Qd07Ad0000000004RL0=ooo`<0oooo00<0oooO09a8M02oool0lP3oool00?l0oooo<`3o
ool01@3ooml0W4P00000000007@0_ooo00@0oooo00<0oooO09a8M02oool0o`3ooooQ0?ooo`050?oo
g`2LB00000000000M02oool0103oool00`3ooml0W4Qd0;ooo`3b0?ooo`00o`3ooolc0?ooo`040=nL
B0000000001d0;ooo`D0oooo00<0oono07@0M02oool0o`3ooooQ0?ooo`040=nLB0000000001d0;oo
o`D0oooo00<0oono07@0M02oool0lP3oool00?l0oooo<@3oool01@3OW4P000000000000004P0W=oo
00@0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`3o0?ooom`0oooo00D0gia80000
00000000001809cOo`040?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0k`3oool0
0?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0oooo
o`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo
0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0
oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803o
ool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0
ooooo`3ooooo0?ooool0oooo803oool007D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`050?ooo`040;md00000000000004RLgdl0oooo00<0gia80000000000001@0000000`1d_ol0
oooo0?ooo`020?ooo`040;md00000000000004RLge40oooo00<0okmd0000000000000P0000000`00
M;l0oooo0?ooo`030?ooo`040;md00000000000004RLgdl0oooo00@0_g@0000000000000B9cOEP3o
ool00`3o_g@000000000000200000003001d_`3oool0oooo00<0oooo00@0_g@0000000000000B9cO
I03oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00@0_g@0000000000000
B9cOC`3oool00`3OW4P00000000000050000000307Boo`3oool0oooo0080oooo00@0_g@000000000
0000B9cOD03oool00`3o_g@000000000000200000003001d_`3oool0oooo00<0oooo00@0_g@00000
00000000B9cOD03oool0102oM000000000000018W=mF0?ooo`030?noM000000000000080000000<0
07Bo0?ooo`3oool00`3oool0102oM000000000000018W=la0?ooo`00M@3oool0203ogi`0B0000018
W03Oool0oooo0?oOW01804P0W=oo0`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0C`3o
ool00`3OW4P00000000000040000000:001d_`3oool0oooo0?oog`2LB00007Bo0?ooo`3ooml0W4P0
001d_e80oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0
C03oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0E`3oool00`2oM000001d0;ooo`040?oo
o`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`1S0?ooo`080?oOW018000004RL0=ooo`3oool0
omnL04P0B02Lgol30?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`1?0?ooo`030=nLB000
0000000000@0000000X007Bo0?ooo`3oool0oooO09a80000M;l0oooo0?oog`2LB00007BoD@3oool0
0`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`1=0?ooo`070?oo
g`2LB00007Bo0?ooo`3ooml0W4P0001d_`1G0?ooo`030;md000007@0_ooo00@0oooo00L0oooO09a8
0000M;l0oooo0?oog`2LB00007Bo0300oooo001k0?ooo`030?noM000B9`0gooo0080oooo00<0okmd
0000B02Lgol00P3oool00`3ogi`0B00007Boo`1?0?ooo`030=nLB018W=l0oooo0080oooo00L0oooO
09a8M02oool0oooo0?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0D@3oool00`2oM000001d
0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0B`3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo05H0oooo00<0_g@00000M02oool0103oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo06P0oooo00<0okmd0018W03Oool00P3oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo04l0oooo00<0gia804RLg`3oool00P3oool01`3ooml0W4Qd
0;ooo`3oool0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1@0?ooo`030;md000007@0_ooo
00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1<0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol0EP3oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol0;`3oool007/0oooo00P0okmd0000B02Lgol0oooo0?oog`2LB000
04RL0=ooo`80oooo00<0oooO09a80000M;l0D03oool00`3OW4P0B9cO0?ooo`040?ooo`040?oog`2L
B00004RL0=ooo`80oooo00<0oooO09a80000M;l0D@3oool00`2oM000001d0;ooo`030?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0BP3oool0103ooml0W4P00018W03Oool20?oo
o`030?oog`2LB00007Bo05H0oooo00<0_g@00000M02oool00`3oool0103ooml0W4P00018W03Oool2
0?ooo`030?oog`2LB00007Bo06P0oooo00P0okmd0000B02Lgol0oooo0?oog`2LB00004RL0=ooo`80
oooo00<0oooO09a80000M;l0D03oool00`3OW4P0B9cO0?ooo`040?ooo`040?oog`2LB00004RL0=oo
o`80oooo00<0oooO09a80000M;l0D03oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB00004RL
0=ooo`80oooo00<0oooO09a80000M;l0B`3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2L
B00007Bo05H0oooo00<0_g@00000M02oool00`3oool0103ooml0W4P00018W03Oool20?ooo`030?oo
g`2LB00007Bo02l0oooo001k0?ooo`070;md000004P0W=oo0?ooo`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo0500oooo00<0gia807Boo`3oool00`3oool00`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo0500oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`03
0;md000007@0_ooo04T0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`1E0?ooo`03
0;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`1W0?ooo`07
0;md000004P0W=oo0?ooo`3ookl0M000001d_`040?ooo`030;md000007@0_ooo0500oooo00<0gia8
07Boo`3oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo04l0oooo00<0_g@0
0000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo04X0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`1E0?ooo`030;md000007@0_ooo00<0oooo00<0oono
07@00000M;l0103oool00`2oM000001d0;ooo`0^0?ooo`00J03oool00`2oM0000000000000070000
000304RLg`3oool0oooo00D0oooo00P0_g@00000000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo
00<0_g@00000M02oool0?`3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo
00<0oooO09a8B02Lgol00`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo03l0oooo
00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030;md000007@0_ooo00<0oooo
00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`190?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool0E@3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo
00<0_g@00000M02oool0E03oool00`2oM0000000000000070000000304RLg`3oool0oooo00D0oooo
00P0_g@00000000007@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool0?`3oool0
0`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol00`3oool0
0`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo03l0oooo00<0_g@00000000000001`000000
0`18W=l0oooo0?ooo`030?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool0
0`2oM000001d0;ooo`1:0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0E@3oool0
0`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0;P3oool0
07L0oooo00<0oono07@0000000000P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0
gia80000B02Lgol0D@3oool00`3ogi`0B01d0;ooo`020?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol0D03oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol0B@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo05D0oooo00<0
_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo06<0oooo00<0
oono07@0000000000P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02L
gol0D@3oool00`3ogi`0B01d0;ooo`020?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol0C`3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol0BP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo05D0oooo00<0_g@00000M02o
ool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo02h0oooo001i0?ooo`030?no
M00004P0W=oo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`1B0?ooo`070;md
0018W=l0oooo0?ooo`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo0500oooo00<0_g@00000
M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo04T0oooo00<0omnL04P0
0018W=l0103oool00`3OW4P0001809cOo`1E0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P0
0018W=l0103oool00`3OW4P0001809cOo`1U0?ooo`030?noM00004P0W=oo00<0oooo00<0omnL04P0
0018W=l0103oool00`3OW4P0001809cOo`1B0?ooo`070;md0018W=l0oooo0?ooo`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo04l0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo04X0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`1E0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`0^0?ooo`00NP3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool0DP3oool01`3OW4P0001d0;ooo`3oool0oono07@00000M;l0103oool00`2oM000001d
0;ooo`1@0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d
0;ooo`190?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0E@3oool00`2oM000001d
0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0IP3oool00`3ogi`0B7Bo
0?ooo`020?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0DP3oool01`3OW4P0001d
0;ooo`3oool0oono07@00000M;l0103oool00`2oM000001d0;ooo`1?0?ooo`030;md000007@0_ooo
00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`1:0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool0E@3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool0;P3oool007X0oooo00<0oooO09a80018W=l00`3oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo05<0oooo00<0okmd0000001d_ol00P3oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo0540oooo00<0_g@00000M02oool0103oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo04/0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`1F0?ooo`030;md000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`1W0?ooo`030?oog`2LB000B9cO00<0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`1C0?ooo`030?noM0000000M;oo0080oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`1@0?ooo`030;md000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3oool00`3ooml0
W4P0001d_`1<0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0EP3oool00`2oM000
001d0;ooo`040?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0;`3oool007D0oooo
00<0oooO09adW03Oool00P3oool00`3ooml0W4P0001d_`030?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol0C@3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo0080oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1A0?ooo`030;md000007@0_ooo00@0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1;0?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol0EP3oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol0HP3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB00007Bo00<0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1=0?ooo`030?oOW02L_ol0oooo00<0oooo
00<0_g@00000001d_ol00P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo0500oooo
00<0_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo04`0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1F0?ooo`030;md000007@0_ooo00@0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0_0?ooo`00MP3oool01`3ogi`0B4RL0=oo
o`3oool0gia80000001d_ol0103oool01P2oM00004RL0=ooo`3oool0_g@0001d_dl0oooo00P0_g@0
07Boo`3oool0oooo0=nLB000000004RL0=ooo`<0oooo00H0_g@00018W03Oool0oooo0;md0000M;m@
0?ooo`050=nLB000000000000000M02oool01@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_dd0
oooo00H0_g@00018W03Oool0oooo0;md0000M;mE0?ooo`050=nLB000000000000000M02oool01@3o
ool01P2oM00004RL0=ooo`3oool0_g@0001d_f@0oooo00L0omnL04Q8W03Oool0oooo0=nLB0000000
M;oo00@0oooo00H0_g@00018W03Oool0oooo0;md0000M;m?0?ooo`080;md001d_ol0oooo0?ooo`3O
W4P000000018W03Oool30?ooo`060;md0000B9`0gooo0?ooo`2oM00007BoC`3oool01@3OW4P00000
0000000007@0_ooo00D0oooo00H0_g@00018W03Oool0oooo0;md0000M;m>0?ooo`060;md0000B9`0
gooo0?ooo`2oM00007BoE@3oool01@3OW4P000000000000007@0_ooo00D0oooo00H0_g@00018W03O
ool0oooo0;md0000M;l`0?ooo`00M`3oool01@3ogi`0B000000000000000B9cO00H0oooo00@0_g@0
00000000000007BoD@3oool01@2oM000000000000000000007Bo00H0oooo00@0_g@0000000000000
07BoDP3oool0103ookl0M0000000M02oool60?ooo`040;md000000000000001d_dl0oooo00@0_g@0
00000000000007BoE`3oool0103ookl0M0000000M02oool60?ooo`040;md000000000000001d_fH0
oooo00D0omnL04P000000000000004RLg`060?ooo`040;md000000000000001d_e40oooo00D0_g@0
0000000000000000001d_`060?ooo`040;md000000000000001d_e40oooo00@0oono07@0000007@0
_ooo1P3oool0102oM000000000000000M;m@0?ooo`040;md000000000000001d_eL0oooo00@0oono
07@0000007@0_ooo1P3oool0102oM000000000000000M;la0?ooo`00o`3ooooo0?ooool0ooooo`3o
oolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?oo
o`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3o
oooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?oo
ool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0oooo
o`3ooolP0?ooo`00H03oool00`3o_g@000000000000200000003001d_`3oool0oooo00L0ooooo`00
002D000004`0oooo00@0_g@0000000000000B9cO2P3ooooo000009<00000;P3oool00680oooo00<0
_g@00000M02oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04P0oooo00L0
oooO09a80000M;l0oooo0?oog`2LB00007Bo00T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0/0?ooo`00HP3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0B03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0/0?ooo`00HP3oool00`2oM000001d0;oo
o`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo04L0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0
001d_`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`1M0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02`0oooo001R0?ooo`030;md000007@0_ooo00X0oooo00<0
00000?ooo`3oool0o`3ooon@0?ooo`030000003oool0oooo04L0oooo00<0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo0?l0ooooS`3oool00`000000oooo0?oo
o`0/0?ooo`00D@3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00<0_g@0
0000M02oool02P3oool00`000000oooo0?ooo`3o0?oooi00oooo00<000000?ooo`3oool0A`3oool0
0`3ogi`0B00004RLg`040?ooo`030;md000007@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooon?
0?ooo`030000003oool0oooo02`0oooo001R0?ooo`030;md000007@0_ooo00X0oooo0`00003o0?oo
ocD0ooooDP0c0?l60?ooo`@00000B@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
00L0oooo0`00003o0?oooaD0ooooLP0c0?l60?ooo`<00000;P3oool00680oooo00<0_g@00000M02o
ool02P3oool00`000000oooo0?ooo`3o0?oooc80oooo0`0c0?l00`3o0000oooo0?ooo`1H0?ooo`03
0000003oool0oooo04L0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`03
0000003oool0oooo0?l0oooo2P3oool;03<0ogX0oooo00<000000?ooo`3oool0;03oool00680oooo
00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oooc00oooo00<0o`0003<0o`3o0000
G@3oool00`000000oooo0?ooo`170?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
1`3oool00`000000oooo0?ooo`3o0?ooo`D0oooo1@0c0?l20?l008<0oooo00<000000?ooo`3oool0
;03oool00680oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?oooc00oooo00<0
<`3o0?ooo`3oool0G@3oool00`000000oooo0?ooo`180?ooo`030;md0000B9`0gooo0080oooo00<0
oooO09a80000M;l0203oool00`000000oooo0?ooo`3o0?ooo`<0oooo0P0c0?n:0?ooo`030000003o
ool0oooo02`0oooo001R0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool0o`3oool_
0?ooo`0303<0o`3oool0oooo05h0oooo00<000000?ooo`3oool0B03oool00`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo00P0oooo00<000000?ooo`3oool0o`3oool10?ooo`80<`3o00<0o`00
0?ooo`3oool0R@3oool00`000000oooo0?ooo`0/0?ooo`00H03oool01@3OW4P000000000000007@0
_ooo00X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030?l0000c0?l0oooo0600oooo00<00000
0?ooo`3oool0B@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00<000000?ooo`3oool0
o@3oool00`3o0000<`3o03<0o`2>0?ooo`030000003oool0oooo02`0oooo001Q0?ooo`040?oo_`1d
0000001d0;ooo`X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`0303<0o`3oool0oooo0600oooo
00<000000?ooo`3oool0BP3oool0102oM000000000000000M;l:0?ooo`030000003oool0oooo0?/0
oooo00<0o`0003<0o`0c0?l0T03oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo
0?ooo`3o0?ooobd0oooo00<0<`3o0?ooo`3oool0H03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0?X0oooo0P0c0?nB0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003o
ool0oooo0?l0oooo;03oool00`0c0?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0n03oool203<0oi@0oooo00<000000?ooo`3oool0;03oool006l0oooo00<00000
0?ooo`3oool0o`3oool/0?ooo`0303<0o`3oool0oooo0640oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`3g0?ooo`0303<0o`3o0000oooo09@0oooo00<000000?ooo`3oool0;03oool0
06l0oooo00<000000?ooo`3oool0o`3oool/0?ooo`0303<0o`3oool0oooo0640oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`3f0?ooo`0303<0o`3o0000oooo09D0oooo00<000000?oo
o`3oool0;03oool006l0oooo00<000000?ooo`3oool0o`3oool[0?ooo`0303<0o`3oool0oooo0680
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3e0?ooo`0303<0o`3o0000oooo09H0
oooo00<000000?ooo`3oool0;03oool006l0oooo0P00003o0?ooob`0oooo00<0<`3o0?ooo`3oool0
H03oool3000005X0oooo0P00003e0?ooo`0303<0o`3o0000oooo09H0oooo0P00000^0?ooo`00K`3o
ool00`000000oooo0?ooo`3o0?ooob/0oooo00<0<`3o0?ooo`3oool0HP3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0?<0oooo00<0<`3o0?l0003oool0V03oool00`000000oooo0?oo
o`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<0<`3o0?ooo`3oool0H`3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?<0oooo00<0<`3o0?ooo`3oool0V03oool0
0`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<0<`3o0?oo
o`3oool0H`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?80oooo00<0<`3o0?oo
o`3oool0V@3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooobX0
oooo00<0<`3o0?ooo`3oool0H`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?80
oooo00<0<`3o0?ooo`3oool0V@3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo
0?ooo`3o0?ooobX0oooo00<0<`3o0?ooo`3oool0H`3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0?40oooo00<0<`3o0?ooo`3oool0VP3oool00`000000oooo0?ooo`0/0?ooo`00K`3o
ool00`000000oooo0?ooo`3o0?ooobT0oooo00<0o`0003<0o`3oool0I03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0?00oooo00<0o`0003<0o`3oool0V`3oool00`000000oooo0?oo
o`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooobT0oooo00<0<`3o0?ooo`3oool0I03oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?00oooo00<0<`3o0?ooo`3oool0V`3oool0
0`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooobT0oooo00<0<`3o0?oo
o`3oool0I03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0>l0oooo00<0o`0003<0
o`3oool0W03oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooobT0
oooo00<0<`3o0?ooo`3oool0I03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0>l0
oooo00<0<`3o0?ooo`3oool0W03oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo
0?ooo`3o0?ooobT0oooo00<0<`3o0?ooo`3oool0I03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0>l0oooo00<0<`3o0?ooo`3oool0W03oool00`000000oooo0?ooo`0/0?ooo`00K`3o
ool00`000000oooo0?ooo`3o0?ooobP0oooo00<0o`0003<0o`3oool0I@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0>h0oooo00<0o`0003<0o`3oool0W@3oool00`000000oooo0?oo
o`0/0?ooo`00K`3oool200000?l0oooo:@3oool00`0c0?l0oooo0?ooo`1S0?ooo`<00000FP3oool2
00000>l0oooo00<0<`3o0?ooo`3oool0W03oool2000002h0oooo001_0?ooo`030000003oool0oooo
0?l0oooo:03oool00`0c0?l0oooo0?ooo`1U0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0k@3oool00`3o0000<`3o0?ooo`2N0?ooo`030000003oool0oooo02`0oooo001_0?ooo`03
0000003oool0oooo0?l0oooo:03oool00`0c0?l0oooo0?ooo`1U0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0k@3oool00`0c0?l0oooo0?ooo`2N0?ooo`030000003oool0oooo02`0
oooo001_0?ooo`030000003oool0oooo0?l0oooo:03oool00`0c0?l0oooo0?ooo`1U0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0k@3oool00`0c0?l0oooo0?ooo`2N0?ooo`030000
003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo:03oool00`0c0?l0oooo0?oo
o`1U0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0k03oool00`0c0?l0oooo0?oo
o`2O0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo:03oool0
0`0c0?l0oooo0?ooo`1U0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0k03oool0
0`0c0?l0oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo
0?l0oooo9`3oool00`0c0?l0oooo0?ooo`1V0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0j`3oool00`0c0?l0oooo0?ooo`2P0?ooo`030000003oool0oooo02`0oooo001_0?ooo`03
0000003oool0oooo0?l0oooo9`3oool00`0c0?l0oooo0?ooo`1V0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0j`3oool00`0c0?l0oooo0?ooo`2P0?ooo`030000003oool0oooo02`0
oooo001_0?ooo`030000003oool0oooo0?l0oooo9`3oool00`0c0?l0oooo0?ooo`1V0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0jP3oool00`3o0000<`3o0?ooo`2Q0?ooo`030000
003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo9`3oool00`0c0?l0oooo0?oo
o`1V0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0jP3oool00`0c0?l0oooo0?oo
o`2Q0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo9`3oool0
0`0c0?l0oooo0?ooo`1V0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0jP3oool0
0`0c0?l0oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo001_0?ooo`800000o`3ooolX0?oo
o`0303<0o`3oool0oooo06@0oooo0`00001J0?ooo`800000jP3oool00`3o0000<`3o0?ooo`2Q0?oo
o`800000;P3oool006l0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`0303<0o`3oool0oooo06H0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3Y0?ooo`0303<0o`3oool0oooo0:80
oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`0303<0
o`3oool0oooo06L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3X0?ooo`030?l0
000c0?l0oooo0:<0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`0303<0o`3oool0oooo06L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`3X0?ooo`030?l0000c0?l0oooo0:<0oooo00<000000?ooo`3oool0;03oool006l0oooo00<00000
0?ooo`3oool0o`3ooolV0?ooo`0303<0o`3oool0oooo06L0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`3X0?ooo`0303<0o`3oool0oooo0:<0oooo00<000000?ooo`3oool0;03oool0
06l0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`0303<0o`3oool0oooo06L0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`3X0?ooo`0303<0o`3oool0oooo0:<0oooo00<000000?oo
o`3oool0;03oool006l0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`0303<0o`3oool0oooo06L0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3W0?ooo`030?l0000c0?l0oooo0:@0
oooo00<000000?ooo`3oool0;03oool00580oooo00@0_g@0000000000000B9cO103oool00`3OW4P0
000004RLg`030?ooo`060?oOW018000000000000000004P0W=oo2@3oool00`000000oooo0?ooo`3o
0?ooobH0oooo00<0<`3o0?ooo`3oool0I`3oool00`000000oooo0?ooo`0j0?ooo`040;md00000000
000004RLg`@0oooo00D0gia800000018W=l0oooo0=nLB0070000000307Boo`3oool0oooo00L0oooo
00<000000?ooo`3oool0i`3oool00`0c0?l0oooo0?ooo`2T0?ooo`030000003oool0oooo02`0oooo
001@0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO0080
oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B00007Boo`P0oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`0303<0o`3oool0oooo06L0oooo00<000000?ooo`3oool0>03oool01`3ooml0W4P0001d
_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`020?ooo`030=nLB0000000000000@0
000000<007Bo0?ooo`3oool01`3oool00`000000oooo0?ooo`3W0?ooo`0303<0o`3oool0oooo0:@0
oooo00<000000?ooo`3oool0;03oool00500oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`070?ooo`030;md000007@0_ooo00<0oooo00<0gia80018W03Oool01`3oool00`000000oooo
0?ooo`3o0?ooobH0oooo00<0<`3o0?ooo`3oool0I`3oool00`000000oooo0?ooo`0h0?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol0203oool00`3OW4P0B9cO0?ooo`020?ooo`030?oo
g`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0i`3oool00`0c0?l0oooo0?ooo`2T0?ooo`030000
003oool0oooo02`0oooo001?0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l0
1`3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo00L0oooo00<000000?ooo`3oool0
o`3ooolU0?ooo`0303<0o`3oool0oooo06P0oooo00<000000?ooo`3oool0=`3oool0103ooml0W4P0
0018W03Oool20?ooo`030?oog`2LB00007Bo00T0oooo00<0gia804RLg`3oool0303oool00`000000
oooo0?ooo`3W0?ooo`0303<0o`3oool0oooo0:@0oooo00<000000?ooo`3oool0;03oool004l0oooo
00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?ooo`030?noM00004P0W=oo0080oooo
00<0gia800000000M;l0203oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0<`3o0?ooo`3oool0
J03oool00`000000oooo0?ooo`0g0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
2@3oool00`3OW4P0M;oo0?ooo`0;0?ooo`030000003oool0oooo0>H0oooo00<0<`3o0?ooo`3oool0
Y@3oool00`000000oooo0?ooo`0/0?ooo`00@P3oool00`2oM0000000000000070000000604RLg`3o
ool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`070?ooo`070=nLB000M;l0oooo0;md
00000000001d0;ooo`080?ooo`<00000o`3ooolU0?ooo`0303<0o`3oool0oooo06D0oooo1000000i
0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02@3oool00`3ooml0W4Q809cOo`0;
0?ooo`<00000iP3oool00`0c0?l0oooo0?ooo`2S0?ooo`<00000;P3oool004l0oooo00<0omnL04P0
0018W=l0103oool00`3OW4P0001809cOo`080?ooo`050?noM000000000000018W03Oool02@3oool0
0`000000oooo0?ooo`3o0?ooobD0oooo00<0<`3o0?ooo`3oool0J03oool00`000000oooo0?ooo`0g
0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02P3oool00`3ogi`0B01d0;ooo`0:
0?ooo`030000003oool0oooo0>H0oooo00<0<`3o0?ooo`3oool0Y@3oool00`000000oooo0?ooo`0/
0?ooo`00C`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00L0oooo00D0omnL04P0
00000000000004RLg`0:0?ooo`030000003oool0oooo0?l0oooo9@3oool00`0c0?l0oooo0?ooo`1X
0?ooo`030000003oool0oooo03L0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0;
0?ooo`030;md0018W=l0oooo00T0oooo00<000000?ooo`3oool0iP3oool00`0c0?l0oooo0?ooo`2U
0?ooo`030000003oool0oooo02`0oooo001?0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000
M02oool01P3oool01`3ogi`0B0000000B02Lgol0oooo0=nLB000M;l02@3oool00`000000oooo0?oo
o`3o0?ooobD0oooo00<0<`3o0?ooo`3oool0J03oool00`000000oooo0?ooo`0g0?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool02`3oool00`3OW4P0001d0;ooo`090?ooo`030000003o
ool0oooo0>D0oooo00<0<`3o0?l0003oool0YP3oool00`000000oooo0?ooo`0/0?ooo`00D03oool0
0`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol00P3oool0
0`3ooml0W4P007Boo`080?ooo`030000003oool0oooo0?l0oooo9@3oool00`0c0?l0oooo0?ooo`1X
0?ooo`030000003oool0oooo03P0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0<
0?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool0i@3oool00`0c0?l0oooo0?ooo`2V
0?ooo`030000003oool0oooo02`0oooo001@0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO00P0oooo00<000000?oo
o`3oool0o`3ooolU0?ooo`0303<0o`3oool0oooo06P0oooo00<000000?ooo`3oool0>03oool00`3o
_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0omnL09boo`3oool00`3oool00`2o
M000000007Boo`090?ooo`030000003oool0oooo0>D0oooo00<0<`3o0?ooo`3oool0YP3oool00`00
0000oooo0?ooo`0/0?ooo`00D@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL
04P00018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo0?l0oooo903oool0
0`0c0?l0o`000?ooo`1Y0?ooo`030000003oool0oooo03T0oooo00H0_g@00018W03Oool0oooo0;md
0000M;l80?ooo`080;md001d_ol0oooo0?ooo`3OW4P000000018W03Oool90?ooo`030000003oool0
oooo0>D0oooo00<0<`3o0?ooo`3oool0YP3oool00`000000oooo0?ooo`0/0?ooo`00DP3oool0102o
M000000000000000M;l:0?ooo`060?oo_`1d000000000000000004P0W=oo2@3oool00`000000oooo
0?ooo`3o0?ooob@0oooo00<0<`3o0?ooo`3oool0J@3oool00`000000oooo0?ooo`0j0?ooo`040;md
000000000000001d_`X0oooo00D0_g@00000000000000000001d_`0;0?ooo`030000003oool0oooo
0>@0oooo00<0<`3o0?l0003oool0Y`3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000
oooo0?ooo`3o0?ooob@0oooo00<0<`3o0?ooo`3oool0J@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo0>@0oooo00<0<`3o0?l0003oool0Y`3oool00`000000oooo0?ooo`0/0?ooo`00
K`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0<`3o0?ooo`3oool0J@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0>@0oooo00<0<`3o0?ooo`3oool0Y`3oool00`000000oooo
0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0<`3o0?ooo`3oool0J@3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0>@0oooo00<0<`3o0?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0<`3o
0?ooo`3oool0J@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0><0oooo00<0<`3o
0?l0003oool0Z03oool00`000000oooo0?ooo`0/0?ooo`00K`3oool200000?l0oooo9@3oool00`0c
0?l0oooo0?ooo`1W0?ooo`<00000FP3oool200000>@0oooo00<0<`3o0?l0003oool0Y`3oool20000
02h0oooo001_0?ooo`030000003oool0oooo0?l0oooo903oool00`0c0?l0oooo0?ooo`1Y0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0h`3oool00`0c0?l0oooo0?ooo`2X0?ooo`03
0000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo8`3oool00`0c0?l0o`00
0?ooo`1Z0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0h`3oool00`0c0?l0oooo
0?ooo`2X0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo8`3o
ool00`0c0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0h`3o
ool00`0c0?l0oooo0?ooo`2X0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0
oooo0?l0oooo8`3oool00`0c0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0hP3oool00`0c0?l0o`000?ooo`2Y0?ooo`030000003oool0oooo02`0oooo001_0?oo
o`030000003oool0oooo0?l0oooo8`3oool00`0c0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0hP3oool00`0c0?l0o`000?ooo`2Y0?ooo`030000003oool0oooo
02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo8`3oool00`0c0?l0oooo0?ooo`1Z0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0hP3oool00`0c0?l0oooo0?ooo`2Y0?ooo`03
0000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo8`3oool00`0c0?l0oooo
0?ooo`1Z0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0hP3oool00`0c0?l0oooo
0?ooo`2Y0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo8`3o
ool00`0c0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0h@3o
ool00`0c0?l0o`000?ooo`2Z0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0
oooo0?l0oooo8`3oool00`0c0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0h@3oool00`0c0?l0o`000?ooo`2Z0?ooo`030000003oool0oooo02`0oooo001_0?oo
o`030000003oool0oooo0?l0oooo8P3oool00`0c0?l0o`000?ooo`1[0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0h@3oool00`0c0?l0oooo0?ooo`2Z0?ooo`030000003oool0oooo
02`0oooo001_0?ooo`030000003oool0oooo0?l0oooo8P3oool00`0c0?l0o`000?ooo`1[0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0h@3oool00`0c0?l0oooo0?ooo`2Z0?ooo`03
0000003oool0oooo02`0oooo001_0?ooo`800000o`3ooolS0?ooo`0303<0o`3oool0oooo06T0oooo
0`00001J0?ooo`800000hP3oool00`0c0?l0oooo0?ooo`2Y0?ooo`800000;P3oool006l0oooo00<0
00000?ooo`3oool0o`3ooolR0?ooo`0303<0o`3oool0oooo06/0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`3P0?ooo`0303<0o`3o0000oooo0:/0oooo00<000000?ooo`3oool0;03o
ool006l0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`0303<0o`3oool0oooo06/0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`3P0?ooo`0303<0o`3o0000oooo0:/0oooo00<00000
0?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`0303<0o`3oool0oooo
06/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3P0?ooo`0303<0o`3oool0oooo
0:/0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`03
03<0o`3oool0oooo06/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3P0?ooo`03
03<0o`3oool0oooo0:/0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0
o`3ooolR0?ooo`0303<0o`3oool0oooo06/0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`3O0?ooo`0303<0o`3o0000oooo0:`0oooo00<000000?ooo`3oool0;03oool006l0oooo00<0
00000?ooo`3oool0o`3ooolQ0?ooo`0303<0o`3o0000oooo06`0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`3O0?ooo`0303<0o`3o0000oooo0:`0oooo00<000000?ooo`3oool0;03o
ool006l0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`0303<0o`3o0000oooo06`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`3O0?ooo`0303<0o`3o0000oooo0:`0oooo00<00000
0?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`0303<0o`3oool0oooo
06`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3O0?ooo`0303<0o`3o0000oooo
0:`0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`03
03<0o`3oool0oooo06`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3O0?ooo`03
03<0o`3oool0oooo0:`0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0
o`3ooolQ0?ooo`0303<0o`3oool0oooo06`0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`3O0?ooo`0303<0o`3oool0oooo0:`0oooo00<000000?ooo`3oool0;03oool006l0oooo00<0
00000?ooo`3oool0o`3ooolQ0?ooo`0303<0o`3oool0oooo06`0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`3N0?ooo`0303<0o`3o0000oooo0:d0oooo00<000000?ooo`3oool0;03o
ool006l0oooo0P00003o0?ooob80oooo00<0<`3o0?ooo`3oool0JP3oool3000005X0oooo0P00003O
0?ooo`0303<0o`3o0000oooo0:`0oooo0P00000^0?ooo`00K`3oool00`000000oooo0?ooo`3o0?oo
ob40oooo00<0<`3o0?ooo`3oool0K03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
0=h0oooo00<0<`3o0?l0003oool0[@3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000
oooo0?ooo`3o0?ooob00oooo00<0<`3o0?l0003oool0K@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo0=h0oooo00<0<`3o0?l0003oool0[@3oool00`000000oooo0?ooo`0/0?ooo`00
K`3oool00`000000oooo0?ooo`3o0?ooob00oooo00<0<`3o0?l0003oool0K@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0=h0oooo00<0<`3o0?ooo`3oool0[@3oool00`000000oooo
0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooob00oooo00<0<`3o0?ooo`3oool0K@3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0=h0oooo00<0<`3o0?ooo`3oool0[@3o
ool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3o0?ooob00oooo00<0<`3o
0?ooo`3oool0K@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0=d0oooo00<0<`3o
0?l0003oool0[P3oool00`000000oooo0?ooo`0/0?ooo`00DP3oool0102oM000000000000018W=l4
0?ooo`030=nLB0000000B9cO00<0oooo00H0oooO09a80000000000000000M02oool90?ooo`030000
003oool0oooo0?l0oooo803oool00`0c0?l0oooo0?ooo`1]0?ooo`030000003oool0oooo03X0oooo
00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo00X0
oooo00<000000?ooo`3oool0g@3oool00`0c0?l0o`000?ooo`2^0?ooo`030000003oool0oooo02`0
oooo001@0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO
0080oooo00P0oono07@00000B9`0gooo0?ooo`3OW4P0001809cOo`P0oooo00<000000?ooo`3oool0
o`3ooolP0?ooo`0303<0o`3oool0oooo06d0oooo00<000000?ooo`3oool0>03oool01`3ooml0W4P0
001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`060?ooo`030?noM0000000M;oo
00X0oooo00<000000?ooo`3oool0g@3oool00`0c0?l0o`000?ooo`2^0?ooo`030000003oool0oooo
02`0oooo001@0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000
001d0;ooo`030?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`03
03<0o`3oool0oooo06d0oooo00<000000?ooo`3oool0>03oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo00/0oooo00<0okmd0000001d_ol02P3oool00`000000oooo0?ooo`3M0?ooo`03
03<0o`3o0000oooo0:h0oooo00<000000?ooo`3oool0;03oool004l0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030?oo_`1d000007Bo00@0oooo00<0gia80000M02o
ool01`3oool00`000000oooo0?ooo`3o0?oooal0oooo00<0<`3o0?l0003oool0KP3oool00`000000
oooo0?ooo`0g0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01P3oool00`3O
W4P0000000000005000000030000B02Lgol0oooo00L0oooo00<000000?ooo`3oool0g@3oool00`0c
0?l0oooo0?ooo`2^0?ooo`030000003oool0oooo02`0oooo001?0?ooo`030?oo_`1d000007Bo00@0
oooo00<0_g@00000M02oool01@3oool00`3ogi`0B00004RLg`040?ooo`030;md000004P0W=oo00L0
oooo00<000000?ooo`3oool0o`3ooolO0?ooo`0303<0o`3o0000oooo06h0oooo00<000000?ooo`3o
ool0=`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04Qd_`3o
ool00P3oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo0=d0oooo00<0<`3o0?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0/0?ooo`00@P3oool00`2oM0000000000000070000000604RL
g`3oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`050?ooo`030?oOW0180000B9cO
00<0oooo00@0oono07@0000007@0_ooo1`3oool00`000000oooo0?ooo`3o0?oooal0oooo00<0<`3o
0?ooo`3oool0KP3oool00`000000oooo0?ooo`0g0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@0
0000M02oool01P3oool01`3OW4P0M;oo0?ooo`3oool0okmd0000001d_ol02P3oool00`000000oooo
0?ooo`3L0?ooo`0303<0o`3o0000oooo0:l0oooo00<000000?ooo`3oool0;03oool002d0oooo00<0
okmd07Boo`3oool01P3oool00`2oM7@0_ooo0?ooo`0F0?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol01@3oool02@3ookl0M00000000000B9`0gooo0?ooo`2oM000000004RLg`080?oo
o`<00000o`3ooolO0?ooo`0303<0o`3oool0oooo06/0oooo1000000U0?ooo`030?noM01d_ol0oooo
00H0oooo00<0_gAd0;ooo`3oool0203oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
00H0oooo00L0oono07@0M02oool0oooo0?noM0000000M;oo00X0oooo0`00003L0?ooo`0303<0o`3o
0000oooo0:d0oooo0`00000^0?ooo`00;@3oool00`3o_g@0001d0;ooo`040?ooo`040?oog`2LB000
001d0;oooaL0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`050?oog`2L
B000001d0;oOW01800000P0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
7`3oool00`0c0?l0oooo0?ooo`1^0?ooo`030000003oool0oooo02<0oooo00<0okmd0000M02oool0
103oool0103ooml0W4P00000M02oool90?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02L
gol01`3oool01P3o_g@007Bo0?ooo`3o_g@0000007Boo`X0oooo00<000000?ooo`3oool0g03oool0
0`0c0?l0o`000?ooo`2_0?ooo`030000003oool0oooo02`0oooo000]0?ooo`040?noM00000000000
04RLg`80oooo00D0oono07@0B02Lgol0gibL0;ooo`0G0?ooo`030?oo_`1d000007Bo00@0oooo00<0
_g@00000M02oool01P3oool00`3o_g@0000004RLg`0=0?ooo`030000003oool0oooo0?l0oooo7`3o
ool00`0c0?l0oooo0?ooo`1^0?ooo`030000003oool0oooo02<0oooo00@0okmd000000000000B9cO
0P3oool01@3ookl0M01809cOo`3OW9`0_ooo00T0oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`080?ooo`050;md001d_ol0okmd0000001d_ol02P3oool00`000000oooo0?ooo`3L0?oo
o`0303<0o`3o0000oooo0:l0oooo00<000000?ooo`3oool0;03oool002d0oooo00P0oknL09cOo`3O
W4P000000000B01dM4P0001d0;oooa/0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d
_`070?ooo`040?oog`2LB000001809cOo``0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`0303<0
o`3o0000oooo06l0oooo00<000000?ooo`3oool08`3oool0203o_i`0W=oo0=nLB0000000001807Ad
B00007@0_ooo3@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00T0oooo00D0oono
07@0M02o_g@0000007Boo`0:0?ooo`030000003oool0oooo0=`0oooo00<0<`3o0?ooo`3oool0[`3o
ool00`000000oooo0?ooo`0/0?ooo`00<03oool0103ookl0M00000000000M;lL0?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol0203oool0103ookl0M0000000M02oool;0?ooo`030000
003oool0oooo0?l0oooo7P3oool00`0c0?l0o`000?ooo`1_0?ooo`030000003oool0oooo02H0oooo
00@0oono07@00000000007Bo3P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00X0
oooo00@0okmd000000000000M;oo2P3oool00`000000oooo0?ooo`3L0?ooo`0303<0o`3oool0oooo
0:l0oooo00<000000?ooo`3oool0;03oool002d0oooo00/0oknL09cOo`3o_g@0001809cOo`3OW4P0
00000000B02Lgol0gibL0;ooo`0I0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2P3oool0103o
oml0W4P000000000M;l:0?ooo`030000003oool0oooo0?l0oooo7P3oool00`0c0?l0oooo0?ooo`1_
0?ooo`030000003oool0oooo02<0oooo00/0oknL09cOo`3o_g@0001809cOo`3OW4P000000000B02L
gol0gibL0;ooo`0;0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2`3oool0103ooml0W4P00000
001d_ol:0?ooo`030000003oool0oooo0=/0oooo00<0<`3o0?l0003oool0/03oool00`000000oooo
0?ooo`0/0?ooo`00;@3oool00`3o_g@00000001d_`030?ooo`050?oo_`1d000000000000M02oool0
6P3oool0102oM000000000000000M;l=0?ooo`050?oOW018000000000018W03Oool01`3oool00`00
0000oooo0?ooo`3o0?oooah0oooo00<0<`3o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0S0?oo
o`030?noM000000007Bo00<0oooo00D0oono07@000000000001d0;ooo`0<0?ooo`040;md00000000
0000001d_`d0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3K0?ooo`0303<0o`3o
0000oooo0;00oooo00<000000?ooo`3oool0;03oool002d0oooo00<0okmd04RLg`3oool01@3oool0
0`3OW4P0001d0;ooo`0g0?ooo`030000003oool0oooo0?l0oooo7P3oool00`0c0?l0oooo0?ooo`1_
0?ooo`030000003oool0oooo02<0oooo00<0okmd04RLg`3oool01@3oool00`3OW4P0001d0;ooo`0Z
0?ooo`030000003oool0oooo0=/0oooo00<0<`3o0?l0003oool0/03oool00`000000oooo0?ooo`0/
0?ooo`00;@3oool00`3o_i`0W=oo0?ooo`060?ooo`030;mdM02oool0oooo03H0oooo00<000000?oo
o`3oool0o`3ooolM0?ooo`0303<0o`3o0000oooo0700oooo00<000000?ooo`3oool08`3oool00`3o
_i`0W=oo0?ooo`060?ooo`030;mdM02oool0oooo02T0oooo00<000000?ooo`3oool0f`3oool00`0c
0?l0o`000?ooo`2`0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0?l0
oooo7@3oool00`0c0?l0oooo0?ooo`1`0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0f`3oool00`0c0?l0oooo0?ooo`2`0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000
003oool0oooo0?l0oooo7@3oool00`0c0?l0oooo0?ooo`1`0?ooo`030000003oool0oooo02L0oooo
00<0_g@000000018W=l0;P3oool00`000000oooo0?ooo`3K0?ooo`0303<0o`3oool0oooo0;00oooo
00<000000?ooo`3oool0;03oool002/0oooo00<0gia80000B02Lgol01`3oool00`3ookl0M01d0;oo
o`0g0?ooo`800000o`3ooolN0?ooo`0303<0o`3oool0oooo06h0oooo0`00000W0?ooo`050?oOW018
0000M;oO09a80018W=l0;P3oool200000=`0oooo00<0<`3o0?ooo`3oool0[`3oool2000002h0oooo
000Z0?ooo`030;md0018W=l0oooo00L0oooo00@0omnL04P0000007@0_ooo=`3oool00`000000oooo
0?ooo`3o0?oooa`0oooo00<0<`3o0?ooo`3oool0L@3oool00`000000oooo0?ooo`0T0?ooo`060;md
0000B9`0gooo0?oog`2LB000B9cO;P3oool00`000000oooo0?ooo`3J0?ooo`0303<0o`3o0000oooo
0;40oooo00<000000?ooo`3oool0;03oool002T0oooo00<0omnL04P0B02Lgol01`3oool01@3OW4P0
04RL0;nLB00007@0_ooo03L0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`0303<0o`3oool0oooo
0740oooo00<000000?ooo`3oool08P3oool00`3ogi`0B00007Boo`020?ooo`030?oog`2LB000B9cO
02h0oooo00<000000?ooo`3oool0fP3oool00`0c0?l0o`000?ooo`2a0?ooo`030000003oool0oooo
02`0oooo000Y0?ooo`030?noM0000000M;oo00D0oooo00L0oooO09a80018W=l0oooo0=nLB00007@0
_ooo03L0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030?l0000c0?l0oooo0780oooo00<00000
0?ooo`3oool08@3oool00`3OW4P004RL0=ooo`030?ooo`030?oog`2LB000B9cO02h0oooo00<00000
0?ooo`3oool0fP3oool00`0c0?l0oooo0?ooo`2a0?ooo`030000003oool0oooo02`0oooo000Y0?oo
o`040?oOW0180000001809cOo`80oooo00@0oooO09a800000000M;oo0P3oool00`3OW4P0001d0;oo
o`0g0?ooo`030000003oool0oooo0?l0oooo6`3oool00`0c0?l0oooo0?ooo`1b0?ooo`030000003o
ool0oooo01l0oooo00<0omnL04P0000000002P0000000`0007@0_ooo0?ooo`0Y0?ooo`030000003o
ool0oooo0=X0oooo00<0<`3o0?ooo`3oool0/@3oool00`000000oooo0?ooo`0/0?ooo`00:@3oool0
0`3ooml0W4P000000004000000030000M02oool0oooo0080oooo00<0gia80000M02oool0=`3oool0
0`000000oooo0?ooo`3o0?oooaX0oooo00<0o`0003<0o`3oool0L`3oool00`000000oooo0?ooo`0O
0?ooo`030?noM0000000000000X0000000<0001d0;ooo`3oool0:@3oool00`000000oooo0?ooo`3J
0?ooo`0303<0o`3oool0oooo0;40oooo00<000000?ooo`3oool0;03oool002X0oooo00H0oooO09a8
0000000000000000B02Lgol40?ooo`040?oog`2LB000001d0;ooocL0oooo00<000000?ooo`3oool0
o`3ooolJ0?ooo`0303<0o`3oool0oooo07<0oooo00<000000?ooo`3oool09`3oool00`3ooml0W4P0
04RLg`0^0?ooo`030000003oool0oooo0=X0oooo00<0<`3o0?ooo`3oool0/@3oool00`000000oooo
0?ooo`0/0?ooo`00=03oool00`3OW4P0001d0;ooo`0h0?ooo`030000003oool0oooo0?l0oooo6P3o
ool00`0c0?l0oooo0?ooo`1c0?ooo`030000003oool0oooo02L0oooo00<0oooO09a80018W=l0;P3o
ool00`000000oooo0?ooo`3I0?ooo`0303<0o`3o0000oooo0;80oooo00<000000?ooo`3oool0;03o
ool006l0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`0303<0o`3o0000oooo07@0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`3I0?ooo`0303<0o`3o0000oooo0;80oooo00<00000
0?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`0303<0o`3o0000oooo
07D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3I0?ooo`0303<0o`3oool0oooo
0;80oooo00<000000?ooo`3oool0;03oool002T0oooo00<0gia80000000000003`0000000`1d_ol0
oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0oooo5`3oool00`0c0?l0o`000?ooo`1f0?ooo`03
0000003oool0oooo01l0oooo00<0gia80000000000003`0000000`1d_ol0oooo0?ooo`0T0?ooo`03
0000003oool0oooo0=T0oooo00<0<`3o0?ooo`3oool0/P3oool00`000000oooo0?ooo`0/0?ooo`00
:@3oool00`3OW9`0_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo0380oooo00<000000?ooo`3oool0
o`3ooolE0?ooo`80<`3o00<0o`000?ooo`3oool0MP3oool00`000000oooo0?ooo`0O0?ooo`030=nL
W02oool0oooo00h0oooo00<0okmd07Boo`3oool09@3oool00`000000oooo0?ooo`3I0?ooo`0303<0
o`3oool0oooo0;80oooo00<000000?ooo`3oool0;03oool002T0oooo00<0gibL0;ooo`3oool03P3o
ool00`3o_g@0M;oo0?ooo`0b0?ooo`800000o`3ooolA0?ooo`D0<`3oN@3oool300000240oooo00<0
gibL0;ooo`3oool03P3oool00`3o_g@0M;oo0?ooo`0U0?ooo`800000fP3oool00`0c0?l0oooo0?oo
o`2a0?ooo`800000;P3oool002T0oooo00<0gibL0;ooo`3oool03P3oool00`3o_g@0M;oo0?ooo`0b
0?ooo`030000003oool0oooo0?l0oooo1`3oool903<0o`030?l0003oool0oooo07d0oooo00<00000
0?ooo`3oool07`3oool00`3OW9`0_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo02D0oooo00<00000
0?ooo`3oool0f03oool00`0c0?l0o`000?ooo`2c0?ooo`030000003oool0oooo02`0oooo001_0?oo
o`030000003oool0oooo0?l0oooo0@3oool603<0ohT0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`3H0?ooo`0303<0o`3oool0oooo0;<0oooo00<000000?ooo`3oool0;03oool002T0
oooo00<0oknL09cOo`3oool0@`3oool00`000000oooo0?ooo`3l0?ooo`050?l0000c0?l0<`3o03<0
o`3o0000SP3oool00`000000oooo0?ooo`0O0?ooo`030?noW02Lgol0oooo03H0oooo00<000000?oo
o`3oool0f03oool00`0c0?l0oooo0?ooo`2c0?ooo`030000003oool0oooo02`0oooo000Y0?ooo`03
0?noM01d_ol0oooo00X0oooo00<0gibL0;ooo`3oool0=P3oool00`000000oooo0?ooo`3i0?ooo`@0
<`3oTP3oool00`000000oooo0?ooo`0O0?ooo`030?noM01d_ol0oooo00X0oooo00<0gibL0;ooo`3o
ool0:@3oool00`000000oooo0?ooo`3H0?ooo`0303<0o`3oool0oooo0;<0oooo00<000000?ooo`3o
ool0;03oool002T0oooo00<0okmd0018W03Oool02P3oool00`2oM7@0_ooo0?ooo`0f0?ooo`030000
003oool0oooo0?H0oooo00<0o`0003<0o`0c0?l0UP3oool00`000000oooo0?ooo`0O0?ooo`030?no
M000B9`0gooo00X0oooo00<0_gAd0;ooo`3oool0:@3oool00`000000oooo0?ooo`3H0?ooo`0303<0
o`3oool0oooo0;<0oooo00<000000?ooo`3oool0;03oool002T0oooo00<0okmd0000000000002P00
00000`0007@0_ooo0?ooo`0f0?ooo`030000003oool0oooo0?D0oooo0P0c0?nH0?ooo`030000003o
ool0oooo01l0oooo00<0okmd0000000000002P0000000`0007@0_ooo0?ooo`0Y0?ooo`030000003o
ool0oooo0=P0oooo00<0<`3o0?ooo`3oool0/`3oool00`000000oooo0?ooo`0/0?ooo`00:P3oool0
102oM00000000000B02Lgol80?ooo`030;mdM02oool0oooo03H0oooo00<000000?ooo`3oool0m03o
ool00`0c0?l0oooo0?ooo`2H0?ooo`030000003oool0oooo0200oooo00@0_g@00000000004P0W=oo
203oool00`2oM7@0_ooo0?ooo`0Y0?ooo`030000003oool0oooo0=L0oooo00<0<`3o0?l0003oool0
]03oool00`000000oooo0?ooo`0/0?ooo`00:`3oool0103OW4P000000000001d_ol70?ooo`030=nL
W02oool0oooo03H0oooo00<000000?ooo`3oool0lP3oool00`3o0000<`3o0?ooo`2J0?ooo`030000
003oool0oooo0240oooo00@0gia8000000000000M;oo1`3oool00`3OW9`0_ooo0?ooo`0Y0?ooo`03
0000003oool0oooo0=L0oooo00<0<`3o0?ooo`3oool0]03oool00`000000oooo0?ooo`0/0?ooo`00
;03oool0103o_g@0000000000000M;lo0?ooo`030000003oool0oooo0?40oooo00<0o`0003<0o`3o
ool0V`3oool00`000000oooo0?ooo`0R0?ooo`040?noM00000000000001d_c80oooo00<000000?oo
o`3oool0e`3oool00`0c0?l0oooo0?ooo`2d0?ooo`030000003oool0oooo02`0oooo000]0?ooo`05
0?oOW018000000000018W03Oool0?@3oool00`000000oooo0?ooo`3`0?ooo`80<`3oW@3oool00`00
0000oooo0?ooo`0S0?ooo`050?oOW018000000000018W03Oool0<03oool00`000000oooo0?ooo`3G
0?ooo`0303<0o`3oool0oooo0;@0oooo00<000000?ooo`3oool0;03oool002h0oooo00D0oono07@0
00000000001809cOo`0l0?ooo`030000003oool0oooo0>l0oooo00<0<`3o0?ooo`3oool0W@3oool0
0`000000oooo0?ooo`0T0?ooo`050?oo_`1d000000000000B02Lgol0;`3oool00`000000oooo0?oo
o`3G0?ooo`0303<0o`3oool0oooo0;@0oooo00<000000?ooo`3oool0;03oool002l0oooo00D0oooO
09a800000000000007Boo`0k0?ooo`800000k`3oool00`0c0?l0oooo0?ooo`2L0?ooo`<000009`3o
ool01@3ooml0W4P0000000000000M;oo02h0oooo0P00003H0?ooo`0303<0o`3oool0oooo0;<0oooo
0P00000^0?ooo`00:@3oool00`3o_i`0W=oo0?ooo`050?ooo`040;md000000000000001d_cX0oooo
00<000000?ooo`3oool0k@3oool00`0c0?l0oooo0?ooo`2O0?ooo`030000003oool0oooo01l0oooo
00<0oknL09cOo`3oool01@3oool0102oM000000000000000M;l]0?ooo`030000003oool0oooo0=H0
oooo00<0<`3o0?ooo`3oool0]@3oool00`000000oooo0?ooo`0/0?ooo`00:@3oool00`3o_g@0M;oo
0?ooo`060?ooo`050=nLB000000000000018W03Oool0>03oool00`000000oooo0?ooo`3/0?ooo`03
0?l0000c0?l0oooo0:00oooo00<000000?ooo`3oool07`3oool00`3o_g@0M;oo0?ooo`060?ooo`05
0=nLB000000000000018W03Oool0:`3oool00`000000oooo0?ooo`3F0?ooo`0303<0o`3oool0oooo
0;D0oooo00<000000?ooo`3oool0;03oool002T0oooo00<0okmd0000000000002P0000000`0004P0
W=oo0?ooo`0f0?ooo`030000003oool0oooo0>`0oooo00<0<`3o0?ooo`3oool0X03oool00`000000
oooo0?ooo`0O0?ooo`030?noM0000000000000X0000000<0001809cOo`3oool0:@3oool00`000000
oooo0?ooo`3F0?ooo`0303<0o`3oool0oooo0;D0oooo00<000000?ooo`3oool0;03oool002T0oooo
00<0okmd07Boo`3oool0@`3oool00`000000oooo0?ooo`3[0?ooo`0303<0o`3oool0oooo0:40oooo
00<000000?ooo`3oool07`3oool00`3o_g@0M;oo0?ooo`0f0?ooo`030000003oool0oooo0=H0oooo
00<0<`3o0?ooo`3oool0]@3oool00`000000oooo0?ooo`0/0?ooo`00:@3oool00`3o_i`0W=oo0?oo
o`130?ooo`030000003oool0oooo0>X0oooo00<0<`3o0?ooo`3oool0XP3oool00`000000oooo0?oo
o`0O0?ooo`030?noW02Lgol0oooo03H0oooo00<000000?ooo`3oool0eP3oool00`0c0?l0oooo0?oo
o`2e0?ooo`030000003oool0oooo02`0oooo001B0?ooo`040;md00000000000004RLg`@0oooo00<0
gia800000018W=l01P3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo0>T0oooo00<0
o`0003<0o`3oool0X`3oool00`000000oooo0?ooo`0j0?ooo`040;md00000000000004RLg`@0oooo
00<0gia800000018W=l00`3oool01P3ooml0W4P0000000000000001d0;ooo`X0oooo00<000000?oo
o`3oool0eP3oool00`0c0?l0oooo0?ooo`2e0?ooo`030000003oool0oooo02`0oooo001@0?ooo`07
0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO00H0oooo00<0okmd
0000001d_ol02@3oool00`000000oooo0?ooo`3Y0?ooo`0303<0o`3oool0oooo0:<0oooo00<00000
0?ooo`3oool0>03oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P00000
04RLg`020?ooo`080?oo_`1d000004RL0=ooo`3oool0gia80000B02Lgol90?ooo`030000003oool0
oooo0=D0oooo00<0<`3o0?ooo`3oool0]P3oool00`000000oooo0?ooo`0/0?ooo`00D03oool00`3o
_g@0001809cOo`020?ooo`030?oOW0180000M;oo00/0oooo00<0okmd0000001d_ol02@3oool00`00
0000oooo0?ooo`3X0?ooo`0303<0o`3oool0oooo0:@0oooo00<000000?ooo`3oool0>03oool00`3o
_g@0001809cOo`020?ooo`030?oOW0180000M;oo00L0oooo00<0_g@00000M02oool00`3oool00`2o
M00007Bo0?ooo`080?ooo`030000003oool0oooo0=D0oooo00<0<`3o0?ooo`3oool0]P3oool00`00
0000oooo0?ooo`0/0?ooo`00:@3oool00`3OW9`0_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo0180
oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB00000000000
00D0000000<0001809cOo`3oool01P3oool00`000000oooo0?ooo`3X0?ooo`0303<0o`3oool0oooo
0:@0oooo00<000000?ooo`3oool07`3oool00`3OW9`0_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo
00@0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`060?ooo`030?oo_`1d0000
07Bo00@0oooo00<0gia80000M02oool0203oool00`000000oooo0?ooo`3E0?ooo`0303<0o`3oool0
oooo0;H0oooo00<000000?ooo`3oool0;03oool002T0oooo00<0gibL0;ooo`3oool03P3oool00`3o
_g@0M;oo0?ooo`0B0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3o
gi`0B7Bo0?ooo`020?ooo`030?noM0000000M;oo00T0oooo00<000000?ooo`3oool0i`3oool00`0c
0?l0oooo0?ooo`2U0?ooo`030000003oool0oooo01l0oooo00<0gibL0;ooo`3oool03P3oool00`3o
_g@0M;oo0?ooo`040?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01@3oool00`3o
gi`0B00004RLg`040?ooo`030;md000004P0W=oo00P0oooo00<000000?ooo`3oool0e@3oool00`0c
0?l0oooo0?ooo`2f0?ooo`030000003oool0oooo02`0oooo000Y0?ooo`030=nLW02oool0oooo00h0
oooo00<0okmd07Boo`3oool01@3oool00`2oM0000000000000070000000604RLg`3oool0oooo0?oO
W0180000B9cO103oool00`2oM000001d0;ooo`060?ooo`070=nLB01d_ol0oooo0?ooo`3o_g@00000
07Boo`090?ooo`030000003oool0oooo0>H0oooo00<0<`3o0?l0003oool0YP3oool00`000000oooo
0?ooo`0O0?ooo`030=nLW02oool0oooo00h0oooo00<0okmd07Boo`3oool0103oool00`3ogi`0B000
04RLg`040?ooo`030;md000007@0_ooo00D0oooo00<0omnL04P00018W=l00`3oool0103ookl0M000
0000M02oool80?ooo`030000003oool0oooo0=D0oooo00<0<`3o0?ooo`3oool0]P3oool00`000000
oooo0?ooo`0/0?ooo`00:@3oool00`3OW4P000000000000?0000000307Boo`3oool0oooo0140oooo
00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o
_g@0000007Boo`090?ooo`<00000iP3oool00`0c0?l0oooo0?ooo`2S0?ooo`@000008@3oool00`3O
W4P000000000000?0000000307Boo`3oool0oooo00<0oooo00<0omnL04P00018W=l0103oool00`3O
W4P0001809cOo`050?ooo`090?oo_`1d000000000018W03Oool0oooo0;md00000000B9cO00T0oooo
0`00003D0?ooo`030?l0000c0?l0oooo0;D0oooo0`00000^0?ooo`00C`3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo00L0oooo00H0okmd001d_`3oool0okmd0000001d_ol90?ooo`03
0000003oool0oooo0>D0oooo00<0<`3o0?l0003oool0Y`3oool00`000000oooo0?ooo`0g0?ooo`03
0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol01@3oool01@3ooml0W4P00000M02ogi`0B000
0080000000<0B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`3D0?ooo`0303<0o`3oool0oooo
0;L0oooo00<000000?ooo`3oool0;03oool004l0oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`080?ooo`050;md001d_ol0okmd0000001d_ol02@3oool00`000000oooo0?ooo`3U0?oo
o`0303<0o`3oool0oooo0:L0oooo00<000000?ooo`3oool0=`3oool00`3ookl0M000001d_`040?oo
o`030;md000007@0_ooo00H0oooo00<0okmd00000018W=l03P3oool00`000000oooo0?ooo`3D0?oo
o`0303<0o`3oool0oooo0;L0oooo00<000000?ooo`3oool0;03oool00500oooo00<0_g@00018W03O
ool00P3oool00`3ooml0W4P0001d_`090?ooo`050?oo_`1d07@0_kmd0000001d_ol02@3oool00`00
0000oooo0?ooo`3T0?ooo`0303<0o`3o0000oooo0:P0oooo00<000000?ooo`3oool0>03oool00`2o
M00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00L0oooo00@0oooO09a8000004P0W=oo3@3oool0
0`000000oooo0?ooo`3D0?ooo`0303<0o`3oool0oooo0;L0oooo00<000000?ooo`3oool0;03oool0
0500oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0:0?ooo`040?noM00000000000
07Boo`T0oooo00<000000?ooo`3oool0i03oool00`0c0?l0oooo0?ooo`2X0?ooo`030000003oool0
oooo03P0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`040?oo_`1d0000
001d0;ooo``0oooo00<000000?ooo`3oool0e03oool00`0c0?l0oooo0?ooo`2g0?ooo`030000003o
ool0oooo02`0oooo001A0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2`3oool0103ooml0W4P0
0000001d_ol90?ooo`030000003oool0oooo0><0oooo00<0<`3o0?l0003oool0Z@3oool00`000000
oooo0?ooo`0i0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2P3oool0103ooml0W4P000000000
M;l;0?ooo`030000003oool0oooo0=@0oooo00<0<`3o0?ooo`3oool0]`3oool00`000000oooo0?oo
o`0/0?ooo`00DP3oool0102oM000000000000000M;l=0?ooo`030?oOW0180000M;oo00T0oooo00<0
00000?ooo`3oool0h`3oool00`0c0?l0oooo0?ooo`2Y0?ooo`030000003oool0oooo03X0oooo00@0
_g@000000000000007Bo3@3oool01@3ogi`0B00000000000B9`0gooo00P0oooo00<000000?ooo`3o
ool0d`3oool00`3o0000<`3o0?ooo`2h0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000
003oool0oooo0><0oooo00<0<`3o0?ooo`3oool0Z@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0=<0oooo00<0<`3o0?ooo`3oool0^03oool00`000000oooo0?ooo`0/0?ooo`00K`3o
ool00`000000oooo0?ooo`3R0?ooo`0303<0o`3oool0oooo0:X0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`3C0?ooo`0303<0o`3oool0oooo0;P0oooo00<000000?ooo`3oool0;03o
ool006l0oooo00<000000?ooo`3oool0hP3oool00`0c0?l0oooo0?ooo`2Z0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0d`3oool00`0c0?l0oooo0?ooo`2h0?ooo`030000003oool0
oooo02`0oooo001_0?ooo`030000003oool0oooo0>80oooo00<0<`3o0?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0=<0oooo00<0<`3o0?ooo`3oool0^03oool00`00
0000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3Q0?ooo`0303<0o`3oool0oooo0:/0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3C0?ooo`0303<0o`3oool0oooo0;P0
oooo00<000000?ooo`3oool0;03oool006l0oooo0P00003R0?ooo`0303<0o`3oool0oooo0:T0oooo
0`00001J0?ooo`800000d`3oool00`3o0000<`3o0?ooo`2h0?ooo`800000;P3oool006l0oooo00<0
00000?ooo`3oool0h@3oool00`0c0?l0oooo0?ooo`2[0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0dP3oool00`0c0?l0oooo0?ooo`2i0?ooo`030000003oool0oooo02`0oooo001_
0?ooo`030000003oool0oooo0>00oooo00<0<`3o0?ooo`3oool0[03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo0=80oooo00<0<`3o0?ooo`3oool0^@3oool00`000000oooo0?ooo`0/
0?ooo`00K`3oool00`000000oooo0?ooo`3P0?ooo`0303<0o`3oool0oooo0:`0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`3B0?ooo`0303<0o`3oool0oooo0;T0oooo00<000000?oo
o`3oool0;03oool006l0oooo00<000000?ooo`3oool0g`3oool00`3o0000<`3o0?ooo`2]0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0dP3oool00`0c0?l0oooo0?ooo`2i0?ooo`03
0000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0=l0oooo00<0<`3o0?ooo`3oool0
[@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0=40oooo00<0o`0003<0o`3oool0
^P3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3O0?ooo`0303<0o`3o
ool0oooo0:d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3A0?ooo`030?l0000c
0?l0oooo0;X0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0gP3oool0
0`3o0000<`3o0?ooo`2^0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0d@3oool0
0`0c0?l0oooo0?ooo`2j0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo
0=h0oooo00<0<`3o0?ooo`3oool0[P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
0=40oooo00<0<`3o0?ooo`3oool0^P3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000
oooo0?ooo`3N0?ooo`0303<0o`3oool0oooo0:h0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`3A0?ooo`0303<0o`3oool0oooo0;X0oooo00<000000?ooo`3oool0;03oool006l0oooo
00<000000?ooo`3oool0g@3oool00`0c0?l0oooo0?ooo`2_0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0d@3oool00`0c0?l0oooo0?ooo`2j0?ooo`030000003oool0oooo02`0oooo
001_0?ooo`030000003oool0oooo0=d0oooo00<0<`3o0?ooo`3oool0[`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0=00oooo00<0o`0003<0o`3oool0^`3oool00`000000oooo0?oo
o`0/0?ooo`00K`3oool200000=h0oooo00<0<`3o0?ooo`3oool0[@3oool3000005X0oooo0P00003A
0?ooo`030?l0000c0?l0oooo0;X0oooo0P00000^0?ooo`00K`3oool00`000000oooo0?ooo`3L0?oo
o`0303<0o`3oool0oooo0;00oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3@0?oo
o`0303<0o`3oool0oooo0;/0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3o
ool0g03oool00`0c0?l0oooo0?ooo`2`0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0d03oool00`0c0?l0oooo0?ooo`2k0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000
003oool0oooo0=`0oooo00<0<`3o0?ooo`3oool0/03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0=00oooo00<0<`3o0?ooo`3oool0^`3oool00`000000oooo0?ooo`0/0?ooo`00K`3o
ool00`000000oooo0?ooo`3K0?ooo`0303<0o`3o0000oooo0;40oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`3@0?ooo`0303<0o`3oool0oooo0;/0oooo00<000000?ooo`3oool0;03o
ool006l0oooo00<000000?ooo`3oool0f`3oool00`0c0?l0oooo0?ooo`2a0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0c`3oool00`3o0000<`3o0?ooo`2l0?ooo`030000003oool0
oooo02`0oooo001_0?ooo`030000003oool0oooo0=/0oooo00<0<`3o0?ooo`3oool0/@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0<l0oooo00<0o`0003<0o`3oool0_03oool00`00
0000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3J0?ooo`0303<0o`3o0000oooo0;80
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3?0?ooo`0303<0o`3oool0oooo0;`0
oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0fP3oool00`0c0?l0oooo
0?ooo`2b0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0c`3oool00`0c0?l0oooo
0?ooo`2l0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0=X0oooo00<0
<`3o0?ooo`3oool0/P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0<l0oooo00<0
<`3o0?ooo`3oool0_03oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3I
0?ooo`0303<0o`3o0000oooo0;<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3?
0?ooo`0303<0o`3oool0oooo0;`0oooo00<000000?ooo`3oool0;03oool006l0oooo0P00003J0?oo
o`0303<0o`3oool0oooo0;40oooo0`00001J0?ooo`800000c`3oool00`0c0?l0oooo0?ooo`2l0?oo
o`800000;P3oool006l0oooo00<000000?ooo`3oool0f03oool00`0c0?l0o`000?ooo`2d0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0cP3oool00`0c0?l0oooo0?ooo`2m0?ooo`03
0000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0=P0oooo00<0<`3o0?l0003oool0
]03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0<h0oooo00<0<`3o0?ooo`3oool0
_@3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3H0?ooo`0303<0o`3o
0000oooo0;@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3>0?ooo`0303<0o`3o
ool0oooo0;d0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0e`3oool0
0`0c0?l0o`000?ooo`2e0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0c@3oool0
0`0c0?l0oooo0?ooo`2n0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo
0=L0oooo00<0<`3o0?l0003oool0]@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
0<d0oooo00<0<`3o0?ooo`3oool0_P3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000
oooo0?ooo`3G0?ooo`0303<0o`3o0000oooo0;D0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`3=0?ooo`0303<0o`3oool0oooo0;h0oooo00<000000?ooo`3oool0;03oool00580oooo
00@0_g@0000000000000B9cO103oool01@3OW4P0000004RLg`3oool0gia800L0000000<0M;oo0?oo
o`3oool01P3oool00`000000oooo0?ooo`3F0?ooo`0303<0o`3o0000oooo0;H0oooo00<000000?oo
o`3oool0>P3oool0102oM000000000000018W=l40?ooo`030=nLB0000000B9cO00<0oooo00H0omnL
04P00000000000000000B02Lgol:0?ooo`030000003oool0oooo0<d0oooo00<0<`3o0?ooo`3oool0
_P3oool00`000000oooo0?ooo`0/0?ooo`00D03oool01`3ooml0W4P0001d_`3oool0oooO09a80000
M;l00`3oool00`3OW4P0000004RLg`020?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3o
ool01P3oool00`000000oooo0?ooo`3F0?ooo`0303<0o`3o0000oooo0;H0oooo00<000000?ooo`3o
ool0>03oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l00`3oool00`3OW4P0000004RLg`02
0?ooo`080?oOW018000004RL0=ooo`3oool0omnL04P0001d_ol90?ooo`030000003oool0oooo0<`0
oooo00<0<`3o0?ooo`3oool0_`3oool00`000000oooo0?ooo`0/0?ooo`00D03oool00`3o_g@00018
09cOo`020?ooo`030?oOW0180000M;oo00P0oooo00<0gia804RLg`3oool00P3oool00`3ooml0W4Qd
0;ooo`070?ooo`030000003oool0oooo0=H0oooo00<0<`3o0?l0003oool0]P3oool00`000000oooo
0?ooo`0h0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol01`3oool00`2oM000001d
0;ooo`030?ooo`030=nLB000B9`0gooo00P0oooo00<000000?ooo`3oool0c03oool00`0c0?l0oooo
0?ooo`2o0?ooo`030000003oool0oooo02`0oooo001?0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0oooO09a80000M;l02@3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030000003oool0oooo0=D0oooo
00<0<`3o0?l0003oool0]`3oool00`000000oooo0?ooo`0g0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0oooO09a80000M;l01`3oool00`2oM000001d0;ooo`030?ooo`030;md0000B9`0gooo00P0
oooo00<000000?ooo`3oool0c03oool00`0c0?l0oooo0?ooo`2o0?ooo`030000003oool0oooo02`0
oooo001?0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`3OW4P0M;oo
0?ooo`0:0?ooo`030000003oool0oooo0=D0oooo00<0<`3o0?l0003oool0]`3oool00`000000oooo
0?ooo`0g0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@00018
09cOo`020?ooo`030=nLB000000007Bo00T0oooo00<000000?ooo`3oool0c03oool00`0c0?l0oooo
0?ooo`2o0?ooo`030000003oool0oooo02`0oooo00120?ooo`030;md00000000000000L0000000H0
B9cO0?ooo`3oool0omnL04P00018W=l40?ooo`030;md000007@0_ooo00T0oooo00<0oooO09a8B02L
gol02P3oool300000=D0oooo00<0<`3o0?ooo`3oool0]03oool4000003T0oooo00<0omnL04P00018
W=l0103oool00`2oM000001d0;ooo`070?ooo`070=nLB000M;l0oooo0;md00000000001d0;ooo`09
0?ooo`<00000b`3oool00`0c0?l0oooo0?ooo`2n0?ooo`<00000;P3oool004l0oooo00<0omnL04P0
0018W=l0103oool00`3OW4P0001809cOo`0:0?ooo`030?oOW01807@0_ooo00T0oooo00<000000?oo
o`3oool0e03oool00`0c0?l0o`000?ooo`2h0?ooo`030000003oool0oooo03L0oooo00<0omnL04P0
0018W=l0103oool00`3OW4P0001809cOo`080?ooo`050?noM000000000000018W03Oool02P3oool0
0`000000oooo0?ooo`3;0?ooo`0303<0o`3oool0oooo0<00oooo00<000000?ooo`3oool0;03oool0
04l0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0;0?ooo`030;md0018W=l0oooo
00P0oooo00<000000?ooo`3oool0e03oool00`0c0?l0o`000?ooo`2h0?ooo`030000003oool0oooo
03L0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`050?oOW01800000000
00000018W=l02`3oool00`000000oooo0?ooo`3;0?ooo`0303<0o`3oool0oooo0<00oooo00<00000
0?ooo`3oool0;03oool004l0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0;0?oo
o`030=nLB00007@0_ooo00P0oooo00<000000?ooo`3oool0e03oool00`0c0?l0oooo0?ooo`2h0?oo
o`030000003oool0oooo03L0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`060?oo
o`070?oOW0180000001809cOo`3oool0gia8001d_`0:0?ooo`030000003oool0oooo0</0oooo00<0
<`3o0?ooo`3oool0`03oool00`000000oooo0?ooo`0/0?ooo`00D03oool00`2oM00004RL0=ooo`02
0?ooo`030?oog`2LB00007Bo00`0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`3C
0?ooo`0303<0o`3o0000oooo0;T0oooo00<000000?ooo`3oool0>03oool00`2oM00004RL0=ooo`02
0?ooo`030?oog`2LB00007Bo00L0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P007Boo`09
0?ooo`030000003oool0oooo0<X0oooo00<0<`3o0?ooo`3oool0`@3oool00`000000oooo0?ooo`0/
0?ooo`00D03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0omnL09bo
o`3oool00`3oool00`2oM000000007Boo`080?ooo`030000003oool0oooo0=<0oooo00<0<`3o0?oo
o`3oool0^@3oool00`000000oooo0?ooo`0h0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0
001d_ol01`3oool00`3OW4P004RL0=ooo`020?ooo`030?oog`2LB000B9cO00T0oooo00<000000?oo
o`3oool0bP3oool00`0c0?l0oooo0?ooo`310?ooo`030000003oool0oooo02`0oooo001A0?ooo`06
0;md0000B9`0gooo0?ooo`2oM00007Bo203oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0
gooo203oool00`000000oooo0?ooo`3C0?ooo`0303<0o`3oool0oooo0;T0oooo00<000000?ooo`3o
ool0>@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00<0omnL04P00018W=l00P3oool0
0`3o_g@0001809cOo`090?ooo`030000003oool0oooo0<X0oooo00<0<`3o0?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0/0?ooo`00DP3oool0102oM000000000000000M;l:0?ooo`050;md00000000
000000000000M;l02P3oool00`000000oooo0?ooo`3B0?ooo`0303<0o`3o0000oooo0;X0oooo00<0
00000?ooo`3oool0>P3oool0102oM000000000000000M;l:0?ooo`060?oo_`1d0000000000000000
04P0W=oo2P3oool00`000000oooo0?ooo`3:0?ooo`0303<0o`3oool0oooo0<40oooo00<000000?oo
o`3oool0;03oool006l0oooo00<000000?ooo`3oool0dP3oool00`0c0?l0oooo0?ooo`2j0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0b@3oool00`0c0?l0oooo0?ooo`320?ooo`03
0000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0=80oooo00<0<`3o0?ooo`3oool0
^P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0<T0oooo00<0<`3o0?ooo`3oool0
`P3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3A0?ooo`0303<0o`3o
ool0oooo0;/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`380?ooo`030?l0000c
0?l0oooo0<<0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0d@3oool0
0`0c0?l0oooo0?ooo`2k0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0b03oool0
0`0c0?l0oooo0?ooo`330?ooo`030000003oool0oooo02`0oooo001_0?ooo`800000dP3oool00`0c
0?l0oooo0?ooo`2i0?ooo`<00000FP3oool200000<T0oooo00<0<`3o0?ooo`3oool0`P3oool20000
02h0oooo001_0?ooo`030000003oool0oooo0=00oooo00<0<`3o0?ooo`3oool0_03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0<L0oooo00<0o`0003<0o`3oool0a03oool00`000000
oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3@0?ooo`0303<0o`3oool0oooo0;`0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`370?ooo`030?l0000c0?l0oooo0<@0oooo
00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0c`3oool00`3o0000<`3o0?oo
o`2m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0a`3oool00`0c0?l0oooo0?oo
o`340?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0<l0oooo00<0<`3o
0?ooo`3oool0_@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0<H0oooo00<0o`00
03<0o`3oool0a@3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3?0?oo
o`0303<0o`3oool0oooo0;d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`360?oo
o`030?l0000c0?l0oooo0<D0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3o
ool0cP3oool00`0c0?l0oooo0?ooo`2n0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0a@3oool00`3o0000<`3o0?ooo`360?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000
003oool0oooo0<h0oooo00<0<`3o0?ooo`3oool0_P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0<D0oooo00<0o`0003<0o`3oool0aP3oool00`000000oooo0?ooo`0/0?ooo`00K`3o
ool00`000000oooo0?ooo`3=0?ooo`0303<0o`3oool0oooo0;l0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`350?ooo`0303<0o`3oool0oooo0<H0oooo00<000000?ooo`3oool0;03o
ool006l0oooo00<000000?ooo`3oool0c@3oool00`0c0?l0oooo0?ooo`2o0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0a03oool00`3o0000<`3o0?ooo`370?ooo`030000003oool0
oooo02`0oooo001_0?ooo`030000003oool0oooo0<`0oooo00<0<`3o0?ooo`3oool0`03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0<@0oooo00<0o`0003<0o`3oool0a`3oool00`00
0000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`3<0?ooo`0303<0o`3oool0oooo0<00
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`330?ooo`030?l0000c0?l0oooo0<P0
oooo00<000000?ooo`3oool0;03oool006l0oooo0P00003<0?ooo`0303<0o`3oool0oooo0;l0oooo
0`00001J0?ooo`800000a03oool00`3o0000<`3o0?ooo`370?ooo`800000;P3oool006l0oooo00<0
00000?ooo`3oool0b`3oool00`0c0?l0oooo0?ooo`310?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0``3oool00`0c0?l0oooo0?ooo`380?ooo`030000003oool0oooo02`0oooo001_
0?ooo`030000003oool0oooo0<X0oooo00<0<`3o0?ooo`3oool0`P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo0<80oooo00<0o`0003<0o`3oool0b@3oool00`000000oooo0?ooo`0/
0?ooo`00K`3oool00`000000oooo0?ooo`3:0?ooo`0303<0o`3oool0oooo0<80oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`320?ooo`0303<0o`3oool0oooo0<T0oooo00<000000?oo
o`3oool0;03oool006l0oooo00<000000?ooo`3oool0b@3oool00`0c0?l0oooo0?ooo`330?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0`@3oool00`3o0000<`3o0?ooo`3:0?ooo`03
0000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo0<T0oooo00<0<`3o0?ooo`3oool0
``3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0<40oooo00<0<`3o0?ooo`3oool0
bP3oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000oooo0?ooo`380?ooo`0303<0o`3o
ool0oooo0<@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`300?ooo`030?l0000c
0?l0oooo0</0oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3oool0b03oool0
0`0c0?l0oooo0?ooo`340?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0`03oool0
0`0c0?l0oooo0?ooo`3;0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003oool0oooo
0<L0oooo00<0<`3o0?ooo`3oool0a@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
0;l0oooo00<0o`0003<0o`3oool0c03oool00`000000oooo0?ooo`0/0?ooo`00K`3oool00`000000
oooo0?ooo`360?ooo`0303<0o`3oool0oooo0<H0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`2n0?ooo`030?l0000c0?l0oooo0<d0oooo00<000000?ooo`3oool0;03oool006l0oooo
00<000000?ooo`3oool0a@3oool00`0c0?l0oooo0?ooo`370?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0_P3oool00`0c0?l0oooo0?ooo`3=0?ooo`030000003oool0oooo02`0oooo
001_0?ooo`030000003oool0oooo0<@0oooo00<0o`0003<0o`3oool0b03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0;d0oooo00<0<`3o0?ooo`3oool0cP3oool00`000000oooo0?oo
o`0/0?ooo`00K`3oool200000<@0oooo00<0o`0003<0o`3oool0a`3oool3000005X0oooo0P00002m
0?ooo`0303<0o`3oool0oooo0<h0oooo0P00000^0?ooo`00K`3oool00`000000oooo0?ooo`320?oo
o`030?l0000c0?l0oooo0<X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`2k0?oo
o`0303<0o`3oool0oooo0=00oooo00<000000?ooo`3oool0;03oool006l0oooo00<000000?ooo`3o
ool0`@3oool00`3o0000<`3o0?ooo`3;0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0^P3oool00`0c0?l0oooo0?ooo`3A0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000
003oool0oooo0<00oooo0P0c0?o=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
^@3oool00`0c0?l0oooo0?ooo`3B0?ooo`030000003oool0oooo02`0oooo001_0?ooo`030000003o
ool0oooo0;h0oooo00<0o`0003<0o`3oool0cP3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo0;L0oooo00<0o`0003<0o`3oool0e03oool00`000000oooo0?ooo`0/0?ooo`00K`3oool0
0`000000oooo0?ooo`2m0?ooo`030?l0000c0?l0oooo0<l0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`2f0?ooo`80<`3oeP3oool00`000000oooo0?ooo`0/0?ooo`00H@3oool0102o
M000000000000018W=l:0?ooo`030000003oool0oooo0;`0oooo0P0c0?oA0?ooo`030000003oool0
oooo04T0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`070?ooo`030000003oool0
oooo0;@0oooo0P0c0?oH0?ooo`030000003oool0oooo02`0oooo001O0?ooo`070?oog`2LB00007Bo
0?ooo`3ooml0W4P0001d_`090?ooo`030000003oool0oooo0;X0oooo0P0c0?oC0?ooo`030000003o
ool0oooo04/0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`2c0?ooo`0303<0o`3o
0000oooo0=P0oooo00<000000?ooo`3oool0;03oool005l0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`080?ooo`030000003oool0oooo0;D0oooo1@0c0?l00`3o0000oooo0?ooo`3B
0?ooo`030000003oool0oooo04/0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`2`
0?ooo`030?l0000c0?l0<`3o0=/0oooo00<000000?ooo`3oool0;03oool005h0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3ooml0W4P0001d_`080?ooo`030000003oool0oooo0;<0oooo0P0c0?l0
0`3o0000oooo0?ooo`3G0?ooo`030000003oool0oooo04/0oooo00<0_g@00000M02oool02P3oool0
0`000000oooo0?ooo`2/0?ooo`030?l0000c0?l0<`3o0080<`3og@3oool00`000000oooo0?ooo`0/
0?ooo`00GP3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00L0oooo00<000000?oo
o`3oool0[@3oool603<0om`0oooo00<000000?ooo`3oool0B`3oool00`2oM000001d0;ooo`0:0?oo
o`030000003oool0oooo0:D0oooo200c0?oQ0?ooo`030000003oool0oooo02`0oooo001N0?ooo`03
0?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01`3oool00`000000oooo0?ooo`290?ooob@0
<`3ohP3oool00`000000oooo0?ooo`1;0?ooo`030;md000007@0_ooo00X0oooo00<000000?ooo`3o
ool0P@3ooolT03<0o`030?l0003oool0oooo0>H0oooo00<000000?ooo`3oool0;03oool005h0oooo
00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`070?ooo`<000001P3ooon303<0o`030?l0
003oool0oooo0?l0oooo0@3oool4000004d0oooo00<0_g@00000M02oool02P3oool3000000H0oooo
N`0c0?l00`3o0000oooo0?ooo`3o0?ooo`T0oooo0`00000^0?ooo`00GP3oool00`3ogi`0B00004RL
g`040?ooo`030=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool0o`3ooon@0?ooo`030000003o
ool0oooo04/0oooo00<0_g@00000M02oool02P3oool00`000000oooo0?ooo`3o0?ooohl0oooo00<0
00000?ooo`3oool0;03oool005h0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`07
0?ooo`030000003oool0oooo0?l0ooooT03oool00`000000oooo0?ooo`1;0?ooo`030;md000007@0
_ooo00X0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`030000003oool0oooo02`0oooo001O0?oo
o`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1;0?oo
o`030;md000007@0_ooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;03oool005l0oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0B`3oool00`2oM000001d0;ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0;03oool00600oooo00H0_g@00018W03Oool0oooo0;md0000M;l90?ooool00000U000001;0?oo
o`050=nLB000000000000000M02oool02P3ooooo000009<00000;P3oool00640oooo00@0_g@00000
0000000007Boo`3ooooZ0?ooo`040?oo_`1d0000001d0;ooool0oooob`3oool00?l0ooooo`3ooooo
0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0
oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803o
ool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0
ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3o
oooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?oo
ool0oooo803oool00?l0ooooo`3ooooo0?ooool0oooo803oool00001\
\>"],
  ImageRangeCache->{{{0, 1051.69}, {324.313, 0}} -> {-0.052212, -0.0154541, \
0.002001, 0.002001}, {{26.0625, 525.813}, {316.563, 7.6875}} -> {-42.6376, \
-1.2867, 0.104517, 0.0042278}, {{525.813, 1025.56}, {316.563, 7.6875}} -> \
{-94.1417, -0.286698, 0.104517, 0.0042278}}]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ 
        The\ conclusion\ is\ that\ even\ when\ x1 = 
          0\ the\ system\ does\ not\ actually\ decouple, \ 
        as\ one\ would\ think\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ 
        To\ check\ if\ the\ result\ for\ x2\ satisfies\ the\ ODE, \ 
        take\ the\ difference\ of\ \(x2'\)[N]\ and\ the\ \(terms : \ 
            4\ x3[N] - 2\ x3[N]\^2 - \(x3'\)[N] - 
              xx2[N] \((2  x3[N] - 4)\)\)\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(dx2dN[Nn_] := 
      4\ x3[N] - 2\ x3[N]\^2 - \(x3'\)[N] - xx2[N] \((2  x3[N] - 4)\) /. 
        N \[Rule] Nn\)], "Input"],

Cell[BoxData[
    \(\(qq = 
        Table[{Nn, dx2dN[Nn] - D[xx2[N], N] /. N \[Rule] Nn}, {Nn, nmin, 
            nmax,  .1}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[qq, Frame \[Rule] True, Axes \[Rule] False, 
        PlotJoined \[Rule] True];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.0238095 0.330115 311355 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.2619 -0.0125 -19.0313 -24.5625 ]
[.2619 -0.0125 19.0313 0 ]
[.5 -0.0125 -19.0313 -24.5625 ]
[.5 -0.0125 19.0313 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -12.0625 -24.5625 ]
[.97619 -0.0125 12.0625 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01876 -83.5 -12.2813 ]
[-0.0125 .01876 0 12.2813 ]
[-0.0125 .0966 -98.5625 -12.2813 ]
[-0.0125 .0966 0 12.2813 ]
[-0.0125 .17444 -83.5 -12.2813 ]
[-0.0125 .17444 0 12.2813 ]
[-0.0125 .25228 -98.5625 -12.2813 ]
[-0.0125 .25228 0 12.2813 ]
[-0.0125 .33011 -14.0625 -12.2813 ]
[-0.0125 .33011 0 12.2813 ]
[-0.0125 .40795 -84.625 -12.2813 ]
[-0.0125 .40795 0 12.2813 ]
[-0.0125 .48579 -69.5625 -12.2813 ]
[-0.0125 .48579 0 12.2813 ]
[-0.0125 .56363 -84.625 -12.2813 ]
[-0.0125 .56363 0 12.2813 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01876 m
.00625 .01876 L
s
gsave
-0.0125 .01876 -144.5 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
89.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
105.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
125.813 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
134.938 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .0966 m
.00625 .0966 L
s
gsave
-0.0125 .0966 -159.563 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
105.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
120.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
140.875 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
150.000 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 .17444 m
.00625 .17444 L
s
gsave
-0.0125 .17444 -144.5 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
89.938 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
105.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
125.813 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
134.938 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 .25228 m
.00625 .25228 L
s
gsave
-0.0125 .25228 -159.563 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
105.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
120.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
140.875 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
150.000 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 .33011 m
.00625 .33011 L
s
gsave
-0.0125 .33011 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .40795 m
.00625 .40795 L
s
gsave
-0.0125 .40795 -145.625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
91.063 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
106.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
126.938 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
136.063 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 .48579 m
.00625 .48579 L
s
gsave
-0.0125 .48579 -130.563 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
76.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
91.750 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
111.875 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
121.000 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 .56363 m
.00625 .56363 L
s
gsave
-0.0125 .56363 -145.625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
91.063 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
106.813 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
126.938 14.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
136.063 14.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 14.188 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03433 m
.00375 .03433 L
s
0 .0499 m
.00375 .0499 L
s
0 .06546 m
.00375 .06546 L
s
0 .08103 m
.00375 .08103 L
s
0 .11217 m
.00375 .11217 L
s
0 .12773 m
.00375 .12773 L
s
0 .1433 m
.00375 .1433 L
s
0 .15887 m
.00375 .15887 L
s
0 .19001 m
.00375 .19001 L
s
0 .20557 m
.00375 .20557 L
s
0 .22114 m
.00375 .22114 L
s
0 .23671 m
.00375 .23671 L
s
0 .26784 m
.00375 .26784 L
s
0 .28341 m
.00375 .28341 L
s
0 .29898 m
.00375 .29898 L
s
0 .31455 m
.00375 .31455 L
s
0 .34568 m
.00375 .34568 L
s
0 .36125 m
.00375 .36125 L
s
0 .37682 m
.00375 .37682 L
s
0 .39239 m
.00375 .39239 L
s
0 .42352 m
.00375 .42352 L
s
0 .43909 m
.00375 .43909 L
s
0 .45466 m
.00375 .45466 L
s
0 .47022 m
.00375 .47022 L
s
0 .50136 m
.00375 .50136 L
s
0 .51693 m
.00375 .51693 L
s
0 .5325 m
.00375 .5325 L
s
0 .54806 m
.00375 .54806 L
s
0 .00319 m
.00375 .00319 L
s
0 .5792 m
.00375 .5792 L
s
0 .59477 m
.00375 .59477 L
s
0 .61033 m
.00375 .61033 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01876 m
1 .01876 L
s
.99375 .0966 m
1 .0966 L
s
.99375 .17444 m
1 .17444 L
s
.99375 .25228 m
1 .25228 L
s
.99375 .33011 m
1 .33011 L
s
.99375 .40795 m
1 .40795 L
s
.99375 .48579 m
1 .48579 L
s
.99375 .56363 m
1 .56363 L
s
.125 Mabswid
.99625 .03433 m
1 .03433 L
s
.99625 .0499 m
1 .0499 L
s
.99625 .06546 m
1 .06546 L
s
.99625 .08103 m
1 .08103 L
s
.99625 .11217 m
1 .11217 L
s
.99625 .12773 m
1 .12773 L
s
.99625 .1433 m
1 .1433 L
s
.99625 .15887 m
1 .15887 L
s
.99625 .19001 m
1 .19001 L
s
.99625 .20557 m
1 .20557 L
s
.99625 .22114 m
1 .22114 L
s
.99625 .23671 m
1 .23671 L
s
.99625 .26784 m
1 .26784 L
s
.99625 .28341 m
1 .28341 L
s
.99625 .29898 m
1 .29898 L
s
.99625 .31455 m
1 .31455 L
s
.99625 .34568 m
1 .34568 L
s
.99625 .36125 m
1 .36125 L
s
.99625 .37682 m
1 .37682 L
s
.99625 .39239 m
1 .39239 L
s
.99625 .42352 m
1 .42352 L
s
.99625 .43909 m
1 .43909 L
s
.99625 .45466 m
1 .45466 L
s
.99625 .47022 m
1 .47022 L
s
.99625 .50136 m
1 .50136 L
s
.99625 .51693 m
1 .51693 L
s
.99625 .5325 m
1 .5325 L
s
.99625 .54806 m
1 .54806 L
s
.99625 .00319 m
1 .00319 L
s
.99625 .5792 m
1 .5792 L
s
.99625 .59477 m
1 .59477 L
s
.99625 .61033 m
1 .61033 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33007 m
.02619 .33011 L
.02857 .33011 L
.03095 .33012 L
.03333 .33011 L
.03571 .33012 L
.0381 .33012 L
.04048 .33011 L
.04286 .33009 L
.04524 .33011 L
.04762 .33013 L
.05 .33012 L
.05238 .33009 L
.05476 .33006 L
.05714 .33002 L
.05952 .32997 L
.0619 .32993 L
.06429 .33 L
.06667 .33009 L
.06905 .3301 L
.07143 .33004 L
.07381 .32993 L
.07619 .32977 L
.07857 .32957 L
.08095 .32934 L
.08333 .32908 L
.08571 .3288 L
.0881 .32852 L
.09048 .32823 L
.09286 .32796 L
.09524 .3277 L
.09762 .32747 L
.1 .32728 L
.10238 .32731 L
.10476 .32771 L
.10714 .32783 L
.10952 .32772 L
.1119 .32741 L
.11429 .32696 L
.11667 .3264 L
.11905 .3258 L
.12143 .32519 L
.12381 .32462 L
.12619 .32474 L
.12857 .32576 L
.13095 .32602 L
.13333 .32566 L
.13571 .32478 L
.1381 .32353 L
.14048 .32201 L
Mistroke
.14286 .32035 L
.14524 .3187 L
.14762 .31716 L
.15 .31774 L
.15238 .3197 L
.15476 .31937 L
.15714 .31738 L
.15952 .31436 L
.1619 .31549 L
.16429 .3168 L
.16667 .31532 L
.16905 .3119 L
.17143 .3074 L
.17381 .31157 L
.17619 .31228 L
.17857 .30867 L
.18095 .30228 L
.18333 .30418 L
.18571 .3066 L
.1881 .30158 L
.19048 .2918 L
.19286 .30041 L
.19524 .29745 L
.19762 .2853 L
.2 .29652 L
.20238 .29016 L
.20476 .28481 L
.20714 .28714 L
.20952 .27646 L
.2119 .28251 L
.21429 .2734 L
.21667 .27421 L
.21905 .27441 L
.22143 .2556 L
.22381 .26929 L
.22619 .26743 L
.22857 .26007 L
.23095 .23966 L
.23333 .24234 L
.23571 .24755 L
.2381 .24207 L
.24048 .24083 L
.24286 .22372 L
.24524 .20872 L
.24762 .22398 L
.25 .22328 L
.25238 .20734 L
.25476 .19279 L
.25714 .19357 L
.25952 .19378 L
Mistroke
.2619 .18319 L
.26429 .19278 L
.26667 .18881 L
.26905 .18599 L
.27143 .19016 L
.27381 .18733 L
.27619 .19074 L
.27857 .18797 L
.28095 .18831 L
.28333 .1839 L
.28571 .18588 L
.2881 .18383 L
.29048 .183 L
.29286 .18192 L
.29524 .17508 L
.29762 .17411 L
.3 .16611 L
.30238 .1644 L
.30476 .15782 L
.30714 .16378 L
.30952 .16304 L
.3119 .16213 L
.31429 .16015 L
.31667 .16213 L
.31905 .16128 L
.32143 .16015 L
.32381 .16082 L
.32619 .15693 L
.32857 .15991 L
.33095 .15163 L
.33333 .15654 L
.33571 .1503 L
.3381 .15221 L
.34048 .15173 L
.34286 .14986 L
.34524 .15198 L
.34762 .14831 L
.35 .15277 L
.35238 .14601 L
.35476 .15248 L
.35714 .14305 L
.35952 .15119 L
.3619 .14123 L
.36429 .148 L
.36667 .14187 L
.36905 .1433 L
.37143 .14442 L
.37381 .13695 L
.37619 .14672 L
.37857 .12904 L
Mistroke
.38095 .14667 L
.38333 .11977 L
.38571 .14385 L
.3881 .11253 L
.39048 .13433 L
.39286 .10455 L
.39524 .13194 L
.39762 .10177 L
.4 .12631 L
.40238 .1005 L
.40476 .12075 L
.40714 .09872 L
.40952 .07624 L
.4119 .11254 L
.41429 .07595 L
.41667 .08788 L
.41905 .07019 L
.42143 .06326 L
.42381 .11405 L
.42619 .07708 L
.42857 .09612 L
.43095 .08088 L
.43333 .01472 L
.43571 .11264 L
.4381 .05939 L
.44048 .05954 L
.44286 .03685 L
.44524 .07422 L
.44762 .0822 L
.45 .06938 L
.45238 .02971 L
.45476 .04048 L
.45714 .06866 L
.45952 .08259 L
.4619 .04536 L
.46429 .02349 L
.46667 .03708 L
.46905 .07402 L
.47143 .097 L
.47381 .07258 L
.47619 .06344 L
.47857 .06393 L
.48095 .06096 L
.48333 .04739 L
.48571 .03946 L
.4881 .0616 L
.49048 .09361 L
.49286 .11522 L
.49524 .11011 L
.49762 .09646 L
Mistroke
.5 .09832 L
.50238 .08744 L
.50476 .11992 L
.50714 .15293 L
.50952 .18142 L
.5119 .15561 L
.51429 .10637 L
.51667 .08198 L
.51905 .15022 L
.52143 .25457 L
.52381 .23785 L
.52619 .15781 L
.52857 .09945 L
.53095 .2136 L
.53333 .15359 L
.53571 .17731 L
.5381 .15754 L
.54048 .16376 L
.54286 .15319 L
.54524 .15965 L
.54762 .22579 L
.55 .19669 L
.55238 .21029 L
.55476 .11741 L
.55714 .20698 L
.55952 .21058 L
.5619 .22229 L
.56429 .21006 L
.56667 .22996 L
.56905 .25138 L
.57143 .24005 L
.57381 .24141 L
.57619 .26314 L
.57857 .27227 L
.58095 .26038 L
.58333 .33495 L
.58571 .32975 L
.5881 .2883 L
.59048 .26401 L
.59286 .27711 L
.59524 .29699 L
.59762 .30874 L
.6 .30806 L
.60238 .29288 L
.60476 .30233 L
.60714 .30716 L
.60952 .29367 L
.6119 .29398 L
.61429 .30928 L
.61667 .30057 L
Mistroke
.61905 .28891 L
.62143 .29398 L
.62381 .31295 L
.62619 .2977 L
.62857 .29428 L
.63095 .31616 L
.63333 .30907 L
.63571 .3049 L
.6381 .29034 L
.64048 .31786 L
.64286 .31892 L
.64524 .30635 L
.64762 .33185 L
.65 .30926 L
.65238 .32015 L
.65476 .30678 L
.65714 .2975 L
.65952 .34419 L
.6619 .31613 L
.66429 .36283 L
.66667 .29782 L
.66905 .29235 L
.67143 .34984 L
.67381 .28592 L
.67619 .35796 L
.67857 .33293 L
.68095 .50474 L
.68333 .34182 L
.68571 .33781 L
.6881 .28881 L
.69048 .37644 L
.69286 .40479 L
.69524 .39603 L
.69762 .39461 L
.7 .39587 L
.70238 .38764 L
.70476 .36419 L
.70714 .31918 L
.70952 .48978 L
.7119 .36983 L
.71429 .42854 L
.71667 .34068 L
.71905 .15794 L
.72143 .60448 L
.72381 .28846 L
.72619 .02087 L
.72857 .26519 L
.73095 .37298 L
.73333 .04752 L
.73571 .5466 L
Mistroke
.7381 .38856 L
.74048 .19831 L
.74286 .13181 L
.74524 .54764 L
.74762 .44031 L
Mfstroke
.74762 .44031 m
.74879 .61803 L
s
.75062 .61803 m
.75238 .09961 L
.75476 .56609 L
.75714 .28216 L
.75952 .37374 L
.7619 .30009 L
.76429 .33825 L
.76667 .21116 L
.76905 .28049 L
.77143 .33593 L
.77381 .36838 L
.77619 .37753 L
.77857 .36861 L
.78095 .34852 L
.78333 .31815 L
.78571 .31306 L
.7881 .31779 L
.79048 .3244 L
.79286 .32963 L
.79524 .3326 L
.79762 .33351 L
.8 .33296 L
.80238 .33156 L
.80476 .3293 L
.80714 .33309 L
.80952 .32742 L
.8119 .32357 L
.81429 .32254 L
.81667 .32351 L
.81905 .32509 L
.82143 .3266 L
.82381 .32785 L
.82619 .3288 L
.82857 .32949 L
.83095 .32994 L
.83333 .33022 L
.83571 .33038 L
.8381 .33045 L
.84048 .33047 L
.84286 .3303 L
.84524 .32835 L
.84762 .33576 L
.85 .32725 L
.85238 .33295 L
.85476 .32836 L
.85714 .33061 L
.85952 .32946 L
.8619 .32969 L
.86429 .33005 L
.86667 .3296 L
Mistroke
.86905 .33026 L
.87143 .32975 L
.87381 .3303 L
.87619 .32989 L
.87857 .33028 L
.88095 .32999 L
.88333 .33015 L
.88571 .3294 L
.8881 .32947 L
.89048 .3304 L
.89286 .33222 L
.89524 .33109 L
.89762 .32994 L
.9 .32928 L
.90238 .32914 L
.90476 .32967 L
.90714 .33017 L
.90952 .33043 L
.9119 .33043 L
.91429 .33028 L
.91667 .33022 L
.91905 .33016 L
.92143 .33012 L
.92381 .33008 L
.92619 .33004 L
.92857 .33002 L
.93095 .33001 L
.93333 .33 L
.93571 .33003 L
.9381 .33005 L
.94048 .33007 L
.94286 .33009 L
.94524 .33011 L
.94762 .33012 L
.95 .33013 L
.95238 .33014 L
.95476 .33014 L
.95714 .33015 L
.95952 .33015 L
.9619 .33015 L
.96429 .33015 L
.96667 .33014 L
.96905 .33014 L
.97143 .33013 L
.97381 .33012 L
.97619 .33011 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{594.375, 367.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009B0001Kb000`400?l00000o`00003oo`3ooooo
0?oooe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00o`3ooooo0?oooe@0oooo
003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00o`3ooooo0?oooe@0oooo003o0?ooool0
ooooE03oool00?l0ooooo`3ooomD0?ooo`00o`3ooooo0?oooe@0oooo003o0?ooool0ooooE03oool0
0?l0ooooo`3ooomD0?ooo`00o`3ooooo0?oooe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3o
oomD0?ooo`00o`3ooooo0?oooe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00
o`3ooooo0?oooe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00o`3ooooo0?oo
oe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00L@3oool00`3ooml0W4P00000
0002000000030018W03Oool0oooo00D0oooo00@0_g@0000000000000B9cOH`3oool00`3OW4P00000
000000050000000307Boo`3oool0oooo0080oooo00@0_g@0000000000000B9cOI@3oool00`3o_g@0
00000000000200000003001d_`3oool0oooo00<0oooo00@0_g@0000000000000B9cOI@3oool0102o
M000000000000018W=mZ0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool00`3oool0
102oM000000000000018W=l60?ooo`00L@3oool0203ogi`0B0000018W03Oool0oooo0?oOW01804P0
W=oo0`3oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0H`3oool00`3OW4P0000000000004
0000000:001d_`3oool0oooo0?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_fH0oooo00<0_g@00000
M02oool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l0HP3oool01`3ooml0W4P0001d
_`3oool0oooO09a80000M;l0J`3oool00`2oM000001d0;ooo`040?ooo`070?oog`2LB00007Bo0?oo
o`3ooml0W4P0001d_`050?ooo`00M`3oool00`3o_g@004RL0=ooo`020?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol0H`3oool00`3OW4P0B9cO0?ooo`020?ooo`070?oog`2LB7@0_ooo
0?ooo`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo06D0oooo00<0_g@00000M02oool0103o
ool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo0640oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`1Z0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3o
ool00`3ogi`0B00007Boo`040?ooo`00M`3oool0203o_g@0001809cOo`3oool0oooO09a80000B9`0
gooo0P3oool00`3ooml0W4P0001d_`1T0?ooo`030=nLB018W=l0oooo00@0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3ooml0W4P0001d_`1U0?ooo`030;md000007@0_ooo00<0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3ooml0W4P0001d_`1P0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
oooO09a80000M;l0JP3oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0oooO09a80000M;l0103oool007L0oooo00L0_g@00000B02Lgol0oooo0?oo_`1d000007Bo00@0
oooo00<0_g@00000M02oool0I03oool00`3OW4P0M;oo0?ooo`030?ooo`030?oo_`1d000007Bo00@0
oooo00<0_g@00000M02oool0I03oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0
oooo00<0_g@00000M02oool0G`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo06T0
oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00<0
oooo001T0?ooo`030;md00000000000000L0000000<0B9cO0?ooo`3oool01@3oool0202oM0000000
0000M02oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`1C0?ooo`030;md00000000
000000L0000000<0B9cO0?ooo`3oool0103oool00`3ooml0W4Q809cOo`030?ooo`030?oOW0180000
B9cO00@0oooo00<0_g@00000M02oool0D`3oool00`2oM0000000000000070000000304RLg`3oool0
oooo00@0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030;md000007@0
_ooo05l0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`1Y0?ooo`030;md000007@0
_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`030?ooo`00L`3oool00`3o
okl0M000000000020000000604RLg`3oool0oooo0?oOW0180000B9cO103oool00`3OW4P0001809cO
o`1U0?ooo`030?oOW01807@0_ooo0080oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`1T0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cO
o`1O0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0J@3oool00`2oM000001d0;oo
o`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol00`3oool007D0oooo00<0okmd
0000B02Lgol00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo06H0oooo00L0_g@0
04RLg`3oool0oooo0?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0I03oool00`2oM000001d
0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0G`3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo06T0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB00004P0W=oo00<0oooo001f0?ooo`030?oOW018M;l0oooo0080oooo00<0
oono07@00000M;l0103oool00`2oM000001d0;ooo`1V0?ooo`070=nLB00007@0_ooo0?ooo`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo06@0oooo00<0_g@00000M02oool00`3oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo05l0oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`1Y0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`030?ooo`00MP3oool00`3ooml0W4P004RLg`030?ooo`030;md0000B9`0gooo0080oooo
00<0oooO09a80000M;l0I`3oool00`3o_g@0000007Boo`020?ooo`030;md0000B9`0gooo0080oooo
00<0oooO09a80000M;l0I@3oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0gooo0080oooo
00<0oooO09a80000M;l0H@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo06X0oooo
00<0_g@00000M02oool0103oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00@0oooo
001a0?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l00`3oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo0640oooo00<0omnL09boo`3oool00`3oool00`2oM000000007Bo
o`020?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0I@3oool00`2oM000001d0;oo
o`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol0H@3oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo06X0oooo00<0_g@00000M02oool0103oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00@0oooo001b0?ooo`070?oOW018B9`0gooo0?ooo`3OW4P00000
07Boo`040?ooo`060;md0000B9`0gooo0?ooo`2oM00007BoH`3oool0202oM000M;oo0?ooo`3oool0
gia800000000B9`0gooo0`3oool01P2oM00004RL0=ooo`3oool0_g@0001d_f@0oooo00D0gia80000
00000000001d0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007BoH`3oool01P2oM00004RL
0=ooo`3oool0_g@0001d_fT0oooo00D0gia8000000000000001d0;ooo`050?ooo`060;md0000B9`0
gooo0?ooo`2oM00007Bo1@3oool007<0oooo00D0omnL04P000000000000004RLg`060?ooo`040;md
000000000000001d_fD0oooo00D0_g@00000000000000000001d_`060?ooo`040;md000000000000
001d_fH0oooo00@0oono07@0000007@0_ooo1P3oool0102oM000000000000000M;mU0?ooo`040;md
000000000000001d_f/0oooo00@0oono07@0000007@0_ooo1P3oool0102oM000000000000000M;l6
0?ooo`00o`3ooooo0?oooe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00o`3o
oooo0?oooe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00o`3ooooo0?oooe@0
oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00o`3ooooo0?oooe@0oooo003o0?oo
ool0ooooE03oool006P0ooooo`00003Z00000040oooo001X0?ooo`<000002@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool200000040oooo
001X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`008@3oool00`3o_g@0000000000002
00000003001d_`3oool0oooo00@0oooo00<0_gA809cOo`3oool01P3oool00`3o_i`0M;oO0?ooo`04
0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool00`3oool0102oM000000000000018
W=lL0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`080?ooo`4000000@3oool002<0oooo00<0_g@00000M02oool01`3oool00`3o_g@0001809cOo`05
0?ooo`030?noM00004P0W=oo00L0oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3o
ool0oooO09a80000M;l06`3oool00`000000oooo0?ooo`3o0?ooonH0oooo0@0000010?ooo`008`3o
ool00`2oM000001d0;ooo`080?ooo`030?noM00004P0W=oo00<0oooo00<0okmd0000B02Lgol0203o
ool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol06P3o
ool00`000000oooo0?ooo`3o0?ooonH0oooo0@0000010?ooo`008`3oool00`2oM000001d0;ooo`09
0?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`090?ooo`030;md000007@0_ooo00<0oooo
00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0J0?ooo`030000003oool0oooo0?l0
ooooiP3oool100000040oooo000S0?ooo`030;md000007@0_ooo00X0oooo00D0okmd0000B02LW7@0
001809cOo`0:0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000
001d0;ooo`0I0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0o`3ooolB0?ooo`40
00000@3oool00180oooo00<0_g@00000000000001`0000000`18W=l0oooo0?ooo`040?ooo`030;md
000007@0_ooo00/0oooo00<0okmd0000B02Lgol02`3oool00`2oM000001d0;ooo`030?ooo`030?oO
W0180000B9cO00@0oooo00<0_g@00000M02oool06@3oool00`000000oooo0?ooo`3A0?ooo`030000
003oool0oooo0?l0oooo4P3oool100000040oooo000S0?ooo`030;md000007@0_ooo00X0oooo00D0
okmd0000B02LW7@0001809cOo`0:0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0
103oool00`3OW4P0001809cOo`0I0?ooo`@00000d03oool00`000000oooo0?ooo`3o0?ooo`l0oooo
100000010?ooo`008`3oool00`2oM000001d0;ooo`090?ooo`070?noM00004P0W=oo0?ooo`3o_g@0
001809cOo`090?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0
001809cOo`0I0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`220?ooo`4000000@3oool002<0oooo00<0_g@00000M02oool0203oool00`3o_g@00018
09cOo`030?ooo`030?noM00004P0W=oo00P0oooo00<0_g@00000M02oool00`3oool00`3ookl0M000
001d_`040?ooo`030;md000007@0_ooo00/0oooo00D0oono07@000000000001d0;ooo`090?ooo`03
0000003oool0oooo0=40oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0880oooo0@0000010?ooo`008`3oool00`2oM000001d0;ooo`070?ooo`030;md
000004P0W=oo00D0oooo00<0okmd00000018W=l01`3oool00`2oM000001d0;ooo`040?ooo`030;md
0000B9`0gooo0080oooo00<0oooO09a80000M;l02`3oool01`3ooml0W4P0001d_`3oool0okmd0018
W03Oool0203oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`220?ooo`4000000@3oool002<0oooo00<0_g@00000M02o
ool01`3oool00`3o_i`0W=oo0?ooo`060?ooo`030?noW02Lgol0oooo00H0oooo00<0_g@00000M02o
ool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00/0oooo00L0omnL04P0M02o
ool0oooo0?oog`2LB4P0W=oo00P0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0PP3oool100000040oooo000Q0?oo
o`050=nLB000000000000000M02oool05`3oool01@3OW4P000000000000007@0_ooo00D0oooo00H0
_g@00018W03Oool0oooo0;md0000M;l20?ooo`030?oo_`1d0000000000@0000000X0001809cOo`3o
ool0okmd0018W03Oool0oooo0?oog`2LB000M;oo203oool00`000000oooo0?ooo`3A0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo0880oooo0@0000010?ooo`008P3oool0103ookl0M0000000M02ooolH0?ooo`040?oo
_`1d0000001d0;ooo`H0oooo00@0_g@000000000000007Bo3@3oool01`3o_g@004RL0=ooo`3oool0
oono07@0001d_ol0203oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool2000007h0oooo00<000000?ooo`3oool0PP3oool100000040oooo001I
0?ooo`070?oOW01807@0M;no0?ooo`3OW4P0001d0;ooo`080?ooo`030000003oool0oooo0=40oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`800000OP3oool00`000000oooo
0?ooo`220?ooo`4000000@3oool005T0oooo00<0oooO09a8001dM7@00P0000000`1d_ol0oooo0?oo
o`070?ooo`<00000d@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000OP3oool00`000000oooo0?ooo`210?ooo`8000000@3oool005X0oooo00<0okmd
0000M02oool02`3oool00`000000oooo0?ooo`3A0?ooo`050000003oool0oooo0?ooo`000000103o
ool2000000<0oooo00<000000?ooo`000000OP3oool00`000000oooo0?ooo`220?ooo`4000000@3o
ool005/0oooo00<0gia80000B02Lgol02P3oool00`000000oooo0?ooo`3A0?ooo`050000003oool0
oooo0?ooo`000000103oool2000000<0oooo00<000000?ooo`000000203oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0880oooo0@0000010?ooo`00G03oool0103ogi`0B0000000B02L
gol80?ooo`030000003oool0oooo0=40oooo00D000000?ooo`3oool0oooo000000040?ooo`800000
0`3oool00`000000oooo000000080?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
PP3oool100000040oooo001X0?ooo`030000003oool0oooo0=40oooo00D000000?ooo`3oool0oooo
000000040?ooo`8000000`3oool00`000000oooo000000070?ooo`800000M@3oool00`000000oooo
0?ooo`220?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0d@3oool01@000000oooo0?oo
o`3oool0000000@0oooo0P0000030?ooo`030000003oool0000000L0oooo0P00001e0?ooo`030000
003oool0oooo0880oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3@0?ooo`8000000`3o
ool2000000<0oooo0P0000030?ooo`030000003oool0000000L0oooo0P00001e0?ooo`040000003o
ool0oooo00000840oooo0@0000010?ooo`00J03oool300000=00oooo0P0000020?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000070?ooo`800000M@3o
ool010000000oooo0?ooo`0000200?ooo`8000000@3oool006P0oooo00<000000?ooo`3oool0d03o
ool200000080oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0000000L0oooo00<000000?ooo`000000M03oool010000000oooo0?ooo`0000210?ooo`400000
0@3oool006P0oooo00<000000?ooo`3oool0d03oool200000080oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`030000003oool0000000L0oooo00<000000?ooo`000000M03o
ool010000000oooo0?ooo`0000210?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0d03o
ool200000080oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0000000H0oooo00@000000?ooo`3oool00000M03oool010000000oooo0?ooo`0000210?oo
o`4000000@3oool006P0oooo00<000000?ooo`3oool0d03oool200000080oooo00<000000?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00@00000
0?ooo`3oool00000M03oool010000000oooo0?ooo`0000210?ooo`4000000@3oool006P0oooo00<0
00000?ooo`3oool0d03oool2000000050?ooo`00000000000?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000M03oool0
10000000oooo0?ooo`0000210?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0d03oool2
000000050?ooo`000000oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000D0oooo00@000000?ooo`3oool00000M03oool010000000oooo0?ooo`000021
0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`020?oo
o`80000000D0oooo0000003oool0oooo000000020?ooo`060000003oool0oooo0000003oool00000
0`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0LP3oool010000000
oooo0?ooo`0000210?ooo`4000000@3oool006P0oooo0`00003;0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`00000000000`3oool00`000000oooo000000020?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0780oooo00@00000
0?ooo`3oool00000P03oool200000040oooo001X0?ooo`030000003oool0oooo0<X0oooo0P000004
0?ooo`040000003oool00000000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0LP3oool010000000oooo
0?ooo`0000210?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0bP3oool2000000@0oooo
00@000000?ooo`00000000000`3oool00`000000oooo000000020?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1a0?ooo`040000003oool0oooo
00000840oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3:0?ooo`800000103oool01000
0000oooo0000000000030?ooo`030000003oool0000000<0oooo0P0000030?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0L@3oool010000000oooo0?ooo`0000210?ooo`400000
0@3oool006P0oooo00<000000?ooo`3oool0bP3oool2000000@0oooo00@000000?ooo`0000000000
0`3oool00`000000oooo000000030?ooo`8000000`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0740oooo00@000000?ooo`3oool00000P@3oool100000040oooo001X0?ooo`03
0000003oool0oooo0<D0oooo00<000000?ooo`0000000P3oool2000000060?ooo`000000oooo0?oo
o`000000oooo0P0000030?ooo`800000103oool2000000<0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1a0?ooo`040000003oool0oooo00000840oooo0@0000010?ooo`00J03o
ool00`000000oooo0?ooo`350?ooo`030000003oool000000080oooo0P0000001P3oool000000?oo
o`3oool000000?ooo`8000000`3oool2000000@0oooo0P0000030?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool0L@3oool010000000oooo0?ooo`0000210?ooo`4000000@3oool006P0
oooo0`0000350?ooo`030000003oool000000080000000@0oooo0000003oool000000P3oool01000
0000oooo0000000000040?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000
003oool0000000L0oooo00<000000?ooo`3oool0L@3oool010000000oooo0?ooo`0000200?ooo`80
00000@3oool006P0oooo00<000000?ooo`3oool0a@3oool00`000000oooo00000002000000040?oo
o`000000oooo00000080oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`030?oo
o`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0I03oool010000000oooo0?ooo`0000210?ooo`4000000@3oool00180oooo00<0
omnL04P0M02oool01@3oool00`3OW4P0000004RLg`020?ooo`060;md00000000000000000000B9`0
gooo203oool00`2oM4P0W=oo0?ooo`060?ooo`030?noW01d_ml0oooo00@0oooo00<0okmd00000000
00000P0000000`00M;l0oooo0?ooo`030?ooo`040;md00000000000004RLga`0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo00000002000000060?ooo`000000oooo0000003oool000000P3o
ool2000000h0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo06@0oooo00@000000?ooo`3oool00000P@3oool100000040oooo000C0?ooo`030;md001d
_ol0oooo00@0oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03O
ool01`3oool00`3o_g@0001809cOo`050?ooo`030?noM00004P0W=oo00L0oooo00<0_g@00000M02o
ool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l06`3oool00`000000oooo0?ooo`35
0?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`0>0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0I03oool010000000oooo0?ooo`0000210?ooo`4000000@3oool0
01<0oooo00<0okmd001d_`3oool03P3oool00`3ogi`0B7Bo0?ooo`070?ooo`030?noM00004P0W=oo
00<0oooo00<0okmd0000B02Lgol0203oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol06P3oool00`000000oooo0?ooo`340?ooo`80000000L0oooo0000
003oool000000?ooo`000000oooo00<000000P3oool00`000000oooo0?ooo`0>0?ooo`800000203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03o
ool010000000oooo0?ooo`0000210?ooo`4000000@3oool001<0oooo00<0oono07@0M02oool03P3o
ool00`3ookl0M01809cOo`080?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`090?ooo`03
0;md000007@0_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0J0?oo
o`030000003oool0oooo0<@0oooo0P0000000`3oool000000?ooo`030?ooo`@000000P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00@000000?ooo`3oool00000P@3oool1
00000040oooo000D0?ooo`030;md001d_ol0oooo00d0oooo00<0oono07@0001d_ol02@3oool01@3o
_g@0001809bLM00004P0W=oo00X0oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`04
0?ooo`030;md000007@0_ooo01T0oooo00<000000?ooo`3oool0a03oool2000000030?ooo`000000
oooo00<0oooo0`0000030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool0I03oool010000000oooo0?oo
o`0000210?ooo`4000000@3oool000<0oooo00<0_g@00000000000001`0000000`18W=l0oooo0?oo
o`040?ooo`030?noM000M;l0oooo00d0oooo00<0okmd0000001d_ol02P3oool00`3o_g@0001809cO
o`0;0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`0I0?ooo`030000003oool0oooo0<@0oooo0`0000050?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`800000
1@3oool2000006H0oooo00@000000?ooo`3oool00000P@3oool100000040oooo000D0?ooo`030?oo
_`1d07@0_ooo00`0oooo00@0omnL04P0000007@0_ooo2@3oool01@3o_g@0001809bLM00004P0W=oo
00X0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
01T0oooo100000330?ooo`030000003oool0000000D0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P0000000`3o
ool000000?ooo`030?ooo`800000IP3oool010000000oooo0?ooo`00001n0?ooo`@000000@3oool0
01D0oooo00<0_g@007Boo`3oool01`3oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0
oooo00L0oooo00L0okmd0000B02Lgol0oooo0?noM00004P0W=oo00T0oooo00<0_g@00000M02oool0
0`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01T0oooo00<000000?ooo`3oool0
a03oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`02000000030?ooo`000000oooo00<0oooo0P0000050?ooo`030000
003oool0oooo05h0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`1e0?ooo`40
00000@3oool001D0oooo00<0okmd001d_`3oool01`3oool00`3o_g@000000000000200000003001d
_`3oool0oooo00L0oooo00<0okmd0000B02Lgol00`3oool00`3o_g@0001809cOo`080?ooo`030;md
000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0<0?ooo`030;md
001d_ol0oooo00X0oooo00<000000?ooo`3oool0_`3oool020000000oooo0?ooo`000000oooo0000
003oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool0GP3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo07D0oooo
0@0000010?ooo`003`3oool00`3ogkl0_moo0?ooo`030?ooo`030?oo_`1d07@0_ooo00L0oooo00D0
oooO09a800000000001d0;ooo`090?ooo`030;md000004P0W=oo00D0oooo00<0okmd00000018W=l0
1`3oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l0
3@3oool00`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo0;l0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00040?ooo`030000003oool0oooo05h0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`1e0?ooo`4000000@3oool000l0oooo00<0oooO09a8M02oool0103oool00`2oM000M;oo0?oo
o`070?ooo`030?noM000M;l0oooo00X0oooo00<0oknL09cOo`3oool01P3oool00`3o_i`0W=oo0?oo
o`060?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Bo
o`0=0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01T0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`1N0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0M@3oool100000040oooo000@0?ooo`030=nLB0000000000000@0000000<007Bo0?ooo`3oool0
1P3oool00`3ooml0W4P000000002000000030000M02oool0oooo01D0oooo00D0gia8000000000000
001d0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo0P3oool00`3ookl0M00000000004
000000030000B02Lgol0oooo00<0oooo00<0_g@007Boo`3oool02@3oool00`000000oooo0?ooo`2m
0?ooo`040000003oool000000?ooo`80000000@0oooo0000003oool000001@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01T0oooo0P0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000103oool00`000000oooo0?ooo`1N0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0M@3oool100000040oooo000@0?ooo`030?oOW0180000000000@00000
00<0001809cOo`3oool01`3oool00`3o_g@00000000000020000000307Boo`3oool0oooo01D0oooo
00@0oono07@0000007@0_ooo1P3oool0102oM000000000000000M;l@0?ooo`030?noM000M;l0oooo
00T0oooo00<000000?ooo`3oool0_@3oool010000000oooo0000003oool2000000040?ooo`000000
oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`8000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0GP3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo07D0oooo0@0000010?ooo`00G03o
ool00`3ookl0M01d0;ooo`090?ooo`030000003oool0oooo0;d0oooo00@000000?ooo`000000oooo
0`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0I0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool0GP3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo07D0
oooo0@0000010?ooo`00G@3oool00`2oM000M;oo0?ooo`080?ooo`<00000^`3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool0GP3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo07@0oooo0P0000010?ooo`00G@3oool00`3o_g@007Bo
0?ooo`080?ooo`030000003oool0oooo0;/0oooo00@000000?ooo`000000oooo0`0000000`3oool0
00000?ooo`0Y0?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00<000000?ooo`3oool0GP3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo07D0oooo0@0000010?ooo`00F@3oool01`3o_i`0W=oo0?ooo`3oool0oono07@0M02oool0
203oool00`000000oooo0?ooo`2k0?ooo`050000003oool000000000003oool00P0000000`3oool0
00000?ooo`0_0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0D@3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo07D0oooo0@0000010?ooo`00F@3oool00`3ooml0W4P0000000030000000307Boo`3oool0
oooo00H0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`02000000040?ooo`000000
oooo00000080oooo00<000000?ooo`3oool0;P3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0540oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool006P0oooo00<000000?ooo`3o
ool0^03oool00`000000oooo00000002000000040?ooo`000000oooo00000080oooo00<000000?oo
o`3oool0;P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0540oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`1e0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0^03oool00`000000oooo0000
0002000000040?ooo`000000oooo000003<0oooo00L000000?ooo`3oool0oooo0000003oool00000
00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1A0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0M@3oool100000040oooo001X0?ooo`030000003oool0oooo
0;P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000<`3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0540oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool0
06P0oooo0`00002h0?ooo`070000003oool000000?ooo`000000oooo0000000e0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0D@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo07@0oooo0P0000010?oo
o`00J03oool00`000000oooo0?ooo`2f0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool0000003D0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo0P00000<0?ooo`03
0000003oool0oooo0540oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`1e0?oo
o`4000000@3oool006P0oooo00<000000?ooo`3oool0]P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo0000000e0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
oooo0P00000<0?ooo`030000003oool0oooo0540oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo0@0000010?ooo`00J03oool00`000000
oooo0?ooo`2f0?ooo`80000000D0oooo000000000000oooo0000000g0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00P00000<0?ooo`030000003oool0oooo0540oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo0@00
00010?ooo`00J03oool00`000000oooo0?ooo`2f0?ooo`80000000<0oooo000000000000>@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00800000303oool00`000000oooo0?oo
o`1A0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1e0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0]03oool4000000030?ooo`00
0000oooo03X0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02000000`0oooo00<0
00000?ooo`3oool0D@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0M@3oool100000040oooo001X0?ooo`030000003oool0oooo0;@0oooo0P00
0000103oool000000?ooo`00000k0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0P00000<0?ooo`030000003oool0oooo0540oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo0@0000010?ooo`00J03oool00`000000oooo
0?ooo`2^0?ooo`030000003oool000000080oooo0`000000103oool000000?ooo`00000k0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P00000<0?ooo`030000003oool0oooo0540
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
07D0oooo0@0000010?ooo`00J03oool300000:`0oooo00@000000?ooo`000000oooo100000001P3o
ool000000?ooo`000000oooo000003/0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`02000000`0oooo00<000000?ooo`3oool0D@3oool2000000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`8000000@3oool006P0oooo00<00000
0?ooo`3oool0Z@3oool01@000000oooo000000000000oooo008000001@3oool00`000000oooo0000
000m0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P00000<0?ooo`030000003o
ool0oooo0540oooo0P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0M@3oool100000040oooo001X0?ooo`030000003oool0oooo0:L0oooo00@00000
0?ooo`000000oooo0`0000000`3oool000000?ooo`140?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P00000<0?ooo`030000003oool0oooo0540oooo0P0000000`3oool000000?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M@3oool100000040oooo001X
0?ooo`030000003oool0oooo0:40oooo00@000000?ooo`3oool0oooo100000001@3oool000000?oo
o`3oool0000004L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02000000`0oooo
00<000000?ooo`3oool0D@3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0W`3o
ool00`000000oooo00000003000000060?ooo`000000oooo0000003oool000000P3oool00`000000
oooo0?ooo`150?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P00000<0?ooo`03
0000003oool0oooo0540oooo0P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0M@3oool100000040oooo001X0?ooo`030000003oool0oooo09l0oooo
0P00001D0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P0000020?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`1A0?ooo`80000000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo0@0000010?ooo`00
J03oool00`000000oooo0?ooo`2L0?ooo`050000003oool000000?ooo`000000E03oool00`000000
oooo000000030?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool0D03oool01@000000oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool006P0oooo0`00002B0?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`0000000000EP3oool00`000000oooo00000003
0?ooo`0;0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000040?oo
o`030000003oool0oooo04d0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`8000000@3oool006P0oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo008000000P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0000000<0oooo00T000000?ooo`3oool00000
0?ooo`000000oooo0000003oool00P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo
04d0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool00200oooo00H0_g@00000000000000000
0018W03Oool70?ooo`030;mdB02Lgol0oooo00H0oooo00<0oknL07Bog`3oool0103oool00`3o_g@0
00000000000200000003001d_`3oool0oooo00<0oooo00@0_g@0000000000000B9cO703oool00`00
0000oooo0?ooo`2A0?ooo`030000003oool0000000<0000000<0oooo000000000000F`3oool00`00
0000oooo000000030?ooo`090000003oool0oooo0000003oool000000?ooo`000000oooo00800000
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`1=0?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M@3oool1
00000040oooo000O0?ooo`030?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool01P3oool00`3o
_g@0001809cOo`050?ooo`030?noM00004P0W=oo00L0oooo00<0_g@00000M02oool0103oool01`3o
oml0W4P0001d_`3oool0oooO09a80000M;l06`3oool00`000000oooo0?ooo`2A0?ooo`030000003o
ool000000640oooo00<000000?ooo`0000000`3oool02@000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`02000000030?ooo`000000oooo0080oooo00<000000?ooo`000000CP3oool02000
0000oooo0?ooo`000000oooo0000003oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo07D0oooo0@0000010?ooo`009@3oool00`3ogi`0B7Bo0?ooo`060?ooo`030?noM000
04P0W=oo00<0oooo00<0okmd0000B02Lgol0203oool00`2oM000001d0;ooo`040?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol06P3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`000000oooo0000003o
ool00`0000020?ooo`070000003oool0oooo0?ooo`000000oooo0000001>0?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`800000103oool00`000000oooo0?ooo`1e0?ooo`40
00000@3oool002D0oooo00<0oono07@0B02Lgol01`3oool01`3o_g@0001809cOo`3oool0okmd0000
B02Lgol02@3oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO
09a80000M;l06P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool00P3oool01`000000oooo0?ooo`000000oooo0000003oool00P0000030?ooo`070000
003oool0oooo0?ooo`000000oooo0000001>0?ooo`080000003oool0oooo0000003oool000000?oo
o`0000030?ooo`800000103oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool002D0oooo00<0
oono07@0001d_ol0203oool01@3o_g@0001809bLM00004P0W=oo00X0oooo00<0_g@00000M02oool0
0`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo01T0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
00000?ooo`02000000030?ooo`000000oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0
000004h0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo0P0000040?ooo`03
0000003oool0oooo07D0oooo0@0000010?ooo`004P3oool00`2oM0000000000000070000000304RL
g`3oool0oooo00H0oooo00<0okmd0000001d_ol02@3oool00`3o_g@0001809cOo`0;0?ooo`030;md
000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0I0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0000003oool00P0000000`3oool000000?ooo`020?ooo`070000003oool0oooo0?oo
o`000000oooo0000001>0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`80
0000103oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool002@0oooo00@0omnL04P0000007@0
_ooo203oool01@3o_g@0001809bLM00004P0W=oo00X0oooo00<0_g@00000M02oool00`3oool00`3o
gi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01T0oooo1000002<0?ooo`800000I`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00P0000000`3oool000000?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo0000001>0?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`800000103oool00`000000oooo0?ooo`1b0?ooo`@000000@3oool0
0200oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`060?ooo`070?noM00004P0
W=oo0?ooo`3o_g@0001809cOo`090?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0
103oool00`3OW4P0001809cOo`0I0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00P0000000`3oool0
00000?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000001>0?ooo`080000003oool0
oooo0000003oool000000?ooo`0000030?ooo`800000103oool00`000000oooo0?ooo`1e0?ooo`40
00000@3oool00200oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`060?ooo`030?no
M00004P0W=oo00<0oooo00<0okmd0000B02Lgol0203oool00`2oM000001d0;ooo`030?ooo`030?oo
_`1d000007Bo00@0oooo00<0_g@00000M02oool0303oool00`2oM000M;oo0?ooo`0:0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0000003oool00P0000060?ooo`060000003oool0oooo0000003oool00000CP3oool0
20000000oooo0?ooo`000000oooo0000003oool000000`3oool2000000@0oooo00<000000?ooo`3o
ool0M@3oool100000040oooo000P0?ooo`050?oog`2LB00000000000M02oool0203oool00`2oM000
001809cOo`050?ooo`030?noM0000000B9cO00L0oooo00<0_g@00000M02oool0103oool00`2oM000
04RL0=ooo`020?ooo`030?oog`2LB00007Bo00d0oooo00<0okmd001d_`3oool02P3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`000000oooo008000001P3oool01P000000oooo0?ooo`000000oooo000004h0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo000000<0oooo0P0000040?ooo`030000003oool0oooo
07D0oooo0@0000010?ooo`008@3oool00`3o_g@007Bo0?ooo`090?ooo`030?noW02Lgol0oooo00H0
oooo00<0oknL09cOo`3oool01P3oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080
oooo00<0omnL04P0001d_ol03@3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool02`3oool2000006h0oooo00D000000?ooo`3oool000000?ooo`020000
00H0oooo00H000000?ooo`3oool000000?ooo`00001>0?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000030?ooo`800000103oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool00240
oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0D0?ooo`050=nLB000000000000000
M02oool01@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`80oooo00<0oono07@0000000001000
00000`0004P0W=oo0?ooo`030?ooo`030;md001d_ol0oooo00T0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool000000700oooo00D000000?ooo`3oool00000
0?ooo`02000000H0oooo00H000000?ooo`3oool000000?ooo`00001>0?ooo`080000003oool0oooo
0000003oool000000?ooo`0000030?ooo`800000103oool00`000000oooo0?ooo`1e0?ooo`400000
0@3oool00280oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0D0?ooo`040?oo_`1d
0000001d0;ooo`H0oooo00@0_g@000000000000007Bo403oool00`3o_g@007Bo0?ooo`090?ooo`03
0000003oool0oooo07d0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`000000L@3oool01@000000oooo0?ooo`000000oooo008000001P3oool01P000000oooo0?oo
o`000000oooo000004h0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo0P00
00040?ooo`030000003oool0oooo07D0oooo0@0000010?ooo`00G03oool00`3ookl0M01d0;ooo`09
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`0000001@0000000`3oool000000000001d
0?ooo`050000003oool0oooo0000003oool00P0000060?ooo`060000003oool0oooo0000003oool0
0000CP3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool2000000@0oooo00<0
00000?ooo`3oool0M@3oool100000040oooo001M0?ooo`030;md001d_ol0oooo00P0oooo0`00001l
0?ooo`030000003oool0000000<0oooo00<000000?ooo`000000MP3oool01@000000oooo0?ooo`00
0000oooo008000001P3oool01P000000oooo0?ooo`000000oooo000004h0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo0P0000040?ooo`030000003oool0oooo07@0oooo0P00
00010?ooo`00G@3oool00`3o_g@007Bo0?ooo`080?ooo`030000003oool0oooo07X0oooo0`000000
0`3oool000000?ooo`1k0?ooo`050000003oool0oooo0000003oool00P0000060?ooo`060000003o
ool0oooo0000003oool00000CP3oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool2000000@0oooo00<000000?ooo`3oool0M@3oool100000040oooo001I0?ooo`070?noW02Lgol0
oooo0?ooo`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
OP3oool01@000000oooo0?ooo`000000oooo008000001P3oool01P000000oooo0?ooo`000000oooo
000004h0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo0P0000040?ooo`03
0000003oool0oooo07D0oooo0@0000010?ooo`00F@3oool00`3ooml0W4P0000000030000000307Bo
o`3oool0oooo00H0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1o0?ooo`050000
003oool0oooo0000003oool00P0000060?ooo`060000003oool000000000003oool00000CP3oool0
20000000oooo0?ooo`000000oooo0000003oool000000`3oool2000000@0oooo00<000000?ooo`3o
ool0M@3oool100000040oooo001X0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`000000
00000?ooo`00001>0?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`800000
103oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3o
ool01P000000oooo000000000000oooo000004h0oooo00P000000?ooo`3oool000000?ooo`000000
oooo000000<0oooo0P0000040?ooo`030000003oool0oooo07D0oooo0@0000010?ooo`00J03oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0800oooo0P0000020?ooo`030000003oool0
oooo00D0oooo00H000000?ooo`00000000000?ooo`00001>0?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`800000103oool00`000000oooo0?ooo`1e0?ooo`4000000@3oool0
06P0oooo0`00001h0?ooo`030000003oool0oooo0840oooo0P0000020?ooo`030000003oool0oooo
00D0oooo00H000000?ooo`00000000000?ooo`00001>0?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000030?ooo`800000103oool00`000000oooo0?ooo`1d0?ooo`8000000@3oool006P0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`210?ooo`8000000P3oool00`000000
oooo0?ooo`050?ooo`060000003oool000000000003oool00000CP3oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool2000000@0oooo00<000000?ooo`3oool0M@3oool100000040
oooo001X0?ooo`030000003oool0oooo07D0oooo00@000000?ooo`3oool00000P`3oool200000080
oooo00<000000?ooo`3oool01@3oool01P000000oooo000000000000oooo000000<0oooo00<00000
0?ooo`3oool0B03oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool2000000@0
oooo00<000000?ooo`3oool0M@3oool100000040oooo001X0?ooo`030000003oool0oooo07D0oooo
00@000000?ooo`3oool00000P`3oool200000080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000004X0oooo00D000000?ooo`3oool000000?ooo`03
000000<0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool1
00000040oooo001X0?ooo`030000003oool0oooo07D0oooo00@000000?ooo`3oool00000P`3oool2
00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000004X0oooo00D000000?ooo`3oool000000?ooo`03000000<0oooo0P0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool100000040oooo001X0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`000000Q03oool2000000/0oooo00<000000?ooo`3oool00`3o
ool3000004X0oooo00D000000?ooo`3oool000000?ooo`03000000<0oooo0P0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool100000040oooo001X0?ooo`030000003o
ool0oooo07@0oooo00@000000?ooo`0000000000Q03oool2000000/0oooo00<000000?ooo`3oool0
0`3oool3000004X0oooo00D000000?ooo`3oool000000?ooo`03000000<0oooo0P0000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool100000040oooo001X0?ooo`030000
003oool0oooo07@0oooo00@000000?ooo`0000000000Q03oool2000000/0oooo00<000000?ooo`3o
ool0103oool2000004X0oooo00D000000?ooo`3oool000000?ooo`03000000<0oooo0P0000040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool100000040oooo001X0?ooo`<0
0000M03oool010000000oooo0000000000240?ooo`8000002`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0000004T0oooo00D000000?ooo`3oool000000?ooo`03000000<0oooo0P000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0K@3oool200000040oooo001X0?oo
o`030000003oool0oooo07@0oooo00@000000?ooo`0000000000Q03oool2000000/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`170?ooo`050000003oool0oooo0000003oool00`00
00030?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06h0oooo0@00
00010?ooo`00J03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo08D0oooo0P00000;
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0A`3oool01@000000oooo0?ooo`00
0000oooo00<000000`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1^0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`25
0?ooo`800000503oool00`000000oooo0?ooo`170?ooo`050000003oool0oooo0000003oool00`00
00030?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06h0oooo0@00
00010?ooo`00J03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo08D0oooo0P00000D
0?ooo`030000003oool0oooo04L0oooo00D000000?ooo`3oool000000?ooo`03000000<0oooo0P00
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool100000040oooo001X
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0QP3oool2000001@0oooo00<00000
0?ooo`3oool0A`3oool01@000000oooo0?ooo`000000oooo00<000000`3oool2000000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1^0?ooo`4000000@3oool006P0oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`260?ooo`800000503oool00`000000oooo0?ooo`17
0?ooo`050000003oool0oooo0000003oool00`0000030?ooo`800000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06h0oooo0@0000010?ooo`00J03oool3000007<0oooo00<00000
0?ooo`3oool0QP3oool2000001@0oooo00<000000?ooo`3oool0A`3oool01@000000oooo0?ooo`00
0000oooo00<000000`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1]0?ooo`8000000@3oool006P0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`26
0?ooo`800000503oool00`000000oooo0?ooo`170?ooo`050000003oool0oooo0000003oool00`00
00030?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06h0oooo0@00
00010?ooo`003`3oool00`3OW4P00000000000050000000607Boo`3oool0oooo0=nLB0000000B9cO
0P3oool01P2oM000000000000000000004RL0=ooo`P0oooo00<0_gA809cOo`3oool01P3oool00`3o
_i`0M;oO0?ooo`040?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool00`3oool0102o
M000000000000018W=lL0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`260?ooo`800000503oool00`000000oooo000000170?ooo`050000003oool0
oooo0000003oool00`0000030?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo06h0oooo0@0000010?ooo`00403oool00`3OW4P00000000000040000000:001d_`3oool0
oooo0=nLB0000000B9cO0?ooo`3ooml0W4P004RLg`80oooo00<0omnL04Q8W03Oool01`3oool00`3o
_g@0001809cOo`050?ooo`030?noM00004P0W=oo00L0oooo00<0_g@00000M02oool0103oool01`3o
oml0W4P0001d_`3oool0oooO09a80000M;l06`3oool00`000000oooo0?ooo`1^0?ooo`80000000<0
oooo000000000000R@3oool2000001D0oooo0`0000160?ooo`050000003oool0oooo0000003oool0
0`0000030?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06h0oooo
0@0000010?ooo`004@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oog`2LB7@0_ooo00/0oooo00<0
omnL04Qd_`3oool01`3oool00`3o_g@0001809cOo`030?ooo`030?noM00004P0W=oo00P0oooo00<0
_g@00000M02oool0103oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo01X0oooo00<0
00000?ooo`3oool0KP3oool2000000030?ooo`000000oooo08T0oooo0P00000E0?ooo`<00000AP3o
ool01@000000oooo0?ooo`000000oooo00<000000`3oool2000000@0oooo00<000000?ooo`3oool0
0`3oool200000700oooo0@0000010?ooo`004P3oool00`3OW4P0B9cO0?ooo`0?0?ooo`030?oo_`1d
04P0W=oo00P0oooo00L0okmd0000B02Lgol0oooo0?noM00004P0W=oo00T0oooo00<0_g@00000M02o
ool00`3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo01X0oooo00<000000?oo
o`3oool0KP3oool00`000000oooo0000002;0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`000000AP3oool01@000000oooo0?ooo`000000oooo00<000000`3oool2000000@0oooo00<00000
0?ooo`3oool00`3oool200000700oooo0@0000010?ooo`004`3oool00`3OW4P0M;oo0?ooo`0>0?oo
o`030?oo_`1d0000M;oo00T0oooo00D0okmd0000B02LW7@0001809cOo`0:0?ooo`030;md000007@0
_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0I0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`000000R`3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0
oooo000004D0oooo00D000000?ooo`3oool000000?ooo`03000000<0oooo0P0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`000000K`3oool100000040oooo00030?ooo`030;md0000
0000000000L0000000<0B9cO0?ooo`3oool00`3oool00`3ooml0W4Q809cOo`0>0?ooo`030?noM000
0000M;oo00X0oooo00<0okmd0000B02Lgol02`3oool00`2oM000001d0;ooo`030?ooo`030?oOW018
0000B9cO00@0oooo00<0_g@00000M02oool06@3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000140?ooo`800000
0P3oool00`000000oooo00000002000000<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`000000K`3oool100000040oooo000D0?ooo`030?oOW01807@0_ooo00`0oooo00@0
omnL04P0000007@0_ooo2@3oool01@3o_g@0001809bLM00004P0W=oo00X0oooo00<0_g@00000M02o
ool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01T0oooo1000001/0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000140?oo
o`8000000P3oool00`000000oooo00000002000000<0oooo0P0000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`000000K03oool400000040oooo000E0?ooo`030;md0018W=l0oooo00L0
oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`070?ooo`070?noM00004P0W=oo
0?ooo`3o_g@0001809cOo`090?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103o
ool00`3OW4P0001809cOo`0I0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0480oooo0P0000020?ooo`030000003o
ool00000008000000`3oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
001_0?ooo`4000000@3oool001D0oooo00<0gia80000M02oool01`3oool00`3o_g@0000000000002
00000003001d_`3oool0oooo00L0oooo00<0okmd0000B02Lgol00`3oool00`3o_g@0001809cOo`08
0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0<
0?ooo`030;md001d_ol0oooo00X0oooo00<000000?ooo`3oool0J@3oool01@000000oooo0?ooo`3o
ool000000:P0oooo00<000000?ooo`3oool0@P3oool200000080oooo00<000000?ooo`0000000P00
00030?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000006l0oooo0@00
00010?ooo`005@3oool00`3o_g@0000007Boo`070?ooo`050?oog`2LB00000000000M02oool02@3o
ool00`2oM000001809cOo`050?ooo`030?noM0000000B9cO00L0oooo00<0_g@00000M02oool0103o
ool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00d0oooo00<0okmd001d_`3oool02P3o
ool00`000000oooo0?ooo`1Y0?ooo`050000003oool0oooo0?ooo`000000Z@3oool00`000000oooo
0?ooo`110?ooo`8000000P3oool00`000000oooo00000002000000<0oooo0P0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`000000K`3oool100000040oooo000?0?ooo`030?oOW02L
_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`3o_g@007Bo0?ooo`0:0?ooo`030?noW02L
gol0oooo00H0oooo00<0oknL09cOo`3oool01P3oool00`2oM000001d0;ooo`040?ooo`030?noM000
04P0W=oo0080oooo00<0omnL04P0001d_ol03@3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003o
ool0oooo06T0oooo00D000000?ooo`3oool0oooo0000002Y0?ooo`030000003oool000000440oooo
0P0000020?ooo`030000003oool00000008000000`3oool2000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0000001_0?ooo`4000000@3oool00100oooo00P0_g@007Boo`3oool0oooo
0=nLB000000004RL0=ooo`P0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0E0?oo
o`050=nLB000000000000000M02oool01@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`80oooo
00<0oono07@000000000100000000`0004P0W=oo0?ooo`030?ooo`030;md001d_ol0oooo00T0oooo
00<000000?ooo`3oool0J@3oool01@000000oooo0?ooo`3oool000000:T0oooo00<000000?ooo`00
0000@@3oool200000080oooo00<000000?ooo`0000000P0000030?ooo`800000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0000006l0oooo0@0000010?ooo`004@3oool01@2oM0000000
00000000000007Bo00/0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0E0?ooo`04
0?oo_`1d0000001d0;ooo`H0oooo00@0_g@000000000000007Bo403oool00`3o_g@007Bo0?ooo`09
0?ooo`030000003oool0oooo06T0oooo0P0000000`3oool000000?ooo`2Y0?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0>`3oool200000080oooo00<000000?ooo`0000000P000003
0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000006l0oooo0@000001
0?ooo`00G03oool00`3ookl0M01d0;ooo`090?ooo`030000003oool0oooo06P0oooo00D000000?oo
o`000000oooo0000002Z0?ooo`<000000`3oool00`000000oooo0?ooo`0k0?ooo`8000000P3oool0
0`000000oooo00000002000000<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`000000K`3oool100000040oooo001M0?ooo`030;md001d_ol0oooo00P0oooo0`00001X0?oo
o`040000003oool0000000000:`0oooo0P0000030?ooo`800000?03oool200000080oooo00<00000
0?ooo`0000000P0000030?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
000006h0oooo0P0000010?ooo`00G@3oool00`3o_g@007Bo0?ooo`080?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool0[@3oool2000000<0oooo0P00000l0?ooo`8000000P3oool00`00
0000oooo00000002000000<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000K`3oool100000040oooo001I0?ooo`070?noW02Lgol0oooo0?ooo`3ookl0M01d0;ooo`08
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`000000[`3oool2000000<0oooo0P00000l
0?ooo`8000000P3oool00`000000oooo00000002000000<0oooo0P0000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`000000K`3oool100000040oooo001I0?ooo`030?oog`2LB0000000
00<0000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?ooo`1V0?ooo`<00000/03oool01`00
0000oooo0?ooo`3oool000000?ooo`000000>`3oool200000080oooo00<000000?ooo`0000000P00
00030?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000006l0oooo0@00
00010?ooo`00J03oool00`000000oooo0?ooo`1S0?ooo`040000003oool0oooo00000;80oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0i0?ooo`8000000P3oool00`000000oooo
00000002000000<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
K`3oool100000040oooo001X0?ooo`030000003oool0oooo06<0oooo0`00002c0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0>@3oool200000080oooo00<000000?ooo`000000
0P0000030?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0000006l0oooo
0@0000010?ooo`00J03oool00`000000oooo0?ooo`1S0?ooo`<00000/`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo03T0oooo0P0000020?ooo`030000003oool0000000800000
0`3oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000001_0?ooo`400000
0@3oool006P0oooo0`00001R0?ooo`040000003oool0oooo00000;<0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0i0?ooo`8000000P3oool00`000000oooo00000002000000<0
oooo0P0000040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000KP3oool200000040
oooo001X0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool00P00002f0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`80
00000P3oool00`000000oooo00000002000000<0oooo0P0000040?ooo`030000003oool0000000<0
oooo00<000000?ooo`000000K`3oool100000040oooo001X0?ooo`030000003oool0oooo05h0oooo
00D000000?ooo`000000oooo0000002f0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0B0?ooo`8000000P3oool00`000000oooo000000020000
00<0oooo0P0000040?ooo`030000003oool0000000<0oooo00<000000?ooo`000000K`3oool10000
0040oooo001X0?ooo`030000003oool0oooo05d0oooo0P0000000`3oool000000?ooo`2g0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool200000080oooo00<000000?oo
o`0000000P0000030?ooo`800000103oool00`000000oooo000000030?ooo`030000003oool00000
06l0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0080
000000<0oooo0000003oool0]`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00P0oooo0P0000080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0;0?ooo`8000000P3oool00`000000oooo00000002000000<0oooo0P0000040?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000K`3oool100000040oooo001X0?ooo`03
0000003oool0oooo05X0oooo00H000000?ooo`3oool000000?ooo`00002i0?ooo`040000003oool0
oooo000000<0oooo00@000000?ooo`3oool000000`3oool200000080oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
1P3oool00`000000oooo0?ooo`0;0?ooo`8000000P3oool00`000000oooo0000000200000080oooo
00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003oool0000006l0oooo
0@0000010?ooo`00J03oool00`000000oooo0?ooo`1J0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool0]`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0
oooo0P0000001P3oool000000?ooo`3oool000000?ooo`800000103oool00`000000oooo0?ooo`0;
0?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0;0?ooo`8000000P3oool0
0`000000oooo0000000200000080oooo00<000000?ooo`000000103oool00`000000oooo00000003
0?ooo`030000003oool0000006l0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`1I0?oo
o`040000003oool0000000000080oooo00<000000?ooo`3oool0]`3oool010000000oooo0?ooo`00
00030?ooo`040000003oool0oooo000000<0oooo0P0000001P3oool000000?ooo`3oool000000?oo
o`800000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0P0000000`3o
ool000000?ooo`050?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`030000003oool00000
008000000P3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000K`3oool100000040oooo001X0?ooo`<00000F@3oool00`000000oooo0000002n0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P0000020?ooo`80000000H0oooo0000003o
ool0oooo0000003oool2000000<0oooo0P0000080?ooo`030000003oool0oooo0080oooo0P000000
0`3oool000000?ooo`050?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`0:0000003oool0
00000000003oool000000?ooo`000000oooo000000@0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000KP3oool200000040oooo001X0?ooo`030000003oool0oooo05H0oooo00@0
00000?ooo`3oool00000`03oool00`000000oooo000000030?ooo`0;0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool010000000oooo0000000000030?ooo`800000
203oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0;0?ooo`8000000P3oool02P000000oooo000000000000oooo0000003oool000000?ooo`00
00040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000006l0oooo0@0000010?oo
o`00J03oool00`000000oooo0?ooo`1E0?ooo`040000003oool0000000000<40oooo00<000000?oo
o`0000000`3oool00`000000oooo000000020?ooo`8000000P3oool200000080oooo00@000000?oo
o`00000000000`3oool2000000L0oooo0P0000040?ooo`80000000<0oooo0000003oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`8000000P3oool02P000000oooo000000000000oooo0000003oool0
00000?ooo`0000040?ooo`090000003oool000000?ooo`000000oooo0000003oool0000006l0oooo
0@0000010?ooo`00J03oool00`000000oooo0?ooo`1E0?ooo`040000003oool0oooo00000<40oooo
00<000000?ooo`000000103oool200000080oooo0P0000020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool01@000000oooo0000003oool0000000@0oooo0P0000040?oo
o`80000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0;0?ooo`8000000P3oool02P00
0000oooo000000000000oooo0000003oool000000?ooo`0000040?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000006l0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`1A
0?ooo`040000003oool0oooo00000<D0oooo00<000000?ooo`000000103oool2000000<0oooo00@0
00000?ooo`3oool00000103oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?oo
o`000000103oool2000000@0oooo0P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo
00/0oooo0P0000020?ooo`0:0000003oool000000000003oool000000?ooo`000000oooo000000@0
oooo00@000000?ooo`000000oooo0P0000020?ooo`030000003oool0oooo06d0oooo0@0000010?oo
o`00J03oool00`000000oooo0?ooo`1@0?ooo`80000000<0oooo0000003oool0a@3oool2000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
00000`3oool00`000000oooo000000020?ooo`040000003oool00000000000@0oooo0P0000000`3o
ool000000?ooo`050?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`0:0000003oool00000
0000003oool000000?ooo`000000oooo000000@0oooo00@000000?ooo`000000oooo0P0000030?oo
o`030000003oool0oooo06`0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`1@0?ooo`04
0000003oool0000000000<H0oooo0P00000B0?ooo`030000003oool0oooo008000000`3oool30000
0080oooo00@000000?ooo`0000000000103oool2000000030?ooo`000000oooo00D0oooo00<00000
0?ooo`3oool02`3oool200000080oooo00X000000?ooo`00000000000?ooo`000000oooo0000003o
ool00000103oool010000000oooo0000003oool2000000<0oooo00<000000?ooo`3oool0K03oool1
00000040oooo001X0?ooo`<00000B`3oool01@000000oooo0?ooo`3oool000000<X0oooo0P00000B
0?ooo`040000003oool0oooo000000@0oooo0`0000020?ooo`80000000<0oooo0000003oool00`3o
ool2000000030?ooo`000000oooo00@0oooo0P00000=0?ooo`8000000P3oool02P000000oooo0000
00000000oooo0000003oool000000?ooo`0000040?ooo`040000003oool000000?ooo`8000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo0P0000010?ooo`00J03oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0000000<00000bP3oool2000001D0oooo00<00000
0?ooo`3oool00P3oool3000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`80
000000<0oooo0000003oool0103oool2000000d0oooo0P0000020?ooo`0:0000003oool000000000
003oool000000?ooo`000000oooo000000@0oooo00@000000?ooo`000000oooo0P0000030?ooo`03
0000003oool0oooo00<0oooo0P00001W0?ooo`4000000@3oool005T0oooo00@0_g@0000000000000
B9cO2`3oool00`000000oooo0?ooo`140?ooo`<000000`3oool00`000000oooo0?ooo`3=0?ooo`80
00006P3oool3000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`@000001@3o
ool2000000d0oooo0P0000020?ooo`0:0000003oool000000000003oool000000?ooo`000000oooo
000000@0oooo00@000000?ooo`000000oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000IP3oool100000040oooo001G0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0
001d_`0:0?ooo`030000003oool0oooo04<0oooo00@000000?ooo`3oool0oooo0`00003@0?ooo`80
00007@3oool2000000060?ooo`000000oooo0000003oool000000P3oool4000000D0oooo0P000008
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00@000000?ooo`000000oooo0P0000030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`000000IP3oool100000040oooo001G0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
0=D0oooo0P00000M0?ooo`800000103oool200000080oooo100000050?ooo`800000203oool00`00
0000oooo0?ooo`020?ooo`8000000P3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0000040?ooo`040000003oool000000?ooo`8000000`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0E`3oool100000040oooo001F0?oo
o`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02@3oool00`000000oooo0?ooo`0j
0?ooo`8000000`3oool300000=P0oooo0P00000M0?ooo`800000103oool200000080oooo00D00000
0?ooo`000000oooo000000040?ooo`800000203oool00`000000oooo0?ooo`020?ooo`8000000P3o
ool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`040000003oool0
00000?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`0000000000E`3oool100000040oooo001F0?ooo`030?oo_`1d000007Bo00@0oooo
00<0_g@00000M02oool0203oool00`000000oooo0?ooo`0e0?ooo`D000000P3oool300000=/0oooo
0P00000M0?ooo`800000103oool200000080oooo00D000000?ooo`000000oooo000000040?ooo`80
0000203oool00`000000oooo0?ooo`020?ooo`8000000P3oool02P000000oooo0?ooo`000000oooo
0000003oool000000?ooo`0000040?ooo`040000003oool000000?ooo`8000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo05@0oooo0@0000010?ooo`00EP3oool00`3ogi`0B00004RLg`040?ooo`03
0;md000007@0_ooo00P0oooo00<000000?ooo`3oool09P3oool?00000>D0oooo0P00000M0?ooo`03
0000003oool0oooo00<0oooo0`0000001P3oool000000?ooo`000000oooo000000@0oooo0P000008
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`0:0000003oool0oooo0000003oool00000
0?ooo`000000oooo000000@0oooo00@000000?ooo`000000oooo0P0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo0`0000080?ooo`030000003oool000000080oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0/0?ooo`4000000@3oool005H0oooo00<0omnL04P00018W=l0103oool00`3O
W4P0001809cOo`080?ooo`@00000203ooolM00000?@0oooo0P00000M0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`00000000000P3oool00`000000oooo000000040?ooo`800000203oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000040?ooo`030000003oool0000000<000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000X0oooo2@0000001@3o
ool000000?ooo`000000oooo0140000000<0oooo0000000000000P0000000`3oool000000000000R
000000L0oooo100000010?ooo`00EP3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
00P0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool00`3oool010000000oooo0000000000020?ooo`040000003oool00000000000<0oooo0P00
00080?ooo`030000003oool0oooo0080oooo0P0000020?ooo`0:0000003oool0oooo0000003oool0
00000?ooo`000000oooo000000@0oooo00<000000?ooo`0000000`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000030?ooo`000000
oooo0140oooo0P0000000`3oool000000?ooo`0B0?ooo`030000003oool0oooo0340oooo0@000001
0?ooo`00EP3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`030000003oool0oooo0280oooo00@000000?ooo`00000000000P3oool0
10000000oooo0000000000030?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3o
ool200000080oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000103oool6
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000005`3oool0
0`000000oooo0?ooo`170?ooo`4000000@3oool005L0oooo00<0_g@00018W03Oool00P3oool00`3o
oml0W4P0001d_`090?ooo`030000003oool0oooo0?l0oooo@03oool010000000oooo000000000002
0?ooo`040000003oool00000000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`@0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0A`3oool100000040oooo001G0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol02@3oool00`000000oooo0?ooo`3o0?oood00oooo00@000000?oo
o`00000000000P3oool010000000oooo0000000000030?ooo`030000003oool0000000L0oooo00<0
00000?ooo`3oool00P3oool200000080oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool00000103oool4000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1W0?ooo`4000000@3oool005P0oooo00H0_g@00018W03Oool0oooo0;md0000
M;l:0?ooo`030000003oool0oooo0?l0oooo@03oool010000000oooo0000000000020?ooo`040000
003oool0000000000080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?oo
o`8000000P3oool020000000oooo0?ooo`000000oooo0000003oool000000P3oool010000000oooo
0?ooo`3oool4000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1W0?ooo`40
00000@3oool005T0oooo00@0_g@000000000000007Bo2`3oool00`000000oooo0?ooo`3o0?oood00
oooo00@000000?ooo`00000000000P3oool010000000oooo0000000000020?ooo`040000003oool0
oooo000000H0oooo0P0000040?ooo`8000000P3oool020000000oooo0?ooo`000000oooo0000003o
ool000000P3oool010000000oooo0?ooo`3oool4000000D0oooo00D000000?ooo`3oool0oooo0000
001Z0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooom00?ooo`040000003oool0
000000000080oooo00@000000?ooo`00000000000P3oool010000000oooo0?ooo`0000060?ooo`80
0000103oool200000080oooo00P000000?ooo`3oool000000?ooo`000000oooo00000080oooo00@0
00000?ooo`3oool0oooo100000050?ooo`050000003oool0oooo0?ooo`000000JP3oool100000040
oooo001X0?ooo`<00000o`3ooom20?ooo`8000000P3oool010000000oooo0000000000020?ooo`04
0000003oool0oooo000000H0oooo0P0000040?ooo`8000000P3oool020000000oooo0?ooo`000000
oooo0000003oool000000P3oool010000000oooo0?ooo`3oool4000000D0oooo00D000000?ooo`3o
ool0oooo0000001Y0?ooo`8000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooom20?ooo`80
00000P3oool010000000oooo0000000000020?ooo`040000003oool0oooo000000H0oooo0P000004
0?ooo`8000000P3oool020000000oooo0?ooo`000000oooo0000003oool000000P3oool010000000
oooo0?ooo`3oool4000000D0oooo00D000000?ooo`3oool0oooo0000001Z0?ooo`4000000@3oool0
06P0oooo00<000000?ooo`3oool0o`3ooom20?ooo`8000000P3oool010000000oooo000000000002
0?ooo`040000003oool0oooo000000H0oooo0P0000040?ooo`8000000P3oool020000000oooo0?oo
o`000000oooo0000003oool000000P3oool010000000oooo0?ooo`3oool4000000D0oooo00D00000
0?ooo`3oool0oooo0000001Z0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooom3
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`040000003oool0oooo000000H0oooo0P00
00040?ooo`8000000P3oool020000000oooo0?ooo`000000oooo0000003oool000000P3oool01000
0000oooo0?ooo`3oool4000000D0oooo00D000000?ooo`3oool0oooo0000001Z0?ooo`4000000@3o
ool006P0oooo00<000000?ooo`3oool0o`3ooom30?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`040000003oool0oooo000000H0oooo0P0000040?ooo`8000000P3oool020000000oooo0?oo
o`000000oooo0000003oool000000P3oool010000000oooo0?ooo`3oool4000000H0oooo00@00000
0?ooo`3oool00000JP3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0oooo@`3oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool010000000oooo0?ooo`0000060?ooo`800000103o
ool200000080oooo00P000000?ooo`3oool000000?ooo`000000oooo00000080oooo00@000000?oo
o`3oool0oooo100000060?ooo`040000003oool0oooo000006X0oooo0@0000010?ooo`00J03oool0
0`000000oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool00P3oool200000080oooo00@00000
0?ooo`3oool000001P3oool2000000@0oooo0P0000020?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000020?ooo`050000003oool0oooo0000003oool00`0000060?ooo`030000003oool0
000006/0oooo0@0000010?ooo`00J03oool300000?l0oooo@`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool2000000@0oooo0P000002
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`050000003oool0oooo0000
003oool00`0000060?ooo`030000003oool0000006X0oooo0P0000010?ooo`00J03oool00`000000
oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool200000080oooo00P000000?oo
o`3oool000000?ooo`000000oooo00000080oooo00D000000?ooo`3oool000000?ooo`03000000H0
oooo00<000000?ooo`000000J`3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0oooo
B@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
00000`3oool200000080oooo00P000000?ooo`3oool000000?ooo`000000oooo00000080oooo00D0
00000?ooo`3oool000000?ooo`03000000H0oooo00<000000?ooo`000000J`3oool100000040oooo
001X0?ooo`030000003oool0oooo0?l0ooooB@3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`0000000`3oool200000080oooo00P000000?ooo`3oool0
00000?ooo`000000oooo00000080oooo00D000000?ooo`3oool000000?ooo`03000000H0oooo00<0
00000?ooo`000000J`3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0ooooB@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00H000000?ooo`000000oooo
0000003oool2000000030?ooo`000000oooo0080oooo00D000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0000003oool00`0000060?ooo`030000003oool0000006/0oooo0@000001
0?ooo`00J03oool00`000000oooo0?ooo`3o0?ooodT0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`060000003oool000000?ooo`000000oooo0P0000000`3oool00000
0?ooo`020?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo
00<000001P3oool00`000000oooo0000001[0?ooo`4000000@3oool006P0oooo00<000000?ooo`3o
ool0o`3ooom90?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool01P00
0000oooo0000003oool000000?ooo`80000000<0oooo0000003oool00P3oool01@000000oooo0000
003oool000000080oooo00D000000?ooo`3oool000000?ooo`03000000H0oooo0P00001/0?ooo`40
00000@3oool006P0oooo00<000000?ooo`3oool0o`3ooom90?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0103oool01P000000oooo0000003oool000000?ooo`80000000<0oooo
0000003oool0103oool00`000000oooo000000020?ooo`050000003oool0oooo0000003oool00P00
00080?ooo`030000003oool0oooo06X0oooo0@0000010?ooo`00J03oool300000?l0ooooBP3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool000000?oo
o`000000oooo0080000000<0oooo0000003oool0103oool00`000000oooo000000020?ooo`050000
003oool0oooo0000003oool00P0000080?ooo`030000003oool0oooo06T0oooo0P0000010?ooo`00
J03oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`070000003oool0oooo0000003oool000000?ooo`02000000030?ooo`000000oooo
00@0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00800000M@3oool1
00000040oooo001X0?ooo`030000003oool0oooo0?l0ooooBP3oool00`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00L000000?ooo`3oool000000?ooo`000000oooo0080000000<0
oooo0000003oool0103oool00`000000oooo000000020?ooo`050000003oool0oooo0000003oool0
0P00001e0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0?ooo`000000oooo0000003o
ool000000?ooo`02000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`000000
oooo00800000M@3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0ooooBP3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool000000?ooo`02
00000080oooo0P0000050?ooo`030000003oool000000080oooo00D000000?ooo`3oool000000?oo
o`02000007D0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3o0?ooodX0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool00P00
00020?ooo`8000001@3oool00`000000oooo000000020?ooo`050000003oool0oooo0000003oool0
0P00001e0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`000000oooo00800000
0P3oool2000000D0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo0080
0000M@3oool100000040oooo001X0?ooo`<00000o`3ooom:0?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0000000000080oooo0P0000050?oo
o`030000003oool000000080oooo00D000000?ooo`3oool000000?ooo`02000007@0oooo0P000001
0?ooo`00J03oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`02000000<0oooo00@000000?ooo`00000000000P3oool2000000D0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00800000M@3oool100000040oooo000@
0?ooo`030=nLB0000000000000D0000000H0M;oo0?ooo`3oool0gia800000018W=l20?ooo`060;md
00000000000000000000B9`0gooo1`3oool00`2oM4P0W=oo0?ooo`060?ooo`030?noW01d_ml0oooo
00@0oooo00<0okmd0000000000000P0000000`00M;l0oooo0?ooo`030?ooo`040;md000000000000
04RLga`0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`030000003oool0000000<0oooo00D00000
0?ooo`000000oooo000000030?ooo`040000003oool0000000000080oooo0P0000050?ooo`030000
003oool000000080oooo00D000000?ooo`3oool000000?ooo`02000007D0oooo0@0000010?ooo`00
4@3oool00`3OW4P00000000000040000000:001d_`3oool0oooo0=nLB0000000B9cO0?ooo`3ooml0
W4P004RLg`80oooo00<0omnL04Q8W03Oool01P3oool00`3o_g@0001809cOo`050?ooo`030?noM000
04P0W=oo00L0oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3oool0oooO09a80000
M;l06`3oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`0000000`3oool2000000H0
oooo00@000000?ooo`00000000000P3oool2000000D0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`000000oooo00800000M@3oool100000040oooo000B0?ooo`030=nLB018W=l0oooo
0080oooo00<0oooO09a8M02oool02`3oool00`3ogi`0B7Bo0?ooo`060?ooo`030?noM00004P0W=oo
00<0oooo00<0okmd0000B02Lgol0203oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol06P3oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?oo
o`0000000`3oool2000000H0oooo00@000000?ooo`00000000000P3oool2000000D0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00800000M@3oool100000040oooo000C
0?ooo`030=nLB018W=l0oooo00l0oooo00<0oono07@0B02Lgol01`3oool01`3o_g@0001809cOo`3o
ool0okmd0000B02Lgol02@3oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0oooO09a80000M;l06P3oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`050?ooo`040000003oool0000000000080oooo0P0000050?oo
o`030000003oool000000080oooo00D000000?ooo`3oool000000?ooo`02000007D0oooo0@000001
0?ooo`00503oool00`3OW4P0M;oo0?ooo`0>0?ooo`030?oo_`1d0000M;oo00P0oooo00D0okmd0000
B02LW7@0001809cOo`0:0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool0
0`2oM000001d0;ooo`0I0?ooo`030000003oool0oooo0?l0ooooBP3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`00000000000P3oool2000000D0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00800000M@3oool100000040oooo
000D0?ooo`030?oog`2LB4P0W=oo00h0oooo00<0okmd0000001d_ol02@3oool00`3o_g@0001809cO
o`0;0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`0I0?ooo`030000003oool0oooo0?l0ooooBP3oool00`000000oooo0000000;0?ooo`040000003o
ool0000000000080oooo0P0000050?ooo`030000003oool000000080oooo00D000000?ooo`3oool0
00000?ooo`02000007D0oooo0@0000010?ooo`005@3oool00`3ogi`0B01d0;ooo`0<0?ooo`040?oO
W0180000001d0;ooo`P0oooo00D0okmd0000B02LW7@0001809cOo`0:0?ooo`030;md000007@0_ooo
00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0I0?ooo`@00000o`3ooom90?oo
o`030000003oool0000000/0oooo00@000000?ooo`00000000000P3oool2000000D0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00800000LP3oool400000040oooo000F
0?ooo`030;md0018W=l0oooo00L0oooo00@0gmoO0?ooo`3oool0_g@00P0000000`18W=l0oooo0?oo
o`060?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`090?ooo`030;md000007@0_ooo00<0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`0I0?ooo`030000003oool0oooo0?l0
ooooBP3oool00`000000oooo0000000;0?ooo`040000003oool0000000000080oooo0P0000050?oo
o`030000003oool000000080oooo00D000000?ooo`3oool000000?ooo`02000007D0oooo0@000001
0?ooo`005P3oool00`3OW4P0001d0;ooo`070?ooo`030?noM000000000000080000000<007Bo0?oo
o`3oool01P3oool00`3o_g@0001809cOo`030?ooo`030?noM00004P0W=oo00P0oooo00<0_g@00000
M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00`0oooo00<0_g@007Bo
o`3oool02P3oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`0000002`3oool01000
0000oooo0000000000020?ooo`8000001@3oool00`000000oooo000000020?ooo`050000003oool0
oooo0000003oool00P00001e0?ooo`4000000@3oool001H0oooo00<0okmd0000001d_ol01`3oool0
1@3ooml0W4P00000000007@0_ooo00P0oooo00<0_g@00000B02Lgol01@3oool00`3o_g@0000004RL
g`070?ooo`030;md000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d
_`0=0?ooo`030?noM000M;l0oooo00X0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`030000003o
ool0000000/0oooo00@000000?ooo`00000000000P3oool2000000D0oooo00<000000?ooo`000000
0P3oool01@000000oooo0?ooo`000000oooo00800000M@3oool100000040oooo000@0?ooo`030?oO
W02L_ol0oooo00<0oooo00<0_g@00000001d_ol0203oool00`3o_g@007Bo0?ooo`090?ooo`030?no
W02Lgol0oooo00H0oooo00<0oknL09cOo`3oool01P3oool00`2oM000001d0;ooo`040?ooo`030?no
M00004P0W=oo0080oooo00<0omnL04P0001d_ol03@3oool00`3ookl0M01d0;ooo`0:0?ooo`030000
003oool0oooo0?l0ooooBP3oool00`000000oooo0000000;0?ooo`040000003oool0000000000080
oooo0P0000050?ooo`030000003oool000000080oooo00D000000?ooo`3oool000000?ooo`020000
07D0oooo0@0000010?ooo`004@3oool0202oM000M;oo0?ooo`3oool0gia800000000B9`0gooo203o
ool00`3ooml0W4P000000002000000030000M02oool0oooo01@0oooo00D0gia8000000000000001d
0;ooo`050?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo0P3oool00`3ookl0M000000000040000
00030000B02Lgol0oooo00<0oooo00<0_g@007Boo`3oool02@3oool00`000000oooo0?ooo`3o0?oo
odX0oooo00<000000?ooo`0000002`3oool010000000oooo0000000000020?ooo`8000001@3oool0
0`000000oooo000000020?ooo`050000003oool0oooo0000003oool00P00001e0?ooo`4000000@3o
ool00180oooo00D0_g@00000000000000000001d_`0;0?ooo`030?noM000000000000080000000<0
M;oo0?ooo`3oool0503oool0103ookl0M0000000M02oool60?ooo`040;md000000000000001d_a00
oooo00<0okmd001d_`3oool02@3oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`00
00002`3oool010000000oooo0000000000020?ooo`8000001@3oool00`000000oooo000000020?oo
o`050000003oool0oooo0000003oool00P00001e0?ooo`4000000@3oool005`0oooo00<0oono07@0
M02oool02@3oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`0000002`3oool01000
0000oooo0000000000020?ooo`8000001@3oool00`000000oooo000000020?ooo`050000003oool0
oooo0000003oool00P00001e0?ooo`4000000@3oool005d0oooo00<0_g@007Boo`3oool0203oool3
00000?l0ooooBP3oool2000000`0oooo00@000000?ooo`00000000000P3oool2000000D0oooo00<0
00000?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000007D0oooo0P0000010?ooo`00
G@3oool00`3o_g@007Bo0?ooo`080?ooo`030000003oool0oooo0?l0ooooBP3oool2000000`0oooo
00@000000?ooo`00000000000P3oool2000000D0oooo00<000000?ooo`0000000P3oool01P000000
oooo0?ooo`000000oooo000007H0oooo0@0000010?ooo`00F@3oool01`3o_i`0W=oo0?ooo`3oool0
oono07@0M02oool0203oool00`000000oooo0?ooo`3o0?ooodX0oooo0P00000<0?ooo`040000003o
ool0000000000080oooo0P0000050?ooo`8000000`3oool01P000000oooo0?ooo`000000oooo0000
07H0oooo0@0000010?ooo`00F@3oool00`3ooml0W4P0000000030000000307Boo`3oool0oooo00H0
oooo00<000000?ooo`3oool0o`3ooom:0?ooo`800000303oool2000000@0oooo0P0000050?ooo`80
00000`3oool01P000000oooo0?ooo`000000oooo000007H0oooo0@0000010?ooo`00J03oool00`00
0000oooo0?ooo`3o0?ooodX0oooo0P00000<0?ooo`800000103oool2000000D0oooo0P0000030?oo
o`060000003oool0oooo0000003oool00000MP3oool100000040oooo001X0?ooo`030000003oool0
oooo0?l0ooooBP3oool2000000`0oooo0P0000040?ooo`8000001@3oool2000000<0oooo00H00000
0?ooo`3oool000000?ooo`00001f0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3o
oom:0?ooo`800000303oool2000000@0oooo0P0000050?ooo`8000000`3oool01P000000oooo0?oo
o`000000oooo000007H0oooo0@0000010?ooo`00J03oool300000?l0ooooBP3oool2000000`0oooo
0P0000040?ooo`8000001@3oool2000000<0oooo00H000000?ooo`3oool000000?ooo`00001e0?oo
o`8000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`800000303oool2000000@0
oooo0P0000050?ooo`8000000`3oool2000000040?ooo`000000oooo000007H0oooo0@0000010?oo
o`00J03oool00`000000oooo0?ooo`3o0?ooodX0oooo0P00000<0?ooo`800000103oool2000000D0
oooo0P0000030?ooo`80000000@0oooo0000003oool00000MP3oool100000040oooo001X0?ooo`03
0000003oool0oooo0?l0ooooBP3oool2000000`0oooo0P0000040?ooo`8000001@3oool2000000<0
oooo0P000000103oool000000?ooo`00001f0?ooo`4000000@3oool006P0oooo00<000000?ooo`3o
ool0o`3ooom:0?ooo`800000303oool2000000@0oooo0P0000050?ooo`8000000`3oool200000004
0?ooo`000000oooo000007H0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3o0?ooodX0
oooo0P00000=0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`8000000`3oool200000004
0?ooo`000000oooo000007H0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3o0?ooodX0
oooo0P00000=0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`8000000`3oool200000004
0?ooo`000000oooo000007H0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3o0?ooodX0
oooo0P00000=0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`8000000`3oool200000004
0?ooo`000000oooo000007H0oooo0@0000010?ooo`00J03oool300000?l0ooooBP3oool2000000d0
oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P0000030?ooo`80000000@0oooo0000003o
ool00000M@3oool200000040oooo001X0?ooo`030000003oool0oooo0?l0ooooBP3oool2000000d0
oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P0000030?ooo`80000000@0oooo0000003o
ool00000MP3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0ooooBP3oool2000000d0
oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P0000030?ooo`80000000@0oooo0000003o
ool00000MP3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0ooooBP3oool2000000d0
oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P0000030?ooo`80000000@0oooo0000003o
ool00000MP3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0ooooB`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`8000000`3oool200000004
0?ooo`000000oooo000007H0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3o0?oood/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`8000001@3oool2000000<0
oooo0P000000103oool000000?ooo`00001f0?ooo`4000000@3oool006P0oooo00<000000?ooo`3o
ool0o`3ooom;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool2000000D0
oooo0P0000030?ooo`80000000@0oooo0000003oool00000MP3oool100000040oooo001X0?ooo`<0
0000o`3ooom;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool2000000D0
oooo0P0000030?ooo`80000000@0oooo0000003oool00000M@3oool200000040oooo001X0?ooo`03
0000003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo0P0000050?ooo`8000000`3oool2000000040?ooo`000000oooo000007H0oooo0@0000010?oo
o`00803oool01P2oM000000000000000000004RL0=ooo`L0oooo00<0_gA809cOo`3oool01P3oool0
0`3o_i`0M;oO0?ooo`040?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool00`3oool0
102oM000000000000018W=lL0?ooo`030000003oool0oooo0?l0ooooB`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`8000000`3oool2000000040?ooo`00
0000oooo000007H0oooo0@0000010?ooo`007`3oool00`3ooml0W4P004RLg`020?ooo`030?oOW018
B9`0gooo00H0oooo00<0okmd0000B02Lgol01@3oool00`3o_g@0001809cOo`070?ooo`030;md0000
07@0_ooo00@0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo01/0oooo00<000000?ooo`3o
ool0o`3ooom;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool2000000D0
oooo0P0000030?ooo`80000000@0oooo0000003oool00000MP3oool100000040oooo000U0?ooo`03
0?oOW018M;l0oooo00H0oooo00<0okmd0000B02Lgol00`3oool00`3o_g@0001809cOo`080?ooo`03
0;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0J0?ooo`03
0000003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo0P0000050?ooo`8000000`3oool2000000040?ooo`000000oooo000007H0oooo0@0000010?oo
o`009@3oool00`3ookl0M01809cOo`070?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`09
0?ooo`030;md000007@0_ooo00<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d
_`0J0?ooo`030000003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0080oooo0P0000050?ooo`8000000`3oool2000000040?ooo`000000oooo000007H0oooo
0@0000010?ooo`009@3oool00`3ookl0M00007Boo`080?ooo`050?noM00004P0W9ad0000B02Lgol0
2P3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool0
6@3oool00`000000oooo0?ooo`3o0?oood/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`8000001@3oool2000000<0oooo0P000000103oool000000?ooo`00001f0?ooo`40
00000@3oool002D0oooo00<0okmd0000001d_ol02@3oool00`3o_g@0001809cOo`0;0?ooo`030;md
000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`0I0?ooo`030000
003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
0P0000050?ooo`8000000`3oool2000000040?ooo`000000oooo000007H0oooo0@0000010?ooo`00
903oool0103ogi`0B0000000M02oool80?ooo`050?noM00004P0W9ad0000B02Lgol02P3oool00`2o
M000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol06@3oool40000
0?l0ooooBP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P0000050?oo
o`8000000`3oool2000000040?ooo`000000oooo000007<0oooo100000010?ooo`00803oool0103O
gml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00H0oooo00L0okmd0000B02Lgol0oooo0?no
M00004P0W=oo00T0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo01T0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool2000000D0oooo0P0000030?ooo`80000000@0oooo0000003oool0
0000MP3oool100000040oooo000P0?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool0
1P3oool00`3o_g@0001809cOo`030?ooo`030?noM00004P0W=oo00P0oooo00<0_g@00000M02oool0
0`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00`0oooo00<0_g@007Boo`3oool0
2P3oool00`000000oooo0?ooo`3o0?oood/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`8000001@3oool2000000<0oooo0P000000103oool000000?ooo`00001f0?ooo`40
00000@3oool00200oooo00D0oooO09a800000000001d0;ooo`080?ooo`030;md000004P0W=oo00D0
oooo00<0okmd00000018W=l01`3oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0gooo0080
oooo00<0oooO09a80000M;l03@3oool00`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo0?l0
ooooB`3oool00`000000oooo0?ooo`0@0?ooo`8000001@3oool2000000<0oooo0P000000103oool0
00000?ooo`00001f0?ooo`4000000@3oool00240oooo00<0okmd001d_`3oool02@3oool00`3o_i`0
W=oo0?ooo`060?ooo`030?noW02Lgol0oooo00H0oooo00<0_g@00000M02oool0103oool00`3o_g@0
001809cOo`020?ooo`030?oOW0180000M;oo00d0oooo00<0oono07@0M02oool02P3oool00`000000
oooo0?ooo`3o0?oood/0oooo00<000000?ooo`3oool0403oool2000000D0oooo0P0000030?ooo`80
000000@0oooo0000003oool00000MP3oool100000040oooo000Q0?ooo`030?oog`2LB00000000080
000000<0001d0;ooo`3oool0503oool01@3OW4P000000000000007@0_ooo00D0oooo00H0_g@00018
W03Oool0oooo0;md0000M;l20?ooo`030?oo_`1d0000000000@0000000<0001809cOo`3oool00`3o
ool00`2oM000M;oo0?ooo`090?ooo`030000003oool0oooo0?l0ooooB`3oool00`000000oooo0?oo
o`0@0?ooo`8000001@3oool2000000<0oooo0P000000103oool000000?ooo`00001f0?ooo`400000
0@3oool00280oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0D0?ooo`040?oo_`1d
0000001d0;ooo`H0oooo00@0_g@000000000000007Bo403oool00`3o_g@007Bo0?ooo`090?ooo`03
0000003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`0@0?ooo`8000001@3oool2000000<0
oooo0P000000103oool000000?ooo`00001f0?ooo`4000000@3oool005`0oooo00<0oono07@0M02o
ool02@3oool00`000000oooo0?ooo`3o0?oood/0oooo00<000000?ooo`3oool0403oool2000000D0
oooo0P0000030?ooo`80000000@0oooo0000003oool00000MP3oool100000040oooo001M0?ooo`03
0;md001d_ol0oooo00P0oooo0`00003o0?oood/0oooo00<000000?ooo`3oool0403oool2000000D0
oooo0P0000030?ooo`80000000@0oooo0000003oool00000M@3oool200000040oooo001M0?ooo`03
0?noM000M;l0oooo00P0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo0100
oooo0P0000050?ooo`8000000`3oool2000000040?ooo`000000oooo000007H0oooo0@0000010?oo
o`00F@3oool01`3o_i`0W=oo0?ooo`3oool0oono07@0M02oool0203oool00`000000oooo0?ooo`3o
0?oooeh0oooo0P0000050?ooo`8000000`3oool2000000040?ooo`000000oooo000007H0oooo0@00
00010?ooo`00F@3oool00`3ooml0W4P0000000030000000307Boo`3oool0oooo00H0oooo00<00000
0?ooo`3oool0o`3ooomN0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo
0000003oool00000MP3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0ooooGP3oool2
000000D0oooo00<000000?ooo`3oool00P3oool2000000040?ooo`000000oooo000007H0oooo0@00
00010?ooo`00J03oool00`000000oooo0?ooo`3o0?oooeh0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P000000103oool000000?ooo`00001f0?ooo`4000000@3oool006P0oooo00<00000
0?ooo`3oool0o`3ooomN0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo
0000003oool00000MP3oool100000040oooo001X0?ooo`<00000o`3ooomN0?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`80000000@0oooo0000003oool00000M@3oool200000040oooo001X
0?ooo`030000003oool0oooo0?l0ooooGP3oool2000000D0oooo00<000000?ooo`3oool00P3oool2
000000040?ooo`000000oooo000007H0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3o
0?oooeh0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P000000103oool000000?ooo`00
001f0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`80000000@0oooo0000003oool00000MP3oool100000040oooo001X
0?ooo`030000003oool0oooo0?l0ooooGP3oool2000000D0oooo00<000000?ooo`3oool00P3oool2
000000040?ooo`000000oooo000007H0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3o
0?oooeh0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`80000000@0oooo
0000003oool00000MP3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0ooooGP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P000000103oool000000?ooo`00
001f0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool01P000000oooo000000000000oooo000007H0oooo
0@0000010?ooo`00J03oool300000?l0ooooGP3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00H000000?ooo`00000000000?ooo`00001e0?ooo`8000000@3oool006P0oooo
00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool01P000000oooo000000000000oooo000007H0oooo0@0000010?ooo`00J03oool00`000000
oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`06
0000003oool000000000003oool00000MP3oool100000040oooo001X0?ooo`030000003oool0oooo
0?l0ooooGP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00H000000?oo
o`00000000000?ooo`00001f0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooomN
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01P000000oooo00000000
0000oooo000007H0oooo0@0000010?ooo`00J03oool00`000000oooo0?ooo`3o0?oooeh0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`060000003oool000000000003oool0
0000MP3oool100000040oooo001X0?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00H000000?ooo`00000000000?ooo`00001f0?oo
o`4000000@3oool006P0oooo0`00003o0?oooeh0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`060000003oool000000000003oool00000M@3oool200000040oooo001X0?oo
o`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo0000
003oool0M@3oool100000040oooo000C0?ooo`030?oOW01807@0_ooo00D0oooo00<0gia800000018
W=l00P3oool01P2oM000000000000000000004RL0=ooo`L0oooo00<0_gA809cOo`3oool01P3oool0
0`3o_i`0M;oO0?ooo`040?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool00`3oool0
102oM000000000000018W=lL0?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?oo
o`0;0?ooo`80000000<0oooo0000003oool0M@3oool100000040oooo000D0?ooo`030;md001d_ol0
oooo00@0oooo00L0gia800000018W=l0oooo0?oog`2LB000B9cO0080oooo00<0omnL04Q8W03Oool0
1P3oool00`3o_g@0001809cOo`050?ooo`030?noM00004P0W=oo00L0oooo00<0_g@00000M02oool0
103oool01`3ooml0W4P0001d_`3oool0oooO09a80000M;l06`3oool00`000000oooo0?ooo`3o0?oo
oeh0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000oooo07D0oooo0@0000010?oo
o`00503oool00`3o_g@007Bo0?ooo`0>0?ooo`030?oOW018M;l0oooo00H0oooo00<0okmd0000B02L
gol00`3oool00`3o_g@0001809cOo`080?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`0J0?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000
oooo0?ooo`0;0?ooo`80000000<0oooo0000003oool0M@3oool100000040oooo000D0?ooo`030?oo
_`1d07@0_ooo00h0oooo00<0oono07@0B02Lgol01`3oool01`3o_g@0001809cOo`3oool0okmd0000
B02Lgol02@3oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO
09a80000M;l06P3oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool02`3oool2
000000030?ooo`000000oooo07D0oooo0@0000010?ooo`005@3oool00`2oM000M;oo0?ooo`0=0?oo
o`030?oo_`1d0000M;oo00P0oooo00D0okmd0000B02LW7@0001809cOo`0:0?ooo`030;md000007@0
_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`0I0?ooo`030000003oool0
oooo0?l0ooooGP3oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo0000003oool0M@3oool1
00000040oooo000E0?ooo`030?noM000M;l0oooo00d0oooo00<0okmd0000001d_ol02@3oool00`3o
_g@0001809cOo`0;0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2o
M000001d0;ooo`0I0?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`0;0?oo
o`80000000<0oooo0000003oool0M@3oool100000040oooo000E0?ooo`030?oo_`1d07@0_ooo00`0
oooo00@0omnL04P0000007@0_ooo203oool01@3o_g@0001809bLM00004P0W=oo00X0oooo00<0_g@0
0000M02oool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo01T0oooo1000003o
0?oooed0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000oooo0780oooo10000001
0?ooo`005P3oool00`2oM000M;oo0?ooo`070?ooo`040=oOg`3oool0oooo0;md0080000000<0B9cO
0?ooo`3oool01P3oool01`3o_g@0001809cOo`3oool0okmd0000B02Lgol02@3oool00`2oM000001d
0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol06@3oool00`000000oooo
0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000oooo07D0oooo
0@0000010?ooo`005P3oool00`3o_g@007Bo0?ooo`070?ooo`030?noM000000000000080000000<0
07Bo0?ooo`3oool01P3oool00`3o_g@0001809cOo`030?ooo`030?noM00004P0W=oo00P0oooo00<0
_g@00000M02oool00`3oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00`0oooo00<0
_g@007Boo`3oool02P3oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool02`3o
ool2000007P0oooo0@0000010?ooo`00403oool00`3ogkl0_moo0?ooo`030?ooo`030?oo_`1d07@0
_ooo00L0oooo00D0oooO09a800000000001d0;ooo`080?ooo`030;md000004P0W=oo00D0oooo00<0
okmd00000018W=l01`3oool00`2oM000001d0;ooo`040?ooo`030;md0000B9`0gooo0080oooo00<0
oooO09a80000M;l03@3oool00`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooGP3o
ool00`000000oooo0?ooo`0;0?ooo`800000N03oool100000040oooo000@0?ooo`030?oog`2LB7@0
_ooo00@0oooo00<0_g@007Boo`3oool01`3oool00`3o_g@007Bo0?ooo`090?ooo`030?noW02Lgol0
oooo00H0oooo00<0oknL09cOo`3oool01P3oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0
W=oo0080oooo00<0omnL04P0001d_ol03@3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0
oooo0?l0ooooGP3oool00`000000oooo0?ooo`0;0?ooo`800000N03oool100000040oooo000A0?oo
o`030=nLB0000000000000@0000000<007Bo0?ooo`3oool01P3oool00`3ooml0W4P0000000020000
00030000M02oool0oooo01@0oooo00D0gia8000000000000001d0;ooo`050?ooo`060;md0000B9`0
gooo0?ooo`2oM00007Bo0P3oool00`3ookl0M00000000004000000030000B02Lgol0oooo00<0oooo
00<0_g@007Boo`3oool02@3oool00`000000oooo0?ooo`3o0?oooeh0oooo00<000000?ooo`3oool0
2`3oool2000007P0oooo0@0000010?ooo`004@3oool00`3ogi`0B00000000004000000030000B02L
gol0oooo00L0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`0D0?ooo`040?oo_`1d
0000001d0;ooo`H0oooo00@0_g@000000000000007Bo403oool00`3o_g@007Bo0?ooo`090?ooo`03
0000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`0;0?ooo`800000N03oool100000040
oooo001L0?ooo`030?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000
003oool0oooo00/0oooo0P00001h0?ooo`4000000@3oool005d0oooo00<0_g@007Boo`3oool0203o
ool300000?l0ooooGP3oool00`000000oooo0?ooo`0;0?ooo`800000M`3oool200000040oooo001M
0?ooo`030?noM000M;l0oooo00P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0
oooo00/0oooo0P00001h0?ooo`4000000@3oool005T0oooo00L0oknL09cOo`3oool0oooo0?oo_`1d
07@0_ooo00P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00/0oooo0P00
001h0?ooo`4000000@3oool005T0oooo00<0oooO09a8000000000`0000000`1d_ol0oooo0?ooo`06
0?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`0;0?ooo`800000N03oool1
00000040oooo001X0?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000oooo0?ooo`0;0?oo
o`800000N03oool100000040oooo001X0?ooo`030000003oool0oooo0?l0ooooGP3oool00`000000
oooo0?ooo`0;0?ooo`800000N03oool100000040oooo001X0?ooo`030000003oool0oooo0?l0oooo
GP3oool00`000000oooo0?ooo`0;0?ooo`800000N03oool100000040oooo001X0?ooo`<00000o`3o
oomN0?ooo`030000003oool0oooo00/0oooo0P00001g0?ooo`8000000@3oool006P0oooo00<00000
0?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00/0oooo0P00001h0?ooo`4000000@3oool0
06P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00/0oooo0P00001h0?oo
o`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000003oool0oooo00/0
oooo0P00001h0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`030000
003oool0oooo00/0oooo0P00001h0?ooo`4000000@3oool006P0oooo00<000000?ooo`3oool0o`3o
oomN0?ooo`030000003oool0oooo00/0oooo0P00001h0?ooo`4000000@3oool006P0oooo00<00000
0?ooo`3oool0o`3ooom/0?ooo`800000N03oool100000040oooo001X0?ooo`030000003oool0oooo
0?l0ooooK03oool2000007P0oooo0@0000010?ooo`00J03oool3000000T0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool00P3oool2000006d0oooo00<000000?ooo`3oool01`3oool200000040oooo001X0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool00P3oool2000006d0oooo00<000000?ooo`3oool0
203oool100000040oooo001X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3o
ool200000100oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`4000000@3o
ool006P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`800000403oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`00J03ooooo0000
0>X000000@3oool00?l0ooooo`3ooomD0?ooo`00o`3ooooo0?oooe@0oooo003o0?ooool0ooooE03o
ool00?l0ooooo`3ooomD0?ooo`00o`3ooooo0?oooe@0oooo003o0?ooool0ooooE03oool00?l0oooo
o`3ooomD0?ooo`00o`3ooooo0?oooe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?oo
o`00o`3ooooo0?oooe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00o`3ooooo
0?oooe@0oooo003o0?ooool0ooooE03oool00?l0ooooo`3ooomD0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 593.375}, {366.375, 0}} -> {-40.0034, -1.37361*^-06, \
0.0860185, 6.57789*^-09}}]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ It\ looks\ \(satisfactory!\)\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    StyleBox[\( (*\(\(\(\(\(\(\ \)\(Now\ for\ completeness, \ 
                    check\ all\ three\ \(terms : \ 1\)\)\()\)\) 
                  the\ RHS\ of\ the\ ODE\ 2\)\()\)\) \(x2'\)[
                N]\ \((the\ LHS)\)\ 3\)\()\)\) the\ analytical\ form\ *) \),
      FontSize->18]], "Input"],

Cell[BoxData[
    \(\(qqm = D[xx2[N], N];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{dx2dN[N], qqm, \(x2anal'\)[N]}, {N, nmin, nmax}, Frame -> True, 
        PlotRange \[Rule] All, Axes \[Rule] False, 
        FrameLabel \[Rule] {"\<N\>", "\<x2[N]\>"}, 
        PlotStyle \[Rule] {Hue[0], Hue[ .7], Hue[ .8]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.738095 0.0238095 0.603319 1.56823 [
[.02381 -0.0125 -19.0313 -24.5625 ]
[.02381 -0.0125 19.0313 0 ]
[.2619 -0.0125 -19.0313 -24.5625 ]
[.2619 -0.0125 19.0313 0 ]
[.5 -0.0125 -19.0313 -24.5625 ]
[.5 -0.0125 19.0313 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -12.0625 -24.5625 ]
[.97619 -0.0125 12.0625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.34375 -49.125 ]
[.5 -0.0125 9.34375 -24.5625 ]
[-0.0125 .05444 -53.125 -12.2813 ]
[-0.0125 .05444 0 12.2813 ]
[-0.0125 .13285 -43.0625 -12.2813 ]
[-0.0125 .13285 0 12.2813 ]
[-0.0125 .21126 -53.125 -12.2813 ]
[-0.0125 .21126 0 12.2813 ]
[-0.0125 .28967 -43.0625 -12.2813 ]
[-0.0125 .28967 0 12.2813 ]
[-0.0125 .36808 -53.125 -12.2813 ]
[-0.0125 .36808 0 12.2813 ]
[-0.0125 .4465 -43.0625 -12.2813 ]
[-0.0125 .4465 0 12.2813 ]
[-0.0125 .52491 -53.125 -12.2813 ]
[-0.0125 .52491 0 12.2813 ]
[-0.0125 .60332 -14.0625 -12.2813 ]
[-0.0125 .60332 0 12.2813 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -77.6875 -26.0938 ]
[-0.01875 .30902 -53.125 26.0938 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -80.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -73.0625 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.3438 -53.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
77.688 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05444 m
.00625 .05444 L
s
gsave
-0.0125 .05444 -114.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
1.000 setlinewidth
grestore
0 .13285 m
.00625 .13285 L
s
gsave
-0.0125 .13285 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .21126 m
.00625 .21126 L
s
gsave
-0.0125 .21126 -114.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
0 .28967 m
.00625 .28967 L
s
gsave
-0.0125 .28967 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .36808 m
.00625 .36808 L
s
gsave
-0.0125 .36808 -114.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
0 .4465 m
.00625 .4465 L
s
gsave
-0.0125 .4465 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .52491 m
.00625 .52491 L
s
gsave
-0.0125 .52491 -114.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07012 m
.00375 .07012 L
s
0 .0858 m
.00375 .0858 L
s
0 .10149 m
.00375 .10149 L
s
0 .11717 m
.00375 .11717 L
s
0 .14853 m
.00375 .14853 L
s
0 .16422 m
.00375 .16422 L
s
0 .1799 m
.00375 .1799 L
s
0 .19558 m
.00375 .19558 L
s
0 .22694 m
.00375 .22694 L
s
0 .24263 m
.00375 .24263 L
s
0 .25831 m
.00375 .25831 L
s
0 .27399 m
.00375 .27399 L
s
0 .30536 m
.00375 .30536 L
s
0 .32104 m
.00375 .32104 L
s
0 .33672 m
.00375 .33672 L
s
0 .3524 m
.00375 .3524 L
s
0 .38377 m
.00375 .38377 L
s
0 .39945 m
.00375 .39945 L
s
0 .41513 m
.00375 .41513 L
s
0 .43081 m
.00375 .43081 L
s
0 .46218 m
.00375 .46218 L
s
0 .47786 m
.00375 .47786 L
s
0 .49354 m
.00375 .49354 L
s
0 .50923 m
.00375 .50923 L
s
0 .54059 m
.00375 .54059 L
s
0 .55627 m
.00375 .55627 L
s
0 .57195 m
.00375 .57195 L
s
0 .58764 m
.00375 .58764 L
s
0 .03876 m
.00375 .03876 L
s
0 .02307 m
.00375 .02307 L
s
0 .00739 m
.00375 .00739 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -152.5 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
87.0938 16.2813 translate
90 rotate
-87.0938 -16.2813 translate
0 32.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
83.125 23.000 moveto
(@) show
90.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
104.500 23.000 moveto
(D) show
111.188 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05444 m
1 .05444 L
s
.99375 .13285 m
1 .13285 L
s
.99375 .21126 m
1 .21126 L
s
.99375 .28967 m
1 .28967 L
s
.99375 .36808 m
1 .36808 L
s
.99375 .4465 m
1 .4465 L
s
.99375 .52491 m
1 .52491 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .07012 m
1 .07012 L
s
.99625 .0858 m
1 .0858 L
s
.99625 .10149 m
1 .10149 L
s
.99625 .11717 m
1 .11717 L
s
.99625 .14853 m
1 .14853 L
s
.99625 .16422 m
1 .16422 L
s
.99625 .1799 m
1 .1799 L
s
.99625 .19558 m
1 .19558 L
s
.99625 .22694 m
1 .22694 L
s
.99625 .24263 m
1 .24263 L
s
.99625 .25831 m
1 .25831 L
s
.99625 .27399 m
1 .27399 L
s
.99625 .30536 m
1 .30536 L
s
.99625 .32104 m
1 .32104 L
s
.99625 .33672 m
1 .33672 L
s
.99625 .3524 m
1 .3524 L
s
.99625 .38377 m
1 .38377 L
s
.99625 .39945 m
1 .39945 L
s
.99625 .41513 m
1 .41513 L
s
.99625 .43081 m
1 .43081 L
s
.99625 .46218 m
1 .46218 L
s
.99625 .47786 m
1 .47786 L
s
.99625 .49354 m
1 .49354 L
s
.99625 .50923 m
1 .50923 L
s
.99625 .54059 m
1 .54059 L
s
.99625 .55627 m
1 .55627 L
s
.99625 .57195 m
1 .57195 L
s
.99625 .58764 m
1 .58764 L
s
.99625 .03876 m
1 .03876 L
s
.99625 .02307 m
1 .02307 L
s
.99625 .00739 m
1 .00739 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02605 .60332 L
.02846 .60332 L
.03279 .60332 L
.03405 .60332 L
.03477 .60332 L
.03543 .60332 L
.03793 .60332 L
.04262 .60332 L
.04375 .60332 L
.04482 .60332 L
.04606 .60332 L
.0472 .60332 L
.0498 .60332 L
.05224 .60332 L
.055 .60332 L
.05759 .60332 L
.05992 .60332 L
.06124 .60332 L
.06244 .60332 L
.06362 .60332 L
.0649 .60332 L
.06555 .60332 L
.06625 .60332 L
.0675 .60332 L
.07032 .60332 L
.07289 .60332 L
.08259 .60332 L
.08813 .60332 L
.09116 .60332 L
.09401 .60332 L
.09663 .60332 L
.09778 .60332 L
.09904 .60332 L
.10034 .60332 L
.10104 .60332 L
.1017 .60332 L
.10243 .60332 L
.10309 .60332 L
.10386 .60332 L
.10458 .60332 L
.10568 .60332 L
.10689 .60332 L
.10934 .60332 L
.11374 .60332 L
.12366 .60332 L
.12493 .60332 L
.1256 .60332 L
.12632 .60332 L
.12762 .60332 L
Mistroke
.12884 .60332 L
.13036 .60332 L
.13174 .60332 L
.13439 .60332 L
.14443 .60332 L
.14563 .60332 L
.14677 .60332 L
.14808 .60332 L
.14928 .60332 L
.15041 .60332 L
.15145 .60332 L
.1526 .60332 L
.15381 .60332 L
.15853 .60332 L
.15982 .60332 L
.16049 .60332 L
.1612 .60332 L
.16251 .60332 L
.16371 .60332 L
.16887 .60332 L
.17183 .60332 L
.17257 .60332 L
.17326 .60332 L
.17457 .60332 L
.17687 .60332 L
.17934 .60332 L
.18203 .60332 L
.18334 .60332 L
.18454 .60332 L
.18678 .60332 L
.18919 .60332 L
.19429 .60332 L
.19923 .60332 L
.2046 .60332 L
.21408 .60332 L
.22306 .60332 L
.2279 .60332 L
.23245 .60332 L
.23785 .60332 L
.24281 .60332 L
.25291 .60331 L
.25822 .60331 L
.26381 .60331 L
.27334 .60331 L
.27868 .60331 L
.28353 .60331 L
.28806 .6033 L
.29297 .6033 L
.30189 .60329 L
.30677 .60329 L
Mistroke
.31134 .60328 L
.31677 .60327 L
.32174 .60326 L
.33188 .60323 L
.33746 .6032 L
.34277 .60317 L
.35237 .6031 L
.35773 .60305 L
.3626 .60299 L
.36715 .60292 L
.37207 .60282 L
.38099 .6026 L
.38591 .60243 L
.3905 .60225 L
.39596 .60197 L
.40094 .60166 L
.41111 .60078 L
.41671 .60011 L
.42201 .59932 L
.43167 .59735 L
.43655 .59602 L
.44194 .59421 L
.44651 .59234 L
.45144 .5899 L
.46036 .58411 L
.46994 .5753 L
.47537 .56879 L
.48042 .56155 L
.49062 .5429 L
.50152 .51651 L
.52145 .45587 L
.53194 .42675 L
.53722 .41609 L
.53867 .41383 L
.54023 .41175 L
.54169 .41015 L
.54304 .40898 L
.54433 .40814 L
.54506 .40779 L
.54571 .40756 L
.54643 .40738 L
.54721 .4073 L
.54795 .40731 L
.54862 .4074 L
.54985 .40778 L
.55055 .40811 L
.5512 .40849 L
.55251 .40947 L
.55392 .41084 L
.55659 .41432 L
Mistroke
.55912 .41858 L
.56386 .42879 L
.58304 .48593 L
.60131 .53631 L
.6117 .55696 L
.62144 .57118 L
.63099 .58117 L
.63636 .58542 L
.64127 .58861 L
.64642 .59136 L
.65205 .59375 L
.65736 .5955 L
.6623 .59672 L
.66494 .59721 L
.66737 .59755 L
.66864 .59768 L
.66937 .59774 L
.67004 .59778 L
.67074 .59781 L
.67149 .59784 L
.67219 .59784 L
.67286 .59784 L
.67406 .59779 L
.67533 .59769 L
.67642 .59755 L
.67762 .59735 L
.67891 .59705 L
.6803 .59662 L
.68161 .5961 L
.68281 .59552 L
.68505 .59408 L
.68714 .59225 L
.68942 .58952 L
.69187 .58551 L
.69444 .57969 L
.69687 .57218 L
.69905 .56324 L
.70141 .55053 L
.70377 .53388 L
.7063 .51041 L
.70869 .48169 L
.71087 .44886 L
.71621 .33842 L
.72128 .20038 L
.72381 .13027 L
.7252 .0954 L
.7265 .06672 L
.72772 .04468 L
.72904 .02716 L
.73024 .01767 L
Mistroke
.73134 .01472 L
.73266 .01861 L
.73389 .02933 L
.7346 .03841 L
.73524 .04838 L
.73668 .07608 L
.74232 .22514 L
.74714 .35367 L
.74978 .41143 L
.75225 .45586 L
.75662 .51321 L
.75894 .53466 L
.76143 .55236 L
.76396 .5658 L
.76672 .57656 L
.7696 .58458 L
.77227 .58988 L
.77479 .5935 L
.77708 .59594 L
.77972 .59802 L
.7822 .59944 L
.7846 .60045 L
.78685 .60116 L
.78931 .60173 L
.79195 .60218 L
.79471 .60251 L
.79733 .60274 L
.79969 .60289 L
.80225 .60301 L
.80446 .60308 L
.80689 .60315 L
.80944 .60319 L
.81183 .60323 L
.81406 .60325 L
.8161 .60326 L
.81835 .60328 L
.82071 .60329 L
.82327 .6033 L
.8257 .6033 L
.82787 .60331 L
.83023 .60331 L
.8328 .60331 L
.83553 .60331 L
.83786 .60332 L
.84042 .60332 L
.8428 .60332 L
.84499 .60332 L
.8475 .60332 L
.8499 .60332 L
.8521 .60332 L
Mistroke
.85414 .60332 L
.85638 .60332 L
.85877 .60332 L
.86138 .60332 L
.86413 .60332 L
.86648 .60332 L
.86906 .60332 L
.87184 .60332 L
.8734 .60332 L
.87482 .60332 L
.87758 .60332 L
.88019 .60332 L
.88263 .60332 L
.88521 .60332 L
.88742 .60332 L
.88986 .60332 L
.89246 .60332 L
.89528 .60332 L
.89793 .60332 L
.90036 .60332 L
.90285 .60332 L
.90511 .60332 L
.90771 .60332 L
.91017 .60332 L
.91245 .60332 L
.91455 .60332 L
.91685 .60332 L
.91929 .60332 L
.92175 .60332 L
.92439 .60332 L
.92688 .60332 L
.92915 .60332 L
.93182 .60332 L
.93322 .60332 L
.93472 .60332 L
.93746 .60332 L
.94 .60332 L
.94227 .60332 L
.94467 .60332 L
.94672 .60332 L
.94896 .60332 L
.95138 .60332 L
.95397 .60332 L
.95642 .60332 L
.95865 .60332 L
.96089 .60332 L
.96297 .60332 L
.96525 .60332 L
.9664 .60332 L
.96766 .60332 L
Mistroke
.96978 .60332 L
.97095 .60332 L
.97206 .60332 L
.97309 .60332 L
.97422 .60332 L
.97619 .60332 L
Mfstroke
.2 0 1 r
.02381 .60332 m
.04262 .60332 L
.04754 .60332 L
.04872 .60332 L
.04996 .60332 L
.05112 .60332 L
.0522 .60332 L
.05342 .60332 L
.05407 .60332 L
.05477 .60332 L
.05552 .60332 L
.05623 .60332 L
.05687 .60332 L
.05756 .60332 L
.05879 .60332 L
.06009 .60332 L
.06133 .60332 L
.06244 .60332 L
.0631 .60332 L
.06379 .60332 L
.06502 .60332 L
.06781 .60332 L
.07286 .60332 L
.07748 .60332 L
.0801 .60332 L
.08255 .60332 L
.08391 .60332 L
.08518 .60332 L
.08582 .60332 L
.08651 .60332 L
.08727 .60332 L
.08797 .60332 L
.08868 .60332 L
.08946 .60332 L
.09028 .60332 L
.09103 .60332 L
.09175 .60332 L
.0924 .60332 L
.09386 .60332 L
.09524 .60332 L
.09651 .60332 L
.09938 .60332 L
.10068 .60332 L
.1019 .60332 L
.10318 .60332 L
.10458 .60332 L
.10721 .60332 L
.10971 .60332 L
.11195 .60332 L
.11322 .60332 L
Mistroke
.11439 .60332 L
.11505 .60332 L
.11577 .60332 L
.11707 .60332 L
.11833 .60332 L
.1195 .60332 L
.12076 .60332 L
.12147 .60332 L
.12214 .60332 L
.12348 .60332 L
.12418 .60332 L
.12493 .60332 L
.12618 .60332 L
.12734 .60332 L
.12962 .60332 L
.13168 .60332 L
.13389 .60332 L
.13512 .60332 L
.13625 .60332 L
.13733 .60332 L
.13846 .60332 L
.1397 .60332 L
.14086 .60332 L
.14213 .60332 L
.14284 .60332 L
.14349 .60332 L
.14469 .60332 L
.14581 .60332 L
.14703 .60332 L
.14835 .60332 L
.14901 .60332 L
.14973 .60332 L
.15104 .60332 L
.15232 .60332 L
.1535 .60332 L
.15459 .60332 L
.15562 .60332 L
.15675 .60332 L
.15796 .60332 L
.15917 .60332 L
.16044 .60332 L
.16152 .60332 L
.16271 .60332 L
.16411 .60332 L
.1648 .60332 L
.16544 .60332 L
.16663 .60332 L
.16792 .60332 L
.16921 .60332 L
.16994 .60332 L
Mistroke
.17062 .60332 L
.17134 .60332 L
.172 .60332 L
.17276 .60332 L
.17349 .60332 L
.17469 .60332 L
.17598 .60332 L
.17719 .60332 L
.17829 .60332 L
.17958 .60332 L
.18031 .60332 L
.18098 .60332 L
.18222 .60332 L
.18352 .60332 L
.18474 .60332 L
.18543 .60332 L
.18607 .60332 L
.18724 .60332 L
.18849 .60332 L
.1896 .60332 L
.19064 .60332 L
.19178 .60332 L
.19301 .60332 L
.19424 .60332 L
.19494 .60332 L
.19559 .60332 L
.19691 .60332 L
.19765 .60332 L
.19831 .60332 L
.19951 .60332 L
.20082 .60332 L
.20204 .60332 L
.20318 .60332 L
.20423 .60332 L
.20537 .60332 L
.20644 .60332 L
.20742 .60332 L
.20857 .60332 L
.20981 .60332 L
.21098 .60332 L
.21209 .60332 L
.21333 .60332 L
.21446 .60332 L
.21567 .60332 L
.21698 .60332 L
.21813 .60332 L
.21934 .60332 L
.22038 .60332 L
.22151 .60332 L
.22283 .60332 L
Mistroke
.22404 .60332 L
.22472 .60332 L
.22537 .60332 L
.22604 .60332 L
.22678 .60332 L
.23176 .60332 L
.23653 .60332 L
.23889 .60332 L
.24004 .60332 L
.24108 .60332 L
.2423 .60332 L
.24359 .60332 L
.24427 .60332 L
.24501 .60332 L
.2457 .60332 L
.24634 .60332 L
.24746 .60332 L
.24868 .60332 L
.25116 .60332 L
.25677 .60331 L
.26201 .60331 L
.26701 .60331 L
.27246 .60331 L
.27725 .60331 L
.28235 .60331 L
.28693 .6033 L
.29199 .6033 L
.30091 .60329 L
.30582 .60329 L
.31099 .60328 L
.32024 .60326 L
.3254 .60325 L
.3302 .60323 L
.33543 .60321 L
.3411 .60318 L
.34657 .60315 L
.35161 .60311 L
.35634 .60306 L
.36155 .603 L
.37057 .60285 L
.37551 .60275 L
.38013 .60262 L
.38511 .60246 L
.39053 .60225 L
.39531 .60201 L
.40041 .6017 L
.40545 .60132 L
.41002 .60089 L
.41894 .5998 L
.42383 .59901 L
Mistroke
.42899 .59798 L
.43822 .59551 L
.44336 .59367 L
.44815 .59158 L
.45337 .58881 L
.45905 .58509 L
.46449 .58069 L
.46952 .57576 L
.47943 .56306 L
.48844 .54737 L
.498 .52577 L
.51772 .46754 L
.52635 .44129 L
.53092 .42918 L
.53579 .41863 L
.53835 .4143 L
.54068 .41122 L
.54181 .41004 L
.54302 .40899 L
.54417 .40823 L
.54523 .40772 L
.54642 .40739 L
.54753 .40729 L
.54875 .40743 L
.55006 .40787 L
.55071 .4082 L
.55143 .40864 L
.55273 .40966 L
.55516 .41232 L
.55766 .416 L
.56041 .42109 L
.566 .43421 L
.57603 .4638 L
.58622 .49574 L
.59697 .52585 L
.60692 .54821 L
.61619 .56408 L
.6251 .57542 L
.63463 .58415 L
.64007 .58789 L
.64521 .59076 L
.65483 .59472 L
.65945 .59606 L
.6621 .59668 L
.66453 .59714 L
.66709 .59751 L
.6685 .59767 L
.66915 .59772 L
.66984 .59777 L
.67107 .59783 L
Mistroke
.67222 .59784 L
.67292 .59784 L
.67358 .59782 L
.67481 .59774 L
.67588 .59763 L
.67706 .59745 L
.67828 .5972 L
.67943 .5969 L
.68148 .59616 L
.68262 .59562 L
.68367 .59502 L
.68603 .59329 L
.68736 .59201 L
.68859 .59061 L
.69085 .58733 L
.69325 .58262 L
.69564 .57627 L
.69814 .56724 L
.70029 .55703 L
.70263 .5425 L
.70516 .52179 L
.70786 .49243 L
.71041 .45633 L
.71273 .41538 L
.72161 .19095 L
.72395 .12647 L
.72524 .09428 L
.72647 .06739 L
.7276 .04659 L
.72884 .02936 L
.72997 .01927 L
.73101 .01501 L
.73222 .01641 L
.73332 .02348 L
.73458 .03815 L
.73577 .05769 L
.73828 .11361 L
.741 .18745 L
.74539 .30981 L
.7502 .41972 L
.75293 .46646 L
.75548 .50055 L
.75817 .52811 L
.76104 .54991 L
.76372 .5647 L
.76626 .575 L
.76853 .58193 L
.771 .58757 L
.77335 .59156 L
.77587 .59474 L
Mistroke
.77825 .59695 L
.78043 .59847 L
.78297 .5998 L
.78575 .60084 L
.78838 .60154 L
.79082 .60201 L
.79357 .60239 L
.79615 .60265 L
.79848 .60282 L
.80099 .60295 L
.80374 .60306 L
.80512 .6031 L
.80664 .60314 L
.80933 .60319 L
.81184 .60323 L
.81444 .60325 L
.81684 .60327 L
.81948 .60328 L
.82228 .60329 L
.82471 .6033 L
.82698 .60331 L
.82948 .60331 L
.83218 .60331 L
.83443 .60331 L
.83689 .60331 L
.83946 .60332 L
.84185 .60332 L
.8441 .60332 L
.84614 .60332 L
.8485 .60332 L
.84966 .60332 L
.85073 .60332 L
.85188 .60332 L
.85311 .60332 L
.85427 .60332 L
.85535 .60332 L
.8566 .60332 L
.85726 .60332 L
.85796 .60332 L
.85926 .60332 L
.86044 .60332 L
.86108 .60332 L
.86176 .60332 L
.86298 .60332 L
.86429 .60332 L
.86504 .60332 L
.86573 .60332 L
.86699 .60332 L
.86814 .60332 L
.86878 .60332 L
Mistroke
.86947 .60332 L
.87072 .60332 L
.87186 .60332 L
.87293 .60332 L
.87411 .60332 L
.87537 .60332 L
.87663 .60332 L
.87795 .60332 L
.87907 .60332 L
.88031 .60332 L
.88145 .60332 L
.88253 .60332 L
.88377 .60332 L
.8849 .60332 L
.88597 .60332 L
.88695 .60332 L
.88803 .60332 L
.88917 .60332 L
.89038 .60332 L
.8917 .60332 L
.89295 .60332 L
.89411 .60332 L
.89523 .60332 L
.89643 .60332 L
.8975 .60332 L
.89862 .60332 L
.89926 .60332 L
.89996 .60332 L
.9012 .60332 L
.90241 .60332 L
.90353 .60332 L
.90421 .60332 L
.90486 .60332 L
.90606 .60332 L
.90736 .60332 L
.90809 .60332 L
.90876 .60332 L
.90982 .60332 L
.91095 .60332 L
.91202 .60332 L
.91299 .60332 L
.91414 .60332 L
.91538 .60332 L
.91766 .60332 L
.92002 .60332 L
.92254 .60332 L
.92471 .60332 L
.92708 .60332 L
.92843 .60332 L
.92969 .60332 L
Mistroke
.93037 .60332 L
.93102 .60332 L
.93176 .60332 L
.93244 .60332 L
.93366 .60332 L
.9348 .60332 L
.93737 .60332 L
.94265 .60332 L
.94546 .60332 L
.94849 .60332 L
.95112 .60332 L
.95354 .60332 L
.95473 .60332 L
.95584 .60332 L
.957 .60332 L
.95827 .60332 L
.95892 .60332 L
.95962 .60332 L
.9609 .60332 L
.96215 .60332 L
.96329 .60332 L
.96454 .60332 L
.9659 .60332 L
.96733 .60332 L
.96866 .60332 L
.97619 .60332 L
Mfstroke
.8 0 1 r
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07295 .60332 L
.08265 .60332 L
.08804 .60332 L
.09308 .60332 L
.09862 .60332 L
.10458 .60332 L
.11468 .60332 L
.1204 .60332 L
.12571 .60332 L
.13544 .60332 L
.14087 .60332 L
.1458 .60332 L
.15068 .60332 L
.15583 .60332 L
.16505 .60332 L
.17018 .60332 L
.17498 .60332 L
.18019 .60332 L
.18587 .60332 L
.1913 .60332 L
.19632 .60332 L
.20103 .60332 L
.20622 .60332 L
.21522 .60332 L
.22015 .60332 L
.22478 .60332 L
.23461 .60332 L
.23955 .60332 L
.24496 .60332 L
.2496 .60332 L
.25455 .60332 L
.26347 .60331 L
.2688 .60331 L
.27371 .60331 L
.279 .60331 L
.28481 .60331 L
.2946 .6033 L
.29996 .60329 L
.30496 .60329 L
.30994 .60328 L
.31537 .60327 L
Mistroke
.32016 .60326 L
.32525 .60325 L
.3303 .60323 L
.33487 .60322 L
.34379 .60317 L
.34868 .60313 L
.35384 .60309 L
.36307 .60298 L
.36822 .6029 L
.37301 .6028 L
.37823 .60268 L
.38391 .60251 L
.38935 .6023 L
.39439 .60206 L
.3991 .60178 L
.4043 .60141 L
.41331 .60054 L
.41824 .5999 L
.42287 .59918 L
.43273 .59709 L
.43768 .59568 L
.44309 .59377 L
.44773 .59178 L
.45269 .58921 L
.46161 .58314 L
.46695 .57839 L
.47188 .57312 L
.48299 .55737 L
.49279 .53818 L
.50316 .51199 L
.52299 .45115 L
.53166 .42739 L
.53404 .42209 L
.53656 .41723 L
.53874 .41373 L
.5411 .41076 L
.54237 .40952 L
.54355 .40861 L
.54467 .40797 L
.54585 .40752 L
.54715 .4073 L
.54836 .40736 L
.54905 .40751 L
.54968 .40771 L
.55041 .40804 L
.5511 .40843 L
.55225 .40925 L
.55347 .41037 L
.55565 .41296 L
.558 .41657 L
Mistroke
.56058 .42144 L
.57138 .44946 L
.58149 .48106 L
.60004 .53336 L
.61054 .55495 L
.62028 .56971 L
.63052 .58075 L
.63624 .58534 L
.64143 .58871 L
.6464 .59135 L
.65178 .59365 L
.65686 .59535 L
.66152 .59656 L
.66399 .59705 L
.66623 .5974 L
.66747 .59756 L
.66882 .59769 L
.67009 .59778 L
.67127 .59783 L
.67235 .59784 L
.67337 .59782 L
.67448 .59776 L
.67568 .59765 L
.67687 .59748 L
.67812 .59724 L
.67919 .59697 L
.68036 .5966 L
.68176 .59603 L
.68308 .59537 L
.68554 .5937 L
.68692 .59246 L
.6882 .59108 L
.69107 .58696 L
.69338 .58233 L
.69591 .57541 L
.69856 .56546 L
.70103 .55282 L
.70362 .53507 L
.70602 .51334 L
.70865 .48221 L
.71145 .43901 L
.71664 .32771 L
.72133 .1988 L
.72357 .13657 L
.72593 .07871 L
.72716 .05413 L
.72782 .04321 L
.72852 .03331 L
.72975 .02082 L
.73089 .01525 L
Mistroke
.73205 .0158 L
.73331 .02342 L
.7345 .037 L
.73559 .05454 L
.73767 .0986 L
.73988 .156 L
.7447 .29143 L
.74928 .40139 L
.75181 .44855 L
.75457 .4893 L
.75707 .51784 L
.7594 .53834 L
.76179 .55452 L
.76405 .56619 L
.76607 .57434 L
.76826 .58119 L
.77065 .58687 L
.77317 .59131 L
.77533 .59414 L
.7777 .5965 L
.78021 .59834 L
.78294 .59978 L
.78551 .60076 L
.7879 .60142 L
.79004 .60187 L
.79241 .60224 L
.79488 .60253 L
.7972 .60273 L
.79976 .60289 L
.80245 .60302 L
.80475 .60309 L
.80726 .60315 L
.80998 .6032 L
.8115 .60322 L
.81288 .60324 L
.81557 .60326 L
.81811 .60328 L
.8205 .60329 L
.82274 .6033 L
.82519 .6033 L
.82783 .60331 L
.83058 .60331 L
.8332 .60331 L
.83555 .60331 L
.83812 .60332 L
.84055 .60332 L
.84275 .60332 L
.84529 .60332 L
.84769 .60332 L
.84991 .60332 L
Mistroke
.85195 .60332 L
.8542 .60332 L
.85657 .60332 L
.85912 .60332 L
.86154 .60332 L
.8637 .60332 L
.86606 .60332 L
.86863 .60332 L
.87135 .60332 L
.87367 .60332 L
.87623 .60332 L
.87861 .60332 L
.88079 .60332 L
.88318 .60332 L
.8857 .60332 L
.8879 .60332 L
.88994 .60332 L
.89218 .60332 L
.89458 .60332 L
.89717 .60332 L
.89992 .60332 L
.90226 .60332 L
.90484 .60332 L
.90761 .60332 L
.90917 .60332 L
.91058 .60332 L
.91334 .60332 L
.91595 .60332 L
.91838 .60332 L
.92096 .60332 L
.92317 .60332 L
.9256 .60332 L
.92821 .60332 L
.93102 .60332 L
.93368 .60332 L
.93611 .60332 L
.93859 .60332 L
.94084 .60332 L
.94344 .60332 L
.9459 .60332 L
.94817 .60332 L
.95026 .60332 L
.95257 .60332 L
.95501 .60332 L
.95746 .60332 L
.96009 .60332 L
.96258 .60332 L
.96485 .60332 L
.96751 .60332 L
.96891 .60332 L
Mistroke
.97041 .60332 L
.97315 .60332 L
.97569 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{544.063, 336.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008P0001D2000`400?l00000o`00003oo`3ooooo
0?ooob80oooo003o0?ooool0oooo8P3oool00?l0ooooo`3ooolR0?ooo`00o`3ooooo0?ooob80oooo
003o0?ooool0oooo8P3oool00?l0ooooo`3ooolR0?ooo`00o`3ooooo0?ooob80oooo003o0?oooc<0
oooo00H0_g@000000000000000000018W03Oool40?ooo`030?oo_`1d07@0_ooo0>40oooo003o0?oo
oc@0oooo00<0oono07@0M02oool01@3oool0103ooml0W4P00000M02ooooQ0?ooo`00o`3ooold0?oo
o`030?oog`2LB7@0_ooo00D0oooo00@0_g@00000000007@0_oooh@3oool00?l0oooo=03oool00`3o
oml0W4Qd0;ooo`040?ooo`050=nLB0000000001804Q8M02oool0h@3oool00?l0oooo=03oool00`3o
oml0W4Qd0;ooo`030?ooo`060?noM0000000001d0;oog`2LB7@0_oooh@3oool00?l0oooo=03oool0
0`3ooml0W4Qd0;ooo`020?ooo`070?oOW0180000001809cOo`3ooml0W4Qd0;ooo`3Q0?ooo`00o`3o
oold0?ooo`0<0?oog`2LB7@0_ooo0?ooo`3ookl0M0000000001d_ol0oooo0?oog`2LB7@0_oooh@3o
ool00?l0oooo=03oool01`3ooml0W4Qd0;ooo`3ooml0W4P000000018W=l00P3oool00`3ooml0W4Qd
0;ooo`3Q0?ooo`00o`3ooold0?ooo`060?oog`2LB7@0_ooO09a80000000007Bo0`3oool00`3ooml0
W4Qd0;ooo`3Q0?ooo`00o`3ooold0?ooo`060?oog`2LB7@0M7@000000000B9`0gooo0`3oool00`3o
oml0W4Qd0;ooo`3Q0?ooo`00o`3ooold0?ooo`050?oog`2LB00000000000M02oool0103oool00`3o
oml0W4Qd0;ooo`3Q0?ooo`00o`3ooold0?ooo`040=nLB0000000001d0;ooo`D0oooo00<0oono07@0
M02oool0h@3oool00?l0oooo<P3oool01@3OW4P000000000000004P0W=oo00@0oooo00<0oooO09a8
000000000P0000000`00B9`0gooo0?ooo`3N0?ooo`00o`3ooooo0?ooob80oooo003o0?ooool0oooo
8P3oool00?l0ooooo`3ooolR0?ooo`00o`3ooooo0?ooob80oooo003o0?ooool0oooo8P3oool00?l0
ooooo`3ooolR0?ooo`00o`3ooooo0?ooob80oooo003o0?ooool0oooo8P3oool00?l0ooooo`3ooolR
0?ooo`00o`3ooooo0?ooob80oooo003o0?ooool0oooo8P3oool00680oooo00<0oooO09a800000000
0P0000000`00B9`0gooo0?ooo`050?ooo`040;md00000000000004RLgeT0oooo00<0gia800000000
00001@0000000`1d_ol0oooo0?ooo`020?ooo`040;md00000000000004RLge/0oooo00<0okmd0000
000000000P0000000`00M;l0oooo0?ooo`030?ooo`040;md00000000000004RLgeX0oooo00@0_g@0
000000000000B9cOH03oool00`3o_g@000000000000200000003001d_`3oool0oooo00<0oooo00@0
_g@0000000000000B9cO303oool00680oooo00P0omnL04P00000B9`0gooo0?ooo`3ogi`0B01809cO
o`<0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo05T0oooo00<0gia80000000000001000
00002P00M;l0oooo0?ooo`3ooml0W4P0001d_`3oool0oooO09a80000M;mL0?ooo`030;md000007@0
_ooo00@0oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo05L0oooo00L0oooO09a80000M;l0
oooo0?oog`2LB00007Bo0640oooo00<0_g@00000M02oool0103oool01`3ooml0W4P0001d_`3oool0
oooO09a80000M;l02`3oool006P0oooo00<0okmd0018W03Oool00P3oool00`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo05T0oooo00<0gia804RLg`3oool00P3oool01`3ooml0W4Qd0;ooo`3o
ool0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1K0?ooo`030;md000007@0_ooo00@0oooo
00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1F0?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol0H03oool00`2oM000001d0;ooo`040?ooo`030?noM00004P0W=oo0080oooo
00<0omnL04P0001d_ol02P3oool006P0oooo00P0okmd0000B02Lgol0oooo0?oog`2LB00004RL0=oo
o`80oooo00<0oooO09a80000M;l0FP3oool00`3OW4P0B9cO0?ooo`040?ooo`040?oog`2LB00004RL
0=ooo`80oooo00<0oooO09a80000M;l0F`3oool00`2oM000001d0;ooo`030?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0oooO09a80000M;l0E@3oool0103ooml0W4P00018W03Oool20?ooo`030?oo
g`2LB00007Bo0600oooo00<0_g@00000M02oool00`3oool0103ooml0W4P00018W03Oool20?ooo`03
0?oog`2LB00007Bo00X0oooo001X0?ooo`070;md000004P0W=oo0?ooo`3ookl0M000001d_`040?oo
o`030;md000007@0_ooo05X0oooo00<0gia807Boo`3oool00`3oool00`3ookl0M000001d_`040?oo
o`030;md000007@0_ooo05X0oooo00<0_g@00000M02oool00`3oool00`3ookl0M000001d_`040?oo
o`030;md000007@0_ooo05@0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`1O0?oo
o`030;md000007@0_ooo00<0oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`090?oo
o`00EP3oool00`2oM0000000000000070000000304RLg`3oool0oooo00@0oooo00P0_g@000000000
07@0_ooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@00000M02oool0B@3oool00`2oM00000000000
00070000000304RLg`3oool0oooo00@0oooo00<0oooO09a8B02Lgol00`3oool00`3ogi`0B00004RL
g`040?ooo`030;md000007@0_ooo04T0oooo00<0_g@00000000000001`0000000`18W=l0oooo0?oo
o`040?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;oo
o`1D0?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool0G`3oool00`2oM000001d0;oo
o`030?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool02@3oool006@0oooo00<0oono
07@0000000000P0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0gia80000B02Lgol0
F`3oool00`3ogi`0B01d0;ooo`020?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
FP3oool00`2oM000001d0;ooo`030?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol0
E03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo05l0oooo00<0_g@00000M02oool0
0`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00T0oooo001V0?ooo`030?noM000
04P0W=oo00<0oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`1L0?ooo`070;md0018
W=l0oooo0?ooo`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo05X0oooo00<0_g@00000M02o
ool00`3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo05@0oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`1O0?ooo`030;md000007@0_ooo00<0oooo00<0omnL04P00018
W=l0103oool00`3OW4P0001809cOo`090?ooo`00I`3oool00`3ogi`0B7Bo0?ooo`020?ooo`030?oo
_`1d000007Bo00@0oooo00<0_g@00000M02oool0G03oool01`3OW4P0001d0;ooo`3oool0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`1J0?ooo`030;md000007@0_ooo00<0oooo00<0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`1D0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000
M02oool0G`3oool00`2oM000001d0;ooo`030?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000
M02oool02@3oool006L0oooo00<0oooO09a80018W=l00`3oool00`2oM00004RL0=ooo`020?ooo`03
0?oog`2LB00007Bo05d0oooo00<0okmd0000001d_ol00P3oool00`2oM00004RL0=ooo`020?ooo`03
0?oog`2LB00007Bo05/0oooo00<0_g@00000M02oool0103oool00`2oM00004RL0=ooo`020?ooo`03
0?oog`2LB00007Bo05H0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`1P0?ooo`03
0;md000007@0_ooo00@0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0:0?ooo`00
HP3oool00`3ooml0W7BL0=ooo`020?ooo`030?oog`2LB00007Bo00<0oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`1G0?ooo`030?oOW02L_ol0oooo00<0oooo00<0_g@00000001d_ol0
0P3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo05/0oooo00<0_g@00000M02oool0
103oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo05H0oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`1P0?ooo`030;md000007@0_ooo00@0oooo00<0okmd0000B02Lgol0
0P3oool00`3ogi`0B00007Boo`0:0?ooo`00H`3oool01`3ogi`0B4RL0=ooo`3oool0gia80000001d
_ol0103oool01P2oM00004RL0=ooo`3oool0_g@0001d_eT0oooo00P0_g@007Boo`3oool0oooo0=nL
B000000004RL0=ooo`<0oooo00H0_g@00018W03Oool0oooo0;md0000M;mJ0?ooo`050=nLB0000000
00000000M02oool01@3oool01P2oM00004RL0=ooo`3oool0_g@0001d_eP0oooo00H0_g@00018W03O
ool0oooo0;md0000M;mO0?ooo`050=nLB000000000000000M02oool01@3oool01P2oM00004RL0=oo
o`3oool0_g@0001d_`/0oooo001T0?ooo`050?oOW0180000000000000018W=l01P3oool0102oM000
000000000000M;mK0?ooo`050;md00000000000000000000M;l01P3oool0102oM000000000000000
M;mL0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00@0_g@000000000000007BoFP3oool0102oM000
000000000000M;mQ0?ooo`040?oo_`1d0000001d0;ooo`H0oooo00@0_g@000000000000007Bo303o
ool00?l0ooooo`3ooolR0?ooo`00o`3ooooo0?ooob80oooo003o0?ooool0oooo8P3oool00?l0oooo
o`3ooolR0?ooo`00o`3ooooo0?ooob80oooo003o0?ooool0oooo8P3oool00?l0ooooo`3ooolR0?oo
o`00o`3ooooo0?ooob80oooo003o0?ooool0oooo8P3oool00?l0ooooo`3ooolR0?ooo`00o`3ooooo
0?ooob80oooo001K0?ooool00000_`0000070?ooo`00F`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1@3oool005/0oooo0`0000080?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01P3o
ool3000000L0oooo001K0?ooo`030000003oool0oooo0?l0oooo^`3oool00`000000oooo0?ooo`05
0?ooo`00F`3oool00`000000oooo0?ooo`3o0?oook/0oooo00<000000?ooo`3oool01@3oool005/0
oooo00<000000?ooo`3oool0o`3ooom30?ooo`030?l0003oool0oooo07D0oooo00<000000?ooo`3o
ool01@3oool005/0oooo00<000000?ooo`3oool0o`3ooom30?ooo`030<`0o`0c0?l0oooo07D0oooo
00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0o`3ooom20?ooo`80c03o00<0
<`3o0?ooo`3oool0M03oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o
0?oood80oooo00<0c03o03<0o`3<0?l0MP3oool00`000000oooo0?ooo`050?ooo`00F`3oool30000
0?l0oooo@P3oool00`3<0?l0<`3o0<`0o`1d0?ooo`<000001`3oool005/0oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`030<`0o`3oool0c03o07H0oooo00<000000?ooo`3oool01@3oool005/0oooo
00<000000?ooo`3oool0o`3ooom20?ooo`030<`0o`3oool0c03o07H0oooo00<000000?ooo`3oool0
1@3oool005/0oooo00<000000?ooo`3oool0o`3ooom20?ooo`030<`0o`3oool0c03o07H0oooo00<0
00000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0o`3ooom20?ooo`040<`0o`3oool0
o`000<`0ogD0oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`040<`0o`3oool0o`000<`0ogD0oooo00<000000?ooo`3oool01@3oool005/0oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`040<`0o`3oool0oooo0<`0ogD0oooo00<000000?ooo`3oool01@3o
ool005/0oooo0`00003o0?oood80oooo00@0c03o0?ooo`3oool0c03oL`3oool3000000L0oooo000c
0?ooo`040;md00000000000004RLg`@0oooo00H0gia800000018W=l0oooo0?oog`2LB00300000003
0018W03Oool0oooo00<0oooo00H0_g@000000000000000000018W03Oool;0?ooo`030000003oool0
oooo0?l0oooo@P3oool0103<0?l0oooo0?ooo`3<0?me0?ooo`030000003oool0oooo00D0oooo000a
0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`0<0=nLB0000000B9cO0?ooo`3o
gi`0B0000018W03Oool0oooo0?oOW01804P0W=oo0P3oool00`3ooml0W4P004RLg`020?ooo`030?oO
W018B9`0gooo00X0oooo00<000000?ooo`3oool0o`3ooom20?ooo`040<`0o`3oool0oooo0<`0ogD0
oooo00<000000?ooo`3oool01@3oool00340oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B000
07Boo`0<0?ooo`030?noM000B9`0gooo00L0oooo00<0omnL04Qd_`3oool02@3oool00`000000oooo
0?ooo`3o0?oood80oooo00@0c03o0?ooo`3oool0c03oM@3oool00`000000oooo0?ooo`050?ooo`00
<03oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00`0oooo00<0okmd0000B02L
gol01`3oool00`3ookl0M01809cOo`090?ooo`030000003oool0oooo0?l0oooo@P3oool0103<0?l0
oooo0?ooo`3<0?me0?ooo`030000003oool0oooo00D0oooo000`0?ooo`030?oo_`1d000007Bo00@0
oooo00<0_g@00000M02oool02`3oool00`2oM000001809cOo`070?ooo`030?oo_`1d0000M;oo00T0
oooo00<000000?ooo`3oool0o`3ooom10?ooo`050<`0o`0c0?l0oooo0?ooo`3<0?l0M@3oool00`00
0000oooo0?ooo`050?ooo`008`3oool00`2oM0000000000000070000000604RLg`3oool0oooo0?oO
W0180000B9cO103oool00`2oM000001d0;ooo`0:0?ooo`040;md00000000001d0;ooo`L0oooo00<0
okmd0000001d_ol02@3oool00`000000oooo0?ooo`3o0?oood40oooo00D0c03o03<0o`3oool0oooo
0<`0o`1e0?ooo`030000003oool0oooo00D0oooo000`0?ooo`030?oOW0180000B9cO00@0oooo00<0
gia80000B02Lgol01`3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00D0oooo00@0
omnL04P0000007@0_ooo2@3oool400000?l0oooo@03oool01@3<0?l0<`3o0?ooo`3oool0c03o0780
oooo100000070?ooo`00<03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00T0oooo
00<0okmd0000B02Lgol0103oool0103Ogml0oooo0?ooo`2oM0020000000304RLg`3oool0oooo00P0
oooo00<000000?ooo`3oool0o`3ooom10?ooo`050<`0o`0c0?l0oooo0?ooo`3<0?l0M@3oool00`00
0000oooo0?ooo`050?ooo`00<03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00X0
oooo00<0omnL04Qd_`3oool00`3oool00`3o_g@000000000000200000003001d_`3oool0oooo00T0
oooo00<000000?ooo`3oool0o`3ooom10?ooo`050<`0o`3oool0oooo0?ooo`3<0?l0M@3oool00`00
0000oooo0?ooo`050?ooo`00<@3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00/0
oooo00<0oooO09a80018W=l00`3oool01@3ooml0W4P00000000007@0_ooo00`0oooo00<000000?oo
o`3oool0o`3ooom10?ooo`050<`0o`3oool0oooo0?ooo`3<0?l0M@3oool00`000000oooo0?ooo`05
0?ooo`00<@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo00H0oooo00<0oooO09ad
W03Oool00P3oool00`3ooml0W4P0001d_`040?ooo`030?noM000M;l0oooo00d0oooo00<000000?oo
o`3oool0o`3ooom10?ooo`060<`0o`3oool0oooo0?ooo`3<0?l0o`00M03oool00`000000oooo0?oo
o`050?ooo`00<P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00L0omnL04Q8W03Oool0
oooo0=nLB0000000M;oo00@0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`080?oo
o`030000003oool0oooo0?l0oooo@@3oool01P3<0?l0oooo0?ooo`3oool0c03o0?l007@0oooo00<0
00000?ooo`3oool01@3oool003<0oooo00@0_g@000000000000007Bo2P3oool01@3ogi`0B0000000
00000000B9cO00H0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`070?ooo`030000
003oool0oooo0?l0oooo@@3oool01P3<0?l0oooo0?ooo`3oool0c03o0?l007@0oooo00<000000?oo
o`3oool01@3oool005/0oooo0`00003o0?oood40oooo00H0c03o0?ooo`3oool0oooo0<`0o`3o001b
0?ooo`<000001`3oool005/0oooo00<000000?ooo`3oool0o`3ooom10?ooo`060<`0o`3oool0oooo
0?ooo`3<0?l0o`00M03oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o
0?oood40oooo00H0c03o0?ooo`3oool0oooo0<`0o`3o001d0?ooo`030000003oool0oooo00D0oooo
001K0?ooo`030000003oool0oooo0?l0oooo@@3oool01P3<0?l0oooo0?ooo`3oool0c03o0?l007@0
oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0o`3ooom10?ooo`060<`0
o`3oool0oooo0?ooo`0c0?l0c03oM03oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000
oooo0?ooo`3o0?oood00oooo00<0<`3o0<`0o`3oool00P3oool00`0c0?l0c03o0?ooo`1c0?ooo`03
0000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo@03oool00`0c0?l0c03o
0?ooo`020?ooo`0303<0o`3<0?l0oooo07<0oooo00<000000?ooo`3oool01@3oool005/0oooo0`00
003o0?oood00oooo00<0<`3o0<`0o`3oool00P3oool00`0c0?l0c03o0?ooo`1a0?ooo`<000001`3o
ool005/0oooo00<000000?ooo`3oool0o`3ooom00?ooo`0303<0o`3<0?l0oooo00<0oooo00<0c03o
0?ooo`3oool0LP3oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?oo
od00oooo00<0<`3o0<`0o`3oool00`3oool00`3<0?l0oooo0?ooo`1b0?ooo`030000003oool0oooo
00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo@03oool00`0c0?l0c03o0?ooo`030?ooo`03
0<`0o`3oool0oooo0780oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0
o`3ooom00?ooo`0303<0o`3<0?l0oooo00<0oooo00<0c03o0?ooo`3oool0LP3oool00`000000oooo
0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?oood00oooo00<0<`3o0<`0o`3oool00`3o
ool00`3<0?l0oooo0?ooo`1b0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0
oooo0?l0oooo@03oool00`0c0?l0c03o0?ooo`030?ooo`030<`0o`3oool0oooo0780oooo00<00000
0?ooo`3oool01@3oool005/0oooo0`00003o0?oood00oooo00<0<`3o0<`0o`3oool00`3oool00`3<
0?l0oooo0?ooo`1`0?ooo`<000001`3oool005/0oooo00<000000?ooo`3oool0o`3ooom00?ooo`03
03<0o`3<0?l0oooo00<0oooo00<0c03o0?ooo`3oool0LP3oool00`000000oooo0?ooo`050?ooo`00
F`3oool00`000000oooo0?ooo`3o0?oood00oooo00<0<`3o0<`0o`3oool00`3oool00`3<0?l0oooo
0?ooo`1b0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo@03o
ool00`3<0?l0oooo0?ooo`030?ooo`030<`0o`3oool0oooo0780oooo00<000000?ooo`3oool01@3o
ool005/0oooo00<000000?ooo`3oool0o`3ooom00?ooo`030<`0o`3oool0oooo00<0oooo00<0c03o
0?ooo`3oool0LP3oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?oo
od00oooo00<0c03o0?ooo`3oool00`3oool00`3<0?l0oooo0?ooo`1b0?ooo`030000003oool0oooo
00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo@03oool00`3<0?l0oooo0?ooo`030?ooo`03
0<`0o`3o0000oooo0780oooo00<000000?ooo`3oool01@3oool005/0oooo0`00003o0?oood00oooo
00<0c03o0?ooo`3oool00`3oool00`3<0?l0o`000?ooo`1`0?ooo`<000001`3oool003d0oooo00@0
_g@0000000000000B9cO103oool01P3OW4P0000004RLg`3oool0oooO09a800<0000000<004RL0=oo
o`3oool02P3oool00`000000oooo0?ooo`3o0?oood00oooo00<0c03o0?ooo`3oool00`3oool00`3<
0?l0o`000?ooo`1b0?ooo`030000003oool0oooo00D0oooo000k0?ooo`070?oog`2LB00007Bo0?oo
o`3ooml0W4P0001d_`030?ooo`0<0=nLB0000000B9cO0?ooo`3ogi`0B0000018W03Oool0oooo0?oO
W01804P0W=oo2P3oool00`000000oooo0?ooo`3o0?oood00oooo00<0c03o0?ooo`3oool00`3oool0
0`3<0?l0o`000?ooo`1b0?ooo`030000003oool0oooo00D0oooo000k0?ooo`030?noM00004P0W=oo
0080oooo00<0omnL04P0001d_ol0303oool00`3o_g@004RL0=ooo`090?ooo`030000003oool0oooo
0?l0oooo@03oool00`3<0?l0oooo0?ooo`030?ooo`030<`0o`3o0000oooo0780oooo00<000000?oo
o`3oool01@3oool003X0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0<0?oo
o`030?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0o`3ooom00?ooo`030<`0o`3oool0oooo
00<0oooo00<0c03o0?l0003oool0LP3oool00`000000oooo0?ooo`050?ooo`00>P3oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo00/0oooo00<0_g@00000B02Lgol02@3oool00`000000
oooo0?ooo`3o0?oood00oooo00<0c03o0?ooo`3oool00`3oool00`0c0?l0c03o0?ooo`1b0?ooo`03
0000003oool0oooo00D0oooo000]0?ooo`030;md00000000000000L0000000H0B9cO0?ooo`3oool0
omnL04P00018W=l40?ooo`030;md000007@0_ooo00X0oooo00@0_g@00000000007@0_ooo2@3oool0
0`000000oooo0?ooo`3o0?oood00oooo00<0c03o0?ooo`3oool00`3oool00`0c0?l0c03o0?ooo`1b
0?ooo`030000003oool0oooo00D0oooo000j0?ooo`030?oOW0180000B9cO00@0oooo00<0gia80000
B02Lgol01`3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00P0oooo1000003o0?oo
ocl0oooo00<0c03o0?ooo`3oool00`3oool00`0c0?l0c03o0?ooo`1_0?ooo`@000001`3oool003X0
oooo00<0omnL04P00018W=l0103oool00`3OW4P0001809cOo`090?ooo`030?noM00004P0W=oo00/0
oooo00<000000?ooo`3oool0o`3ooom00?ooo`030<`0o`3oool0oooo00<0oooo00<0<`3o0<`0o`3o
ool0LP3oool00`000000oooo0?ooo`050?ooo`00>P3oool00`3ookl0M000001d_`040?ooo`030;md
000007@0_ooo00X0oooo00<0omnL04Qd_`3oool02P3oool00`000000oooo0?ooo`3o0?oood00oooo
00<0c03o0?ooo`3oool00`3oool00`0c0?l0c03o0?ooo`1b0?ooo`030000003oool0oooo00D0oooo
000k0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000M;l02`3oool00`3ooml0W4P004RL
g`0:0?ooo`030000003oool0oooo0?l0oooo@03oool00`3<0?l0oooo0?ooo`030?ooo`0303<0o`3<
0?l0oooo0780oooo00<000000?ooo`3oool01@3oool003/0oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`060?ooo`030?oog`2LM9`0gooo0080oooo00<0oooO09a80000M;l02P3oool0
0`000000oooo0?ooo`3o0?oood00oooo00<0c03o0?ooo`3oool00`3oool00`0c0?l0c03o0?ooo`1b
0?ooo`030000003oool0oooo00D0oooo000l0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo203o
ool01`3ogi`0B4RL0=ooo`3oool0gia80000001d_ol02P3oool00`000000oooo0?ooo`3o0?oood00
oooo00<0c03o0?ooo`3oool00`3oool00`0c0?l0c03o0?ooo`1b0?ooo`030000003oool0oooo00D0
oooo000m0?ooo`040;md000000000000001d_`X0oooo00D0omnL04P000000000000004RLg`0;0?oo
o`030000003oool0oooo0?l0oooo@03oool00`3<0?l0oooo0?ooo`030?ooo`0303<0o`3<0?l0oooo
0780oooo00<000000?ooo`3oool01@3oool005/0oooo0`00003o0?oood00oooo00<0c03o0?ooo`3o
ool00`3oool00`0c0?l0c03o0?ooo`1`0?ooo`<000001`3oool005/0oooo00<000000?ooo`3oool0
o`3ooom00?ooo`030<`0o`3oool0oooo00@0oooo00<0c03o0?ooo`3oool0L@3oool00`000000oooo
0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?oood00oooo00<0c03o0?ooo`3oool0103o
ool00`3<0?l0oooo0?ooo`1a0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0
oooo0?l0oooo@03oool00`3<0?l0oooo0?ooo`040?ooo`030<`0o`3oool0oooo0740oooo00<00000
0?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0o`3ooom00?ooo`030<`0o`3oool0oooo
00@0oooo00<0c03o0?ooo`3oool0L@3oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000
oooo0?ooo`3o0?ooocl0oooo00<0<`3o0<`0o`3oool01@3oool00`3<0?l0oooo0?ooo`1a0?ooo`03
0000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo?`3oool00`0c0?l0c03o
0?ooo`050?ooo`030<`0o`3oool0oooo0740oooo00<000000?ooo`3oool01@3oool005/0oooo0`00
003o0?ooocl0oooo00<0<`3o0<`0o`3oool01@3oool00`3<0?l0oooo0?ooo`1_0?ooo`<000001`3o
ool005/0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`0303<0o`3<0?l0oooo00D0oooo00<0c03o
0?ooo`3oool0L@3oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?oo
ocl0oooo00<0c03o0?ooo`3oool01@3oool00`3<0?l0oooo0?ooo`1a0?ooo`030000003oool0oooo
00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo?`3oool00`3<0?l0oooo0?ooo`050?ooo`03
0<`0o`3oool0oooo0740oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0
o`3ooolo0?ooo`030<`0o`3oool0oooo00D0oooo00<0c03o0?ooo`3oool0L@3oool00`000000oooo
0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?ooocl0oooo00<0c03o0?ooo`3oool01@3o
ool00`3<0?l0oooo0?ooo`1a0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0
oooo0?l0oooo?`3oool00`3<0?l0oooo0?ooo`050?ooo`030<`0o`3oool0oooo0740oooo00<00000
0?ooo`3oool01@3oool005/0oooo0`00003o0?ooocl0oooo00<0c03o0?ooo`3oool01@3oool00`3<
0?l0oooo0?ooo`1_0?ooo`<000001`3oool005/0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`03
0<`0o`3oool0oooo00D0oooo00<0c03o0?ooo`3oool0L@3oool00`000000oooo0?ooo`050?ooo`00
F`3oool00`000000oooo0?ooo`3o0?ooocl0oooo00<0c03o0?ooo`3oool01@3oool00`3<0?l0oooo
0?ooo`1a0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo?`3o
ool00`3<0?l0oooo0?ooo`050?ooo`030<`0o`3oool0oooo0740oooo00<000000?ooo`3oool01@3o
ool005/0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`030<`0o`3oool0oooo00D0oooo00<0c03o
0?l0003oool0L@3oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?oo
ocl0oooo00<0c03o0?ooo`3oool01@3oool00`0c0?l0c03o0?ooo`1a0?ooo`030000003oool0oooo
00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo?`3oool00`3<0?l0oooo0?ooo`050?ooo`03
03<0o`3<0?l0oooo0740oooo00<000000?ooo`3oool01@3oool005/0oooo0`00003o0?ooocl0oooo
00<0c03o0?ooo`3oool01@3oool00`0c0?l0c03o0?ooo`1_0?ooo`<000001`3oool003<0oooo00@0
_g@0000000000000B9cO103oool01@3OW4P0000004RLg`3oool0gia800L0000000@0M;oo0?ooo`3o
ool0_g@00`0000000`00B9`0gooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo?`3oool00`3<
0?l0oooo0?ooo`050?ooo`0303<0o`3<0?l0oooo0740oooo00<000000?ooo`3oool01@3oool00340
oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool0
0`3OW4P000000000000400000005001d_`3oool0oooO09a80018W=l00P3oool00`3ogi`0B4RL0=oo
o`0:0?ooo`030000003oool0oooo0?l0oooo?`3oool00`3<0?l0oooo0?ooo`050?ooo`0303<0o`3<
0?l0oooo0740oooo00<000000?ooo`3oool01@3oool00340oooo00<0okmd0000B02Lgol00P3oool0
0`3ogi`0B00007Boo`080?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8M02oool01P3oool0
0`3ogi`0B7Bo0?ooo`090?ooo`030000003oool0oooo0?l0oooo?`3oool00`3<0?l0oooo0?ooo`05
0?ooo`0303<0o`3<0?l0oooo0740oooo00<000000?ooo`3oool01@3oool00300oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3ooml0W4P0001d_`090?ooo`030=nLB018W=l0oooo00X0oooo00<0oono
07@0B02Lgol02@3oool00`000000oooo0?ooo`3o0?ooocl0oooo00<0c03o0?ooo`3oool01@3oool0
0`0c0?l0c03o0?ooo`1a0?ooo`030000003oool0oooo00D0oooo000`0?ooo`030?oo_`1d000007Bo
00@0oooo00<0_g@00000M02oool02@3oool00`3OW4P0M;oo0?ooo`090?ooo`030?oo_`1d0000M;oo
00T0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`030<`0o`3oool0oooo00D0oooo00<0<`3o0<`0
o`3oool0L@3oool00`000000oooo0?ooo`050?ooo`008`3oool00`2oM00000000000000700000006
04RLg`3oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;ooo`090?ooo`030?oog`2LB4P0
W=oo00T0oooo00<0okmd0000001d_ol02@3oool00`000000oooo0?ooo`3o0?ooocl0oooo00<0c03o
0?ooo`3oool01@3oool00`0c0?l0c03o0?ooo`1a0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02P3oool00`3ogi`0B01d0;ooo`070?oo
o`040?oOW0180000001d0;ooo`T0oooo1000003o0?oooch0oooo00<0c03o0?ooo`3oool01@3oool0
0`0c0?l0c03o0?ooo`1^0?ooo`@000001`3oool00300oooo00<0omnL04P00018W=l0103oool00`3O
W4P0001809cOo`0;0?ooo`030;md0018W=l0oooo0080oooo00@0gmoO0?ooo`3oool0_g@00P000000
0`18W=l0oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo?`3oool00`3<0?l0oooo0?ooo`05
0?ooo`0303<0o`3<0?l0oooo0740oooo00<000000?ooo`3oool01@3oool00300oooo00<0oono07@0
0000M;l0103oool00`2oM000001d0;ooo`0;0?ooo`030=nLB00007@0_ooo0080oooo00<0okmd0000
000000000P0000000`00M;l0oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo?`3oool00`3<
0?l0oooo0?ooo`050?ooo`0303<0o`3<0?l0oooo0740oooo00<000000?ooo`3oool01@3oool00340
oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`0<0?ooo`030?noM0000000M;oo0080
oooo00D0oooO09a800000000001d0;ooo`0<0?ooo`030000003oool0oooo0?l0oooo?`3oool00`3<
0?l0oooo0?ooo`060?ooo`030<`0o`3oool0oooo0700oooo00<000000?ooo`3oool01@3oool00340
oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`060?ooo`030?oOW02L_ol0oooo00<0
oooo00<0_g@00000001d_ol00`3oool00`3o_g@007Bo0?ooo`0=0?ooo`030000003oool0oooo0?l0
oooo?P3oool00`0c0?l0c03o0?ooo`070?ooo`030<`0o`3oool0oooo0700oooo00<000000?ooo`3o
ool01@3oool00380oooo00H0_g@00018W03Oool0oooo0;md0000M;l80?ooo`080;md001d_ol0oooo
0?ooo`3OW4P000000018W03Oool30?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0
203oool00`000000oooo0?ooo`3o0?oooch0oooo00<0<`3o0<`0o`3oool01`3oool00`3<0?l0oooo
0?ooo`1`0?ooo`030000003oool0oooo00D0oooo000c0?ooo`040;md000000000000001d_`X0oooo
00D0_g@00000000000000000001d_`060?ooo`030?noM000000000000080000000<0M;oo0?ooo`3o
ool01`3oool00`000000oooo0?ooo`3o0?oooch0oooo00<0<`3o0<`0o`3oool01`3oool00`3<0?l0
oooo0?ooo`1`0?ooo`030000003oool0oooo00D0oooo001K0?ooo`<00000o`3oooln0?ooo`0303<0
o`3<0?l0oooo00L0oooo00<0c03o0?ooo`3oool0KP3oool3000000L0oooo001K0?ooo`030000003o
ool0oooo0?l0oooo?P3oool00`0c0?l0c03o0?ooo`070?ooo`030<`0o`3oool0oooo0700oooo00<0
00000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0o`3oooln0?ooo`030<`0o`3oool0
oooo00L0oooo00<0c03o0?ooo`3oool0L03oool00`000000oooo0?ooo`050?ooo`00F`3oool00`00
0000oooo0?ooo`3o0?oooch0oooo00<0c03o0?ooo`3oool01`3oool00`3<0?l0oooo0?ooo`1`0?oo
o`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo?P3oool00`3<0?l0
oooo0?ooo`070?ooo`030<`0o`3oool0oooo0700oooo00<000000?ooo`3oool01@3oool005/0oooo
00<000000?ooo`3oool0o`3oooln0?ooo`030<`0o`3oool0oooo00L0oooo00<0c03o0?ooo`3oool0
L03oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?oooch0oooo00<0
c03o0?ooo`3oool01`3oool00`3<0?l0oooo0?ooo`1`0?ooo`030000003oool0oooo00D0oooo001K
0?ooo`<00000o`3oooln0?ooo`030<`0o`3oool0oooo00L0oooo00<0c03o0?ooo`3oool0KP3oool3
000000L0oooo001K0?ooo`030000003oool0oooo0?l0oooo?P3oool00`3<0?l0oooo0?ooo`070?oo
o`030<`0o`3oool0oooo0700oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3o
ool0o`3oooln0?ooo`030<`0o`3oool0oooo00L0oooo00<0c03o0?ooo`3oool0L03oool00`000000
oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?oooch0oooo00<0c03o0?ooo`3oool0
1`3oool00`3<0?l0oooo0?ooo`1`0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003o
ool0oooo0?l0oooo?P3oool00`3<0?l0oooo0?ooo`070?ooo`030<`0o`3oool0oooo0700oooo00<0
00000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0o`3oooln0?ooo`030<`0o`3oool0
oooo00L0oooo00<0c03o0?ooo`3oool0L03oool00`000000oooo0?ooo`050?ooo`003P3oool00`3o
_g@0M;oo0?ooo`060?ooo`030;mdM02oool0oooo0440oooo00<000000?ooo`3oool0o`3oooln0?oo
o`030<`0o`3oool0oooo00L0oooo00<0c03o0?ooo`3oool0L03oool00`000000oooo0?ooo`050?oo
o`003P3oool00`3o_g@0001d0;ooo`040?ooo`040?oog`2LB000001d0;oood80oooo0`00003o0?oo
och0oooo00<0c03o0?ooo`3oool01`3oool00`0c0?l0c03o0?ooo`1^0?ooo`<000001`3oool000h0
oooo00@0okmd000000000000B9cO0P3oool01@3ookl0M01809cOo`3OW9`0_ooo0480oooo00<00000
0?ooo`3oool0o`3oooln0?ooo`030<`0o`3oool0oooo00L0oooo00<0<`3o0<`0o`3oool0L03oool0
0`000000oooo0?ooo`050?ooo`003P3oool0203o_i`0W=oo0=nLB0000000001807AdB00007@0_ooo
A@3oool00`000000oooo0?ooo`3o0?oooch0oooo00<0c03o0?ooo`3oool01`3oool00`0c0?l0c03o
0?ooo`1`0?ooo`030000003oool0oooo00D0oooo000A0?ooo`040?oo_`1d00000000001d_dH0oooo
00<000000?ooo`3oool0o`3oooln0?ooo`030<`0o`3oool0oooo00L0oooo00<0<`3o0<`0o`3oool0
L03oool00`000000oooo0?ooo`050?ooo`003P3oool02`3o_i`0W=oo0?noM00004P0W=oo0=nLB000
0000001809cOo`3OW9`0_ooo0480oooo00<000000?ooo`3oool0o`3oooln0?ooo`030<`0o`3oool0
oooo00L0oooo00<0<`3o0<`0o`3oool0L03oool00`000000oooo0?ooo`050?ooo`003P3oool00`3o
_g@00000001d_`030?ooo`050?oo_`1d000000000000M02oool0@P3oool00`000000oooo0?ooo`3o
0?ooocd0oooo00<0o`000<`0o`3oool0203oool00`0c0?l0c03o0?ooo`1`0?ooo`030000003oool0
oooo00D0oooo000>0?ooo`030?noM018W=l0oooo00D0oooo00<0gia80000M02oool0@P3oool00`00
0000oooo0?ooo`3o0?ooocd0oooo00<0o`000<`0o`3oool0203oool00`0c0?l0c03o0?ooo`1`0?oo
o`030000003oool0oooo00D0oooo000>0?ooo`030?noW02Lgol0oooo00H0oooo00<0_gAd0;ooo`3o
ool0@@3oool300000?l0oooo?@3oool00`3o0000c03o0?ooo`080?ooo`0303<0o`3<0?l0oooo06h0
oooo0`0000070?ooo`00?@3oool0102oM000000000000018W=l40?ooo`050=nLB0000000B9cO0?oo
o`3OW4P01`0000000`1d_ol0oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo?@3oool00`0c
0?l0c03o0?ooo`080?ooo`0303<0o`3<0?l0oooo0700oooo00<000000?ooo`3oool01@3oool003/0
oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00<0oooo00<0gia800000018W=l00P3oool0
0`3OW4P000000000000400000003001d_`3oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolm
0?ooo`0303<0o`3<0?l0oooo00P0oooo00<0<`3o0<`0o`3oool0L03oool00`000000oooo0?ooo`05
0?ooo`00303oool00`3OW4P0001809cOo`070?ooo`030?oo_`1d07@0_ooo0280oooo00<0okmd0000
B02Lgol00P3oool00`3ogi`0B00007Boo`080?ooo`030=nLB018W=l0oooo0080oooo00<0oooO09a8
M02oool0203oool00`000000oooo0?ooo`3o0?ooocd0oooo00<0<`3o0<`0o`3oool02@3oool00`3<
0?l0oooo0?ooo`1_0?ooo`030000003oool0oooo00D0oooo000;0?ooo`030;md0018W=l0oooo00L0
oooo00@0omnL04P0000007@0_ooo8@3oool0103ooml0W4P00018W03Oool20?ooo`030?oog`2LB000
07Bo00T0oooo00<0gia804RLg`3oool0303oool00`000000oooo0?ooo`3o0?ooocd0oooo00<0<`3o
0<`0o`3oool02@3oool00`3<0?l0oooo0?ooo`1_0?ooo`030000003oool0oooo00D0oooo000:0?oo
o`030?oOW01804P0W=oo00L0oooo00D0gia80018W02oW4P0001d0;ooo`0Q0?ooo`030?oo_`1d0000
07Bo00@0oooo00<0_g@00000M02oool02@3oool00`3OW4P0M;oo0?ooo`0;0?ooo`030000003oool0
oooo0?l0oooo?@3oool00`0c0?l0c03o0?ooo`090?ooo`030<`0o`3oool0oooo06l0oooo00<00000
0?ooo`3oool01@3oool000X0oooo00<0okmd0000001d_ol01@3oool01`3ooml0W4P004RLg`3oool0
gia80000M02oool0503oool00`2oM0000000000000070000000604RLg`3oool0oooo0?oOW0180000
B9cO103oool00`2oM000001d0;ooo`090?ooo`030?oog`2LB4P0W=oo00/0oooo00<000000?ooo`3o
ool0o`3ooolm0?ooo`0303<0o`3<0?l0oooo00T0oooo00<0c03o0?ooo`3oool0K`3oool00`000000
oooo0?ooo`050?ooo`002P3oool0103ogi`0B0000000B02Lgol20?ooo`040?oog`2LB000000007Bo
o`80oooo00<0gia80000M02oool08@3oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
00X0oooo00<0omnL04P0M02oool02P3oool400000?l0oooo?03oool00`0c0?l0c03o0?ooo`090?oo
o`030<`0o`3oool0oooo06`0oooo100000070?ooo`002P3oool00`3ooml0W4P00000000400000003
0000M02oool0oooo0080oooo00<0gia80000M02oool08@3oool00`3ogi`0B00004RLg`040?ooo`03
0=nLB00004P0W=oo00/0oooo00<0_g@004RLg`3oool02@3oool00`000000oooo0?ooo`3o0?ooocd0
oooo00<0<`3o0<`0o`3oool02@3oool00`3<0?l0oooo0?ooo`1_0?ooo`030000003oool0oooo00D0
oooo000;0?ooo`060?oog`2LB00000000000000004P0W=oo103oool0103ooml0W4P00000M02ooolQ
0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02`3oool00`3OW4P0001d0;ooo`09
0?ooo`030000003oool0oooo0?l0oooo?@3oool00`0c0?l0c03o0?ooo`090?ooo`030<`0o`3oool0
oooo06l0oooo00<000000?ooo`3oool01@3oool001D0oooo00<0gia80000M02oool08`3oool00`2o
M00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00`0oooo00<0okmd0000001d_ol02@3oool00`00
0000oooo0?ooo`3o0?ooocd0oooo00<0c03o0?ooo`3oool02@3oool00`3<0?l0oooo0?ooo`1_0?oo
o`030000003oool0oooo00D0oooo000k0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol01P3oool00`3ogi`0W;oo0?ooo`030?ooo`030;md00000000M;oo00T0oooo00<000000?ooo`3o
ool0o`3ooolm0?ooo`030<`0o`3oool0oooo00T0oooo00<0c03o0?ooo`3oool0K`3oool00`000000
oooo0?ooo`050?ooo`00?03oool01P2oM00004RL0=ooo`3oool0_g@0001d_`P0oooo00P0_g@007Bo
o`3oool0oooo0=nLB000000004RL0=ooo`T0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`030<`0
o`3oool0oooo00T0oooo00<0c03o0?ooo`3oool0K`3oool00`000000oooo0?ooo`050?ooo`002P3o
ool00`3OW4P000000000000?0000000307Boo`3oool0oooo01h0oooo00@0_g@000000000000007Bo
2P3oool01@2oM000000000000000000007Bo00/0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`03
0<`0o`3oool0oooo00T0oooo00<0c03o0?ooo`3oool0K`3oool00`000000oooo0?ooo`050?ooo`00
2P3oool00`3OW9`0_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo03d0oooo0`00003o0?ooocd0oooo
00<0c03o0?ooo`3oool02@3oool00`3<0?l0oooo0?ooo`1]0?ooo`<000001`3oool000X0oooo00<0
gibL0;ooo`3oool03P3oool00`3o_g@0M;oo0?ooo`0m0?ooo`030000003oool0oooo0?l0oooo?@3o
ool00`3<0?l0oooo0?ooo`090?ooo`030<`0o`3oool0oooo06l0oooo00<000000?ooo`3oool01@3o
ool000X0oooo00<0gibL0;ooo`3oool03P3oool00`3o_g@0M;oo0?ooo`0m0?ooo`030000003oool0
oooo0?l0oooo?@3oool00`3<0?l0oooo0?ooo`090?ooo`030<`0o`3oool0oooo06l0oooo00<00000
0?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`030<`0o`3oool0oooo
00T0oooo00<0c03o0?ooo`3oool0K`3oool00`000000oooo0?ooo`050?ooo`002P3oool00`3o_i`0
W=oo0?ooo`1>0?ooo`030000003oool0oooo0?l0oooo?03oool00`3o0000c03o0?ooo`0:0?ooo`03
0<`0o`3oool0oooo06l0oooo00<000000?ooo`3oool01@3oool000X0oooo00<0okmd07Boo`3oool0
2P3oool00`3OW9`0_ooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo?03oool00`3o0000c03o
0?ooo`0:0?ooo`030<`0o`3oool0oooo06l0oooo00<000000?ooo`3oool01@3oool000X0oooo00<0
okmd0018W03Oool02P3oool00`2oM7@0_ooo0?ooo`110?ooo`030000003oool0oooo0?l0oooo?03o
ool00`3o0000c03o0?ooo`0:0?ooo`030<`0o`3oool0oooo06l0oooo00<000000?ooo`3oool01@3o
ool000X0oooo00<0okmd0000000000002P0000000`0007@0_ooo0?ooo`110?ooo`<00000o`3oooll
0?ooo`030?l0003<0?l0oooo00X0oooo00<0<`3o0<`0o`3oool0K@3oool3000000L0oooo000;0?oo
o`040;md00000000001809cOo`P0oooo00<0_gAd0;ooo`3oool0@@3oool00`000000oooo0?ooo`3o
0?oooc`0oooo00<0o`000<`0o`3oool02P3oool00`0c0?l0c03o0?ooo`1_0?ooo`030000003oool0
oooo00D0oooo000<0?ooo`040=nLB0000000000007Boo`L0oooo00<0gibL0;ooo`3oool0@@3oool0
0`000000oooo0?ooo`3o0?oooc`0oooo00<0o`000<`0o`3oool02P3oool00`0c0?l0c03o0?ooo`1_
0?ooo`030000003oool0oooo00D0oooo000=0?ooo`040?noM00000000000001d_dX0oooo00<00000
0?ooo`3oool0o`3oooll0?ooo`030?l0003<0?l0oooo00X0oooo00<0<`3o0<`0o`3oool0K`3oool0
0`000000oooo0?ooo`050?ooo`003P3oool01@3ogi`0B00000000000B9`0gooo04P0oooo00<00000
0?ooo`3oool0o`3oooll0?ooo`030?l0003<0?l0oooo00/0oooo00<0c03o0?ooo`3oool0KP3oool0
0`000000oooo0?ooo`050?ooo`003`3oool01@3ookl0M0000000000004P0W=oo04L0oooo00<00000
0?ooo`3oool0o`3oooll0?ooo`0303<0o`3<0?l0oooo00/0oooo00<0c03o0?ooo`3oool0KP3oool0
0`000000oooo0?ooo`050?ooo`00403oool01@3ooml0W4P0000000000000M;oo04H0oooo00<00000
0?ooo`3oool0o`3oooll0?ooo`0303<0o`3<0?l0oooo00/0oooo00<0c03o0?ooo`3oool0KP3oool0
0`000000oooo0?ooo`050?ooo`002P3oool00`3o_i`0W=oo0?ooo`050?ooo`040;md000000000000
001d_dD0oooo0`00003o0?oooc`0oooo00<0<`3o0<`0o`3oool02`3oool00`3<0?l0oooo0?ooo`1/
0?ooo`<000001`3oool000X0oooo00<0okmd07Boo`3oool01P3oool01@3OW4P0000000000000B9`0
gooo04<0oooo00<000000?ooo`3oool0o`3oooll0?ooo`0303<0o`3<0?l0oooo00/0oooo00<0c03o
0?ooo`3oool0KP3oool00`000000oooo0?ooo`050?ooo`002P3oool00`3o_g@000000000000:0000
00030000B02Lgol0oooo0440oooo00<000000?ooo`3oool0o`3oooll0?ooo`0303<0o`3<0?l0oooo
00/0oooo00<0c03o0?ooo`3oool0KP3oool00`000000oooo0?ooo`050?ooo`002P3oool00`3o_g@0
M;oo0?ooo`1>0?ooo`030000003oool0oooo0?l0oooo?03oool00`0c0?l0c03o0?ooo`0;0?ooo`03
0<`0o`3oool0oooo06h0oooo00<000000?ooo`3oool01@3oool000X0oooo00<0oknL09cOo`3oool0
CP3oool00`000000oooo0?ooo`3o0?oooc`0oooo00<0<`3o0<`0o`3oool02`3oool00`3<0?l0oooo
0?ooo`1^0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo?03o
ool00`3<0?l0oooo0?ooo`0;0?ooo`030<`0o`3oool0oooo06h0oooo00<000000?ooo`3oool01@3o
ool005/0oooo00<000000?ooo`3oool0o`3oooll0?ooo`030<`0o`3oool0oooo00/0oooo00<0c03o
0?ooo`3oool0KP3oool00`000000oooo0?ooo`050?ooo`00F`3oool300000?l0oooo?03oool00`3<
0?l0oooo0?ooo`0;0?ooo`030<`0o`3oool0oooo06`0oooo0`0000070?ooo`002P3oool00`3OW9`0
_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo01D0oooo00@0_g@0000000000000B9cO103oool00`3O
W4P0000004RLg`030?ooo`030?noM000000000000080000000D007Bo0?ooo`3oool0oooo0;md0003
000000030018W03Oool0oooo00X0oooo00<000000?ooo`3oool0o`3oooll0?ooo`030<`0o`3oool0
oooo00/0oooo00<0c03o0?ooo`3oool0KP3oool00`000000oooo0?ooo`050?ooo`002P3oool00`3O
W9`0_ooo0?ooo`0>0?ooo`030?noM01d_ol0oooo01<0oooo00L0oooO09a80000M;l0oooo0?oog`2L
B00007Bo00<0oooo00<0gia800000018W=l01@3oool00`2oM000001d0;ooo`030?ooo`030?oog`2L
B000B9cO0080oooo00<0omnL04Q8W03Oool02P3oool00`000000oooo0?ooo`3o0?oooc`0oooo00<0
c03o0?ooo`3oool02`3oool00`3<0?l0oooo0?ooo`1^0?ooo`030000003oool0oooo00D0oooo000:
0?ooo`030=nLW02oool0oooo00h0oooo00<0okmd07Boo`3oool04`3oool00`3o_g@0001809cOo`02
0?ooo`030?oOW0180000M;oo00X0oooo00<0_g@00000M02oool02@3oool00`3ogi`0B7Bo0?ooo`09
0?ooo`030000003oool0oooo0?l0oooo?03oool00`3<0?l0oooo0?ooo`0;0?ooo`030<`0o`3oool0
oooo06h0oooo00<000000?ooo`3oool01@3oool000X0oooo00<0gia80000000000003`0000000`1d
_ol0oooo0?ooo`0A0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l02P3oool0
0`2oM000001d0;ooo`090?ooo`030?oo_`1d04P0W=oo00T0oooo00<000000?ooo`3oool0o`3oooll
0?ooo`030<`0o`3oool0oooo00/0oooo00<0c03o0?ooo`3oool0KP3oool00`000000oooo0?ooo`05
0?ooo`00<03oool00`3ookl0M000001d_`040?ooo`030;md000007@0_ooo00T0oooo00<0_g@00000
M02oool02@3oool00`3ookl0M00007Boo`090?ooo`030000003oool0oooo0?l0oooo?03oool00`3<
0?l0oooo0?ooo`0;0?ooo`030<`0o`3oool0oooo06h0oooo00<000000?ooo`3oool01@3oool002<0
oooo00<0_g@00000000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00004RLg`@0oooo00<0_g@0
0000M02oool02@3oool00`2oM000001d0;ooo`090?ooo`030?noM0000000M;oo00T0oooo00<00000
0?ooo`3oool0o`3ooolk0?ooo`030?l0003<0?l0oooo00`0oooo00<0c03o03<0o`3oool0KP3oool0
0`000000oooo0?ooo`050?ooo`00<03oool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo
00T0oooo00<0_g@00000M02oool0203oool0103ogi`0B0000000M02oool90?ooo`@00000o`3ooolj
0?ooo`030?l0003<0?l0oooo00`0oooo00<0c03o03<0o`3oool0J`3oool4000000L0oooo000`0?oo
o`030?oOW0180000B9cO00@0oooo00<0gia80000B02Lgol02@3oool00`2oM000001d0;ooo`040?oo
o`040=oOg`3oool0oooo0;md0080000000<0B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?oooc/0oooo00<0o`000<`0o`3oool0303oool00`3<0?l0<`3o0?ooo`1^0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`2o
M000001d0;ooo`040?ooo`030?noM000000000000080000000<007Bo0?ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?oooc/0oooo00<0o`000<`0o`3oool0303oool00`3<0?l0<`3o0?ooo`1^0?oo
o`030000003oool0oooo00D0oooo000a0?ooo`030;md0000B9`0gooo0080oooo00<0oooO09a80000
M;l02P3oool00`2oM000001d0;ooo`040?ooo`050?oog`2LB00000000000M02oool0303oool00`00
0000oooo0?ooo`3o0?oooc/0oooo00<0o`000<`0o`3oool0303oool00`3o0000c03o0?ooo`1^0?oo
o`030000003oool0oooo00D0oooo000a0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d
_ol02P3oool00`2oM000001d0;ooo`050?ooo`030?noM000M;l0oooo00d0oooo00<000000?ooo`3o
ool0o`3ooolk0?ooo`030?l0003<0?l0oooo00`0oooo00<0o`000<`0o`3oool0KP3oool00`000000
oooo0?ooo`050?ooo`00<P3oool01P2oM00004RL0=ooo`3oool0_g@0001d_`T0oooo00D0gia80000
00000000001d0;ooo`050?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool0203oool0
0`000000oooo0?ooo`3o0?oooc/0oooo00<0o`000<`0o`3oool0303oool00`3o0000c03o0?ooo`1^
0?ooo`030000003oool0oooo00D0oooo000c0?ooo`040;md000000000000001d_`/0oooo00@0oono
07@0000007@0_ooo1P3oool00`3o_g@00000000000020000000307Boo`3oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3ooolk0?ooo`030?l0003<0?l0oooo00`0oooo00<0o`000<`0o`3oool0KP3o
ool00`000000oooo0?ooo`050?ooo`00F`3oool300000?l0oooo>`3oool00`3<0?l0<`3o0?ooo`0=
0?ooo`030<`0o`3oool0oooo06/0oooo0`0000070?ooo`00F`3oool00`000000oooo0?ooo`3o0?oo
oc/0oooo00<0c03o03<0o`3oool03@3oool00`3<0?l0oooo0?ooo`1]0?ooo`030000003oool0oooo
00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo>`3oool00`3<0?l0oooo0?ooo`0=0?ooo`03
0<`0o`3oool0oooo06d0oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0
o`3ooolk0?ooo`030<`0o`3oool0oooo00d0oooo00<0c03o0?ooo`3oool0K@3oool00`000000oooo
0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3o0?oooc/0oooo00<0c03o0?ooo`3oool03@3o
ool00`3<0?l0oooo0?ooo`1]0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0
oooo0?l0oooo>`3oool00`3<0?l0oooo0?ooo`0=0?ooo`030<`0o`3oool0oooo06d0oooo00<00000
0?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`030<`0o`3oool0oooo
00d0oooo00<0c03o0?ooo`3oool0K@3oool00`000000oooo0?ooo`050?ooo`00F`3oool300000?l0
oooo>`3oool00`3<0?l0oooo0?ooo`0=0?ooo`030<`0o`3oool0oooo06/0oooo0`0000070?ooo`00
F`3oool00`000000oooo0?ooo`3o0?oooc/0oooo00<0c03o0?ooo`3oool03@3oool00`3<0?l0<`3o
0?ooo`1]0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0?l0oooo>`3o
ool00`3<0?l0oooo0?ooo`0=0?ooo`030<`0o`0c0?l0oooo06d0oooo00<000000?ooo`3oool01@3o
ool005/0oooo00<000000?ooo`3oool0k`3oool40<`0odL0oooo00<0c03o0?ooo`3oool03@3oool0
0`3<0?l0<`3o0?ooo`1]0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo
0>h0oooo0P3<0?l20?ooo`80c03oAP3oool00`3<0?l0oooo0?ooo`0=0?ooo`030<`0o`0c0?l0oooo
06d0oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0k@3oool00`0c0?l0
c03o0?ooo`030?ooo`030<`0o`0c0?l0oooo04@0oooo00<0c03o0?ooo`3oool03@3oool00`3<0?l0
<`3o0?ooo`1]0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0>`0oooo
00<0<`3o0<`0o`3oool01@3oool00`3<0?l0oooo0?ooo`130?ooo`030<`0o`3oool0oooo00d0oooo
00<0c03o03<0o`3oool0K@3oool00`000000oooo0?ooo`050?ooo`00F`3oool300000>/0oooo00<0
<`3o0<`0o`3oool01`3oool00`3<0?l0oooo0?ooo`120?ooo`030<`0o`3oool0oooo00d0oooo00<0
c03o03<0o`3oool0J`3oool3000000L0oooo001K0?ooo`030000003oool0oooo0>/0oooo00<0c03o
0?l0003oool01`3oool00`3<0?l0o`000?ooo`120?ooo`030<`0o`3oool0oooo00d0oooo00<0c03o
03<0o`3oool0K@3oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3[0?oo
o`030<`0o`3oool0oooo00P0oooo00<0c03o0?ooo`3oool0@03oool00`3<0?l0<`3o0?ooo`0>0?oo
o`030<`0o`0c0?l0oooo06d0oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3o
ool0jP3oool00`3<0?l0o`000?ooo`090?ooo`030<`0o`3o0000oooo0400oooo00<0c03o03<0o`3o
ool03P3oool00`3<0?l0<`3o0?ooo`1]0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000
003oool0oooo0>T0oooo00<0c03o03<0o`3oool02`3oool00`3<0?l0oooo0?ooo`0o0?ooo`030<`0
o`0c0?l0oooo00h0oooo00<0o`000<`0o`3oool0K@3oool00`000000oooo0?ooo`050?ooo`00F`3o
ool00`000000oooo0?ooo`3Y0?ooo`030<`0o`3o0000oooo00/0oooo00<0c03o0?l0003oool0?`3o
ool00`3<0?l0<`3o0?ooo`0>0?ooo`030?l0003<0?l0oooo06d0oooo00<000000?ooo`3oool01@3o
ool005/0oooo00<000000?ooo`3oool0j@3oool00`3<0?l0o`000?ooo`0<0?ooo`030<`0o`3oool0
oooo03h0oooo00<0c03o03<0o`3oool03P3oool00`3o0000c03o0?ooo`1]0?ooo`030000003oool0
oooo00D0oooo001K0?ooo`<00000j03oool00`3<0?l0<`3o0?ooo`0=0?ooo`030<`0o`3oool0oooo
03h0oooo00<0c03o03<0o`3oool03P3oool00`3o0000c03o0?ooo`1[0?ooo`<000001`3oool003d0
oooo00@0_g@0000000000000B9cO103oool00`3OW4P0000004RLg`030?ooo`030?noM00000000000
0080000000<007Bo0?ooo`3oool0203oool00`000000oooo0?ooo`3X0?ooo`030<`0o`3o0000oooo
00d0oooo00<0c03o03<0o`3oool0?P3oool00`3<0?l0<`3o0?ooo`0>0?ooo`030?l0003<0?l0oooo
06d0oooo00<000000?ooo`3oool01@3oool003/0oooo00L0oooO09a80000M;l0oooo0?oog`2LB000
07Bo00<0oooo00<0gia800000018W=l01@3oool00`2oM000001d0;ooo`0;0?ooo`030000003oool0
oooo0>P0oooo00<0c03o0?ooo`3oool03P3oool00`3<0?l0oooo0?ooo`0m0?ooo`030<`0o`3oool0
oooo00l0oooo00<0c03o0?ooo`3oool0K03oool00`000000oooo0?ooo`050?ooo`00>`3oool00`3o
_g@0001809cOo`020?ooo`030?oOW0180000M;oo00X0oooo00<0_g@00000M02oool02`3oool00`00
0000oooo0?ooo`3W0?ooo`0303<0o`3<0?l0oooo00l0oooo00<0c03o03<0o`3oool0?@3oool00`3<
0?l0oooo0?ooo`0?0?ooo`030<`0o`3oool0oooo06`0oooo00<000000?ooo`3oool01@3oool003X0
oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`0:0?ooo`030;md000007@0_ooo
00/0oooo00<000000?ooo`3oool0i`3oool00`3<0?l0o`000?ooo`0?0?ooo`030<`0o`0c0?l0oooo
03d0oooo00<0c03o0?ooo`3oool03`3oool00`3<0?l0oooo0?ooo`1/0?ooo`030000003oool0oooo
00D0oooo000j0?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`2oM000
001d0;ooo`0;0?ooo`030000003oool0oooo0>L0oooo00<0c03o0?ooo`3oool0403oool00`3<0?l0
oooo0?ooo`0l0?ooo`030<`0o`3oool0oooo00l0oooo00<0c03o0?ooo`3oool0K03oool00`000000
oooo0?ooo`050?ooo`00;@3oool00`2oM0000000000000070000000604RLg`3oool0oooo0?oOW018
0000B9cO103oool00`2oM000001d0;ooo`090?ooo`030;md000007@0_ooo00/0oooo1000003U0?oo
o`0303<0o`3<0?l0oooo0140oooo00<0c03o03<0o`3oool0?03oool00`3<0?l0oooo0?ooo`0?0?oo
o`030<`0o`0c0?l0oooo06T0oooo100000070?ooo`00>P3oool00`3ogi`0B00004RLg`040?ooo`03
0=nLB00004P0W=oo00T0oooo00<0_g@00000M02oool02`3oool00`000000oooo0?ooo`3V0?ooo`03
03<0o`3<0?l0oooo0180oooo00<0c03o0?ooo`3oool0>`3oool00`3<0?l0oooo0?ooo`0?0?ooo`03
0<`0o`0c0?l0oooo06`0oooo00<000000?ooo`3oool01@3oool003X0oooo00<0omnL04P00018W=l0
103oool00`3OW4P0001809cOo`090?ooo`030;md000007@0_ooo00/0oooo00<000000?ooo`3oool0
iP3oool00`3<0?l0oooo0?ooo`0B0?ooo`030<`0o`3oool0oooo03/0oooo00<0c03o0?ooo`3oool0
3`3oool00`3<0?l0<`3o0?ooo`1/0?ooo`030000003oool0oooo00D0oooo000j0?ooo`030?oo_`1d
000007Bo00@0oooo00<0_g@00000M02oool02@3oool00`2oM000001d0;ooo`0;0?ooo`030000003o
ool0oooo0>D0oooo00<0<`3o0<`0o`3oool04`3oool00`3<0?l0oooo0?ooo`0k0?ooo`030<`0o`3o
ool0oooo00l0oooo00<0c03o03<0o`3oool0K03oool00`000000oooo0?ooo`050?ooo`00>`3oool0
0`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0_g@00000M02oool02`3oool0
0`000000oooo0?ooo`3U0?ooo`0303<0o`3<0?l0oooo01@0oooo00<0c03o0?ooo`3oool0>P3oool0
0`3<0?l0oooo0?ooo`0?0?ooo`030<`0o`0c0?l0oooo06`0oooo00<000000?ooo`3oool01@3oool0
03/0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`0:0?ooo`030;md000007@0_ooo
00/0oooo00<000000?ooo`3oool0i@3oool00`3<0?l0oooo0?ooo`0D0?ooo`030<`0o`3oool0oooo
03X0oooo00<0c03o0?ooo`3oool03`3oool00`3<0?l0<`3o0?ooo`1/0?ooo`030000003oool0oooo
00D0oooo000l0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2@3oool01@3OW4P0000000000000
07@0_ooo00/0oooo00<000000?ooo`3oool0i03oool00`0c0?l0c03o0?ooo`0E0?ooo`030<`0o`3o
ool0oooo03X0oooo00<0c03o0?ooo`3oool03`3oool00`3o0000c03o0?ooo`1/0?ooo`030000003o
ool0oooo00D0oooo000m0?ooo`040;md000000000000001d_`/0oooo00@0oono07@0000007@0_ooo
2`3oool300000>@0oooo00<0<`3o0<`0o`3oool05@3oool00`3o0000c03o0?ooo`0i0?ooo`030<`0
o`0c0?l0oooo0100oooo00<0o`000<`0o`3oool0JP3oool3000000L0oooo001K0?ooo`030000003o
ool0oooo0>@0oooo00<0c03o0?ooo`3oool05P3oool00`3<0?l0oooo0?ooo`0h0?ooo`030<`0o`0c
0?l0oooo0100oooo00<0o`000<`0o`3oool0K03oool00`000000oooo0?ooo`050?ooo`00F`3oool0
0`000000oooo0?ooo`3S0?ooo`0303<0o`3<0?l0oooo01L0oooo00<0c03o0?ooo`3oool0>03oool0
0`3<0?l0<`3o0?ooo`0@0?ooo`030?l0003<0?l0oooo06`0oooo00<000000?ooo`3oool01@3oool0
05/0oooo00<000000?ooo`3oool0h`3oool00`0c0?l0c03o0?ooo`0G0?ooo`030?l0003<0?l0oooo
03P0oooo00<0c03o03<0o`3oool0403oool00`3o0000c03o0?ooo`1/0?ooo`030000003oool0oooo
00D0oooo001K0?ooo`030000003oool0oooo0><0oooo00<0c03o0?ooo`3oool0603oool00`3<0?l0
oooo0?ooo`0g0?ooo`030<`0o`0c0?l0oooo0100oooo00<0o`000<`0o`3oool0K03oool00`000000
oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3R0?ooo`0303<0o`3<0?l0oooo01T0oooo
00<0<`3o0<`0o`3oool0=`3oool00`3<0?l0<`3o0?ooo`0A0?ooo`030<`0o`3oool0oooo06/0oooo
00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0hP3oool00`0c0?l0c03o0?oo
o`0I0?ooo`030?l0003<0?l0oooo03L0oooo00<0c03o0?ooo`3oool04@3oool00`3<0?l0oooo0?oo
o`1[0?ooo`030000003oool0oooo00D0oooo001K0?ooo`<00000hP3oool00`3<0?l0oooo0?ooo`0J
0?ooo`030<`0o`3oool0oooo03H0oooo00<0c03o0?ooo`3oool04@3oool00`3<0?l0oooo0?ooo`1Y
0?ooo`<000001`3oool005/0oooo00<000000?ooo`3oool0h@3oool00`0c0?l0c03o0?ooo`0K0?oo
o`0303<0o`3<0?l0oooo03H0oooo00<0c03o0?ooo`3oool04@3oool00`3<0?l0oooo0?ooo`1[0?oo
o`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0>40oooo00<0<`3o0<`0o`3o
ool06`3oool00`3o0000c03o0?ooo`0f0?ooo`030<`0o`3oool0oooo0140oooo00<0<`3o0<`0o`3o
ool0J`3oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3Q0?ooo`030<`0
o`3oool0oooo01`0oooo00<0c03o0?ooo`3oool0=@3oool00`3<0?l0oooo0?ooo`0A0?ooo`0303<0
o`3<0?l0oooo06/0oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0h03o
ool00`0c0?l0c03o0?ooo`0M0?ooo`030?l0003<0?l0oooo03D0oooo00<0c03o0?ooo`3oool04@3o
ool00`3o0000c03o0?ooo`1[0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0
oooo0>00oooo00<0<`3o0<`0o`3oool07@3oool00`3o0000c03o0?ooo`0e0?ooo`030<`0o`3oool0
oooo0140oooo00<0o`000<`0o`3oool0J`3oool00`000000oooo0?ooo`050?ooo`00F`3oool00`00
0000oooo0?ooo`3P0?ooo`030<`0o`3oool0oooo01h0oooo00<0c03o0?ooo`3oool0=03oool00`3<
0?l0oooo0?ooo`0A0?ooo`030?l0003<0?l0oooo06/0oooo00<000000?ooo`3oool01@3oool005/0
oooo0`00003O0?ooo`0303<0o`3<0?l0oooo01l0oooo00<0o`000<`0o`3oool0=03oool00`3<0?l0
oooo0?ooo`0A0?ooo`030?l0003<0?l0oooo06T0oooo0`0000070?ooo`00F`3oool00`000000oooo
0?ooo`3O0?ooo`0303<0o`3<0?l0oooo01l0oooo00<0o`000<`0o`3oool0=03oool00`3<0?l0oooo
0?ooo`0A0?ooo`030?l0003<0?l0oooo06/0oooo00<000000?ooo`3oool01@3oool005/0oooo00<0
00000?ooo`3oool0gP3oool00`0c0?l0c03o0?ooo`0Q0?ooo`030<`0o`3oool0oooo0380oooo00<0
c03o03<0o`3oool04P3oool00`3o0000c03o0?ooo`1[0?ooo`030000003oool0oooo00D0oooo001K
0?ooo`030000003oool0oooo0=h0oooo00<0<`3o0<`0o`3oool08@3oool00`3o0000c03o0?ooo`0b
0?ooo`030<`0o`0c0?l0oooo01<0oooo00<0c03o0?ooo`3oool0JP3oool00`000000oooo0?ooo`05
0?ooo`00F`3oool00`000000oooo0?ooo`3N0?ooo`0303<0o`3<0?l0oooo0280oooo00<0c03o0?oo
o`3oool0<@3oool00`3<0?l0<`3o0?ooo`0C0?ooo`030<`0o`3oool0oooo06X0oooo00<000000?oo
o`3oool01@3oool005/0oooo00<000000?ooo`3oool0g@3oool00`0c0?l0c03o0?ooo`0S0?ooo`03
0<`0o`3oool0oooo0340oooo00<0c03o03<0o`3oool04`3oool00`3<0?l0oooo0?ooo`1Z0?ooo`03
0000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0=d0oooo00<0<`3o0<`0o`3oool0
8`3oool00`0c0?l0c03o0?ooo`0a0?ooo`030<`0o`0c0?l0oooo01<0oooo00<0<`3o0<`0o`3oool0
JP3oool00`000000oooo0?ooo`050?ooo`00F`3oool300000=d0oooo00<0<`3o0<`0o`3oool0903o
ool00`3<0?l0oooo0?ooo`0`0?ooo`030<`0o`3oool0oooo01<0oooo00<0<`3o0<`0o`3oool0J03o
ool3000000L0oooo001K0?ooo`030000003oool0oooo0=`0oooo00<0<`3o0<`0o`3oool09@3oool0
0`0c0?l0c03o0?ooo`0`0?ooo`030<`0o`3oool0oooo01<0oooo00<0<`3o0<`0o`3oool0JP3oool0
0`000000oooo0?ooo`050?ooo`00<`3oool0102oM000000000000018W=l40?ooo`030=nLB0000000
B9cO00@0oooo00@0_g@0000000000000B9cO103oool01P2oM000000000000000000004RL0=ooo`/0
oooo00<000000?ooo`3oool0g03oool00`0c0?l0c03o0?ooo`0U0?ooo`0303<0o`3<0?l0oooo0300
oooo00<0c03o0?ooo`3oool04`3oool00`0c0?l0c03o0?ooo`1Z0?ooo`030000003oool0oooo00D0
oooo000a0?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB0000000B9cO
0080oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo0080oooo00<0oooO09a80018W=l00P3o
ool00`3ogi`0B4RL0=ooo`0:0?ooo`030000003oool0oooo0=`0oooo00<0<`3o0<`0o`3oool09P3o
ool00`3<0?l0oooo0?ooo`0_0?ooo`030<`0o`3oool0oooo01<0oooo00<0<`3o0<`0o`3oool0JP3o
ool00`000000oooo0?ooo`050?ooo`00<@3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000
M;oo00L0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`070?ooo`030?oOW018M;l0
oooo00T0oooo00<000000?ooo`3oool0f`3oool00`0c0?l0c03o0?ooo`0W0?ooo`0303<0o`3<0?l0
oooo02l0oooo00<0c03o0?ooo`3oool04`3oool00`3o0000c03o0?ooo`1Z0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oooO09a80000M;l01P3oool0
103ooml0W4P00018W03Oool20?ooo`030?oog`2LB00007Bo00L0oooo00<0oono07@0B02Lgol02@3o
ool00`000000oooo0?ooo`3K0?ooo`0303<0o`3<0?l0oooo02L0oooo00<0<`3o0<`0o`3oool0;`3o
ool00`3<0?l0oooo0?ooo`0C0?ooo`030?l0003<0?l0oooo06X0oooo00<000000?ooo`3oool01@3o
ool00300oooo00<0oono07@00000M;l0103oool00`2oM000001d0;ooo`050?ooo`030?oo_`1d0000
07Bo00@0oooo00<0_g@00000M02oool01P3oool00`3ookl0M00007Boo`090?ooo`030000003oool0
oooo0=/0oooo00<0c03o0?ooo`3oool09`3oool00`0c0?l0c03o0?ooo`0^0?ooo`030?l0003<0?l0
oooo01@0oooo00<0o`000<`0o`3oool0JP3oool00`000000oooo0?ooo`050?ooo`008`3oool00`2o
M0000000000000070000000604RLg`3oool0oooo0?oOW0180000B9cO103oool00`2oM000001d0;oo
o`050?ooo`030?oOW0180000B9cO00@0oooo00<0_g@00000M02oool01P3oool00`3o_g@0000007Bo
o`090?ooo`@00000f@3oool00`0c0?l0c03o0?ooo`0Y0?ooo`0303<0o`3<0?l0oooo02d0oooo00<0
c03o03<0o`3oool0503oool00`3o0000c03o0?ooo`1W0?ooo`@000001`3oool00300oooo00<0omnL
04P00018W=l0103oool00`3OW4P0001809cOo`050?ooo`030?oOW0180000B9cO00@0oooo00<0gia8
0000B02Lgol01@3oool0103ogi`0B0000000M02oool90?ooo`030000003oool0oooo0=X0oooo00<0
c03o0?ooo`3oool0:@3oool00`0c0?l0c03o0?ooo`0]0?ooo`030<`0o`0c0?l0oooo01D0oooo00<0
c03o0?ooo`3oool0J@3oool00`000000oooo0?ooo`050?ooo`00<03oool00`3ogi`0B00004RLg`04
0?ooo`030=nLB00004P0W=oo00D0oooo00<0omnL04P00018W=l0103oool01@3OW4P0001809cOo`3o
ool0gmoO0080oooo00@0_g@0000000000000B9cO2P3oool00`000000oooo0?ooo`3J0?ooo`030<`0
o`3oool0oooo02T0oooo00<0<`3o0<`0o`3oool0;@3oool00`3<0?l0oooo0?ooo`0E0?ooo`0303<0
o`3<0?l0oooo06T0oooo00<000000?ooo`3oool01@3oool00300oooo00<0oono07@00000M;l0103o
ool00`2oM000001d0;ooo`050?ooo`030?oo_`1d000007Bo00@0oooo00D0_g@00000M02oool0oooo
0?noM00400000003001d_`3oool0oooo00T0oooo00<000000?ooo`3oool0f@3oool00`3<0?l0oooo
0?ooo`0[0?ooo`0303<0o`3<0?l0oooo02`0oooo00<0c03o0?ooo`3oool05@3oool00`0c0?l0c03o
0?ooo`1Y0?ooo`030000003oool0oooo00D0oooo000a0?ooo`030;md0000B9`0gooo0080oooo00<0
oooO09a80000M;l01`3oool00`2oM00004RL0=ooo`020?ooo`030?oog`2LB00007Bo0080oooo00D0
oooO09a800000000001d0;ooo`0<0?ooo`030000003oool0oooo0=T0oooo00<0c03o0?ooo`3oool0
:`3oool00`0c0?l0c03o0?ooo`0/0?ooo`030<`0o`3oool0oooo01D0oooo00<0<`3o0<`0o`3oool0
J@3oool00`000000oooo0?ooo`050?ooo`00<@3oool00`3o_g@0001809cOo`020?ooo`030?oOW018
0000M;oo00L0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000
M;l0oooo00d0oooo00<000000?ooo`3oool0f03oool00`3<0?l0oooo0?ooo`0]0?ooo`030<`0o`3o
ool0oooo02/0oooo00<0c03o0?ooo`3oool05@3oool00`0c0?l0c03o0?ooo`1Y0?ooo`030000003o
ool0oooo00D0oooo000b0?ooo`060;md0000B9`0gooo0?ooo`2oM00007Bo2@3oool01P2oM00004RL
0=ooo`3oool0_g@0001d_`@0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`080?oo
o`030000003oool0oooo0=P0oooo00<0c03o0?ooo`3oool0;@3oool00`0c0?l0c03o0?ooo`0Z0?oo
o`0303<0o`3<0?l0oooo01H0oooo00<0<`3o0<`0o`3oool0J@3oool00`000000oooo0?ooo`050?oo
o`00<`3oool0102oM000000000000000M;l;0?ooo`040;md000000000000001d_`H0oooo00<0okmd
0000000000000P0000000`1d_ol0oooo0?ooo`070?ooo`<00000e`3oool00`0c0?l0c03o0?ooo`0_
0?ooo`030<`0o`3oool0oooo02T0oooo00<0<`3o0<`0o`3oool05P3oool00`3o0000c03o0?ooo`1W
0?ooo`<000001`3oool005/0oooo00<000000?ooo`3oool0e`3oool00`3<0?l0oooo0?ooo`0_0?oo
o`0303<0o`3<0?l0oooo02T0oooo00<0<`3o0<`0o`3oool05`3oool00`3<0?l0oooo0?ooo`1X0?oo
o`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0=H0oooo00<0<`3o0<`0o`3o
ool0<@3oool00`3<0?l0oooo0?ooo`0X0?ooo`030<`0o`3oool0oooo01L0oooo00<0c03o0?ooo`3o
ool0J03oool00`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3F0?ooo`030<`0
o`3oool0oooo0340oooo00<0c03o0?ooo`3oool0:03oool00`3<0?l0oooo0?ooo`0G0?ooo`030<`0
o`3oool0oooo06P0oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0e@3o
ool00`0c0?l0c03o0?ooo`0c0?ooo`030<`0o`3oool0oooo02L0oooo00<0c03o0?ooo`3oool05`3o
ool00`0c0?l0c03o0?ooo`1X0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0
oooo0=D0oooo00<0c03o0?ooo`3oool0<`3oool00`3<0?l0<`3o0?ooo`0V0?ooo`0303<0o`3<0?l0
oooo01P0oooo00<0<`3o0<`0o`3oool0J03oool00`000000oooo0?ooo`050?ooo`00F`3oool00`00
0000oooo0?ooo`3D0?ooo`0303<0o`3<0?l0oooo03D0oooo00<0c03o0?ooo`3oool09@3oool00`0c
0?l0c03o0?ooo`0I0?ooo`030<`0o`3oool0oooo06L0oooo00<000000?ooo`3oool01@3oool005/0
oooo0`00003D0?ooo`030<`0o`3oool0oooo03D0oooo00<0c03o03<0o`3oool09@3oool00`0c0?l0
c03o0?ooo`0I0?ooo`030<`0o`3oool0oooo06D0oooo0`0000070?ooo`00F`3oool00`000000oooo
0?ooo`3C0?ooo`0303<0o`3<0?l0oooo03L0oooo00<0c03o0?ooo`3oool0903oool00`0c0?l0c03o
0?ooo`0I0?ooo`030<`0o`3oool0oooo06L0oooo00<000000?ooo`3oool01@3oool005/0oooo00<0
00000?ooo`3oool0d`3oool00`3<0?l0oooo0?ooo`0h0?ooo`030<`0o`3oool0oooo02<0oooo00<0
c03o0?ooo`3oool06@3oool00`3<0?l0oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo001K
0?ooo`030000003oool0oooo0=80oooo00<0<`3o0<`0o`3oool0>@3oool00`3<0?l0oooo0?ooo`0R
0?ooo`0303<0o`3<0?l0oooo01/0oooo00<0c03o0?ooo`3oool0IP3oool00`000000oooo0?ooo`05
0?ooo`00F`3oool00`000000oooo0?ooo`3A0?ooo`0303<0o`3<0?l0oooo03/0oooo00<0c03o0?oo
o`3oool08@3oool00`0c0?l0c03o0?ooo`0K0?ooo`030<`0o`3oool0oooo06H0oooo00<000000?oo
o`3oool01@3oool005/0oooo00<000000?ooo`3oool0d@3oool00`3<0?l0oooo0?ooo`0l0?ooo`03
0<`0o`3oool0oooo0200oooo00<0<`3o0<`0o`3oool06`3oool00`3<0?l0oooo0?ooo`1V0?ooo`03
0000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0=00oooo00<0c03o0?ooo`3oool0
?@3oool00`3o0000c03o0?ooo`0P0?ooo`030<`0o`3oool0oooo01/0oooo00<0c03o0?ooo`3oool0
IP3oool00`000000oooo0?ooo`050?ooo`00F`3oool300000<l0oooo00<0<`3o0<`0o`3oool0?`3o
ool00`0c0?l0c03o0?ooo`0N0?ooo`0303<0o`3<0?l0oooo01`0oooo00<0o`000<`0o`3oool0I03o
ool3000000L0oooo001K0?ooo`030000003oool0oooo0<l0oooo00<0c03o0?ooo`3oool0@03oool0
0`0c0?l0c03o0?ooo`0M0?ooo`030<`0o`3o0000oooo01d0oooo00<0c03o0?ooo`3oool0I@3oool0
0`000000oooo0?ooo`050?ooo`00F`3oool00`000000oooo0?ooo`3>0?ooo`030<`0o`3oool0oooo
0480oooo00<0c03o0?l0003oool0703oool00`3<0?l0oooo0?ooo`0M0?ooo`030<`0o`3oool0oooo
06D0oooo00<000000?ooo`3oool01@3oool005/0oooo00<000000?ooo`3oool0c@3oool00`3<0?l0
oooo0?ooo`140?ooo`030<`0o`3o0000oooo01/0oooo00<0c03o0?ooo`3oool07@3oool00`0c0?l0
c03o0?ooo`1U0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0</0oooo
0P3<0?m80?ooo`030<`0o`3o0000oooo01T0oooo00<0c03o0?l0003oool07P3oool00`3o0000c03o
0?ooo`1U0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0<X0oooo00<0
c03o03<0o`3oool0B@3oool20<`0oaT0oooo00<0c03o0?ooo`3oool07`3oool00`3<0?l0oooo0?oo
o`1T0?ooo`030000003oool0oooo00D0oooo001K0?ooo`030000003oool0oooo0<T0oooo00<0c03o
0?l0003oool0B`3oool00`0c0?l0c03o0?ooo`0F0?ooo`030<`0o`3o0000oooo0200oooo00<0<`3o
0<`0o`3oool0I03oool00`000000oooo0?ooo`050?ooo`00F`3oool300000<L0oooo0P3<0?l00`3o
0000oooo0?ooo`1=0?ooo`030<`0o`0c0?l0oooo01@0oooo00<0c03o0?ooo`3oool0803oool00`3o
0000c03o0?ooo`1R0?ooo`<000001`3oool004`0oooo00@0_g@0000000000000B9cO2`3oool00`00
0000oooo0?ooo`360?ooo`030<`0o`0c0?l0oooo0540oooo00<0c03o03<0o`3oool04P3oool00`3<
0?l0o`000?ooo`0R0?ooo`030<`0o`3oool0oooo06<0oooo00<000000?ooo`3oool01@3oool004X0
oooo00L0oooO09a80000M;l0oooo0?oog`2LB00007Bo00X0oooo00<000000?ooo`3oool0``3oool0
0`3o0000c03o0<`0o`1E0?ooo`<0c03o403oool20<`0obD0oooo00<0c03o0?ooo`3oool0HP3oool0
0`000000oooo0?ooo`050?ooo`00BP3oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo
00T0oooo00<000000?ooo`3oool0`@3oool00`3o0000c03o0<`0o`1J0?ooo`80c03o00<0<`3o0?oo
o`3oool02`3oool00`3<0?l0oooo0?ooo`0U0?ooo`030<`0o`3oool0oooo0640oooo00<000000?oo
o`3oool01@3oool004T0oooo00@0oooO09a80000B9`0gooo0P3oool00`3ooml0W4P0001d_`090?oo
o`030000003oool0oooo0;`0oooo1P3<0?mN0?ooo`D0c03o00<0o`000?ooo`3oool00`3oool30<`0
obT0oooo00<0c03o0?ooo`3oool0H03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`3ookl0
M000001d_`040?ooo`030;md000007@0_ooo00P0oooo00<000000?ooo`3oool0^03oool0103o0000
c03o0<`0o`3<0?l303<0ofH0oooo1`3<0?l/0?ooo`030<`0o`3o0000oooo05l0oooo00<000000?oo
o`3oool01@3oool004T0oooo00<0omnL04P00018W=l0103oool00`2oM000001d0;ooo`080?ooo`03
0000003oool0oooo0:l0oooo00<0<`3o0<`0o`3<0?l01`3<0?nP0?ooo`<0c03o00<0<`3o0?ooo`3o
ool0F`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`3ogi`0B00004RLg`040?ooo`030=nL
B00004P0W=oo00P0oooo100000070?ooojP0c03o[03ooomD0<`0o`L0oooo100000070?ooo`00B@3o
ool00`3ogi`0B00004RLg`040?ooo`030=nLB00004P0W=oo00P0oooo00<000000?ooo`3oool0o`3o
oonk0?ooo`030000003oool0oooo00D0oooo00190?ooo`030?oo_`1d000007Bo00@0oooo00<0_g@0
0000M02oool0203oool00`000000oooo0?ooo`3o0?oook/0oooo00<000000?ooo`3oool01@3oool0
04X0oooo00<0_g@00018W03Oool00P3oool00`3ooml0W4P0001d_`090?ooo`030000003oool0oooo
0?l0oooo^`3oool00`000000oooo0?ooo`050?ooo`00BP3oool00`3o_g@0001809cOo`020?ooo`03
0?oOW0180000M;oo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool004/0oooo00H0_g@00018W03Oool0
oooo0;md0000M;l:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool004`0
oooo00@0_g@000000000000007Bo2`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo001K0?ooool00000_`0000070?ooo`00o`3ooooo0?ooob80oooo003o0?ooool0oooo8P3o
ool00?l0ooooo`3ooolR0?ooo`00o`3ooooo0?ooob80oooo003o0?ooool0oooo8P3oool00001\
\>"],
  ImageRangeCache->{{{0, 543.063}, {335.25, 0}} -> {-39.6392, -0.463131, \
0.0944507, 0.00143399}}]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 717}},
CellGrouping->Manual,
WindowSize->{1272, 683},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 217, 4, 35, "Input"],

Cell[CellGroupData[{
Cell[1996, 59, 113, 2, 35, "Input"],
Cell[2112, 63, 178, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[2315, 70, 1662, 36, 560, "Input"],
Cell[3980, 108, 219, 4, 25, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4248, 118, 169, 4, 32, "Input"],
Cell[4420, 124, 503, 7, 91, "Input"],
Cell[4926, 133, 201, 4, 90, "Input"],
Cell[5130, 139, 136, 3, 35, "Input"],

Cell[CellGroupData[{
Cell[5291, 146, 784, 15, 110, "Input"],
Cell[6078, 163, 128258, 4085, 234, 63378, 3280, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[134385, 4254, 212, 4, 32, "Input"],

Cell[CellGroupData[{
Cell[134622, 4262, 381, 8, 70, "Input"],
Cell[135006, 4272, 77, 1, 42, "Output"]
}, Open  ]],
Cell[135098, 4276, 335, 5, 50, "Input"],
Cell[135436, 4283, 200, 4, 90, "Input"],
Cell[135639, 4289, 60, 1, 30, "Input"],
Cell[135702, 4292, 89, 2, 35, "Input"],

Cell[CellGroupData[{
Cell[135816, 4298, 1746, 34, 190, "Input"],
Cell[137565, 4334, 266334, 7775, 598, 117534, 5934, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[403914, 12112, 89, 2, 35, "Input"],

Cell[CellGroupData[{
Cell[404028, 12118, 1098, 20, 150, "Input"],
Cell[405129, 12140, 116746, 3982, 301, 60874, 3288, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[521912, 16127, 784, 15, 110, "Input"],
Cell[522699, 16144, 131812, 3807, 334, 55189, 2857, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[654526, 19954, 216, 5, 61, "Input"],
Cell[654745, 19961, 305, 6, 61, "Input"],
Cell[655053, 19969, 142, 3, 30, "Input"],
Cell[655198, 19974, 141, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[655364, 19981, 124, 2, 30, "Input"],
Cell[655491, 19985, 128955, 2853, 376, 32733, 1661, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[784461, 22841, 101, 2, 35, "Input"],
Cell[784565, 22845, 311, 5, 61, "Input"],
Cell[784879, 22852, 56, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[784960, 22857, 268, 4, 30, "Input"],
Cell[785231, 22863, 97641, 2829, 345, 38671, 2097, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

